(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    406647,       8526]
NotebookOptionsPosition[    248279,       5294]
NotebookOutlinePosition[    392727,       8252]
CellTagsIndexPosition[    392684,       8249]
WindowTitle->10. Discrete\:2010Time Systems as Difference Equations | \
Signals, Systems, and Signal Processing
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Discrete-Time Systems as Difference Equations", "SectionDoubleDigit",
 PageBreakAbove->False,
 CellChangeTimes->{
  3.652728456208679*^9, 3.652728527108994*^9, {3.915549540576313*^9, 
   3.9155495438024945`*^9}},
 CounterAssignments->{{"Section", 9}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellID->1066132550,ExpressionUUID->"f9a6b797-267e-4aca-9fe4-bf8242dc7e65"],

Cell["\<\
Discrete-time systems are mathematical algorithms that operate on numerical \
data or sampled versions of analog signals. This section begins with examples \
of three common discrete-time linear shift-invariant (LSI) systems and some \
practical applications. Also, a method of obtaining the output of any of \
these systems using a simple recursive numerical calculation is presented.\
\>", "Text",
 CellChangeTimes->{{3.805061447352362*^9, 3.805061453522876*^9}, {
  3.805065419703594*^9, 3.805065452474812*^9}, {3.805065493247415*^9, 
  3.805065504201138*^9}, {3.8915999576150775`*^9, 3.8915999608333745`*^9}, {
  3.891600076319535*^9, 3.89160010941839*^9}, {3.891600147112447*^9, 
  3.89160019621408*^9}},
 CellID->2033700929,ExpressionUUID->"6521c5b6-1d38-4e21-a75d-b3e9f3c20ae8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time-Domain Representation of Discrete-Time LSI Systems", "Subsection",
 CellChangeTimes->{
  3.6127916653612843`*^9, {3.652487583199093*^9, 3.652487651195413*^9}, {
   3.695078687993275*^9, 3.695078700597995*^9}, {3.695079178235733*^9, 
   3.695079182572505*^9}, {3.777849802993335*^9, 3.777849822161013*^9}, {
   3.830422885200701*^9, 3.830422901586381*^9}, {3.830423356282282*^9, 
   3.830423362636698*^9}, {3.831115440663398*^9, 3.8311154411275053`*^9}, {
   3.9185613478052406`*^9, 3.9185613479725533`*^9}},
 CellID->1061788051,ExpressionUUID->"0e3035d2-db0d-492b-b661-3442fb133d1f"],

Cell["\<\
An important class of LSI systems is characterized by a linear constant \
coefficient difference equation of the form\
\>", "Text",
 CellChangeTimes->{{3.695078718927877*^9, 3.6950787422341275`*^9}, {
   3.6950787973017745`*^9, 3.695078832744747*^9}, {3.830423397433021*^9, 
   3.830423397877488*^9}, {3.830872871721557*^9, 3.830872878904696*^9}, 
   3.830874004908664*^9, 3.9162371048101177`*^9},
 CellID->2030150234,ExpressionUUID->"d2e15949-2c38-4923-9c36-a43878a2b37c"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], 
        RowBox[{"y", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["a", "N"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "N"}], "]"}]}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", 
         RowBox[{"0", " "}]], 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", "M"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "M"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "cdd2b4f4-a8f0-431f-939b-ca00a48fdce3"]
}], "Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.8032442684758096`*^9, 3.803244272282296*^9}, {
   3.8032445939179897`*^9, 3.8032445993992777`*^9}, {3.830872901082903*^9, 
   3.830872926954898*^9}, {3.831115455096583*^9, 3.831115455096662*^9}},
 CellID->1514799302,ExpressionUUID->"a86f0369-db5d-4488-a393-50bf014c1ab1"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "4fb89869-6f47-4996-837b-3d68514696c4"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "f36d65a4-feff-42b3-8785-7a41ec5d5e06"],
 " are the output and input of the system, respectively. "
}], "Text",
 CellChangeTimes->{{3.6950790824835463`*^9, 3.695079163509427*^9}, {
  3.7782674416218414`*^9, 3.778267450107893*^9}, {3.803244277308256*^9, 
  3.8032442774458666`*^9}, {3.844643674758023*^9, 3.844643688667263*^9}, {
  3.844643724404935*^9, 3.84464372792663*^9}},
 CellID->813233529,ExpressionUUID->"3e27be8e-7740-406d-8efd-fd16cf635cbd"],

Cell[TextData[{
 "The difference equation is also known as a recursive difference equation \
and systems characterized by such equations are known as recursive systems. \
Equations of this type can be solved analytically in a manner analogous to \
that for differential equations, giving an explicit solution for the output \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "78061bc7-dc0a-49d4-855b-058e1d2e8698"],
 ", but they can also be solved numerically by recursion for any value ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "382bdfb3-8672-4560-bd42-bb93b8a995e0"],
 " if the ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],ExpressionUUID->
  "2d41980f-9779-4cab-85fe-24bd3cf754ae"],
 " preceding values ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"n", "-", "1"}], "]"}], TraditionalForm]],ExpressionUUID->
  "93064cb8-f21c-4173-92dd-c78272e50223"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"n", "-", "2"}], "]"}], TraditionalForm]],ExpressionUUID->
  "80932334-d6b3-4b9f-a3d1-c9c2a7305e55"],
 ", ..., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"n", "-", "N"}], "]"}], TraditionalForm]],ExpressionUUID->
  "cbca794d-1be1-4acd-b101-8e32ec85c9c4"],
 " are known. "
}], "Text",
 CellChangeTimes->{{3.6950790824835463`*^9, 3.695079163509427*^9}, {
  3.7782674416218414`*^9, 3.778267450107893*^9}, {3.803244277308256*^9, 
  3.8032442774458666`*^9}, {3.844643674758023*^9, 3.844643688667263*^9}, {
  3.844643724404935*^9, 3.844643775251841*^9}, {3.8916002457695904`*^9, 
  3.891600281048063*^9}},
 CellID->1429992395,ExpressionUUID->"6387577b-b899-4d8f-8cd6-bc9c94ed1d82"],

Cell["\<\
Another important class of systems modeled by difference equations is \
independent of past outputs\
\>", "Text",
 CellChangeTimes->{{3.399248907140625*^9, 3.399248989203125*^9}, {
   3.778267403790647*^9, 3.778267410229891*^9}, {3.77826818899835*^9, 
   3.7782682501888237`*^9}, {3.803211294300024*^9, 3.803211323986737*^9}, {
   3.830872957696368*^9, 3.830872957776073*^9}, 3.9162371106395836`*^9},
 CellID->1392689188,ExpressionUUID->"ee2ed6f5-7c78-412a-8d8b-7bfd61f57f30"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", "M"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "M"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "efcb6509-e24b-4d38-8b8f-8f7edc98c8ae"]
}], "Text",
 CellChangeTimes->{{3.3992488741875*^9, 3.39924887571875*^9}, 
   3.6127916020532837`*^9, {3.8032445208156033`*^9, 3.803244527253626*^9}, {
   3.8308729621154118`*^9, 3.830872973403154*^9}, {3.830874027409986*^9, 
   3.830874027410074*^9}, {3.831115493338282*^9, 3.83111549333836*^9}},
 CellID->1502914063,ExpressionUUID->"4d8d391d-9b0f-4fff-afb2-555b22715e30"],

Cell[TextData[{
 "Such systems are called non-recursive. In such systems, the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "36de250a-8c88-4a19-877f-162b31b7c3fd"],
 " is simply a weighted average of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "3207078c-8778-4339-a484-fdd1fd08bdaf"],
 " values of the input ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "39246d2a-bbbd-4a0e-8469-df367da01cba"],
 ". "
}], "Text",
 CellChangeTimes->{{3.778267061444903*^9, 3.778267102021128*^9}, {
   3.77826715722003*^9, 3.778267173129306*^9}, {3.77826722399695*^9, 
   3.778267242138005*^9}, {3.778268261188173*^9, 3.7782682637394357`*^9}, 
   3.8008341437844396`*^9, {3.803211328515661*^9, 3.803211351654837*^9}, {
   3.8032444968286877`*^9, 3.8032445077272615`*^9}, {3.803244549982532*^9, 
   3.803244550674865*^9}, {3.819894083473996*^9, 3.819894107889278*^9}},
 CellID->774000827,ExpressionUUID->"7510c00b-e8c0-4137-addf-ed483ef9b182"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Moving-Average System", "Subsection",
 CellChangeTimes->{{3.80321239930979*^9, 3.803212408775756*^9}, 
   3.803221350386483*^9, {3.803301381618243*^9, 3.803301383021453*^9}, {
   3.83042342656946*^9, 3.8304234413091564`*^9}, {3.830874042969597*^9, 
   3.830874043180277*^9}},
 CellID->1323449510,ExpressionUUID->"b7cefa4d-cc40-487f-bb70-82ed8cbb1ca8"],

Cell["\<\
A simple averaging system, commonly known as the moving-average system, is \
probably the most frequently encountered discrete-time system in practice. It \
is an example of a non-recursive system. Such a system is typically used to \
smooth an input sequence (i.e. data) by reducing the local variations in \
sample values.\
\>", "Text",
 CellChangeTimes->{{3.803218231396672*^9, 3.80321829960332*^9}, {
   3.80321833311363*^9, 3.803218384614913*^9}, {3.803218666296479*^9, 
   3.803218670110081*^9}, {3.803219387696149*^9, 3.80321938978856*^9}, {
   3.803379201597536*^9, 3.803379202135316*^9}, {3.803379239959963*^9, 
   3.803379262951743*^9}, {3.819894132352643*^9, 3.819894142030031*^9}, 
   3.830423473111365*^9, {3.830874046405712*^9, 3.830874047655098*^9}, {
   3.891600323392178*^9, 3.8916003817929196`*^9}, 3.9155530191994133`*^9},
 CellID->1727782591,ExpressionUUID->"395ad1ce-7600-4b58-b438-6dbfac1c8068"],

Cell["\<\
It is usually defined by the following non-recursive difference formula\
\>", "Text",
 CellChangeTimes->{{3.803218588424927*^9, 3.80321869030006*^9}, {
   3.803379296885436*^9, 3.803379298185808*^9}, {3.830423585884205*^9, 
   3.830423587802952*^9}, {3.830874067203174*^9, 3.830874071492962*^9}, {
   3.891600405354057*^9, 3.89160044197561*^9}, 3.916237118757414*^9},
 CellID->568132203,ExpressionUUID->"75c2dca3-bb23-4db1-8f32-b43fbb0494f4"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "=", 
    RowBox[{
     FractionBox["1", "N"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "n", "]"}], "+", 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "1"}], "]"}], "+"}], "..."}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "N", "+", "1"}], "]"}]}], ")"}]}]}], 
   TraditionalForm]],ExpressionUUID->"cfc81c04-7c38-47df-8abb-01bd7f5d3d7f"]
}], "Text",
 CellChangeTimes->{{3.3992488741875*^9, 3.39924887571875*^9}, 
   3.6127916020532837`*^9, {3.803218697033048*^9, 3.8032187202336526`*^9}, {
   3.803224215700845*^9, 3.803224216032913*^9}, {3.830873015786945*^9, 
   3.830873030122534*^9}, {3.8308740824776*^9, 3.83087408247766*^9}},
 CellID->885641259,ExpressionUUID->"2a611482-0731-4abb-bb22-746c7da19745"],

Cell[TextData[{
 "Therefore, the output value at time ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f1f78e9c-5a45-4296-907d-484eefb6f3f9"],
 " is simply the mean of ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],ExpressionUUID->
  "6414fa91-eaba-41a3-a864-7207f46ac893"],
 " present and past values of the input. Such an operation has a smoothing, \
also called blurring, effect on the processed data, as shown here:"
}], "Text",
 CellChangeTimes->{{3.803218770457227*^9, 3.803218848647487*^9}, {
  3.8916004245161066`*^9, 3.89160042723014*^9}, {3.915534002528675*^9, 
  3.915534133062626*^9}, {3.918562371043804*^9, 3.9185623831099987`*^9}},
 CellID->763482656,ExpressionUUID->"7a183c82-7360-4d34-85a8-72c2b99b4788"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["4", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["37768", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    Row[{
      ListPlot[{$CellContext`row, 
        ListConvolve[
         ConstantArray[1./$CellContext`L, $CellContext`L], $CellContext`row, 
         Ceiling[$CellContext`L/2], 0.]}, Filling -> Axis, AspectRatio -> 1/3,
        Ticks -> {Automatic, {0, 1}}, PlotLegends -> {
         Style["input", Small], 
         Style["output", Small]}, ImageSize -> 220], 
      MeanFilter[$CellContext`img, $CellContext`L]}, 
     Spacer[50]], {{$CellContext`L, 7, 
      Style["N", Italic]}, 1, 21, 1}, 
    Initialization :> ($CellContext`img = Image[
        Image[CompressedData["
1:eJxkvAdUU1n3Pnyp6SRA6CWL3ouAIAh27B17720cex/HPjq2KY6jY+/jODqO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         "], "Byte", ColorSpace -> "Grayscale", Interleaving -> None], 
        Magnification -> 0.65]; $CellContext`row = Part[
        ImageData[$CellContext`img], 100]; Null), ControlPlacement -> Top],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.777578688623347*^9, 3.777578691657133*^9}, 
   3.777579084242275*^9, {3.77757912113034*^9, 3.77757912206761*^9}, {
   3.777579155432147*^9, 3.777579167943034*^9}, {3.777579609731536*^9, 
   3.7775796216867466`*^9}, {3.777579751380155*^9, 3.777579771984101*^9}, {
   3.777579914255678*^9, 3.777579940051753*^9}, {3.828631793597198*^9, 
   3.828631949717949*^9}, {3.828631984108415*^9, 3.828632000325784*^9}, {
   3.828632034357957*^9, 3.828632034458644*^9}, {3.828632404559893*^9, 
   3.828632404603655*^9}, {3.892209619492116*^9, 3.892209659136537*^9}, {
   3.89220997404402*^9, 3.892210035919047*^9}, 3.892210196158461*^9, {
   3.892577219997797*^9, 3.892577275009916*^9}, {3.89280863959351*^9, 
   3.892808655437543*^9}, {3.8940523585117087`*^9, 3.894052401644276*^9}, {
   3.894052449439959*^9, 3.894052496432393*^9}, 3.8940525269923162`*^9, 
   3.894058703394153*^9, 3.8940587976824074`*^9, {3.899209433995644*^9, 
   3.899209479311602*^9}},
 CellID->223408541,ExpressionUUID->"4f24e0fb-ac1b-4d0d-a6d7-270cab94ce2a"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`L$$ = 7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`L$$], 7, 
       Style["N", Italic]}, 1, 21, 1}}, Typeset`size$$ = {
    389.3658839734395, {72.72506274081843, 69.91621103603393}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`L$$ = 7}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Row[{
         ListPlot[{$CellContext`row, 
           ListConvolve[
            ConstantArray[
            1./$CellContext`L$$, $CellContext`L$$], $CellContext`row, 
            Ceiling[$CellContext`L$$/2], 0.]}, Filling -> Axis, AspectRatio -> 
          1/3, Ticks -> {Automatic, {0, 1}}, PlotLegends -> {
            Style["input", Small], 
            Style["output", Small]}, ImageSize -> 220], 
         MeanFilter[$CellContext`img, $CellContext`L$$]}, 
        Spacer[50]], "Specifications" :> {{{$CellContext`L$$, 7, 
          Style["N", Italic]}, 1, 21, 1}}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{
      433.8658839734395, {111.20442595092618`, 118.43684782592618`}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`img = Image[
         Image[CompressedData["
1:eJxkvAdUU1n3Pnyp6SRA6CWL3ouAIAh27B17720cex/HPjq2KY6jY+/jODqO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          "], "Byte", ColorSpace -> "Grayscale", Interleaving -> None], 
         Magnification -> 0.65]; $CellContext`row = Part[
         ImageData[$CellContext`img], 100]; Null); Typeset`initDone$$ = True),
    
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8940587829488764`*^9, 3.894058800457838*^9}, 
   3.8975702291012664`*^9, {3.899209472318133*^9, 3.899209481548323*^9}, 
   3.902782007275158*^9, 3.9040424518283978`*^9},
 CellID->268819566,ExpressionUUID->"236a81f5-1c54-4cb0-bde1-fe4d4f9ef032"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compound Interest and Exponential Growth", "Subsection",
 CellChangeTimes->{{3.699133165800669*^9, 3.699133196519122*^9}, {
  3.793717112375878*^9, 3.7937171356030273`*^9}, {3.793717497936722*^9, 
  3.79371750024284*^9}, {3.80322633610289*^9, 3.803226358160867*^9}, {
  3.803238989088387*^9, 3.8032390143537703`*^9}, {3.803250249328021*^9, 
  3.803250249488545*^9}, {3.803301601335308*^9, 3.803301602778458*^9}, {
  3.830423630324473*^9, 3.8304236404380074`*^9}},
 CellID->638208567,ExpressionUUID->"76b7da40-a916-4f0b-b428-39ba793dd37f"],

Cell[TextData[{
 "Compound interest is the addition of interest to the principal sum of a \
loan or deposit. It is used in most transactions in the banking and finance \
sectors. For example, in a savings account, the principal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "14b57a60-2261-40ed-828a-e60f4f66ebd1"],
 " at time ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "2861712b-33f8-4f55-8503-67579c806640"],
 " is equal to the principal at time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "-", "1"}], TraditionalForm]],ExpressionUUID->
  "01b56c8b-244e-4ec0-ad5d-cb885ce1953a"],
 " plus the accumulated interest using interest rate ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "21f0ddee-64c9-4934-8a75-dd970f3713e7"],
 " and any deposits or deductions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "b9bf3b8b-aead-420c-ae32-02eb0b99b231"]
}], "Text",
 CellChangeTimes->{{3.803239045372381*^9, 3.803239050049904*^9}, {
   3.803239108765794*^9, 3.803239109632468*^9}, {3.8032393205756063`*^9, 
   3.803239333806218*^9}, {3.803239555481782*^9, 3.8032396344305935`*^9}, {
   3.8032396699567633`*^9, 3.803239773831155*^9}, {3.803301636439517*^9, 
   3.8033016419248476`*^9}, {3.891600606215998*^9, 3.8916006088100343`*^9}, 
   3.915553111486993*^9, 3.9162371238326263`*^9},
 CellID->1838052451,ExpressionUUID->"c3a82708-f27f-474f-ab49-c6e18c8c9648"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{"x", "[", "n", "]"}]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{"x", "[", "n", "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "5f142598-81cd-43ed-98d0-98af41372ab1"]
}], "Text",
 CellChangeTimes->{{3.6047813142628*^9, 3.604781365543*^9}, {
  3.6047817378128*^9, 3.604781751416*^9}, {3.604781790182*^9, 
  3.6047818168892*^9}, {3.803240341433736*^9, 3.8032403808878164`*^9}, {
  3.803240467773819*^9, 3.803240468370229*^9}, {3.803242759858939*^9, 
  3.803242761329998*^9}, {3.830873070995601*^9, 3.830873097890745*^9}, {
  3.8623169030450983`*^9, 3.862316912781043*^9}, {3.9284126710030746`*^9, 
  3.928412671043129*^9}},
 CellID->595281862,ExpressionUUID->"7f49d719-80c1-493c-914e-ac1dc0372463"],

Cell["In standard form", "Text",
 CellChangeTimes->{{3.8032405641349783`*^9, 3.8032405722093844`*^9}, {
   3.803242767954279*^9, 3.803242772839216*^9}, 3.9162371315407696`*^9},
 CellID->1923426908,ExpressionUUID->"c4976cc7-6861-4ebb-b978-3f304b6fcb7a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}], "=", 
    RowBox[{"x", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "a7f7400e-0b56-4532-be39-5154792013f1"]
}], "Text",
 CellChangeTimes->{{3.6047813142628*^9, 3.604781365543*^9}, {
  3.6047817378128*^9, 3.604781751416*^9}, {3.604781790182*^9, 
  3.6047818168892*^9}, {3.803240341433736*^9, 3.8032403808878164`*^9}, {
  3.803240467773819*^9, 3.803240468370229*^9}, {3.803240583829702*^9, 
  3.8032405931029005`*^9}, {3.803242780099774*^9, 3.8032427848490863`*^9}, {
  3.830873082707793*^9, 3.830873092948007*^9}},
 CellID->964704465,ExpressionUUID->"c2143601-b3ce-4b77-a211-7e6a6e92f1b5"],

Cell[TextData[{
 "This shows the effect of compounding interest on the amount of principal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "9d6ef055-2490-4648-9ee2-f7c9fd4e2b58"],
 " over a range of interest rates with an initial deposit of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "0", "]"}], "=", "1000"}], TraditionalForm]],
  ExpressionUUID->"320e1254-4b34-45e6-9c72-5fe499765d72"],
 " and no further deposits or deductions (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"7befac53-feef-459e-a270-ada29e74f1b0"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">", "0"}], TraditionalForm]],ExpressionUUID->
  "f6716a51-520f-46e8-9f8a-ae6a79ee2112"],
 "):"
}], "Text",
 CellChangeTimes->{{3.803240823825301*^9, 3.803240842071489*^9}, 
   3.8032408764777336`*^9, {3.80324093872087*^9, 3.8032409882194276`*^9}, {
   3.803241122915089*^9, 3.803241186507913*^9}, {3.803242192095669*^9, 
   3.803242246391386*^9}, {3.803242319249582*^9, 3.80324232910022*^9}, {
   3.80324240568577*^9, 3.8032424066441927`*^9}, {3.8032424609891567`*^9, 
   3.8032424613801107`*^9}, {3.803242514684528*^9, 3.803242568146497*^9}, {
   3.803242905460352*^9, 3.803242956110814*^9}, {3.8032429872684565`*^9, 
   3.803242989364833*^9}, {3.8032441811652904`*^9, 3.803244185225678*^9}, {
   3.803249159106638*^9, 3.803249197580983*^9}, {3.803249505505762*^9, 
   3.803249519517686*^9}, {3.8033282378756866`*^9, 3.8033282540275393`*^9}, {
   3.830873101938957*^9, 3.8308731029631968`*^9}},
 CellID->286408405,ExpressionUUID->"e3ae91d7-5c9b-4e71-9f9e-a50695527981"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2424", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[{$CellContext`x, $CellContext`y, $CellContext`r}, 
    Manipulate[
     ListPlot[
      Evaluate[
       RecurrenceTable[{$CellContext`y[$CellContext`n] - (
           1 + $CellContext`r) $CellContext`y[$CellContext`n - 
            1] == $CellContext`x[$CellContext`n], $CellContext`y[-1] == 0}, 
        $CellContext`y[$CellContext`n], {$CellContext`n, 0, 15}]], 
      PlotRange -> {0, 4200}, Filling -> 0, PlotStyle -> PointSize[Medium], 
      AxesLabel -> {
        Style["years", Italic], None}], {{$CellContext`r, 0.05}, -0.05, 0.1}, 
     Initialization :> ($CellContext`x[
         Pattern[$CellContext`n, 
          Blank[]]] := 1000 KroneckerDelta[$CellContext`n]; Null), 
     ControlPlacement -> Top]],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.8032418144391584`*^9, 3.803241830736545*^9}, {
   3.8032418640683565`*^9, 3.803242087979398*^9}, {3.803242125600523*^9, 
   3.80324214521212*^9}, {3.8032422523005695`*^9, 3.8032422969103622`*^9}, {
   3.803242333441607*^9, 3.803242338543967*^9}, {3.8032423798803544`*^9, 
   3.803242380628364*^9}, {3.8032424178595767`*^9, 3.803242466575178*^9}, {
   3.803242616109161*^9, 3.803242619918967*^9}, {3.8032430107885103`*^9, 
   3.8032430478633013`*^9}, {3.8032490121954155`*^9, 3.803249020776055*^9}, {
   3.803249100899232*^9, 3.803249101160546*^9}, {3.803249251272334*^9, 
   3.8032492882746897`*^9}, {3.803249319298587*^9, 3.803249330653338*^9}, {
   3.80324938261202*^9, 3.803249409664625*^9}, {3.803249468884191*^9, 
   3.803249478667678*^9}, {3.8033414474617653`*^9, 3.803341456394886*^9}, {
   3.822691396619803*^9, 3.8226914197603345`*^9}, 3.822691474198547*^9, {
   3.892213965173451*^9, 3.892214055214635*^9}, {3.894058823075592*^9, 
   3.894058842625057*^9}, 3.9027819312226796`*^9, 3.902782024612254*^9, {
   3.9027820620568914`*^9, 3.902782082318386*^9}},
 CellID->1155209908,ExpressionUUID->"8b5f37da-2cbe-4614-aee1-fee0e4f6aa53"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`x$$, $CellContext`y$$, $CellContext`r$$}, 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`r$$ = 0.05, Typeset`show$$ = True, 
     Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
     "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`r$$], 0.05}, -0.05, 0.1}}, Typeset`size$$ = {
     240., {61.383498676061635`, 68.6159207481295}}, Typeset`update$$ = 0, 
     Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, "Variables" :> {$CellContext`r$$ = 0.05}, 
       "ControllerVariables" :> {}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> ListPlot[
         Evaluate[
          
          RecurrenceTable[{$CellContext`y$$[$CellContext`n] - (
              1 + $CellContext`r$$) $CellContext`y$$[$CellContext`n - 
               1] == $CellContext`x$$[$CellContext`n], $CellContext`y$$[-1] == 
            0}, 
           $CellContext`y$$[$CellContext`n], {$CellContext`n, 0, 15}]], 
         PlotRange -> {0, 4200}, Filling -> 0, PlotStyle -> PointSize[Medium],
          AxesLabel -> {
           Style["years", Italic], None}], 
       "Specifications" :> {{{$CellContext`r$$, 0.05}, -0.05, 0.1}}, 
       "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
      ImageSizeCache->{284.5, {104.88349877459557`, 112.11592064959557`}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>(($CellContext`x$$[
          Pattern[$CellContext`n, 
           Blank[]]] := 1000 KroneckerDelta[$CellContext`n]; Null); 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]],
  DynamicModuleValues:>{{DownValues[$CellContext`x$$] = {HoldPattern[
         $CellContext`x$$[
          Pattern[$CellContext`n, 
           Blank[]]]] :> 1000 KroneckerDelta[$CellContext`n]}}}]], "Output",
 CellChangeTimes->{
  3.803242042603079*^9, 3.8032420890555067`*^9, {3.80324213336182*^9, 
   3.803242146832743*^9}, {3.8032422762504826`*^9, 3.8032422975316906`*^9}, 
   3.803242339213168*^9, 3.803242381624688*^9, {3.803242420001831*^9, 
   3.803242467259381*^9}, 3.803249021507268*^9, 3.803249105868392*^9, 
   3.803249334600175*^9, {3.803249413750899*^9, 3.803249429301237*^9}, 
   3.803249480828864*^9, {3.803341440039604*^9, 3.803341457081035*^9}, {
   3.822691396781372*^9, 3.822691420646963*^9}, 3.822691475577108*^9, {
   3.8922139742473803`*^9, 3.892214057876326*^9}, {3.894058833334335*^9, 
   3.89405884573516*^9}, 3.897570234247907*^9, 3.9027819384184575`*^9, {
   3.902782013148177*^9, 3.902782041895194*^9}, 3.902782087991415*^9, 
   3.904042456830723*^9},
 CellID->336734127,ExpressionUUID->"32056209-9fd9-402f-bee8-18ef13960715"]
}, Open  ]],

Cell["\<\
Such first-order difference equations also model other phenomena, such as \
increase or decrease in population, growth of bacteria, rise or depreciation \
in the value of an item, and more. \
\>", "Text",
 CellChangeTimes->{{3.8032390453723793`*^9, 3.803239050049904*^9}, {
   3.803239108765794*^9, 3.803239109632468*^9}, {3.8032393205756063`*^9, 
   3.803239333806218*^9}, {3.803239555481782*^9, 3.8032396344305935`*^9}, {
   3.8032396699567633`*^9, 3.803239773831155*^9}, {3.803301636439517*^9, 
   3.8033016396100388`*^9}, {3.803301842295235*^9, 3.8033018611902356`*^9}, 
   3.8308731290447063`*^9, {3.830874127737528*^9, 3.830874131331908*^9}, {
   3.915553139886303*^9, 3.915553148472391*^9}},
 CellID->213271229,ExpressionUUID->"e718049d-bd1a-488b-89f9-720ede2a640b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equalization", "Subsection",
 CellChangeTimes->{{3.8033088365384583`*^9, 3.8033088415680475`*^9}},
 CellID->299338960,ExpressionUUID->"76c60dc5-5613-47ed-ae50-4c3c715e1de2"],

Cell["\<\
Equalization, commonly used in audio recording and reproduction, is the \
process of adjusting the balance between frequency components in an audio \
signal. The effect is achieved by increasing or decreasing the signal \
magnitude within specific frequency bands. The following recursive difference \
equation models an equalizer that amplifies a band of mid-range frequencies \
in a signal\
\>", "Text",
 CellChangeTimes->{{3.8033869849962068`*^9, 3.80338703933819*^9}, {
   3.803387109797552*^9, 3.803387112213913*^9}, {3.803387180821067*^9, 
   3.803387249995408*^9}, {3.80338738807766*^9, 3.803387397185948*^9}, {
   3.803387578780837*^9, 3.803387603947976*^9}, {3.803387760336906*^9, 
   3.803387786683143*^9}, {3.803387827246372*^9, 3.803387828322534*^9}, {
   3.805067534118064*^9, 3.805067546058154*^9}, {3.830423773439651*^9, 
   3.8304238026382923`*^9}, {3.891600634681737*^9, 3.891600637237129*^9}, {
   3.902491792977111*^9, 3.902491796904927*^9}, {3.902491847115465*^9, 
   3.902491868269563*^9}, {3.915534169114521*^9, 3.91553428274001*^9}, {
   3.91553432127676*^9, 3.91553436007251*^9}, 3.916237138040575*^9},
 CellID->1583199446,ExpressionUUID->"d3d8f34e-296a-4306-bc82-2846a44092f5"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{"1.7", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{"0.9", " ", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}], "=", 
    RowBox[{
     RowBox[{"1.2", " ", 
      RowBox[{"x", "[", "n", "]"}]}], "-", 
     RowBox[{"1.7", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{"0.7", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "9731c91e-b3a0-4b62-97be-24921488e10d"]
}], "Text",
 CellChangeTimes->{{3.803339756613647*^9, 3.803339804145727*^9}, {
  3.830873147123925*^9, 3.830873147643249*^9}, {3.843430195715431*^9, 
  3.8434302266118*^9}, {3.8623119571842346`*^9, 3.86231195724536*^9}},
 CellID->1510702592,ExpressionUUID->"c2a7d299-814f-4fb7-b8ac-9012f286cbf7"],

Cell[TextData[{
 "Such an equalizer is known as a peaking equalizer. Observe how as the \
frequency of the input sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "a4b265cd-e2ce-41e9-92fe-c79e10085447"],
 " increases, the amplitude of the output sequence, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "5fd473eb-5d1f-4bf9-9b8a-ad70b71fa01c"],
 ", also increases but only for a limited range of frequencies:"
}], "Text",
 CellChangeTimes->{{3.803339565785219*^9, 3.803339576405842*^9}, {
   3.803339606453492*^9, 3.8033396094814215`*^9}, {3.803339946782801*^9, 
   3.803339961697925*^9}, {3.803340556587511*^9, 3.8033405800389614`*^9}, {
   3.803380935062347*^9, 3.8033809662880893`*^9}, {3.803381043864235*^9, 
   3.803381046124834*^9}, 3.8198941987912273`*^9, 3.8198942341209517`*^9, {
   3.830424001836057*^9, 3.830424073643314*^9}, {3.830424119749503*^9, 
   3.830424169316525*^9}, {3.830424230905291*^9, 3.830424255232432*^9}, 
   3.830873157611311*^9, {3.8434302599187098`*^9, 3.8434302605191035`*^9}, {
   3.915534372333086*^9, 3.915534375098039*^9}, {3.915534410848219*^9, 
   3.91553443207737*^9}, {3.915534485300831*^9, 3.915534531409284*^9}, 
   3.915624045208281*^9, {3.9185624937622547`*^9, 3.9185625082460804`*^9}},
 CellID->679305263,ExpressionUUID->"f8cb32bd-9007-422c-a88f-085ceb6a3862"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["3", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2056", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    ListPlot[
     Evaluate[{$CellContext`in = Table[
         Sin[((2 Pi) $CellContext`k) ($CellContext`n/256.)], {$CellContext`n, 
          0., 255.}], 
       RecurrenceFilter[{{1, -1.7, 0.9}, {1.2, -1.7, 
         0.7}}, $CellContext`in]}], Filling -> 0, PlotRange -> {-5, 5}, 
     PlotStyle -> PointSize[0.006], PlotLegends -> {
       Style["x[n]", Small, Italic], 
       Style["y[n]", Small, Italic]}], {{$CellContext`k, 17, "frequency"}, 3, 
     32, 1}, ControlPlacement -> Top],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.8033321332199593`*^9, 3.803332341498875*^9}, {
   3.803332373115368*^9, 3.8033323740019693`*^9}, {3.803333450253595*^9, 
   3.803333473731839*^9}, {3.803333531978227*^9, 3.803333532319404*^9}, {
   3.803333577350445*^9, 3.803333626728956*^9}, {3.803333666486663*^9, 
   3.8033336956466894`*^9}, {3.8033367534892693`*^9, 3.80333678365873*^9}, {
   3.803336835929454*^9, 3.803336836046098*^9}, {3.8033371355866814`*^9, 
   3.80333713750356*^9}, {3.803337170348858*^9, 3.8033371812248297`*^9}, 
   3.803337499360555*^9, 3.843428308071595*^9, {3.84342872603407*^9, 
   3.843428736967715*^9}, {3.843428772082039*^9, 3.843428779334843*^9}, {
   3.8434288257917757`*^9, 3.84342883685288*^9}, {3.843428869693898*^9, 
   3.843428930758938*^9}, 3.843428990290957*^9, {3.843429096353867*^9, 
   3.843429125790925*^9}, {3.843429162775994*^9, 3.843429166460354*^9}, {
   3.843429264074464*^9, 3.843429303232903*^9}, {3.8434293544545717`*^9, 
   3.843429354494465*^9}, {3.843429407676675*^9, 3.843429440418886*^9}, 
   3.843429544234158*^9, 3.8434296895950794`*^9, 3.843429798383324*^9, {
   3.843429869006027*^9, 3.84342987898111*^9}, {3.843429909090064*^9, 
   3.843429930868328*^9}, {3.8434301080027046`*^9, 3.8434301081500845`*^9}, {
   3.8434302988781853`*^9, 3.8434304000194893`*^9}, {3.8434304315020885`*^9, 
   3.843430439632478*^9}, {3.843430535378009*^9, 3.843430558901297*^9}, 
   3.8434306532661753`*^9, {3.843430705375103*^9, 3.843430728574099*^9}, {
   3.843430797402035*^9, 3.843430856946124*^9}, {3.8922140796365194`*^9, 
   3.8922141213213673`*^9}, 3.89280958277279*^9, {3.894058853053525*^9, 
   3.8940588719594336`*^9}, 3.894058941719624*^9, {3.894492123898764*^9, 
   3.894492184857516*^9}, {3.894492223604258*^9, 3.894492257082605*^9}, {
   3.904043183540497*^9, 3.904043203390765*^9}, 3.904043252888643*^9},
 CellID->296925958,ExpressionUUID->"3f2bbe08-ebc2-40a4-8b6b-c5cadad1cd49"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 17, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`k$$], 17, "frequency"}, 3, 32, 1}}, 
    Typeset`size$$ = {288.5556640625, {67.90142024803941, 75.13384232010728}},
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`k$$ = 17}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ListPlot[
        Evaluate[{$CellContext`in = Table[
            
            Sin[((2 Pi) $CellContext`k$$) ($CellContext`n/
              256.)], {$CellContext`n, 0., 255.}], 
          
          RecurrenceFilter[{{1, -1.7, 0.9}, {1.2, -1.7, 
            0.7}}, $CellContext`in]}], Filling -> 0, PlotRange -> {-5, 5}, 
        PlotStyle -> PointSize[0.006], PlotLegends -> {
          Style["x[n]", Small, Italic], 
          Style["y[n]", Small, Italic]}], 
      "Specifications" :> {{{$CellContext`k$$, 17, "frequency"}, 3, 32, 1}}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{
      333.0556640625, {111.40142034657335`, 118.63384222157335`}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.89449219020394*^9, {3.894492224370164*^9, 3.8944922601207395`*^9}, 
   3.8975702398657227`*^9, 3.9027820993189363`*^9, 3.904042427985241*^9, 
   3.904042463901563*^9, {3.9040432434680758`*^9, 3.904043263940315*^9}},
 CellID->111412891,ExpressionUUID->"7e743566-eeb3-41c7-9333-b645b9a4a820"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Solutions", "Subsection",
 CellChangeTimes->{{3.694995382739919*^9, 3.694995417571895*^9}, {
   3.8008340262434607`*^9, 3.800834028159337*^9}, 3.800834078670472*^9, {
   3.805059434709981*^9, 3.8050594367984066`*^9}, {3.831115616586261*^9, 
   3.831115617106476*^9}},
 CellID->1060487789,ExpressionUUID->"6bb7911c-273f-4e1d-a929-b2e863d9c22f"],

Cell[TextData[{
 "Consider the following general form of an ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],ExpressionUUID->
  "c9c9d1ff-9fb4-43ba-b4f2-e936aea3e817"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", "th"], TraditionalForm]],ExpressionUUID->
  "7eb20682-230f-4c72-b7be-005549487bac"],
 "-order difference equation"
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
   3.6526109512051954`*^9}, {3.6949954881396437`*^9, 3.694995503045548*^9}, {
   3.6949955952867584`*^9, 3.694995625842363*^9}, {3.803208950177101*^9, 
   3.803208980634334*^9}, {3.9156240800355964`*^9, 3.915624083550296*^9}, 
   3.9162371467017097`*^9},
 CellID->1651483270,ExpressionUUID->"b6ffa6e0-4d60-44dc-ba96-b0803bc33d8d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], 
        RowBox[{"y", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["a", "N"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "N"}], "]"}]}]}], "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", "M"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "M"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "875e9a5f-3ee1-4128-a974-6170bd169903"]
}], "Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.801567401748525*^9, 3.80156740465173*^9}, {
   3.830873178245071*^9, 3.8308731969153137`*^9}, {3.831115635379459*^9, 
   3.83111563537954*^9}},
 CellID->253181415,ExpressionUUID->"a34fd5fd-0763-4136-83cb-8210b47dbb31"],

Cell[TextData[{
 "Assuming, as is common, that you want to obtain the output for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[GreaterEqual]", "0"}], TraditionalForm]],ExpressionUUID->
  "784c3fb7-36e7-4059-b82d-a21689ff9840"],
 ", this equation can be solved numerically by iteration given an input ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "4b9129ed-51d5-4c28-8918-944a0d5a752d"],
 " and ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],ExpressionUUID->
  "ec4f8792-ce9f-4360-93a9-1adbf5fa2ab7"],
 " so-called initial conditions: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"-", "1"}], "]"}], TraditionalForm]],ExpressionUUID->
  "f3eeb4bd-9494-4fc2-a37a-8ec65af7ea90"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"-", "2"}], "]"}], TraditionalForm]],ExpressionUUID->
  "98585a1e-b57d-43fc-8e82-94d8a8cc8b1c"],
 ", .., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", 
    RowBox[{"-", "N"}], "]"}], TraditionalForm]],ExpressionUUID->
  "b810bcc2-164e-4d1e-bb25-4560727f09e5"],
 ". "
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.488103906234375*^9, 3.48810393971875*^9}, {3.488104140328125*^9, 
   3.4881041673125*^9}, {3.611531338124013*^9, 3.611531338810414*^9}, {
   3.611531390602505*^9, 3.6115314201644015`*^9}, {3.611531457108897*^9, 
   3.61153150809029*^9}, {3.652543334836928*^9, 3.6525433407502904`*^9}, 
   3.652610909428463*^9, {3.652610967179493*^9, 3.65261098328459*^9}, {
   3.694995642870854*^9, 3.6949957347342668`*^9}, {3.694995952300075*^9, 
   3.694995955654053*^9}, {3.695080662441419*^9, 3.695080751797646*^9}, {
   3.801567309493207*^9, 3.801567332334167*^9}, {3.83087320324353*^9, 
   3.8308732034757137`*^9}, {3.8916007077993345`*^9, 3.891600715395339*^9}},
 CellID->1054937198,ExpressionUUID->"fc00b513-eb2b-4b08-9cfe-99914b43d88d"],

Cell[TextData[{
 "The output value ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "88ac5267-dfaf-480a-824f-fce387db0cfd"],
 " is given by the following equation"
}], "Text",
 CellChangeTimes->{{3.6949965325243616`*^9, 3.694996586577817*^9}, {
   3.758818240875676*^9, 3.758818292376598*^9}, {3.801567475708379*^9, 
   3.8015674968652925`*^9}, 3.9162371521270866`*^9},
 CellID->704497154,ExpressionUUID->"4e471c71-1c6d-4e96-9b61-d5d6f65b35d4"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["b", "0"], 
         RowBox[{"x", "[", "n", "]"}]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         RowBox[{"x", "[", 
          RowBox[{"n", "-", "1"}], "]"}]}]}], " ", "..."}], "+", 
      RowBox[{
       SubscriptBox["b", "M"], 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "M"}], "]"}]}], "-", " ", 
      RowBox[{
       SubscriptBox["a", "1"], 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}]}], "..."}], "-", 
    RowBox[{
     SubscriptBox["a", "N"], 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "N"}], "]"}]}]}]}], 
  TraditionalForm]],ExpressionUUID->"91aa6ada-f30e-43ec-9f7f-62673d1b8489"]], \
"Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.694995796791069*^9, 3.694995868367812*^9}, {
   3.694996064314759*^9, 3.694996079549661*^9}, {3.75881824562862*^9, 
   3.758818263798932*^9}, {3.801567422169489*^9, 3.801567438800169*^9}, {
   3.830872818269668*^9, 3.830872818269748*^9}, {3.830873221756998*^9, 
   3.830873246580969*^9}, {3.8311156495170393`*^9, 3.831115649517133*^9}, 
   3.891600733943054*^9},
 CellID->1406321367,ExpressionUUID->"891225ed-9877-4ec0-acb9-e53b48a3e871"],

Cell[TextData[{
 "Starting at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "ffa2384b-4818-4263-8229-9236d91ced30"]
}], "Text",
 CellChangeTimes->{{3.694995983042678*^9, 3.694995993388411*^9}, {
   3.830873251619659*^9, 3.830873252835891*^9}, 3.9162371567629414`*^9},
 CellID->838196287,ExpressionUUID->"97d0debc-330d-42ba-bee7-f48dd6df91ab"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["b", "0"], 
          RowBox[{"x", "[", "0", "]"}]}], "+", 
         RowBox[{
          SubscriptBox["b", "1"], 
          RowBox[{"x", "[", 
           RowBox[{"-", "1"}], "]"}]}]}], "..."}], "+", 
       RowBox[{
        SubscriptBox["b", "M"], 
        RowBox[{"x", "[", 
         RowBox[{"-", "M"}], "]"}]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], 
        RowBox[{"y", "[", 
         RowBox[{"-", "1"}], "]"}]}], "-", 
       RowBox[{
        SubscriptBox["a", "2"], 
        RowBox[{"y", "[", 
         RowBox[{"-", "2"}], "]"}]}]}], "..."}], "-", 
     RowBox[{
      SubscriptBox["a", "N"], 
      RowBox[{"y", "[", 
       RowBox[{"-", "N"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "69d5797b-2844-4a8d-a031-dd14ded0c737"]
}], "Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.694995796791069*^9, 3.694995868367812*^9}, {
   3.694996003358747*^9, 3.694996060192386*^9}, {3.6949961035689073`*^9, 
   3.6949961035689073`*^9}, {3.8015675428931866`*^9, 
   3.8015675621187897`*^9}, {3.830872821154612*^9, 3.830872821154688*^9}, {
   3.830873262379385*^9, 3.830873287461125*^9}, {3.83111566141273*^9, 
   3.831115661412829*^9}, {3.9285819157768574`*^9, 3.9285819157768574`*^9}},
 CellID->72271289,ExpressionUUID->"c94b3b5a-f576-46ea-b4c7-5ad9045aa122"],

Cell[TextData[{
 "Continuing for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "4765edee-d239-4ed7-b109-7b52b5f798e9"]
}], "Text",
 CellChangeTimes->{{3.6949961569541655`*^9, 3.694996188175565*^9}, 
   3.9162371597439613`*^9},
 CellID->1335293668,ExpressionUUID->"394a93a4-4b09-4e21-83d8-d35328b2bb95"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["b", "0"], 
         RowBox[{"x", "[", "1", "]"}]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         RowBox[{"x", "[", "0", "]"}]}]}], "..."}], "+", 
      RowBox[{
       SubscriptBox["b", "M"], 
       RowBox[{"x", "[", 
        RowBox[{"1", "-", "M"}], "]"}]}], "-", 
      RowBox[{
       SubscriptBox["a", "1"], 
       RowBox[{"y", "[", "0", "]"}]}], "-", 
      RowBox[{
       SubscriptBox["a", "2"], 
       RowBox[{"y", "[", 
        RowBox[{"-", "1"}], "]"}]}]}], "..."}], "-", 
    RowBox[{
     SubscriptBox["a", "N"], 
     RowBox[{"y", "[", 
      RowBox[{"1", "-", "N"}], "]"}]}]}]}], 
  TraditionalForm]],ExpressionUUID->"da1136b9-6d76-4568-adc7-200818343c0c"]], \
"Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.694995796791069*^9, 3.694995868367812*^9}, {
   3.694996003358747*^9, 3.694996060192386*^9}, {3.6949961035689073`*^9, 
   3.6949961035689073`*^9}, {3.694996195027921*^9, 3.694996229488902*^9}, {
   3.8015675945919356`*^9, 3.801567611129728*^9}, {3.8308728240402775`*^9, 
   3.830872824040343*^9}, {3.83087329551711*^9, 3.830873323469722*^9}, {
   3.831115674061599*^9, 3.831115674061695*^9}, 3.891600757879568*^9, {
   3.9285819061265907`*^9, 3.9285819195622425`*^9}},
 CellID->1076566926,ExpressionUUID->"3c9c4d63-8331-4093-bc55-228d3add2cb7"],

Cell[TextData[{
 "Finally, in general, for any value ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "k"}], TraditionalForm]],ExpressionUUID->
  "d7411a71-431e-4ed9-8278-fe68ad4a4dea"]
}], "Text",
 CellChangeTimes->{{3.694996627207958*^9, 3.6949966537441864`*^9}, {
   3.777849865613922*^9, 3.7778498701555624`*^9}, {3.801567713942895*^9, 
   3.801567735998801*^9}, {3.803393655977206*^9, 3.803393666115994*^9}, 
   3.830873328874352*^9, {3.891600806549582*^9, 3.891600818773332*^9}, 
   3.916237164424078*^9, 3.9185625776666584`*^9},
 CellID->1310599307,ExpressionUUID->"8d2ebe31-133c-46db-91b5-e713253b3ba3"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "k", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["b", "0"], 
         RowBox[{"x", "[", "k", "]"}]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         RowBox[{"x", "[", 
          RowBox[{"k", "-", "1"}], "]"}]}]}], "..."}], "+", 
      RowBox[{
       SubscriptBox["b", "M"], 
       RowBox[{"x", "[", 
        RowBox[{"k", "-", "M"}], "]"}]}], "-", 
      RowBox[{
       SubscriptBox["a", "1"], 
       RowBox[{"y", "[", 
        RowBox[{"k", "-", "1"}], "]"}]}], "-", 
      RowBox[{
       SubscriptBox["a", "2"], 
       RowBox[{"y", "[", 
        RowBox[{"k", "-", "2"}], "]"}]}]}], "..."}], "-", 
    RowBox[{
     SubscriptBox["a", "N"], 
     RowBox[{"y", "[", 
      RowBox[{"k", "-", "N"}], "]"}]}]}]}], 
  TraditionalForm]],ExpressionUUID->"8af0e3b7-1eee-4414-a617-db696825c2c2"]], \
"Text",
 CellChangeTimes->{{3.399247238875*^9, 3.399247248515625*^9}, 
   3.61273599997344*^9, {3.694995796791069*^9, 3.694995868367812*^9}, {
   3.694996003358747*^9, 3.694996060192386*^9}, {3.6949961035689073`*^9, 
   3.6949961035689073`*^9}, {3.694996195027921*^9, 3.694996229488902*^9}, {
   3.7782685889721413`*^9, 3.77826863183304*^9}, {3.801567743747037*^9, 
   3.801567771259512*^9}, {3.80156780690016*^9, 3.801567840156356*^9}, {
   3.830872826867178*^9, 3.830872826867243*^9}, {3.8308735544233103`*^9, 
   3.830873582211259*^9}, {3.83111568350167*^9, 3.8311156835017967`*^9}, 
   3.891600823873456*^9, {3.928581922692707*^9, 3.928581922692707*^9}},
 CellID->502785470,ExpressionUUID->"0cf15f1d-58f1-49db-968a-7e1ea331dc34"],

Cell["\<\
This process can be continued until all desired output values are obtained. A \
numerical solution may therefore be easily obtained with nothing more than a \
simple calculator.\
\>", "Text",
 CellChangeTimes->{{3.8033936632464685`*^9, 3.8033936772811756`*^9}, {
  3.803393831301885*^9, 3.803393860305992*^9}},
 CellID->2114726992,ExpressionUUID->"277abcd0-cffd-4bb3-b5ce-d902af9ad59d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection",
 CellChangeTimes->{{3.399247677078125*^9, 3.399247682859375*^9}, 
   3.612737317626639*^9, {3.694996659642949*^9, 3.6949966610937395`*^9}, {
   3.69499715809816*^9, 3.694997158644156*^9}, {3.6950803123796625`*^9, 
   3.695080312473262*^9}, {3.7273667258546696`*^9, 3.727366725870303*^9}, {
   3.777849885574727*^9, 3.777849885699628*^9}, {3.778970463661465*^9, 
   3.778970463721305*^9}, {3.803393619955982*^9, 3.803393620028677*^9}},
 CellID->1362196694,ExpressionUUID->"8029a7a4-8dad-4206-8657-a7290a051ee0"],

Cell[TextData[{
 "Obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "20bf87de-e5e1-44b7-b0ea-b264d92ad5bf"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2"}], TraditionalForm]],
  ExpressionUUID->"affb9a42-9db5-4c99-975d-e7e2feae653a"],
 " given input ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{"cos", "(", 
      RowBox[{"\[Pi]", " ", "n"}], ")"}], "=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}]}], TraditionalForm]],ExpressionUUID->
  "9f111b36-036a-483b-90c1-0c4323b6f6d0"],
 " and the following first-order difference equation and initial condition"
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
   3.6526109512051954`*^9}, {3.694996672499266*^9, 3.694996754242944*^9}, {
   3.6950802301369896`*^9, 3.695080260541195*^9}, {3.801570939491125*^9, 
   3.80157095853519*^9}, {3.8032084563143063`*^9, 3.803208456701305*^9}, {
   3.8033269057196865`*^9, 3.803326908033674*^9}, {3.830873611697692*^9, 
   3.830873612379049*^9}, {3.891600863302743*^9, 3.89160087273446*^9}, {
   3.8916009616610928`*^9, 3.8916009618214025`*^9}, 3.916237174380274*^9},
 CellID->116675391,ExpressionUUID->"ebc208b9-a474-4a23-8e8b-3ba9acb2b795"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{
      FractionBox["2", "3"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}], "=", 
    RowBox[{"x", "[", "n", "]"}], " "}], TraditionalForm]],ExpressionUUID->
  "74fb8a0a-4e17-440e-86df-96bbf4f483fd"],
 ",\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "1"}], "]"}], "=", "0"}], TraditionalForm]],ExpressionUUID->
  "fb08c2ac-67f3-42ce-848c-860e8ca2d85a"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.48810448403125*^9, 3.488104486015625*^9}, 3.61273640209794*^9, {
   3.65261095986314*^9, 3.65261096145433*^9}, {3.803208427883411*^9, 
   3.803208431876732*^9}, {3.830873620948722*^9, 3.830873634787331*^9}, {
   3.831115714837583*^9, 3.831115714837677*^9}},
 CellID->310726826,ExpressionUUID->"60988a32-7763-43e8-bfb1-c12e3b94f31a"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.694996768752851*^9, 3.694996771186438*^9}},
 CellID->1853018725,ExpressionUUID->"5de12b1c-ca6b-4814-b643-773f845bf1ff"],

Cell[TextData[{
 "The function ",
 ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"],
 " returns the desired values:"
}], "Text",
 CellChangeTimes->{{3.696804408076399*^9, 3.696804430009717*^9}, {
   3.696804568052347*^9, 3.6968045688323407`*^9}, {3.803208588216113*^9, 
   3.803208637208024*^9}, {3.803208760414318*^9, 3.803208809093091*^9}, 
   3.803393826592325*^9, {3.8033938920406876`*^9, 3.803393902325892*^9}, {
   3.830873667584852*^9, 3.830873680025208*^9}, {3.9235681373135586`*^9, 
   3.9235681373157177`*^9}},
 CellID->877862281,ExpressionUUID->"d5db835a-7169-4af5-8553-e503e1085183"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RecurrenceTable", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], "-", 
       RowBox[{
        FractionBox["2", "3"], 
        RowBox[{"y", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}]}], "\[Equal]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"]}], ",", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"-", "1"}], "]"}], "==", "0"}]}], "}"}], ",", 
   RowBox[{"y", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696804447216297*^9, 3.696804544278252*^9}, {
  3.7778517935885344`*^9, 3.777851793697913*^9}, {3.800833877287288*^9, 
  3.800833878270652*^9}, {3.801571123098679*^9, 3.801571126289103*^9}, {
  3.803208854147528*^9, 3.8032088576781263`*^9}, {3.8916009672619734`*^9, 
  3.891600967341188*^9}, {3.89221425060201*^9, 3.892214254617996*^9}, {
  3.897570257016695*^9, 3.89757025746027*^9}},
 CellID->1018701877,ExpressionUUID->"7db473fc-0048-4e93-94f6-317546e7789c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"-", 
    FractionBox["1", "3"]}], ",", 
   FractionBox["7", "9"]}], "}"}]], "Output",
 CellChangeTimes->{{3.696804533093196*^9, 3.6968045560405016`*^9}, 
   3.777851794986407*^9, 3.8008338792919226`*^9, {3.80157112959828*^9, 
   3.801571140830158*^9}, 3.803208524088541*^9, 3.803208859132229*^9, 
   3.891600967841534*^9, 3.892214255121998*^9, 3.894058968636724*^9, 
   3.897570259042435*^9},
 CellID->452923894,ExpressionUUID->"057336b9-9193-4cbc-85ae-46a18b880565"]
}, Open  ]],

Cell[TextData[{
 "This plots the output for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "n", "\[LessEqual]", "31"}], 
   TraditionalForm]],ExpressionUUID->"b011d8bc-50ae-4bdc-86b4-24a7a327267a"],
 ":"
}], "Text",
 CellChangeTimes->{{3.801571154086228*^9, 3.80157116300736*^9}, {
  3.803208874031022*^9, 3.8032089060204077`*^9}},
 CellID->1582812855,ExpressionUUID->"dd01ebb7-7988-4e4e-9fd0-711fbd5c2a00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["4", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1544", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    Evaluate[
     RecurrenceTable[{$CellContext`y[$CellContext`n] - (2/
         3) $CellContext`y[$CellContext`n - 
          1] == (-1)^$CellContext`n, $CellContext`y[-1] == 0}, 
      $CellContext`y[$CellContext`n], {$CellContext`n, 0, 31}]], Filling -> 0,
     PlotStyle -> PointSize[Medium], AxesLabel -> {
      Style["n", Small, Italic], None}],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.801571165124877*^9, 3.801571179167939*^9}, {
   3.8032085062997203`*^9, 3.8032085186845274`*^9}, {3.803208870821602*^9, 
   3.803208902520744*^9}, 3.819895798188116*^9, 3.8916009252669983`*^9, {
   3.8922141670189953`*^9, 3.892214220989137*^9}, {3.892214276801329*^9, 
   3.892214303557677*^9}, {3.8940589509823356`*^9, 3.894058956701379*^9}, 
   3.894058988220063*^9, {3.894655109252723*^9, 3.894655133309114*^9}},
 CellID->1455718596,ExpressionUUID->"a0ecb938-615b-46e1-a4fe-a90ecb9883ba"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[GraphicsComplexBox[CompressedData["
1:eJzt088rw3Ecx/Elv3+FyGQr1kiMfffLvmM/XpymHFjmV5TEwVpNzcFSCgdF
uezg5GJycZjyMxduNCUHu/m5UbvIXCSl/Pp+PuX9L/CuT+8ePY+f3pXDPtdo
ikwmG/p8X/tnko7fWwb390QPf5gJy1JcXIonpF6ArMeq7eXza6kX433TWTZ5
8CB1OXpu1E/huTupKzB+ZM25dd1LvQLZUU3I449JXYU1RcyWvxWXuhr21rGZ
lyvWqzE7PdKV7mW9Bl3dRcrOvLjUa3FS3rY80c66BlOPgeSAivUG9OWm7njt
rAvwrbrm9+pY12E36O8QRNb1mF8ZjNxoWTdgvcV75jGxboT1Yu90X8e6CfVK
YVJrZL0RsRZT2qKedTMOpy87QwbWRcxslE4keLfALSYzRnlvwrF2563QwHoz
zhcue9t4tyLy6vWpebchEM7NsfFuR/9te0jDuwNlJaqgmXfg6TnoFHjn/84G
v5lJXEBcTCwnVhBXEKuI1cTVxDXEtcQa4gZigVhHrCc2EBuJTcSNxGZikdhC
3ETcTGwlthHbiR3EIP6//796/x92zyfk
       "], {{{}, {}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
          LineBox[{34, 2}], LineBox[{36, 4}], LineBox[{38, 6}], 
          LineBox[{40, 8}], LineBox[{42, 10}], LineBox[{44, 12}], 
          LineBox[{46, 14}], LineBox[{48, 16}], LineBox[{50, 18}], 
          LineBox[{52, 20}], LineBox[{54, 22}], LineBox[{56, 24}], 
          LineBox[{58, 26}], LineBox[{60, 28}], LineBox[{62, 30}], 
          LineBox[{64, 32}]}, 
         {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
          LineBox[{33, 1}], LineBox[{35, 3}], LineBox[{37, 5}], 
          LineBox[{39, 7}], LineBox[{41, 9}], LineBox[{43, 11}], 
          LineBox[{45, 13}], LineBox[{47, 15}], LineBox[{49, 17}], 
          LineBox[{51, 19}], LineBox[{53, 21}], LineBox[{55, 23}], 
          LineBox[{57, 25}], LineBox[{59, 27}], LineBox[{61, 29}], 
          LineBox[{63, 31}]}}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[2], 
          PointBox[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 
           79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95,
            96}]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", 
        GraphicsComplex[CompressedData["
1:eJzt088rw3Ecx/Elv3+FyGQr1kiMfffLvmM/XpymHFjmV5TEwVpNzcFSCgdF
uezg5GJycZjyMxduNCUHu/m5UbvIXCSl/Pp+PuX9L/CuT+8ePY+f3pXDPtdo
ikwmG/p8X/tnko7fWwb390QPf5gJy1JcXIonpF6ArMeq7eXza6kX433TWTZ5
8CB1OXpu1E/huTupKzB+ZM25dd1LvQLZUU3I449JXYU1RcyWvxWXuhr21rGZ
lyvWqzE7PdKV7mW9Bl3dRcrOvLjUa3FS3rY80c66BlOPgeSAivUG9OWm7njt
rAvwrbrm9+pY12E36O8QRNb1mF8ZjNxoWTdgvcV75jGxboT1Yu90X8e6CfVK
YVJrZL0RsRZT2qKedTMOpy87QwbWRcxslE4keLfALSYzRnlvwrF2563QwHoz
zhcue9t4tyLy6vWpebchEM7NsfFuR/9te0jDuwNlJaqgmXfg6TnoFHjn/84G
v5lJXEBcTCwnVhBXEKuI1cTVxDXEtcQa4gZigVhHrCc2EBuJTcSNxGZikdhC
3ETcTGwlthHbiR3EIP6//796/x92zyfk
         "], {{{}, {}, {}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{34, 2}], 
            Line[{36, 4}], 
            Line[{38, 6}], 
            Line[{40, 8}], 
            Line[{42, 10}], 
            Line[{44, 12}], 
            Line[{46, 14}], 
            Line[{48, 16}], 
            Line[{50, 18}], 
            Line[{52, 20}], 
            Line[{54, 22}], 
            Line[{56, 24}], 
            Line[{58, 26}], 
            Line[{60, 28}], 
            Line[{62, 30}], 
            Line[{64, 32}]}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{33, 1}], 
            Line[{35, 3}], 
            Line[{37, 5}], 
            Line[{39, 7}], 
            Line[{41, 9}], 
            Line[{43, 11}], 
            Line[{45, 13}], 
            Line[{47, 15}], 
            Line[{49, 17}], 
            Line[{51, 19}], 
            Line[{53, 21}], 
            Line[{55, 23}], 
            Line[{57, 25}], 
            Line[{59, 27}], 
            Line[{61, 29}], 
            Line[{63, 31}]}}, {
           Annotation[{
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]], 
             
             Point[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 
              79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 
              95, 96}]}, "Charting`Private`Tag#1"]}}], <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{0., 32.}, {-0.5999986093079864, 1.}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                Opacity[0.3]], 
               Line[{{2., 0.}, {2., -0.3333333333333333}}], 
               Line[{{4., 0.}, {4., -0.48148148148148145`}}], 
               Line[{{6., 0.}, {6., -0.5473251028806584}}], 
               Line[{{8., 0.}, {8., -0.5765889346136259}}], 
               Line[{{10., 0.}, {10., -0.5895950820505005}}], 
               Line[{{12., 0.}, {12., -0.5953755920224446}}], 
               Line[{{14., 0.}, {14., -0.597944707565531}}], 
               Line[{{16., 0.}, {16., -0.5990865366957915}}], 
               Line[{{18., 0.}, {18., -0.5995940163092407}}], 
               Line[{{20., 0.}, {20., -0.599819562804107}}], 
               Line[{{22., 0.}, {22., -0.5999198056907142}}], 
               Line[{{24., 0.}, {24., -0.5999643580847619}}], 
               Line[{{26., 0.}, {26., -0.599984159148783}}], 
               Line[{{28., 0.}, {28., -0.5999929596216813}}], 
               Line[{{30., 0.}, {30., -0.5999968709429695}}], 
               Line[{{32., 0.}, {32., -0.5999986093079864}}]}, {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                Opacity[0.3]], 
               Line[{{1., 0.}, {1., 1.}}], 
               Line[{{3., 0.}, {3., 0.7777777777777778}}], 
               Line[{{5., 0.}, {5., 0.6790123456790124}}], 
               Line[{{7., 0.}, {7., 0.635116598079561}}], 
               Line[{{9., 0.}, {9., 0.6156073769242494}}], 
               Line[{{11., 0.}, {11., 0.6069366119663331}}], 
               Line[{{13., 0.}, {13., 0.6030829386517036}}], 
               Line[{{15., 0.}, {15., 0.6013701949563127}}], 
               Line[{{17., 0.}, {17., 0.600608975536139}}], 
               Line[{{19., 0.}, {19., 0.6002706557938395}}], 
               Line[{{21., 0.}, {21., 0.6001202914639286}}], 
               Line[{{23., 0.}, {23., 0.6000534628728572}}], 
               Line[{{25., 0.}, {25., 0.6000237612768254}}], 
               Line[{{27., 0.}, {27., 0.6000105605674779}}], 
               Line[{{29., 0.}, {29., 0.6000046935855458}}], 
               Line[{{31., 0.}, {31., 0.6000020860380203}}]}}, {
              Annotation[{
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Medium]], {
                 Point[{1., 1.}], 
                 Point[{2., -0.3333333333333333}], 
                 Point[{3., 0.7777777777777778}], 
                 Point[{4., -0.48148148148148145`}], 
                 Point[{5., 0.6790123456790124}], 
                 Point[{6., -0.5473251028806584}], 
                 Point[{7., 0.635116598079561}], 
                 Point[{8., -0.5765889346136259}], 
                 Point[{9., 0.6156073769242494}], 
                 Point[{10., -0.5895950820505005}], 
                 Point[{11., 0.6069366119663331}], 
                 Point[{12., -0.5953755920224446}], 
                 Point[{13., 0.6030829386517036}], 
                 Point[{14., -0.597944707565531}], 
                 Point[{15., 0.6013701949563127}], 
                 Point[{16., -0.5990865366957915}], 
                 Point[{17., 0.600608975536139}], 
                 Point[{18., -0.5995940163092407}], 
                 Point[{19., 0.6002706557938395}], 
                 Point[{20., -0.599819562804107}], 
                 Point[{21., 0.6001202914639286}], 
                 Point[{22., -0.5999198056907142}], 
                 Point[{23., 0.6000534628728572}], 
                 Point[{24., -0.5999643580847619}], 
                 Point[{25., 0.6000237612768254}], 
                 Point[{26., -0.599984159148783}], 
                 Point[{27., 0.6000105605674779}], 
                 Point[{28., -0.5999929596216813}], 
                 Point[{29., 0.6000046935855458}], 
                 Point[{30., -0.5999968709429695}], 
                 Point[{31., 0.6000020860380203}], 
                 Point[{32., -0.5999986093079864}]}}, 
               "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListPlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{0., 32.}, {-0.5999986093079864, 1.}}, 
          "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2], 
             PointSize[Medium]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               Opacity[0.3]], 
              Line[{{2., 0.}, {2., -0.3333333333333333}}], 
              Line[{{4., 0.}, {4., -0.48148148148148145`}}], 
              Line[{{6., 0.}, {6., -0.5473251028806584}}], 
              Line[{{8., 0.}, {8., -0.5765889346136259}}], 
              Line[{{10., 0.}, {10., -0.5895950820505005}}], 
              Line[{{12., 0.}, {12., -0.5953755920224446}}], 
              Line[{{14., 0.}, {14., -0.597944707565531}}], 
              Line[{{16., 0.}, {16., -0.5990865366957915}}], 
              Line[{{18., 0.}, {18., -0.5995940163092407}}], 
              Line[{{20., 0.}, {20., -0.599819562804107}}], 
              Line[{{22., 0.}, {22., -0.5999198056907142}}], 
              Line[{{24., 0.}, {24., -0.5999643580847619}}], 
              Line[{{26., 0.}, {26., -0.599984159148783}}], 
              Line[{{28., 0.}, {28., -0.5999929596216813}}], 
              Line[{{30., 0.}, {30., -0.5999968709429695}}], 
              Line[{{32., 0.}, {32., -0.5999986093079864}}]}, {
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               Opacity[0.3]], 
              Line[{{1., 0.}, {1., 1.}}], 
              Line[{{3., 0.}, {3., 0.7777777777777778}}], 
              Line[{{5., 0.}, {5., 0.6790123456790124}}], 
              Line[{{7., 0.}, {7., 0.635116598079561}}], 
              Line[{{9., 0.}, {9., 0.6156073769242494}}], 
              Line[{{11., 0.}, {11., 0.6069366119663331}}], 
              Line[{{13., 0.}, {13., 0.6030829386517036}}], 
              Line[{{15., 0.}, {15., 0.6013701949563127}}], 
              Line[{{17., 0.}, {17., 0.600608975536139}}], 
              Line[{{19., 0.}, {19., 0.6002706557938395}}], 
              Line[{{21., 0.}, {21., 0.6001202914639286}}], 
              Line[{{23., 0.}, {23., 0.6000534628728572}}], 
              Line[{{25., 0.}, {25., 0.6000237612768254}}], 
              Line[{{27., 0.}, {27., 0.6000105605674779}}], 
              Line[{{29., 0.}, {29., 0.6000046935855458}}], 
              Line[{{31., 0.}, {31., 0.6000020860380203}}]}}, {
             Annotation[{
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2], 
                PointSize[Medium]], {
                Point[{1., 1.}], 
                Point[{2., -0.3333333333333333}], 
                Point[{3., 0.7777777777777778}], 
                Point[{4., -0.48148148148148145`}], 
                Point[{5., 0.6790123456790124}], 
                Point[{6., -0.5473251028806584}], 
                Point[{7., 0.635116598079561}], 
                Point[{8., -0.5765889346136259}], 
                Point[{9., 0.6156073769242494}], 
                Point[{10., -0.5895950820505005}], 
                Point[{11., 0.6069366119663331}], 
                Point[{12., -0.5953755920224446}], 
                Point[{13., 0.6030829386517036}], 
                Point[{14., -0.597944707565531}], 
                Point[{15., 0.6013701949563127}], 
                Point[{16., -0.5990865366957915}], 
                Point[{17., 0.600608975536139}], 
                Point[{18., -0.5995940163092407}], 
                Point[{19., 0.6002706557938395}], 
                Point[{20., -0.599819562804107}], 
                Point[{21., 0.6001202914639286}], 
                Point[{22., -0.5999198056907142}], 
                Point[{23., 0.6000534628728572}], 
                Point[{24., -0.5999643580847619}], 
                Point[{25., 0.6000237612768254}], 
                Point[{26., -0.599984159148783}], 
                Point[{27., 0.6000105605674779}], 
                Point[{28., -0.5999929596216813}], 
                Point[{29., 0.6000046935855458}], 
                Point[{30., -0.5999968709429695}], 
                Point[{31., 0.6000020860380203}], 
                Point[{32., -0.5999986093079864}]}}, 
              "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
        "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListPlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[
     GraphicsComplex[CompressedData["
1:eJzt088rw3Ecx/Elv3+FyGQr1kiMfffLvmM/XpymHFjmV5TEwVpNzcFSCgdF
uezg5GJycZjyMxduNCUHu/m5UbvIXCSl/Pp+PuX9L/CuT+8ePY+f3pXDPtdo
ikwmG/p8X/tnko7fWwb390QPf5gJy1JcXIonpF6ArMeq7eXza6kX433TWTZ5
8CB1OXpu1E/huTupKzB+ZM25dd1LvQLZUU3I449JXYU1RcyWvxWXuhr21rGZ
lyvWqzE7PdKV7mW9Bl3dRcrOvLjUa3FS3rY80c66BlOPgeSAivUG9OWm7njt
rAvwrbrm9+pY12E36O8QRNb1mF8ZjNxoWTdgvcV75jGxboT1Yu90X8e6CfVK
YVJrZL0RsRZT2qKedTMOpy87QwbWRcxslE4keLfALSYzRnlvwrF2563QwHoz
zhcue9t4tyLy6vWpebchEM7NsfFuR/9te0jDuwNlJaqgmXfg6TnoFHjn/84G
v5lJXEBcTCwnVhBXEKuI1cTVxDXEtcQa4gZigVhHrCc2EBuJTcSNxGZikdhC
3ETcTGwlthHbiR3EIP6//796/x92zyfk
      "], {{{}, {}, {}, {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.3]], 
         Line[{34, 2}], 
         Line[{36, 4}], 
         Line[{38, 6}], 
         Line[{40, 8}], 
         Line[{42, 10}], 
         Line[{44, 12}], 
         Line[{46, 14}], 
         Line[{48, 16}], 
         Line[{50, 18}], 
         Line[{52, 20}], 
         Line[{54, 22}], 
         Line[{56, 24}], 
         Line[{58, 26}], 
         Line[{60, 28}], 
         Line[{62, 30}], 
         Line[{64, 32}]}, {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.3]], 
         Line[{33, 1}], 
         Line[{35, 3}], 
         Line[{37, 5}], 
         Line[{39, 7}], 
         Line[{41, 9}], 
         Line[{43, 11}], 
         Line[{45, 13}], 
         Line[{47, 15}], 
         Line[{49, 17}], 
         Line[{51, 19}], 
         Line[{53, 21}], 
         Line[{55, 23}], 
         Line[{57, 25}], 
         Line[{59, 27}], 
         Line[{61, 29}], 
         Line[{63, 31}]}}, {
        Annotation[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2], 
           PointSize[Medium]], 
          
          Point[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
           80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 
           96}]}, "Charting`Private`Tag#1"]}}], <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{0., 32.}, {-0.5999986093079864, 1.}}, 
        "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0., 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2], 
           PointSize[Medium]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{{2., 0.}, {2., -0.3333333333333333}}], 
            Line[{{4., 0.}, {4., -0.48148148148148145`}}], 
            Line[{{6., 0.}, {6., -0.5473251028806584}}], 
            Line[{{8., 0.}, {8., -0.5765889346136259}}], 
            Line[{{10., 0.}, {10., -0.5895950820505005}}], 
            Line[{{12., 0.}, {12., -0.5953755920224446}}], 
            Line[{{14., 0.}, {14., -0.597944707565531}}], 
            Line[{{16., 0.}, {16., -0.5990865366957915}}], 
            Line[{{18., 0.}, {18., -0.5995940163092407}}], 
            Line[{{20., 0.}, {20., -0.599819562804107}}], 
            Line[{{22., 0.}, {22., -0.5999198056907142}}], 
            Line[{{24., 0.}, {24., -0.5999643580847619}}], 
            Line[{{26., 0.}, {26., -0.599984159148783}}], 
            Line[{{28., 0.}, {28., -0.5999929596216813}}], 
            Line[{{30., 0.}, {30., -0.5999968709429695}}], 
            Line[{{32., 0.}, {32., -0.5999986093079864}}]}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{{1., 0.}, {1., 1.}}], 
            Line[{{3., 0.}, {3., 0.7777777777777778}}], 
            Line[{{5., 0.}, {5., 0.6790123456790124}}], 
            Line[{{7., 0.}, {7., 0.635116598079561}}], 
            Line[{{9., 0.}, {9., 0.6156073769242494}}], 
            Line[{{11., 0.}, {11., 0.6069366119663331}}], 
            Line[{{13., 0.}, {13., 0.6030829386517036}}], 
            Line[{{15., 0.}, {15., 0.6013701949563127}}], 
            Line[{{17., 0.}, {17., 0.600608975536139}}], 
            Line[{{19., 0.}, {19., 0.6002706557938395}}], 
            Line[{{21., 0.}, {21., 0.6001202914639286}}], 
            Line[{{23., 0.}, {23., 0.6000534628728572}}], 
            Line[{{25., 0.}, {25., 0.6000237612768254}}], 
            Line[{{27., 0.}, {27., 0.6000105605674779}}], 
            Line[{{29., 0.}, {29., 0.6000046935855458}}], 
            Line[{{31., 0.}, {31., 0.6000020860380203}}]}}, {
           Annotation[{
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]], {
              Point[{1., 1.}], 
              Point[{2., -0.3333333333333333}], 
              Point[{3., 0.7777777777777778}], 
              Point[{4., -0.48148148148148145`}], 
              Point[{5., 0.6790123456790124}], 
              Point[{6., -0.5473251028806584}], 
              Point[{7., 0.635116598079561}], 
              Point[{8., -0.5765889346136259}], 
              Point[{9., 0.6156073769242494}], 
              Point[{10., -0.5895950820505005}], 
              Point[{11., 0.6069366119663331}], 
              Point[{12., -0.5953755920224446}], 
              Point[{13., 0.6030829386517036}], 
              Point[{14., -0.597944707565531}], 
              Point[{15., 0.6013701949563127}], 
              Point[{16., -0.5990865366957915}], 
              Point[{17., 0.600608975536139}], 
              Point[{18., -0.5995940163092407}], 
              Point[{19., 0.6002706557938395}], 
              Point[{20., -0.599819562804107}], 
              Point[{21., 0.6001202914639286}], 
              Point[{22., -0.5999198056907142}], 
              Point[{23., 0.6000534628728572}], 
              Point[{24., -0.5999643580847619}], 
              Point[{25., 0.6000237612768254}], 
              Point[{26., -0.599984159148783}], 
              Point[{27., 0.6000105605674779}], 
              Point[{28., -0.5999929596216813}], 
              Point[{29., 0.6000046935855458}], 
              Point[{30., -0.5999968709429695}], 
              Point[{31., 0.6000020860380203}], 
              Point[{32., -0.5999986093079864}]}}, 
            "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox[
      StyleBox["\"n\"", Small, Italic, StripOnInput -> False], HoldForm], 
     TraditionalForm], None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 32.}, {-0.5999986093079864, 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.801571181339205*^9, {3.8032085200173674`*^9, 3.8032085274779806`*^9}, 
   3.803208908809949*^9, 3.892214194465165*^9, {3.8922142569056673`*^9, 
   3.892214307143277*^9}, {3.8940589576829*^9, 3.894058990375827*^9}, 
   3.897570296025368*^9},
 CellID->104536998,ExpressionUUID->"2fc1b417-46d5-4301-b36d-4acf93a917a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->2128736348,ExpressionUUID->"3b2e1913-da18-4709-9083-abafbacf9586"],

Cell[TextData[{
 "First, rewrite the equation so that the only term on the left is the \
desired output at time ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "a8c29ca3-00c6-4358-831c-f6e7a62372a3"]
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.488103906234375*^9, 3.48810393971875*^9}, {3.488104140328125*^9, 
   3.4881041673125*^9}, {3.611531338124013*^9, 3.611531338810414*^9}, {
   3.611531390602505*^9, 3.6115314201644015`*^9}, {3.611531457108897*^9, 
   3.61153150809029*^9}, {3.652543334836928*^9, 3.6525433407502904`*^9}, 
   3.652610909428463*^9, 3.652610967179493*^9, {3.652611008488428*^9, 
   3.652611045081194*^9}, {3.803393724678489*^9, 3.803393735460227*^9}, {
   3.819895803368499*^9, 3.819895809583375*^9}, 3.830873699882445*^9, {
   3.9162371844667225`*^9, 3.9162371847034855`*^9}},
 CellID->594241816,ExpressionUUID->"2e23cdac-7fa0-466e-9af2-2078062d60a0"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"], "+", " ", 
     RowBox[{
      FractionBox["2", "3"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "86694960-ea4c-4870-ab74-51cc23f790ce"],
 ",\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"-", "1"}], "]"}], " ", "=", " ", "0"}]}], TraditionalForm]],
  ExpressionUUID->"8709b4dc-3333-4d43-a667-4697dc720b1f"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530992842389*^9, 
   3.6115309965083942`*^9}, {3.801571000400376*^9, 3.8015710068699436`*^9}, {
   3.803326849885923*^9, 3.803326865277809*^9}, {3.9162371922186375`*^9, 
   3.9162371931797237`*^9}},
 CellID->1623242962,ExpressionUUID->"d152a73e-043f-452a-9c5d-53fe00e29c65"],

Cell[TextData[{
 "Then recursively, for values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "..."}], 
   TraditionalForm]],ExpressionUUID->"d1dfa2fe-6498-430c-a7ca-4ead6c2d93b6"],
 ", you get"
}], "Text",
 CellChangeTimes->{{3.6115304222596517`*^9, 3.61153044430249*^9}, {
   3.6115305271442657`*^9, 3.611530543883095*^9}, {3.611531071398023*^9, 
   3.611531080467454*^9}, {3.611531522089145*^9, 3.611531525489951*^9}, {
   3.801571020498493*^9, 3.801571021147709*^9}, {3.803326932021551*^9, 
   3.8033269397499604`*^9}, {3.819895823045537*^9, 3.81989583245199*^9}, {
   3.830873706738161*^9, 3.830873714481763*^9}, 3.9162371988597164`*^9, 
   3.918560110962332*^9},
 CellID->212210846,ExpressionUUID->"83558f9a-effa-402d-ba3b-e017d16b997f"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", 
        RowBox[{"-", "1"}], "]"}]}]}], "=", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["2", "3"], " ", "0"}]}], "=", "1"}]}]}], 
   TraditionalForm]],ExpressionUUID->"381a02e4-ff1a-4525-9b76-bbbbba13fbe8"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530458550946*^9, 
   3.6115304702977657`*^9}, {3.611530551874939*^9, 3.6115305837457943`*^9}, {
   3.611531002717205*^9, 3.611531009951464*^9}, {3.6526110707866297`*^9, 
   3.652611071597824*^9}, {3.80157102482687*^9, 3.801571026402695*^9}, {
   3.8308737255259657`*^9, 3.830873751695795*^9}, {3.8311157439011707`*^9, 
   3.831115743901227*^9}},
 CellID->1804834702,ExpressionUUID->"e880cef6-e77b-45fb-a003-e2a9dc34472a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "1", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", "0", "]"}]}]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        FractionBox["2", "3"], " ", "1"}]}], "=", 
      RowBox[{"-", 
       FractionBox["1", "3"]}]}]}]}], TraditionalForm]],ExpressionUUID->
  "915e5762-a799-4476-a963-0daa7bd2081a"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530588035802*^9, 
   3.6115306336190825`*^9}, {3.611531018774212*^9, 3.611531027390346*^9}, {
   3.652611075692998*^9, 3.6526110764105935`*^9}, {3.8015710292939234`*^9, 
   3.801571031721434*^9}, {3.801571100824814*^9, 3.8015711162170906`*^9}, {
   3.83087372418554*^9, 3.83087374906514*^9}, {3.83087420570398*^9, 
   3.830874206200976*^9}, {3.83111575386943*^9, 3.8311157538694897`*^9}},
 CellID->650322639,ExpressionUUID->"2660f347-55a6-4b27-a014-d110bda7d643"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "2", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", "1", "]"}]}]}], "=", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["1", "3"]}], ")"}]}]}], "=", 
      FractionBox["7", "9"]}]}]}], TraditionalForm]],ExpressionUUID->
  "5cf65637-bcd0-498a-8fed-cfe83fc93d72"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530588035802*^9, 
   3.6115306336190825`*^9}, {3.611531018774212*^9, 3.611531027390346*^9}, {
   3.652611075692998*^9, 3.6526110764105935`*^9}, {3.8015710292939234`*^9, 
   3.801571031721434*^9}, {3.801571100824814*^9, 3.8015711162170906`*^9}, {
   3.81989584435049*^9, 3.819895893922999*^9}, {3.830873721873322*^9, 
   3.8308737461746283`*^9}, {3.830874208529484*^9, 3.830874209850881*^9}, {
   3.831115760413149*^9, 3.831115760413211*^9}},
 CellID->1428314090,ExpressionUUID->"e8b84dbe-681e-4773-8a2e-9c9078e26b82"],

Cell["\t\[VerticalEllipsis]", "Text",
 CellChangeTimes->{
  3.80157103911966*^9, {3.80157107112512*^9, 3.801571071127114*^9}},
 CellID->1102704464,ExpressionUUID->"c15aea80-ed53-4155-a528-2aef6166c357"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection",
 CellChangeTimes->{{3.399247677078125*^9, 3.399247682859375*^9}, 
   3.612737317626639*^9, {3.694996659642949*^9, 3.6949966610937395`*^9}, {
   3.69499715809816*^9, 3.694997158644156*^9}, {3.6950803123796625`*^9, 
   3.695080312473262*^9}, {3.7273667258546696`*^9, 3.727366725870303*^9}, {
   3.777849885574727*^9, 3.777849885699628*^9}, {3.778970463661465*^9, 
   3.778970463721305*^9}, {3.803393619955982*^9, 3.803393620028677*^9}, {
   3.803394717759713*^9, 3.80339471781618*^9}},
 CellID->370052838,ExpressionUUID->"6b5bce33-c34d-4886-b17f-050250dd65be"],

Cell[TextData[{
 "Obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "2084032a-736a-4c89-9c6c-08cab1dfd03c"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "3", ",", "..."}], 
   TraditionalForm]],ExpressionUUID->"c48dceb6-c382-47ea-be33-8e3867dc41fd"],
 " given input ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"u", "[", " ", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "793be096-29be-47c0-a5e9-11728d9dcafb"],
 " and the following third-order difference equation and initial conditions"
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
   3.6526109512051954`*^9}, {3.694996672499266*^9, 3.694996754242944*^9}, {
   3.6950802301369896`*^9, 3.695080260541195*^9}, {3.801570939491125*^9, 
   3.80157095853519*^9}, {3.8032084563143063`*^9, 3.803208456701305*^9}, {
   3.8033269057196865`*^9, 3.803326908033674*^9}, {3.80339420198642*^9, 
   3.803394215879613*^9}, {3.803394246481119*^9, 3.803394278731959*^9}, {
   3.891601031000166*^9, 3.891601033574459*^9}, 3.916237206092516*^9},
 CellID->365406554,ExpressionUUID->"4667c141-3c4e-4f8c-af5b-bad46d5fb6b2"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{
      FractionBox["2", "3"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}]}], "=", 
    RowBox[{"x", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "be7fced5-936e-46b5-897f-bba9e2b48da6"],
 ",\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "3"}], "]"}], "=", 
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"-", "2"}], "]"}], "=", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"-", "1"}], "]"}], "=", "0"}]}]}], TraditionalForm]],
  ExpressionUUID->"ca5fce3b-2c85-4515-ac26-33738d471ac9"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.48810448403125*^9, 3.488104486015625*^9}, 3.61273640209794*^9, {
   3.65261095986314*^9, 3.65261096145433*^9}, {3.803208427883411*^9, 
   3.803208431876732*^9}, {3.803394232126576*^9, 3.803394240907795*^9}, {
   3.803394287000309*^9, 3.803394315891756*^9}, {3.830873770371336*^9, 
   3.830873785372699*^9}},
 CellID->1732206305,ExpressionUUID->"f7932127-5690-43b6-9fde-2bc4c608ed4f"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.694996768752851*^9, 3.694996771186438*^9}},
 CellID->1903049403,ExpressionUUID->"b1604aa2-f28b-45a4-9c23-b022a9b6bae2"],

Cell[TextData[{
 "Using ",
 ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"],
 ":"
}], "Text",
 CellChangeTimes->{{3.696804408076399*^9, 3.696804430009717*^9}, {
   3.696804568052347*^9, 3.6968045688323402`*^9}, {3.803208588216113*^9, 
   3.803208637208024*^9}, {3.803208760414318*^9, 3.803208809093091*^9}, 
   3.803393826592325*^9, {3.8033938920406876`*^9, 3.803393902325892*^9}, {
   3.803394534562505*^9, 3.803394544451735*^9}, {3.8308737954708138`*^9, 
   3.830873807038251*^9}, {3.902782132759501*^9, 3.902782132760502*^9}, {
   3.9235681675371494`*^9, 3.9235681675371494`*^9}},
 CellID->2077361450,ExpressionUUID->"b66a6836-1bbd-484d-9692-65e48ca15c45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RecurrenceTable", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], "-", 
       RowBox[{
        FractionBox["2", "3"], 
        RowBox[{"y", "[", 
         RowBox[{"n", "-", "3"}], "]"}]}]}], "\[Equal]", 
      RowBox[{"UnitStep", "[", "n", "]"}]}], ",", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"-", "3"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"-", "2"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"-", "1"}], "]"}], "==", "0"}]}], "}"}], ",", 
   RowBox[{"y", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696804447216297*^9, 3.696804544278252*^9}, {
  3.7778517935885344`*^9, 3.777851793697913*^9}, {3.800833877287288*^9, 
  3.800833878270652*^9}, {3.801571123098679*^9, 3.801571126289103*^9}, {
  3.803208854147528*^9, 3.8032088576781263`*^9}, {3.803394549068482*^9, 
  3.8033945938277054`*^9}},
 CellID->424757224,ExpressionUUID->"0a93bfbe-2710-4ec6-b074-10e6ee9d2df8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1", ",", 
   FractionBox["5", "3"], ",", 
   FractionBox["5", "3"], ",", 
   FractionBox["5", "3"], ",", 
   FractionBox["19", "9"], ",", 
   FractionBox["19", "9"], ",", 
   FractionBox["19", "9"], ",", 
   FractionBox["65", "27"]}], "}"}]], "Output",
 CellChangeTimes->{{3.696804533093196*^9, 3.6968045560405016`*^9}, 
   3.777851794986407*^9, 3.8008338792919226`*^9, {3.80157112959828*^9, 
   3.801571140830158*^9}, 3.803208524088541*^9, 3.803208859132229*^9, 
   3.80339459503964*^9, 3.819895965355692*^9, 3.892214315591427*^9, 
   3.897570318584659*^9},
 CellID->69304788,ExpressionUUID->"7e6a0d21-3ac3-49af-9b5a-081e2476e1e8"]
}, Open  ]],

Cell[TextData[{
 "This plots the output for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "n", "\[LessEqual]", "31"}], 
   TraditionalForm]],ExpressionUUID->"dce7d26c-d660-46c8-aca1-dc1fdb9c4d63"],
 ":"
}], "Text",
 CellChangeTimes->{{3.801571154086228*^9, 3.80157116300736*^9}, {
  3.803208874031022*^9, 3.8032089060204077`*^9}},
 CellID->659021140,ExpressionUUID->"92b3d9ba-cc91-45fc-8b83-f2b68f3a8877"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["4", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1856", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    Evaluate[
     RecurrenceTable[
      Sequence[{$CellContext`y[$CellContext`n] - (2/
          3) $CellContext`y[$CellContext`n - 3] == 
        UnitStep[$CellContext`n], $CellContext`y[-3] == 0, $CellContext`y[-2] == 
        0, $CellContext`y[-1] == 0}, 
       $CellContext`y[$CellContext`n], {$CellContext`n, 0, 31}]]], Filling -> 
    0, PlotStyle -> PointSize[Medium], AxesLabel -> {
      Style["n", Small, Italic], None}],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.801571165124877*^9, 3.801571179167939*^9}, {
   3.8032085062997203`*^9, 3.8032085186845274`*^9}, {3.803208870821602*^9, 
   3.803208902520744*^9}, {3.8033946133201084`*^9, 3.803394638078054*^9}, {
   3.805059531709744*^9, 3.805059532068779*^9}, 3.819895960398281*^9, 
   3.8916010078430767`*^9, {3.892214321548287*^9, 3.892214362413413*^9}, {
   3.894058997440305*^9, 3.894059024314516*^9}},
 CellID->1595132401,ExpressionUUID->"1868e212-e9ad-4a95-bcfc-3f61dd7bcfa2"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[GraphicsComplexBox[CompressedData["
1:eJzt071Kw2AUxvGgVUsXMxTt0KENJZRSQ5v0I+lXDoKTuDiLVKE4uvQKvIAO
gig4u+jq4K6r4OQoQl3aQRQcSqdafF8h/1vQBw6H33KWw5M9PN7tLRiG0f2e
+f7JRxjdhkQdh025uZ5nqpyEU3BagsHQHwz13QxswTmxb8+f9jcXlW04Dxfk
weq9jp5jykXYgUuysf4+vnxbUi7DLuxJf/Xr8+hiWbkCV+Ga7CQm21vminId
9uFAvL0r1+lqN+Am3JLH0/ts/0y7DXfgUF4OTtYmd9oC//5dR6KMwyachFNw
Gs7AFpyDbTgPF+Ai7MAluAy7sAdX4Cpcg+uwDwdwA27CLbgNd+AQFvi//3+1
/zNQ1AE0
       "], {{{}, {}, {}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
          LineBox[{33, 1}], LineBox[{34, 2}], LineBox[{35, 3}], 
          LineBox[{36, 4}], LineBox[{37, 5}], LineBox[{38, 6}], 
          LineBox[{39, 7}], LineBox[{40, 8}], LineBox[{41, 9}], 
          LineBox[{42, 10}], LineBox[{43, 11}], LineBox[{44, 12}], 
          LineBox[{45, 13}], LineBox[{46, 14}], LineBox[{47, 15}], 
          LineBox[{48, 16}], LineBox[{49, 17}], LineBox[{50, 18}], 
          LineBox[{51, 19}], LineBox[{52, 20}], LineBox[{53, 21}], 
          LineBox[{54, 22}], LineBox[{55, 23}], LineBox[{56, 24}], 
          LineBox[{57, 25}], LineBox[{58, 26}], LineBox[{59, 27}], 
          LineBox[{60, 28}], LineBox[{61, 29}], LineBox[{62, 30}], 
          LineBox[{63, 31}], LineBox[{64, 32}]}}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[2], 
          PointBox[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 
           79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95,
            96}]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", 
        GraphicsComplex[CompressedData["
1:eJzt071Kw2AUxvGgVUsXMxTt0KENJZRSQ5v0I+lXDoKTuDiLVKE4uvQKvIAO
gig4u+jq4K6r4OQoQl3aQRQcSqdafF8h/1vQBw6H33KWw5M9PN7tLRiG0f2e
+f7JRxjdhkQdh025uZ5nqpyEU3BagsHQHwz13QxswTmxb8+f9jcXlW04Dxfk
weq9jp5jykXYgUuysf4+vnxbUi7DLuxJf/Xr8+hiWbkCV+Ga7CQm21vminId
9uFAvL0r1+lqN+Am3JLH0/ts/0y7DXfgUF4OTtYmd9oC//5dR6KMwyachFNw
Gs7AFpyDbTgPF+Ai7MAluAy7sAdX4Cpcg+uwDwdwA27CLbgNd+AQFvi//3+1
/zNQ1AE0
         "], {{{}, {}, {}, {}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{33, 1}], 
            Line[{34, 2}], 
            Line[{35, 3}], 
            Line[{36, 4}], 
            Line[{37, 5}], 
            Line[{38, 6}], 
            Line[{39, 7}], 
            Line[{40, 8}], 
            Line[{41, 9}], 
            Line[{42, 10}], 
            Line[{43, 11}], 
            Line[{44, 12}], 
            Line[{45, 13}], 
            Line[{46, 14}], 
            Line[{47, 15}], 
            Line[{48, 16}], 
            Line[{49, 17}], 
            Line[{50, 18}], 
            Line[{51, 19}], 
            Line[{52, 20}], 
            Line[{53, 21}], 
            Line[{54, 22}], 
            Line[{55, 23}], 
            Line[{56, 24}], 
            Line[{57, 25}], 
            Line[{58, 26}], 
            Line[{59, 27}], 
            Line[{60, 28}], 
            Line[{61, 29}], 
            Line[{62, 30}], 
            Line[{63, 31}], 
            Line[{64, 32}]}}, {
           Annotation[{
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]], 
             
             Point[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 
              79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 
              95, 96}]}, "Charting`Private`Tag#1"]}}], <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{0., 32.}, {0, 2.965316940168335}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {}, {
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                Opacity[0.3]], 
               Line[{{1., 0.}, {1., 1.}}], 
               Line[{{2., 0.}, {2., 1.}}], 
               Line[{{3., 0.}, {3., 1.}}], 
               Line[{{4., 0.}, {4., 1.6666666666666667`}}], 
               Line[{{5., 0.}, {5., 1.6666666666666667`}}], 
               Line[{{6., 0.}, {6., 1.6666666666666667`}}], 
               Line[{{7., 0.}, {7., 2.111111111111111}}], 
               Line[{{8., 0.}, {8., 2.111111111111111}}], 
               Line[{{9., 0.}, {9., 2.111111111111111}}], 
               Line[{{10., 0.}, {10., 2.4074074074074074`}}], 
               Line[{{11., 0.}, {11., 2.4074074074074074`}}], 
               Line[{{12., 0.}, {12., 2.4074074074074074`}}], 
               Line[{{13., 0.}, {13., 2.6049382716049383`}}], 
               Line[{{14., 0.}, {14., 2.6049382716049383`}}], 
               Line[{{15., 0.}, {15., 2.6049382716049383`}}], 
               Line[{{16., 0.}, {16., 2.736625514403292}}], 
               Line[{{17., 0.}, {17., 2.736625514403292}}], 
               Line[{{18., 0.}, {18., 2.736625514403292}}], 
               Line[{{19., 0.}, {19., 2.824417009602195}}], 
               Line[{{20., 0.}, {20., 2.824417009602195}}], 
               Line[{{21., 0.}, {21., 2.824417009602195}}], 
               Line[{{22., 0.}, {22., 2.88294467306813}}], 
               Line[{{23., 0.}, {23., 2.88294467306813}}], 
               Line[{{24., 0.}, {24., 2.88294467306813}}], 
               Line[{{25., 0.}, {25., 2.921963115378753}}], 
               Line[{{26., 0.}, {26., 2.921963115378753}}], 
               Line[{{27., 0.}, {27., 2.921963115378753}}], 
               Line[{{28., 0.}, {28., 2.947975410252502}}], 
               Line[{{29., 0.}, {29., 2.947975410252502}}], 
               Line[{{30., 0.}, {30., 2.947975410252502}}], 
               Line[{{31., 0.}, {31., 2.965316940168335}}], 
               Line[{{32., 0.}, {32., 2.965316940168335}}]}}, {
              Annotation[{
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Medium]], {
                 Point[{1., 1.}], 
                 Point[{2., 1.}], 
                 Point[{3., 1.}], 
                 Point[{4., 1.6666666666666667`}], 
                 Point[{5., 1.6666666666666667`}], 
                 Point[{6., 1.6666666666666667`}], 
                 Point[{7., 2.111111111111111}], 
                 Point[{8., 2.111111111111111}], 
                 Point[{9., 2.111111111111111}], 
                 Point[{10., 2.4074074074074074`}], 
                 Point[{11., 2.4074074074074074`}], 
                 Point[{12., 2.4074074074074074`}], 
                 Point[{13., 2.6049382716049383`}], 
                 Point[{14., 2.6049382716049383`}], 
                 Point[{15., 2.6049382716049383`}], 
                 Point[{16., 2.736625514403292}], 
                 Point[{17., 2.736625514403292}], 
                 Point[{18., 2.736625514403292}], 
                 Point[{19., 2.824417009602195}], 
                 Point[{20., 2.824417009602195}], 
                 Point[{21., 2.824417009602195}], 
                 Point[{22., 2.88294467306813}], 
                 Point[{23., 2.88294467306813}], 
                 Point[{24., 2.88294467306813}], 
                 Point[{25., 2.921963115378753}], 
                 Point[{26., 2.921963115378753}], 
                 Point[{27., 2.921963115378753}], 
                 Point[{28., 2.947975410252502}], 
                 Point[{29., 2.947975410252502}], 
                 Point[{30., 2.947975410252502}], 
                 Point[{31., 2.965316940168335}], 
                 Point[{32., 2.965316940168335}]}}, 
               "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListPlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{0., 32.}, {0, 2.965316940168335}}, 
          "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2], 
             PointSize[Medium]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {}, {
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               Opacity[0.3]], 
              Line[{{1., 0.}, {1., 1.}}], 
              Line[{{2., 0.}, {2., 1.}}], 
              Line[{{3., 0.}, {3., 1.}}], 
              Line[{{4., 0.}, {4., 1.6666666666666667`}}], 
              Line[{{5., 0.}, {5., 1.6666666666666667`}}], 
              Line[{{6., 0.}, {6., 1.6666666666666667`}}], 
              Line[{{7., 0.}, {7., 2.111111111111111}}], 
              Line[{{8., 0.}, {8., 2.111111111111111}}], 
              Line[{{9., 0.}, {9., 2.111111111111111}}], 
              Line[{{10., 0.}, {10., 2.4074074074074074`}}], 
              Line[{{11., 0.}, {11., 2.4074074074074074`}}], 
              Line[{{12., 0.}, {12., 2.4074074074074074`}}], 
              Line[{{13., 0.}, {13., 2.6049382716049383`}}], 
              Line[{{14., 0.}, {14., 2.6049382716049383`}}], 
              Line[{{15., 0.}, {15., 2.6049382716049383`}}], 
              Line[{{16., 0.}, {16., 2.736625514403292}}], 
              Line[{{17., 0.}, {17., 2.736625514403292}}], 
              Line[{{18., 0.}, {18., 2.736625514403292}}], 
              Line[{{19., 0.}, {19., 2.824417009602195}}], 
              Line[{{20., 0.}, {20., 2.824417009602195}}], 
              Line[{{21., 0.}, {21., 2.824417009602195}}], 
              Line[{{22., 0.}, {22., 2.88294467306813}}], 
              Line[{{23., 0.}, {23., 2.88294467306813}}], 
              Line[{{24., 0.}, {24., 2.88294467306813}}], 
              Line[{{25., 0.}, {25., 2.921963115378753}}], 
              Line[{{26., 0.}, {26., 2.921963115378753}}], 
              Line[{{27., 0.}, {27., 2.921963115378753}}], 
              Line[{{28., 0.}, {28., 2.947975410252502}}], 
              Line[{{29., 0.}, {29., 2.947975410252502}}], 
              Line[{{30., 0.}, {30., 2.947975410252502}}], 
              Line[{{31., 0.}, {31., 2.965316940168335}}], 
              Line[{{32., 0.}, {32., 2.965316940168335}}]}}, {
             Annotation[{
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2], 
                PointSize[Medium]], {
                Point[{1., 1.}], 
                Point[{2., 1.}], 
                Point[{3., 1.}], 
                Point[{4., 1.6666666666666667`}], 
                Point[{5., 1.6666666666666667`}], 
                Point[{6., 1.6666666666666667`}], 
                Point[{7., 2.111111111111111}], 
                Point[{8., 2.111111111111111}], 
                Point[{9., 2.111111111111111}], 
                Point[{10., 2.4074074074074074`}], 
                Point[{11., 2.4074074074074074`}], 
                Point[{12., 2.4074074074074074`}], 
                Point[{13., 2.6049382716049383`}], 
                Point[{14., 2.6049382716049383`}], 
                Point[{15., 2.6049382716049383`}], 
                Point[{16., 2.736625514403292}], 
                Point[{17., 2.736625514403292}], 
                Point[{18., 2.736625514403292}], 
                Point[{19., 2.824417009602195}], 
                Point[{20., 2.824417009602195}], 
                Point[{21., 2.824417009602195}], 
                Point[{22., 2.88294467306813}], 
                Point[{23., 2.88294467306813}], 
                Point[{24., 2.88294467306813}], 
                Point[{25., 2.921963115378753}], 
                Point[{26., 2.921963115378753}], 
                Point[{27., 2.921963115378753}], 
                Point[{28., 2.947975410252502}], 
                Point[{29., 2.947975410252502}], 
                Point[{30., 2.947975410252502}], 
                Point[{31., 2.965316940168335}], 
                Point[{32., 2.965316940168335}]}}, 
              "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
        "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListPlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[
     GraphicsComplex[CompressedData["
1:eJzt071Kw2AUxvGgVUsXMxTt0KENJZRSQ5v0I+lXDoKTuDiLVKE4uvQKvIAO
gig4u+jq4K6r4OQoQl3aQRQcSqdafF8h/1vQBw6H33KWw5M9PN7tLRiG0f2e
+f7JRxjdhkQdh025uZ5nqpyEU3BagsHQHwz13QxswTmxb8+f9jcXlW04Dxfk
weq9jp5jykXYgUuysf4+vnxbUi7DLuxJf/Xr8+hiWbkCV+Ga7CQm21vminId
9uFAvL0r1+lqN+Am3JLH0/ts/0y7DXfgUF4OTtYmd9oC//5dR6KMwyachFNw
Gs7AFpyDbTgPF+Ai7MAluAy7sAdX4Cpcg+uwDwdwA27CLbgNd+AQFvi//3+1
/zNQ1AE0
      "], {{{}, {}, {}, {}, {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.3]], 
         Line[{33, 1}], 
         Line[{34, 2}], 
         Line[{35, 3}], 
         Line[{36, 4}], 
         Line[{37, 5}], 
         Line[{38, 6}], 
         Line[{39, 7}], 
         Line[{40, 8}], 
         Line[{41, 9}], 
         Line[{42, 10}], 
         Line[{43, 11}], 
         Line[{44, 12}], 
         Line[{45, 13}], 
         Line[{46, 14}], 
         Line[{47, 15}], 
         Line[{48, 16}], 
         Line[{49, 17}], 
         Line[{50, 18}], 
         Line[{51, 19}], 
         Line[{52, 20}], 
         Line[{53, 21}], 
         Line[{54, 22}], 
         Line[{55, 23}], 
         Line[{56, 24}], 
         Line[{57, 25}], 
         Line[{58, 26}], 
         Line[{59, 27}], 
         Line[{60, 28}], 
         Line[{61, 29}], 
         Line[{62, 30}], 
         Line[{63, 31}], 
         Line[{64, 32}]}}, {
        Annotation[{
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2], 
           PointSize[Medium]], 
          
          Point[{65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
           80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 
           96}]}, "Charting`Private`Tag#1"]}}], <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{0., 32.}, {0, 2.965316940168335}}, 
        "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0., 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2], 
           PointSize[Medium]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {{{}, {}, {}, {}, {
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[0.3]], 
            Line[{{1., 0.}, {1., 1.}}], 
            Line[{{2., 0.}, {2., 1.}}], 
            Line[{{3., 0.}, {3., 1.}}], 
            Line[{{4., 0.}, {4., 1.6666666666666667`}}], 
            Line[{{5., 0.}, {5., 1.6666666666666667`}}], 
            Line[{{6., 0.}, {6., 1.6666666666666667`}}], 
            Line[{{7., 0.}, {7., 2.111111111111111}}], 
            Line[{{8., 0.}, {8., 2.111111111111111}}], 
            Line[{{9., 0.}, {9., 2.111111111111111}}], 
            Line[{{10., 0.}, {10., 2.4074074074074074`}}], 
            Line[{{11., 0.}, {11., 2.4074074074074074`}}], 
            Line[{{12., 0.}, {12., 2.4074074074074074`}}], 
            Line[{{13., 0.}, {13., 2.6049382716049383`}}], 
            Line[{{14., 0.}, {14., 2.6049382716049383`}}], 
            Line[{{15., 0.}, {15., 2.6049382716049383`}}], 
            Line[{{16., 0.}, {16., 2.736625514403292}}], 
            Line[{{17., 0.}, {17., 2.736625514403292}}], 
            Line[{{18., 0.}, {18., 2.736625514403292}}], 
            Line[{{19., 0.}, {19., 2.824417009602195}}], 
            Line[{{20., 0.}, {20., 2.824417009602195}}], 
            Line[{{21., 0.}, {21., 2.824417009602195}}], 
            Line[{{22., 0.}, {22., 2.88294467306813}}], 
            Line[{{23., 0.}, {23., 2.88294467306813}}], 
            Line[{{24., 0.}, {24., 2.88294467306813}}], 
            Line[{{25., 0.}, {25., 2.921963115378753}}], 
            Line[{{26., 0.}, {26., 2.921963115378753}}], 
            Line[{{27., 0.}, {27., 2.921963115378753}}], 
            Line[{{28., 0.}, {28., 2.947975410252502}}], 
            Line[{{29., 0.}, {29., 2.947975410252502}}], 
            Line[{{30., 0.}, {30., 2.947975410252502}}], 
            Line[{{31., 0.}, {31., 2.965316940168335}}], 
            Line[{{32., 0.}, {32., 2.965316940168335}}]}}, {
           Annotation[{
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Medium]], {
              Point[{1., 1.}], 
              Point[{2., 1.}], 
              Point[{3., 1.}], 
              Point[{4., 1.6666666666666667`}], 
              Point[{5., 1.6666666666666667`}], 
              Point[{6., 1.6666666666666667`}], 
              Point[{7., 2.111111111111111}], 
              Point[{8., 2.111111111111111}], 
              Point[{9., 2.111111111111111}], 
              Point[{10., 2.4074074074074074`}], 
              Point[{11., 2.4074074074074074`}], 
              Point[{12., 2.4074074074074074`}], 
              Point[{13., 2.6049382716049383`}], 
              Point[{14., 2.6049382716049383`}], 
              Point[{15., 2.6049382716049383`}], 
              Point[{16., 2.736625514403292}], 
              Point[{17., 2.736625514403292}], 
              Point[{18., 2.736625514403292}], 
              Point[{19., 2.824417009602195}], 
              Point[{20., 2.824417009602195}], 
              Point[{21., 2.824417009602195}], 
              Point[{22., 2.88294467306813}], 
              Point[{23., 2.88294467306813}], 
              Point[{24., 2.88294467306813}], 
              Point[{25., 2.921963115378753}], 
              Point[{26., 2.921963115378753}], 
              Point[{27., 2.921963115378753}], 
              Point[{28., 2.947975410252502}], 
              Point[{29., 2.947975410252502}], 
              Point[{30., 2.947975410252502}], 
              Point[{31., 2.965316940168335}], 
              Point[{32., 2.965316940168335}]}}, "Charting`Private`Tag#1"]}}, 
        "GCFlag" -> True|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListPlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox[
      StyleBox["\"n\"", Small, Italic, StripOnInput -> False], HoldForm], 
     TraditionalForm], None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "IncludeHighlighting" -> "CurrentPoint", 
    "HighlightStyle" -> Automatic, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 32.}, {0, 2.965316940168335}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.894059014878719*^9, 3.894059026905066*^9}, 
   3.897570320876211*^9},
 CellID->576954319,ExpressionUUID->"bd3ddbc0-084c-42e8-abc0-18d11e621f29"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->204414459,ExpressionUUID->"abe6233f-1d34-4290-a2cd-b29f16c2845b"],

Cell[TextData[{
 "First, rewrite the equation so that the only term on the left is the \
desired output at time ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7dda7ca8-5b49-4687-9019-a3d6e8e5beb8"]
}], "Text",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.488103906234375*^9, 3.48810393971875*^9}, {3.488104140328125*^9, 
   3.4881041673125*^9}, {3.611531338124013*^9, 3.611531338810414*^9}, {
   3.611531390602505*^9, 3.6115314201644015`*^9}, {3.611531457108897*^9, 
   3.61153150809029*^9}, {3.652543334836928*^9, 3.6525433407502904`*^9}, 
   3.652610909428463*^9, 3.652610967179493*^9, {3.652611008488428*^9, 
   3.652611045081194*^9}, {3.803393724678489*^9, 3.803393735460227*^9}, {
   3.819895974681221*^9, 3.819895979886056*^9}, 3.8308738162017517`*^9, {
   3.9162372218071327`*^9, 3.916237221946842*^9}},
 CellID->1767460860,ExpressionUUID->"a54ed0fc-46ab-45a5-9666-ba45d570114d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "=", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["2", "3"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "05824aa0-c5ed-4cb5-990f-e709cd49e98a"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530992842389*^9, 
   3.6115309965083942`*^9}, {3.801571000400376*^9, 3.8015710068699436`*^9}, {
   3.803326849885923*^9, 3.803326865277809*^9}, {3.803394328052215*^9, 
   3.803394351685069*^9}, {3.83087382177667*^9, 3.830873829147031*^9}},
 CellID->1720868716,ExpressionUUID->"5a2ff46b-40ed-48e3-a042-339682aed8e6"],

Cell[TextData[{
 "Then for values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "..."}], TraditionalForm]],
  ExpressionUUID->"83344c46-3617-47bd-9a74-d672d4a3b4c9"],
 ", you get"
}], "Text",
 CellChangeTimes->{{3.6115304222596517`*^9, 3.61153044430249*^9}, {
   3.6115305271442657`*^9, 3.611530543883095*^9}, {3.611531071398023*^9, 
   3.611531080467454*^9}, {3.611531522089145*^9, 3.611531525489951*^9}, {
   3.801571020498493*^9, 3.801571021147709*^9}, {3.803326932021551*^9, 
   3.8033269397499604`*^9}, {3.830873834672921*^9, 3.830873841750237*^9}, 
   3.91623722449597*^9},
 CellID->330752016,ExpressionUUID->"81a06bec-7158-4550-91be-a443d7467b9f"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", 
        RowBox[{"-", "3"}], "]"}]}]}], "=", "1"}]}], TraditionalForm]],
  ExpressionUUID->"e92c3cbf-3d7d-4dcf-ba00-2e6850fc6fb5"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530458550946*^9, 
   3.6115304702977657`*^9}, {3.611530551874939*^9, 3.6115305837457943`*^9}, {
   3.611531002717205*^9, 3.611531009951464*^9}, {3.6526110707866297`*^9, 
   3.652611071597824*^9}, {3.80157102482687*^9, 3.801571026402695*^9}, {
   3.803394389732315*^9, 3.803394399660265*^9}, {3.803394462246965*^9, 
   3.803394462341715*^9}, {3.830873847875342*^9, 3.830873856775647*^9}},
 CellID->1261454476,ExpressionUUID->"706da941-225b-465d-b714-befbb4976fa1"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "1", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", 
        RowBox[{"-", "2"}], "]"}]}]}], "=", "1"}]}], TraditionalForm]],
  ExpressionUUID->"8a8052bc-fd5e-498a-952b-1e01d9bc4a8b"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530588035802*^9, 
   3.6115306336190825`*^9}, {3.611531018774212*^9, 3.611531027390346*^9}, {
   3.652611075692998*^9, 3.6526110764105935`*^9}, {3.8015710292939234`*^9, 
   3.801571031721434*^9}, {3.801571100824814*^9, 3.8015711162170906`*^9}, {
   3.803394379586615*^9, 3.803394379586615*^9}, {3.803394416756687*^9, 
   3.803394434488221*^9}, {3.8033944681781855`*^9, 3.80339447574484*^9}, {
   3.830873859529496*^9, 3.830873868334969*^9}},
 CellID->1306814948,ExpressionUUID->"72a31799-5053-4688-8a40-9af07e71c299"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "2", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", 
        RowBox[{"-", "1"}], "]"}]}]}], "=", "1"}]}], TraditionalForm]],
  ExpressionUUID->"6d537297-aad6-46a8-ba5a-9c8b7f83b8b7"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530588035802*^9, 
   3.6115306336190825`*^9}, {3.611531018774212*^9, 3.611531027390346*^9}, {
   3.652611075692998*^9, 3.6526110764105935`*^9}, {3.8015710292939234`*^9, 
   3.801571031721434*^9}, {3.801571100824814*^9, 3.8015711162170906`*^9}, {
   3.803394379586615*^9, 3.803394379586615*^9}, {3.803394416756687*^9, 
   3.803394488377844*^9}, {3.830873870414995*^9, 3.8308738755083637`*^9}},
 CellID->1323573167,ExpressionUUID->"58dce830-2b8a-4cd2-84e0-2e6cdae91503"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "3", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["2", "3"], 
       RowBox[{"y", "[", "0", "]"}]}]}], "=", 
     FractionBox["5", "3"]}]}], TraditionalForm]],ExpressionUUID->
  "d1d03f9a-1317-4565-98eb-4cbd01613441"]
}], "Text",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.488103967546875*^9, 3.48810398128125*^9}, {3.488104176984375*^9, 
   3.48810419259375*^9}, {3.4881050325*^9, 3.488105034703125*^9}, {
   3.525444868*^9, 3.525444872359375*^9}, {3.6115302908461456`*^9, 
   3.611530303248167*^9}, 3.611530357472738*^9, {3.611530588035802*^9, 
   3.6115306336190825`*^9}, {3.611531018774212*^9, 3.611531027390346*^9}, {
   3.652611075692998*^9, 3.6526110764105935`*^9}, {3.8015710292939234`*^9, 
   3.801571031721434*^9}, {3.801571100824814*^9, 3.8015711162170906`*^9}, {
   3.803394379586615*^9, 3.803394379586615*^9}, {3.803394416756687*^9, 
   3.803394519561214*^9}, {3.830873877566473*^9, 3.830873887279143*^9}},
 CellID->1658602143,ExpressionUUID->"6833aeab-72f8-4057-8c5f-a2b5420a66d2"],

Cell["\t\[VerticalEllipsis]", "Text",
 CellChangeTimes->{
  3.80157103911966*^9, {3.80157107112512*^9, 3.801571071127114*^9}},
 CellID->1788479341,ExpressionUUID->"57fff9a9-0f0c-42b3-852c-dfd5acb824d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "SummarySection",
 CellID->643677128,ExpressionUUID->"228d3a38-4e2f-4b48-997b-5c69da92c70c"],

Cell["\<\
Select LSI systems were presented along with their common practical \
applications.\
\>", "SummaryNote",
 CellChangeTimes->{{3.819896087775447*^9, 3.819896095651218*^9}, {
   3.8198963019447937`*^9, 3.8198963280914197`*^9}, {3.8198965953623075`*^9, 
   3.8198966604161067`*^9}, {3.830424352602648*^9, 3.8304243580755606`*^9}, 
   3.830873900760206*^9, {3.9001004202471957`*^9, 3.9001004339320717`*^9}, {
   3.9156245581906586`*^9, 3.9156245602322235`*^9}, {3.915624608435351*^9, 
   3.9156246085952578`*^9}, {3.915630889584297*^9, 3.915630896011205*^9}},
 CellID->1406360357,ExpressionUUID->"149f85f1-5da3-4cd4-9b7e-e1593fdd60fd"],

Cell["\<\
Such systems are modeled by ordinary constant coefficient difference equations\
\>", "SummaryNote",
 CellChangeTimes->{{3.8198965581382904`*^9, 3.8198965897295723`*^9}, {
   3.830873908098098*^9, 3.830873914493536*^9}, 3.9162372311662807`*^9},
 CellID->1493501217,ExpressionUUID->"4b7e400c-bf92-4d2b-9956-ce913bab76e0"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "=", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}], ")"}]}]}],
    FontSize->14], TraditionalForm]],ExpressionUUID->
  "3dca14c7-9db0-469b-a6eb-8515190fc459"],
 "\t\t",
 Cell[BoxData[
  GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1L9KglEYx/GXJkcLKQspk5CIiDQ1TfN90rqBhsaGoLkbkHhvoWa1xoaG
WqKiP9RQd9Da0FLQH6GWGqr3PP3OcH5X0OAXRD4+eDz4Hs7o2sbyeo/neY3w
Zd7/6vjtlunFxwdyfmZ6hiPSapqso1LRrGPS0KzjNE+Iu35Sfr5Nr3BKvj5N
T/CYrGh3cFr6tGt4XAa1E3hCRrR7eBK+hKckqu3C09Kv3cAZGdYu4Kz0aofw
jHhOOUloTczzEtf24IIMaafwLH2/SOuXsL8DeA7r78Nl7PcIrtB+58lVrBfA
vmxvma5gcX8/EBnQbjFfkI930wPmC3JybHrEvCa+9oZ5TTY1+zzr7vMO6lLV
7HxRdtomOCB7S7KqWXfsubTR/xkhR8kxcpycICfJKfIYOU0eJ0+QJ8lT5Gly
hpwl58h5coFcJJfIc+QyuUKeJ1fJPllcB+Tw/Llzcnj+3Dk5PH/unByeP3dO
Ds+f6+792L0f/+f9+AvEizQ3
     "], {{{}, {}, {}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
        LineBox[{43, 1}], LineBox[{44, 2}], LineBox[{45, 3}], 
        LineBox[{46, 4}], LineBox[{47, 5}], LineBox[{48, 6}], 
        LineBox[{49, 7}], LineBox[{50, 8}], LineBox[{51, 9}], 
        LineBox[{52, 10}], LineBox[{53, 11}], LineBox[{54, 12}], 
        LineBox[{55, 13}], LineBox[{56, 14}], LineBox[{57, 15}], 
        LineBox[{58, 16}], LineBox[{59, 17}], LineBox[{60, 18}], 
        LineBox[{61, 20}], LineBox[{62, 21}], LineBox[{63, 22}], 
        LineBox[{64, 24}], LineBox[{65, 25}], LineBox[{66, 26}], 
        LineBox[{67, 27}], LineBox[{68, 28}], LineBox[{69, 29}], 
        LineBox[{70, 30}], LineBox[{71, 31}], LineBox[{72, 32}], 
        LineBox[{73, 33}], LineBox[{74, 34}], LineBox[{75, 35}], 
        LineBox[{76, 36}], LineBox[{77, 37}], LineBox[{78, 38}], 
        LineBox[{79, 39}], LineBox[{80, 40}], LineBox[{81, 41}], 
        LineBox[{82, 42}]}}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
       AbsoluteThickness[1.6], 
       PointBox[{83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
        98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
        112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 
        124}]}}], {{}, {}}},
   AspectRatio->NCache[
     Rational[1, 3], 0.3333333333333333],
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0., 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->120,
   Method->{
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 42.}, {0, 0.9764705882352941}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}]],
  CellChangeTimes->{{3.82801018085336*^9, 3.82801022699593*^9}, 
    3.828010258969507*^9, {3.82801032170518*^9, 3.828010328136689*^9}},
  ExpressionUUID->"006c42b1-11ec-457c-aeea-814281bfddc4"],
 " ",
 Cell[BoxData[
  GraphicsBox[
   {GrayLevel[0.7], 
    PolygonBox[{{0, 0}, {-0.5, 0.5}, {-0.5, 
      0.25}, {-1, 0.25}, {-1, -0.25}, {-0.5, -0.25}, {-0.5, -0.5}}]},
   ContentSelectable->False,
   ImageSize->25]],
  ShowStringCharacters->False,ExpressionUUID->
  "8f793227-cf08-4c3b-9d3d-d7ad6b76f28b"],
 Cell[BoxData[
  GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1EtLG3EUBfDQlctYEomYpiqiQURMosZXkqM2CzeCfgQhXShYX8si2VW3
2akohUJAEEURXUR8gCgqiLVLH7gSBZUs3IhSeme8/8WcT9BFDicMv9xhJkwu
UzHwrT/1weVyTcrHOr4nn7ieikifEvoF4neZ2F3mUV2Ev29WHtRuXIZ+SI09
8B+OSo19eM32vWX7jP3wjx1Kjcsxb8dcvxJXl1bMvAqbG1Zu1dUoGz2QXqiD
8JVaOVLXYqHnWXqqrsOngBXjeszmk3P55Im6Qa+XU4dQdjAiNQ4jcDQu3VZH
8Pl4QrqiboTbzk91E0r3h6Uz6mbYtw8sq6M6X1S36PNYUrfCW2Ilq25DwHG/
dhRvfZWuqjv0/A11jH5/HN7BHc/gzro6gZK9Iak5H/hoZ+3daaA4l3LnUrs6
70TGzrnOO/H7zMqNzrvw8qtXeq/zLnyvOZea/69bn5/uU7pbn4fZry+Y/BOU
mrnYjpkncR2ZlhrnzV6awMkispvsIfvIfnI5uZJcRa4mB8m15DpyPbmBHCKH
yRFyI7mJ3EyOklvIreQ2cju5gxwjx8kJMpxOk2U/nXOy7KdzTpb9dM7Jsp/O
OVn20+nC+7Pw/vw/35//AIjXfjk=
     "], {{{}, {}, {}, {}, 
       {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.3], 
        LineBox[{43, 1}], LineBox[{44, 2}], LineBox[{45, 3}], 
        LineBox[{46, 4}], LineBox[{47, 5}], LineBox[{48, 6}], 
        LineBox[{49, 7}], LineBox[{50, 8}], LineBox[{51, 9}], 
        LineBox[{52, 10}], LineBox[{53, 11}], LineBox[{54, 12}], 
        LineBox[{55, 13}], LineBox[{56, 14}], LineBox[{57, 15}], 
        LineBox[{58, 16}], LineBox[{59, 17}], LineBox[{60, 18}], 
        LineBox[{61, 19}], LineBox[{62, 20}], LineBox[{63, 21}], 
        LineBox[{64, 22}], LineBox[{65, 23}], LineBox[{66, 24}], 
        LineBox[{67, 25}], LineBox[{68, 26}], LineBox[{69, 27}], 
        LineBox[{70, 28}], LineBox[{71, 29}], LineBox[{72, 30}], 
        LineBox[{73, 31}], LineBox[{74, 32}], LineBox[{75, 33}], 
        LineBox[{76, 34}], LineBox[{77, 35}], LineBox[{78, 36}], 
        LineBox[{79, 37}], LineBox[{80, 38}], LineBox[{81, 39}], 
        LineBox[{82, 40}], LineBox[{83, 41}], LineBox[{84, 42}]}}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.02], 
       AbsoluteThickness[1.6], 
       PointBox[{85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
        100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
        126}]}}], {{}, {}}},
   AspectRatio->NCache[
     Rational[1, 3], 0.3333333333333333],
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0., 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->120,
   Method->{
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 42.}, {0, 0.9542483660130718}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}]],
  CellChangeTimes->{3.8280102886767645`*^9, 3.828010339856859*^9, 
   3.828010495540484*^9},ExpressionUUID->
  "8d3b080f-8997-4d29-a0c7-75689b5f8a48"]
}], "SummaryNote",
 CellChangeTimes->{{3.828010438724664*^9, 3.828010475373642*^9}, {
   3.8280105115130997`*^9, 3.828010540104919*^9}, {3.828010813322809*^9, 
   3.828010843566138*^9}, 3.828011026102003*^9, 3.828012682059768*^9, {
   3.900100386821686*^9, 3.9001004072496824`*^9}},
 CellID->1486087983,ExpressionUUID->"6c528365-e822-4d2a-9b0e-8d4950cb3610"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{
      FractionBox["3", "4"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}], "=", 
    RowBox[{
     FractionBox["1", "4"], 
     RowBox[{"x", "[", "n", "]"}]}]}], TraditionalForm]],
  FontSize->14,ExpressionUUID->"2e34496d-7f4b-42c6-8b4f-8cf7235d1fc9"],
 "\t\t\t",
 Cell[BoxData[
  GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1L9KglEYx/GXJkcLKQspk5CIiDQ1TfN90rqBhsaGoLkbkHhvoWa1xoaG
WqKiP9RQd9Da0FLQH6GWGqr3PP3OcH5X0OAXRD4+eDz4Hs7o2sbyeo/neY3w
Zd7/6vjtlunFxwdyfmZ6hiPSapqso1LRrGPS0KzjNE+Iu35Sfr5Nr3BKvj5N
T/CYrGh3cFr6tGt4XAa1E3hCRrR7eBK+hKckqu3C09Kv3cAZGdYu4Kz0aofw
jHhOOUloTczzEtf24IIMaafwLH2/SOuXsL8DeA7r78Nl7PcIrtB+58lVrBfA
vmxvma5gcX8/EBnQbjFfkI930wPmC3JybHrEvCa+9oZ5TTY1+zzr7vMO6lLV
7HxRdtomOCB7S7KqWXfsubTR/xkhR8kxcpycICfJKfIYOU0eJ0+QJ8lT5Gly
hpwl58h5coFcJJfIc+QyuUKeJ1fJPllcB+Tw/Llzcnj+3Dk5PH/unByeP3dO
Ds+f6+792L0f/+f9+AvEizQ3
     "], {{{}, {}, {}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
        LineBox[{43, 1}], LineBox[{44, 2}], LineBox[{45, 3}], 
        LineBox[{46, 4}], LineBox[{47, 5}], LineBox[{48, 6}], 
        LineBox[{49, 7}], LineBox[{50, 8}], LineBox[{51, 9}], 
        LineBox[{52, 10}], LineBox[{53, 11}], LineBox[{54, 12}], 
        LineBox[{55, 13}], LineBox[{56, 14}], LineBox[{57, 15}], 
        LineBox[{58, 16}], LineBox[{59, 17}], LineBox[{60, 18}], 
        LineBox[{61, 20}], LineBox[{62, 21}], LineBox[{63, 22}], 
        LineBox[{64, 24}], LineBox[{65, 25}], LineBox[{66, 26}], 
        LineBox[{67, 27}], LineBox[{68, 28}], LineBox[{69, 29}], 
        LineBox[{70, 30}], LineBox[{71, 31}], LineBox[{72, 32}], 
        LineBox[{73, 33}], LineBox[{74, 34}], LineBox[{75, 35}], 
        LineBox[{76, 36}], LineBox[{77, 37}], LineBox[{78, 38}], 
        LineBox[{79, 39}], LineBox[{80, 40}], LineBox[{81, 41}], 
        LineBox[{82, 42}]}}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
       AbsoluteThickness[1.6], 
       PointBox[{83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
        98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
        112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 
        124}]}}], {{}, {}}},
   AspectRatio->NCache[
     Rational[1, 3], 0.3333333333333333],
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0., 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->120,
   Method->{
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 42.}, {0, 0.9764705882352941}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}]],
  CellChangeTimes->{{3.82801018085336*^9, 3.82801022699593*^9}, 
    3.828010258969507*^9, {3.82801032170518*^9, 3.828010328136689*^9}},
  ExpressionUUID->"d32b4e41-4838-4051-a733-dd81fc9be37f"],
 " ",
 Cell[BoxData[
  GraphicsBox[
   {GrayLevel[0.7], 
    PolygonBox[{{0, 0}, {-0.5, 0.5}, {-0.5, 
      0.25}, {-1, 0.25}, {-1, -0.25}, {-0.5, -0.25}, {-0.5, -0.5}}]},
   ContentSelectable->False,
   ImageSize->25]],
  ShowStringCharacters->False,ExpressionUUID->
  "6c700ac5-e5c0-4bd1-ad24-91fac1243450"],
 " ",
 Cell[BoxData[
  GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1N1LU3EYB/CxLhqEsNoytYU6lsgwUzfdfNu+8yVW0IYWWJRdLLqaKHln
ha15kRcZpbQoMCQ1yZVkOVu5CRIklYWE9CIJNc1pES268CJ7OQefc3Gev6AL
v3A4fM73B4dzfg+/TE9T7QmlQqFoFS7xvpaE/Ua3mJd2eoBTLWLek1UIjYj5
SFbjakDMPFkLtZjpz+QUbBfjjZN1iIwJWVkiZ6DjgpCWL2Q9luLx+MBhyQY8
CofDqouL5CzcCQaDA5ti5GxoNRpNUu8HshHbkpMDmyvmyDlo8/v1Z+ffknPh
8Xhm072vyXkQ3n4rrWuanA/hY6LenilyAbZoDiSar0+STXC5bOY3DybIZlgs
6eo2d4RciIaGNHe/LUwuwru62XP+kGQLYhPHP2W23ydbMbTVfbfeKLkYew7+
rX7eO0wuQVi5wXpk/B65FJcmz3/fq5XWl8Fcv+vXeHKIXI7GjuUngUMPyTZ0
DjZ1/VBK6+0YbT+68nvfKBmYGnwW9a+OrNkH9L2IXfvmHKPegVrF7aT9u19R
78CZyGlH6pD0PyvQWnTMmTpM8+AT7Fy80mxYoL4ST3fM1EX9tH++Siz0N17u
PintfxU0fY9n5laXqa/C6E3TRtfOr9RXo6fmj67zp+SENJdSIKeKWc2sZU5h
1jFnMOuZDcxZzNnMRuYc5lzmPOZ85gJmE7OZuZC5iNnCbGUuZi5hLmUuYy5n
tjHbmSG3j1mYT3nPLMynvGcW5lPeMwvzKe+ZhfmUe/38XD8//8/z8x/gGJT3

     "], {{{}, {}, {}, {}, 
       {RGBColor[0.88, 0.61, 0.14], Opacity[0.3], LineBox[{43, 1}], 
        LineBox[{44, 2}], LineBox[{45, 3}], LineBox[{46, 4}], 
        LineBox[{47, 5}], LineBox[{48, 6}], LineBox[{49, 7}], 
        LineBox[{50, 8}], LineBox[{51, 9}], LineBox[{52, 10}], 
        LineBox[{53, 11}], LineBox[{54, 12}], LineBox[{55, 13}], 
        LineBox[{56, 14}], LineBox[{57, 15}], LineBox[{58, 16}], 
        LineBox[{59, 17}], LineBox[{60, 18}], LineBox[{61, 19}], 
        LineBox[{62, 20}], LineBox[{63, 21}], LineBox[{64, 22}], 
        LineBox[{65, 23}], LineBox[{66, 24}], LineBox[{67, 25}], 
        LineBox[{68, 26}], LineBox[{69, 27}], LineBox[{70, 28}], 
        LineBox[{71, 29}], LineBox[{72, 30}], LineBox[{73, 31}], 
        LineBox[{74, 32}], LineBox[{75, 33}], LineBox[{76, 34}], 
        LineBox[{77, 35}], LineBox[{78, 36}], LineBox[{79, 37}], 
        LineBox[{80, 38}], LineBox[{81, 39}], LineBox[{82, 40}], 
        LineBox[{83, 41}], LineBox[{84, 42}]}}, 
      {RGBColor[0.88, 0.61, 0.14], PointSize[0.02], AbsoluteThickness[1.6], 
       PointBox[{85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
        100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
        126}]}}], {{}, {}}},
   AspectRatio->NCache[
     Rational[1, 3], 0.3333333333333333],
   Axes->{False, False},
   AxesLabel->{None, None},
   AxesOrigin->{0., 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->120,
   Method->{
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotRange->{{0., 42.}, {0, 0.873482758167075}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}]],
  CellChangeTimes->{{3.8280109921860356`*^9, 3.828011005085178*^9}},
  ExpressionUUID->"4249a8f0-836e-409d-b671-aee023e74daa"]
}], "SummaryNote",
 CellChangeTimes->{{3.828011042909655*^9, 3.828011089486066*^9}, {
   3.828012630547239*^9, 3.8280126319274526`*^9}, {3.8280126704794874`*^9, 
   3.828012683285747*^9}, 3.830424342773391*^9},
 CellID->1445915671,ExpressionUUID->"2af70652-6018-4025-8c82-2527c8fefeb9"],

Cell["\<\
It was shown that the output of any LSI system can be easily obtained \
numerically given the input and the requisite number of initial conditions by \
simply recursively evaluating the difference equation for each desired output \
value.\
\>", "SummaryNote",
 CellChangeTimes->{{3.8198968184177647`*^9, 3.8198968510154*^9}, {
  3.8198969400880747`*^9, 3.81989701475022*^9}, {3.819897057635703*^9, 
  3.8198970614977813`*^9}, {3.819897106703595*^9, 3.8198971745674133`*^9}, {
  3.915547753559826*^9, 3.915547754181319*^9}, {3.915624628117629*^9, 
  3.915624631004971*^9}, {3.91563091061948*^9, 3.9156309225893593`*^9}},
 CellID->579733045,ExpressionUUID->"db8f3be8-a6d8-409c-858b-011c8c7c6226"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSection",
 CellID->439980876,ExpressionUUID->"6ba10263-6931-46dd-b111-8561d073739c"],

Cell[TextData[{
 "The input into a moving average system of order ",
 Cell[BoxData[
  FormBox[
   RowBox[{"M", "=", "2"}], TraditionalForm]],ExpressionUUID->
  "e38dd246-f281-4668-bced-e8457638a7ee"],
 " is the sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"cos", "(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"8cdb9335-c442-4a50-9b8d-8573e5be541c"],
 ". Obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "89d49ecd-8800-40c1-955b-ebb612a216bb"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"9433b7d4-1190-47b8-8163-878e3a7fe19f"],
 "."
}], "Exercise",
 CellID->972386311,ExpressionUUID->"a18b2bcc-e6ba-4441-ac05-9d04fa9376e0"],

Cell[CellGroupData[{

Cell["A non-recursive system is defined", "Exercise",
 CellChangeTimes->{3.916237241682476*^9},
 CellID->546175307,ExpressionUUID->"a3987ecb-6316-4539-af70-98bc9f0e5039"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}], 
  TraditionalForm]],ExpressionUUID->"0475ae60-ed2e-4d44-8000-9acf4b928472"]], \
"ExerciseNote",
 CellChangeTimes->{{3.844644889711525*^9, 3.844644922486371*^9}, {
  3.8642194543658733`*^9, 3.8642194543670197`*^9}},
 CellID->138784315,ExpressionUUID->"72b232a3-1cce-478c-909b-f81006025059"],

Cell[TextData[{
 "Obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "6360331a-05fd-45ba-bc27-ac9dc4185758"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"a56968c4-3eb4-40ac-822e-79219e2f82de"],
 " given the input ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"sin", "(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "n"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"4a6a2da0-8bdf-4ed7-8237-e665c1e731d2"],
 "."
}], "ExerciseNote",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
   3.6526109512051954`*^9}, {3.694996672499266*^9, 3.694996754242944*^9}, {
   3.6950802301369896`*^9, 3.695080260541195*^9}, {3.778268781613352*^9, 
   3.7782687864801207`*^9}, {3.778318411035839*^9, 3.778318420923517*^9}, {
   3.7783192883035455`*^9, 3.7783192941283245`*^9}, {3.840796190041807*^9, 
   3.84079619083346*^9}, {3.844643957219439*^9, 3.844644067845601*^9}, {
   3.8446448745449376`*^9, 3.844644883176081*^9}, {3.8446449557073*^9, 
   3.844644980214753*^9}, {3.844645161569257*^9, 3.844645161894699*^9}, 
   3.8446452884409995`*^9, {3.864219454367375*^9, 3.8642194543693743`*^9}, {
   3.892995706927979*^9, 3.892995710740369*^9}},
 CellID->181970589,ExpressionUUID->"d8bafd31-62b2-4bb6-bf3a-567541f18e4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A moving average system is defined", "Exercise",
 CellChangeTimes->{3.9162372459756947`*^9},
 CellID->1223277471,ExpressionUUID->"7e12edba-8b18-4340-aaa6-bab6bf0bf06a"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "3"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}], ")"}]}]}], 
  TraditionalForm]],ExpressionUUID->"966c622e-cbc8-4906-929a-e26bfafe1d79"]], \
"ExerciseNote",
 CellChangeTimes->{{3.855610494686028*^9, 3.855610516543709*^9}, {
  3.8642194543845673`*^9, 3.864219454385051*^9}},
 CellID->111742113,ExpressionUUID->"853f6de5-f30c-427a-b1db-54c8458cb19f"],

Cell[TextData[{
 "Obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "2c1f7133-90e4-489c-8392-91c045aa51ca"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "3"}]}], ",", 
    RowBox[{"-", "2"}], ",", 
    RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"112b0c41-f5bb-4950-a6c3-692cfbbe33b2"],
 " given the input sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"\[Delta]", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "8e9533dc-4841-4300-87bf-090f818ef3e6"],
 "."
}], "ExerciseNote",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
  3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
  3.6526109512051954`*^9}, {3.694996672499266*^9, 3.694996754242944*^9}, {
  3.6950802301369896`*^9, 3.695080260541195*^9}, {3.778268781613352*^9, 
  3.7782687864801207`*^9}, {3.778318411035839*^9, 3.778318420923517*^9}, {
  3.7783192883035455`*^9, 3.7783192941283245`*^9}, {3.840796190041807*^9, 
  3.84079619083346*^9}, {3.844643957219439*^9, 3.844644067845601*^9}, {
  3.844645320022716*^9, 3.84464535360274*^9}, {3.844645406617443*^9, 
  3.8446454070539227`*^9}, {3.855610564446441*^9, 3.855610610809359*^9}, {
  3.8642194543859043`*^9, 3.864219454389629*^9}},
 CellID->87485674,ExpressionUUID->"00256121-3f50-4485-a962-553c8c7da167"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Given the input sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"\[Delta]", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "5e945f09-2d38-4ab4-a4e6-680f29062bc0"],
 ", use recursion to solve the following difference equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"-", "1"}]}], ",", "0", ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"b2e665e2-08e6-4488-87fa-61ccd5dcc550"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.915547463562162*^9, {3.915625564089748*^9, 3.915625564732381*^9}, 
   3.9162372511148243`*^9, 3.9333368150866146`*^9},
 CellID->43492384,ExpressionUUID->"5077d729-0605-47ae-86e1-dc023cab99ca"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"55256774-23c5-4d32-9fe5-03e2701d0800"],
 ",\t \t",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "<", "0"}], TraditionalForm]],ExpressionUUID->
  "aa85698d-9f46-42cb-b055-726d407c9154"]
}], "ExerciseNote",
 CellChangeTimes->{{3.855610494686028*^9, 3.855610516543709*^9}, {
  3.8642194543845673`*^9, 3.864219454385051*^9}, {3.915547508892538*^9, 
  3.915547538584072*^9}, {3.916237262394804*^9, 3.9162373292025547`*^9}},
 CellID->244220582,ExpressionUUID->"c0744604-631c-448d-92fd-543e54f06ec2"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"x", "[", "n", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "7509d603-bc9a-49a0-9be0-5dd0f5a55043"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">=", "0"}], TraditionalForm]],ExpressionUUID->
  "16c01025-03c8-46ef-87f6-c8b329dd3f2e"]
}], "ExerciseNote",
 CellChangeTimes->{{3.855610494686028*^9, 3.855610516543709*^9}, {
  3.8642194543845673`*^9, 3.864219454385051*^9}, {3.915547508892538*^9, 
  3.915547538584072*^9}, {3.916237262394804*^9, 3.9162372697894726`*^9}, {
  3.916237307809721*^9, 3.916237314378273*^9}},
 CellID->432239463,ExpressionUUID->"07834398-0f3e-4e33-bcc4-3361e32eded5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use recursion to solve the following difference equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "2"}], ",", "3", ",", "...", ",", "7"}], 
   TraditionalForm]],ExpressionUUID->"0387e06f-469d-4e74-bfae-7e00880a5110"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.915625590504179*^9, 3.915625598451892*^9}, {
   3.916237363702385*^9, 3.916237364452378*^9}, 3.93333682162607*^9},
 CellID->1763502366,ExpressionUUID->"02db8abb-c05b-4c80-a7cc-84e802039b55"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "1"}], "]"}], "-", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"61736dd0-9b4a-459b-ae68-8687b0e20764"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "1", "]"}], "=", "1"}], TraditionalForm]],
  ExpressionUUID->"2c64a90f-480a-4dea-8503-1f4ecb256651"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"956b94bf-bf43-4887-9be7-a6f7520b3eee"]
}], "ExerciseNote",
 CellChangeTimes->{{3.652443129038666*^9, 3.6524431616213403`*^9}, {
   3.6524774865993505`*^9, 3.652477489299323*^9}, {3.652477520005017*^9, 
   3.652477520475012*^9}, {3.695159241154778*^9, 3.695159241279578*^9}, {
   3.6963448506522846`*^9, 3.6963449070122848`*^9}, {3.696345593518285*^9, 
   3.696345601141285*^9}, {3.696345650401284*^9, 3.696345660721285*^9}, 
   3.778319411129918*^9, {3.778540730179979*^9, 3.778540815970645*^9}, {
   3.7785409326294007`*^9, 3.77854094494978*^9}, 3.8407967934422207`*^9, {
   3.864219454416965*^9, 3.8642194544205103`*^9}, 3.892996085723099*^9, 
   3.8996645421987133`*^9},
 CellID->86264469,ExpressionUUID->"1568625e-2968-4d72-861d-59751fa3596f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use recursion to obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "540c4dd0-080a-4e33-82e5-6d95a2a83a0b"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"042848a2-5e32-44a4-8944-9ff362d3edaf"],
 " given input ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"\[Delta]", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "be7f3d24-196e-4324-85c6-b2c6812551b3"],
 " and the following first-order difference equation and initial condition."
}], "Exercise",
 CellChangeTimes->{3.916237369898033*^9, 3.933336839385174*^9},
 CellID->1762453115,ExpressionUUID->"f19b3187-d305-4e69-894f-5d5f31ff2632"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n", "]"}], "-", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}], "=", 
    RowBox[{"x", "[", "n", "]"}], " "}], TraditionalForm]],ExpressionUUID->
  "ca9f9e60-1a39-4503-b7f4-636370186125"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "1"}], "]"}], " ", "=", " ", "0"}], TraditionalForm]],
  ExpressionUUID->"1dcd8892-55ea-4add-8c96-46febb3d6e62"]
}], "ExerciseNote",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.48810448403125*^9, 3.488104486015625*^9}, 3.61273640209794*^9, {
   3.65261095986314*^9, 3.65261096145433*^9}, {3.7783184256023235`*^9, 
   3.7783184287324295`*^9}, {3.840796194378932*^9, 3.840796194953655*^9}, {
   3.840797151401949*^9, 3.8407971514020166`*^9}, {3.864219454446619*^9, 
   3.8642194544475613`*^9}, 3.8929960795281277`*^9, 3.89336234278627*^9, 
   3.899664534986907*^9},
 CellID->50770850,ExpressionUUID->"588080f8-c543-488a-aacc-b4a743bbd264"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use recursion to obtain the output ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "ca00aaaf-28c3-4928-bc04-345376b90c45"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", "1", ",", "2", ",", "3"}], 
   TraditionalForm]],ExpressionUUID->"7e49fa84-d142-477c-a7e5-f0c5beeabb7c"],
 " given the input ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"]}], TraditionalForm]],ExpressionUUID->
  "d891050f-6871-457d-83d5-2bbc581877ac"],
 " and the following difference equation and initial conditions."
}], "Exercise",
 CellChangeTimes->{3.916237373588793*^9, 3.933336853686035*^9},
 CellID->1307560734,ExpressionUUID->"3602ed5f-b759-49d9-89e5-9552518131f0"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"8", 
      RowBox[{"y", "[", "n", "]"}]}], "-", 
     RowBox[{"6", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{"3", 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}]}], "=", 
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], "+", 
     RowBox[{"2", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}], TraditionalForm]],ExpressionUUID->
  "324fad78-e3cc-40d2-9039-e15e5983b47f"],
 ", \t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "1"}], "]"}], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "1883a854-0564-4d78-a0f3-932f0c557783"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "2"}], "]"}], "=", "0"}], TraditionalForm]],ExpressionUUID->
  "70b94630-d4ba-4ea9-a206-014d5a8e875a"]
}], "ExerciseNote",
 CellChangeTimes->{{3.652443129038666*^9, 3.6524431616213403`*^9}, {
   3.6524774865993505`*^9, 3.652477489299323*^9}, {3.652477520005017*^9, 
   3.652477520475012*^9}, {3.695159241154778*^9, 3.695159241279578*^9}, {
   3.6963448506522846`*^9, 3.6963449070122848`*^9}, {3.696345593518285*^9, 
   3.696345601141285*^9}, {3.696345650401284*^9, 3.696345660721285*^9}, 
   3.778319411129918*^9, 3.840796647936606*^9, {3.844646108823903*^9, 
   3.8446461220993166`*^9}, {3.864219454467944*^9, 3.864219454472103*^9}, 
   3.8929960723736105`*^9, 3.899664519113033*^9, 3.916237380927742*^9},
 CellID->480891019,ExpressionUUID->"5b41596e-813e-46ef-9774-1d0fcba8e456"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Given an input of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"u", "[", "n", "]"}]}]}], TraditionalForm]],ExpressionUUID->
  "30956fe9-4ea8-47b6-b24a-6b2752e0022c"],
 " and an initial condition of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"-", "1"}], "]"}], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "364cb28f-5f86-446a-81f7-1d32fe9305cc"],
 ", use recursion to show that the following difference equation returns a \
sequence that converges on the ",
 Cell[BoxData[
  FormBox["value", TraditionalForm]],ExpressionUUID->
  "a9540bc4-da43-4b18-8eee-16c8af54ba32"],
 " of ",
 Cell[BoxData[
  FormBox[
   SqrtBox["\[Alpha]"], TraditionalForm]],ExpressionUUID->
  "cdb4767b-e0bb-40b3-b92e-7c03b526d1b9"],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "->", "\[Infinity]"}], TraditionalForm]],ExpressionUUID->
  "5747c518-0908-4b9b-a9e3-7be310d2081e"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.915547668369863*^9, 3.915549559728206*^9, {3.915625642154284*^9, 
   3.915625643350085*^9}, 3.9162373870711308`*^9, 3.930307529452471*^9},
 CellID->38139717,ExpressionUUID->"980e855e-1f17-4afb-8b40-538de605f2bf"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "/", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}]}], ")"}]}]}], 
  TraditionalForm]],ExpressionUUID->"c04acc3f-9566-4626-9d84-0c3c6ef69b30"]], \
"ExerciseNote",
 CellChangeTimes->{{3.39924779653125*^9, 3.399247797890625*^9}, {
   3.48810448403125*^9, 3.488104486015625*^9}, 3.61273640209794*^9, {
   3.65261095986314*^9, 3.65261096145433*^9}, {3.7783184256023235`*^9, 
   3.7783184287324295`*^9}, {3.840796194378932*^9, 3.840796194953655*^9}, {
   3.840797151401949*^9, 3.8407971514020176`*^9}, {3.864219454446619*^9, 
   3.8642194544475613`*^9}, 3.892996079528127*^9, 3.89336234278627*^9, 
   3.899664534986907*^9, {3.915547684074665*^9, 3.915547689187835*^9}},
 CellID->106857559,ExpressionUUID->"9eb189e8-94e9-4b7e-b93c-09097a071b17"],

Cell[TextData[{
 "Obtain the value of ",
 Cell[BoxData[
  FormBox[
   SqrtBox["2"], TraditionalForm]],ExpressionUUID->
  "7b77fa52-0d1a-4e29-87e6-96210306871e"],
 "."
}], "ExerciseNote",
 CellChangeTimes->{{3.39924778259375*^9, 3.39924778328125*^9}, {
   3.65261071434711*^9, 3.6526107172098913`*^9}, {3.652610943960842*^9, 
   3.6526109512051954`*^9}, {3.694996672499266*^9, 3.694996754242944*^9}, {
   3.6950802301369896`*^9, 3.695080260541195*^9}, {3.778268781613352*^9, 
   3.7782687864801207`*^9}, {3.778318411035839*^9, 3.778318420923517*^9}, {
   3.7783192883035455`*^9, 3.7783192941283245`*^9}, {3.840796190041807*^9, 
   3.84079619083346*^9}, {3.844643957219439*^9, 3.844644067845601*^9}, {
   3.844645320022716*^9, 3.84464535360274*^9}, {3.844645406617443*^9, 
   3.8446454070539227`*^9}, {3.855610564446441*^9, 3.855610610809359*^9}, {
   3.8642194543859043`*^9, 3.864219454389629*^9}, 3.915547712306553*^9},
 CellID->109590416,ExpressionUUID->"77b9a180-ecc1-4e14-a270-c2262686a281"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["\[Copyright] 2024 Wolfram Media, Inc.", "SmallText",
 CellMargins->{{66, 66}, {20, 100}},
 CellGroupingRules->"SectionGrouping",
 FontSize->12,
 FontColor->RGBColor[
  0.7098039215686275, 0.7098039215686275, 0.7098039215686275],
 CellID->1402660677,ExpressionUUID->"82099fe5-ccbe-41b1-8a23-dd532f020ea8"]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellInsertionPointCell->None,
WindowSize->Automatic,
WindowMargins->{Automatic, Automatic},
WindowFrame->"Normal",
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"10. Discrete\[Hyphen]Time Systems as Difference Equations | \
Signals, Systems, and Signal Processing",
DockedCells->{
  Cell[
   TagBox[
    GridBox[{{
       PaneBox[
        TagBox[
         GridBox[{{
            StyleBox["Wolfram eTextbook Series", 12, 
             RGBColor[
             0.8823529411764706, 0.40784313725490196`, 0.1450980392156863], 
             FontFamily -> "Source Sans Pro"]}, {
            TemplateBox[{
              StyleBox["\"Signals, Systems, and Signal Processing\"", 20, 
               GrayLevel[1], FontWeight -> "SemiBold", FontFamily -> 
               "Source Sans Pro"], 
              "https://www.wolfram.com/wolfram-u/courses/image-signal-\
processing/signals-systems-and-signal-processing/"}, "HyperlinkURL"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}], "Grid"], 
        ImageSize -> Full, FrameMargins -> {{20, 20}, {5, 12}}], 
       PaneBox[
        PaneBox[
         TemplateBox[{"\[ThinSpace]", "\" \"", 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-09_CT_Convolution.nb", 
                    ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
               ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-09_CT_Convolution.nb", 
                    ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                 Method -> "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], 
             "\"9. Continuous\[Hyphen]Time Convolution\"", TooltipDelay -> 
             0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, "9. Continuous\[Hyphen]Time Convolution", 
             "Tooltip"]& ], 
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[5], Selectable -> False], 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-11_DT_Solution-Methods.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                 Automatic, Method -> "Preemptive"], True -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-11_DT_Solution-Methods.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                 GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                 "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], 
             "\"11. Difference Equation Solution Methods\"", TooltipDelay -> 
             0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, "11. Difference Equation Solution Methods", 
             "Tooltip"]& ]}, "RowWithSeparators"], Alignment -> Right], 
        Alignment -> Right, FrameMargins -> {{0, 6}, {0, 0}}, 
        ImageSize -> {100, 30}], 
       TagBox[
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0., 0.1607843137254902, 0.4], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Cover" :> NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00a_Cover.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Preface" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00b_Preface.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Signals and Systems\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "1. Introduction to Signals and Systems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2. Signal Classification" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-02_Signal-Classification.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3. Elementary Signals and Sequences" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-03_Elementary-Signals.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4. Elementary Operations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-04_Elementary-Operations.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5. System Properties" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-05_System-Properties.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "6. Continuous\[Hyphen]Time Systems as Differential Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "7. Differential Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-07_CT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "8. Continuous\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-08_CT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "9. Continuous\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-09_CT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10. Discrete\[Hyphen]Time Systems as Difference Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11. Difference Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-11_DT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12. Discrete\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-12_DT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13. Discrete\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-13_DT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14. Continuous\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15. Continuous\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-15_CT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16. Continuous\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-16_CT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "17. Continuous\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-17_CT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18. Discrete\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19. Discrete\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-19_DT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20. Discrete\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-20_DT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "21. Discrete\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-21_DT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Laplace Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "22. Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "23. Inverse Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-23_Inverse-Laplace-Transform.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "24. Laplace Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-24_Laplace-Transform-Theorems.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "25. Unilateral Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-25_Unilateral-Laplace-\
Transform.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"z\[Hyphen]Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "26. z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "27. Inverse z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-27_Inverse-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "28. z\[Hyphen]Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-28_Z-Transform-Theorems.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "29. Unilateral z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-29_Unilateral-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Sampling and Filter Design\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "30. Sampling" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "31. FIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-31_FIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "32. Butterworth Filter" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-32_Butterworth-Filter.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "33. IIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-33_IIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Sample Exam\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-34_Sample-Exam.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None], 
        MouseAppearanceTag["LinkHand"]]}}, AutoDelete -> False, 
     GridBoxItemSize -> {
      "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"], 
   Background -> RGBColor[0., 0.1607843137254902, 0.4], 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrameColor -> 
   RGBColor[0., 0.1607843137254902, 0.4], CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameMargins -> {{0, 20}, {5, 0}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, CellGroupingRules -> {"SectionGrouping", 0}, 
   CellContext -> CellGroup], 
  Cell[
   BoxData[
    GridBox[{{
       DynamicModuleBox[{$CellContext`open$$ = False}, 
        PaneSelectorBox[{True -> ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{93, 93, 93, 19}, {140, 140, 
                   140, 237}, {115, 115, 115, 181}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {115, 115, 115, 181}, {140,
                    140, 140, 237}, {93, 93, 93, 19}}, {{140, 140, 140, 
                   236}, {179, 179, 179, 255}, {179, 179, 179, 255}, {127, 
                   127, 127, 216}, {92, 92, 92, 11}, {92, 92, 92, 11}, {127, 
                   127, 127, 216}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {140, 140, 140, 236}}, {{102, 102, 102, 119}, {167, 
                   167, 167, 255}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {142, 142, 142, 240}, {141, 141, 141, 239}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {167, 167, 167, 
                   255}, {102, 102, 102, 119}}, {{0, 0, 0, 0}, {98, 98, 98, 
                   75}, {158, 158, 158, 251}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {179, 179, 179, 255}, {179, 179, 179, 255}, {
                   158, 158, 158, 251}, {98, 98, 98, 75}, {0, 0, 0, 0}}, {{0, 
                   0, 0, 0}, {0, 0, 0, 0}, {93, 93, 93, 38}, {144, 144, 144, 
                   241}, {179, 179, 179, 255}, {179, 179, 179, 255}, {144, 
                   144, 144, 241}, {93, 93, 93, 38}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {92, 92, 
                   92, 11}, {129, 129, 129, 222}, {129, 129, 129, 222}, {92, 
                   92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}}], {{0, 6.}, {10., 0}}, {0, 255}, ColorFunction -> 
                  RGBColor, ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {10., 6.}, PlotRange -> {{0, 10.}, {0, 6.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"], False -> 
          ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{0, 0, 0, 0}, {98, 98, 98, 
                   78}, {132, 132, 132, 225}, {97, 97, 97, 21}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{93, 93, 93, 49}, {168, 
                   168, 168, 255}, {179, 179, 179, 255}, {141, 141, 141, 
                   238}, {92, 92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{102,
                    102, 102, 15}, {149, 149, 149, 246}, {179, 179, 179, 
                   255}, {179, 179, 179, 255}, {133, 133, 133, 229}, {102, 
                   102, 102, 5}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {95, 95, 95, 
                   40}, {156, 156, 156, 250}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {129, 129, 129, 217}, {255, 255, 255, 1}}, {{0,
                    0, 0, 0}, {0, 0, 0, 0}, {95, 95, 95, 56}, {163, 163, 163, 
                   253}, {179, 179, 179, 255}, {179, 179, 179, 255}, {115, 
                   115, 115, 181}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {103, 103, 
                   103, 123}, {174, 174, 174, 255}, {179, 179, 179, 255}, {
                   176, 176, 176, 255}, {102, 102, 102, 119}}, {{0, 0, 0, 
                   0}, {100, 100, 100, 102}, {172, 172, 172, 255}, {179, 179, 
                   179, 255}, {179, 179, 179, 255}, {109, 109, 109, 154}, {0, 
                   0, 0, 0}}, {{91, 91, 91, 42}, {167, 167, 167, 255}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {114, 114, 114, 
                   176}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{97, 97, 97, 21}, {147,
                    147, 147, 245}, {179, 179, 179, 255}, {119, 119, 119, 
                   194}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0,
                    0}, {93, 93, 93, 19}, {103, 103, 103, 128}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}], {{
                   0, 10.}, {7., 0}}, {0, 255}, ColorFunction -> RGBColor, 
                  ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {7., 10.}, PlotRange -> {{0, 7.}, {0, 10.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"]}, 
         Dynamic[$CellGroupContext`open$$]], 
        Initialization :> ($CellGroupContext`open$$ = False), 
        DynamicModuleValues :> {}]}}, 
     GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
     GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}]], "Text", 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   CellFrameMargins -> {{28, 0}, {2, 2}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.], CellContext -> 
   CellGroup], 
  Cell[
   BoxData[
    TemplateBox[{
      TemplateBox[{
        StyleBox[
        "\"M. Jankowski (2024), \"", FontWeight -> "Bold", FontSize -> 11, 
         FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Signals, Systems, and Signal Processing: A Computational Approach, \
\"", Selectable -> True, Copyable -> True, FontSlant -> Italic, FontWeight -> 
         "Bold", FontSize -> 11, FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing.\"", 
         FontWeight -> "Bold", FontSize -> 11, FontFamily -> 
         "Source Sans Pro", FontColor -> 
         RGBColor[
          0.2784313725490196, 0.403921568627451, 0.5137254901960784]]}, 
       "RowDefault"], 
      "M. Jankowski (2024), \!\(\*StyleBox[\"Signals\",FontSlant->\"Italic\"]\
\)\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Systems\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \",FontSlant->\
\"Italic\"]\)\!\(\*StyleBox[\"and\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Signal\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Processing\",FontSlant->\"Italic\"\
]\)\!\(\*StyleBox[\":\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"A\",FontSlant->\"Italic\"]\)\!\(\*\
StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Computational\",FontSlant->\"\
Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Approach\",FontSlant->\"Italic\"]\
\), Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing."}, 
     "ClickToCopy2", BaseStyle -> {LineBreakWithin -> Automatic}]], "Text", 
   Selectable -> True, CellFrame -> {{0, 1}, {0, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {0, -1}}, 
   CellElementSpacings -> {"CellMinHeight" -> 2, "ClosedCellHeight" -> 1}, 
   Copyable -> True, CellOpen -> Dynamic[$CellGroupContext`open$$], 
   CellContext -> CellGroup, CellFrameMargins -> {{28, 0}, {5, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   LineSpacing -> {1, -3}, ShowStringCharacters -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.]]},
ShowCellBracket->Automatic,
ShowSelection->True,
TaggingRules->{
 "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.9.2094", "$MVersion" -> "12", "$FlaggedVersion" -> 
    11.3}, "SlideshowSettings" -> {"Toolbar" -> True}},
ShowCellLabel->False,
CellLabelAutoDelete->True,
CellLabelTemplate-><|
 "In" -> "In[`1`]:=", "InExpired" -> "In[`1`]:=", "Out" -> "Out[`1`]=", 
  "OutExpired" -> "Out[`1`]="|>,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
AutoStyleOptions->{"HighlightComments"->True},
AutoMultiplicationSymbol->{},
Magnification->1,
FrontEndVersion->"14.0 for Mac OS X ARM (64-bit) (December 12, 2023)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["eBook Styles", "Section"], 
      Cell[
       StyleData["ContentsTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       MenuSortingValue -> 20000, FontFamily -> "Helvetica", FontSize -> 36, 
       FontWeight -> "Bold", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Leader"], TabFilling -> ".", MenuSortingValue -> 10000, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       18, FontWeight -> "Plain"], 
      Cell[
       StyleData["LeaderNoDots"], TabFilling -> " ", MenuSortingValue -> 
       10000, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["PageLink"], MenuSortingValue -> 10000, StyleMenuListing -> 
       None, ButtonStyleMenuListing -> Automatic, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[0.269993, 0.308507, 0.6], 
       ButtonBoxOptions -> {
        Active -> True, Appearance -> {Automatic, None}, 
         ButtonFunction :> (FrontEndExecute[{
            FrontEnd`NotebookLocate[#2]}]& )}], 
      Cell[
       StyleData["TOCPage"], CellSize -> {40, Inherited}, TextAlignment -> 
       Right, MenuSortingValue -> 20010, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["TOCTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 36, 
       CounterIncrements -> "TOCTitle", MenuSortingValue -> 20020, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Bold", FontColor -> 
       GrayLevel[0]], 
      Cell[
       StyleData["TOCSection"], CellMargins -> {{95, 95}, {1, 1}}, 
       CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 34, 
       CounterIncrements -> "TOCSection", MenuSortingValue -> 20030, 
       FontFamily -> "Source Sans Pro", FontSize -> 16], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 81}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"ItemGrouping", 70}, CellFrameLabelMargins -> 
          4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Baskerville", FontSize -> 
          18], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{81, 81}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["SectionSingleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
       CellDingbat -> Cell[
         TextData[
          CounterBox["Section"], 
          StyleBox[
          "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
           RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
           FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]], 
         "SectionNumber"], CellMargins -> {{100, 100}, {12, 64}}, Evaluatable -> 
       True, CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
       True, ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       26, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsubsection"], 
          CellMargins -> {{66, 66}, {2, 10}}, 
          StyleKeyMapping -> {
           "Backspace" -> 
            "Subsubsubsection", $CellContext`KeyEvent[
             "Tab", $CellContext`Modifiers -> {"Shift"}] -> 
            "Subsubsubsection"}, CellGroupingRules -> {"SectionGrouping", 70},
           PageBreakBelow -> False, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsubsubsection", 
          CounterAssignments -> {{"Item", 0}, {"Subitem", 0}, {
            "Subsubitem", 0}, {"ItemNumbered", 0}, {"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> None, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsubsubsection", "Printout"], 
          CellMargins -> {{66, 66}, {2, 10}}], 
         Cell[
          StyleData["Chapter", "Printout"], 
          CellMargins -> {{Inherited, Inherited}, {62, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
       CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
       Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
       PageBreakBelow -> False, ShowCellLabel -> False, 
       CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
       RGBColor[0.901961, 0.411765, 0.027451], 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, MenuSortingValue -> 10015, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       GridBoxOptions -> {GridBoxAlignment -> {}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{108, 108}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10025, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{110, 110}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummarySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], MenuSortingValue -> 9000, 
          FontFamily -> "Source Sans Pro", FontSize -> 18, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["SummarySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 9010, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryNote", "Printout"], 
          CellMargins -> {{68, 68}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryList"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 9020, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryList", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Open]], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[5]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Appearance -> "PopupMenu",
                Method -> "Queued", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {"PageSize" -> {504, 720}}, 
       AutoStyleOptions -> {"UndefinedSymbolStyle" -> None}, Magnification -> 
       0.6], 
      Cell[
       StyleData[All, "Invisibles"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, Appearance -> 
               "PopupMenu", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Method -> "Queued", 
               FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], 
       PrintingOptions -> {"PageHeaderMargins" -> {28, 28}}, StyleMenuListing -> 
       None, FontFamily -> "Source Sans Pro", FontSize -> 8, FontWeight -> 
       "Regular", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> WindowWidth, 
       PrintingOptions -> {
        "FirstPageHeader" -> True, "InnerOuterMargins" -> {30, 30}, 
         "PaperOrientation" -> "Portrait", "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, 64}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, 64}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{64, 64}, {12, 64}}, 
          CellGroupingRules -> {"SectionGrouping", 30}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{62, 62}, {52, 182}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, 112}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, 112}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionBar"], FontFamily -> "Source Sans Pro", 
          FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionBar", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], CellMargins -> {{64, 64}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, 64}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumbered"], CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Subsection"]}], "SubsectionNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{98, 98}, {Inherited, 32}}, CounterIncrements -> 
          "Subsection", FontFamily -> "Source Sans Pro Semibold", FontSize -> 
          18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsectionNumbered", "Printout"], 
          CellMargins -> {{102, 102}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumber"], FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          GrayLevel[0.25]], 
         Cell[
          StyleData["SubsectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionFirst"], CellMargins -> {{64, 64}, {2, 72}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, 64}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsubsectionTopMargin"], 
          CellMargins -> {{64, 64}, {2, 14}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsubsectionTopMargin", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.45]], 
         Cell[
          StyleData["Subsubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, 64}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, 64}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsection"], 
          CellMargins -> {{64, 64}, {2, 10}}, FontFamily -> "Source Sans Pro",
           FontSize -> 16, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsectionSM"], 
          CellFrame -> {{0, 0}, {0.75, 0}}, 
          CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Regular", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {6, 15}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakBelow -> False, ShowCellLabel -> False, 
          CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, 64}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsectionSM"], 
          CellMargins -> {{64, 64}, {4, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ExerciseSubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> False, CellMargins -> {{106, 106}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 62}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{108, 108}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellGroupingRules -> {"SectionGrouping", 62.}, PageBreakBelow -> 
          False, LineSpacing -> {1., 1., 2.}, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}, LineSpacing -> {0.8, 1., 2.}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {2, 12}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, CounterIncrements -> "Question", 
          MenuSortingValue -> 10030, MenuCommandKey :> "3", FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, 65}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> WindowWidth, 
          CellMargins -> {{66, 66}, {4, 1}}, ReturnCreatesNewCell -> True, 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`DefaultReturnCreatedCellStyle -> 
          "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 66}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSubsection"], CellMargins -> {{64, 64}, {2, 10}},
           FontFamily -> "Source Sans Pro", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["TechNoteSubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, 93}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, 93}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteNoDingbat"], PageWidth :> WindowWidth, 
          CellMargins -> {{82, 82}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"\[FilledSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 4, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 1, FontSize -> 
          14], 
         Cell[
          StyleData["TechNoteInput", "Printout"], 
          CellMargins -> {{99, 99}, {3, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TechNoteOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 14], 
         Cell[
          StyleData["TechNoteOutput", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10050, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], CellMargins -> {{64, 64}, {4, 8}},
           PageBreakBelow -> False, FontFamily -> "Source Sans Pro Light", 
          FontSize -> 14, FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{1, 1}, {1, 1}}, CellMargins -> {{52, 52}, {-1, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{16, 8}, {6, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "Bold", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[1], Background -> 
          RGBColor[0.901961, 0.411765, 0.027451]], 
         Cell[
          StyleData["TakeawaysSection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysHeader"], CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "SemiBold", 
          FontSlant -> "Regular", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysHeader", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysTable"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 0}}, CellMargins -> {{52, 52}, {12, -1}}, 
          ReturnCreatesNewCell -> True, 
          CellFrameMargins -> {{18, 12}, {20, 12}}, CellFrameLabelMargins -> 
          6, LineSpacing -> {1.25, 1., 2.}, SpanMaxSize -> 1, FontFamily -> 
          "Source Sans Pro Light", FontColor -> GrayLevel[0.25], Background -> 
          RGBColor[1., 0.9490196078431372, 0.8509803921568627], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"TakeawaysDingbat", Inherited}, 
              "Rows" -> {{SpanFromLeft, Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.75}}}}], 
         Cell[
          StyleData["TakeawaysTable", "Printout"], 
          CellMargins -> {{51.5, 51.5}, {12, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysText", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TakeawaysDingbat", StyleDefinitions -> StyleData["Text"]], 
          FontFamily -> "Source Sans Pro", FontSize -> 10, FontWeight -> 
          "SemiBold", FontColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TakeawaysDingbat", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeText", StyleDefinitions -> StyleData["Text"]], 
          CellMargins -> {{66, 66}, {3, 15}}, LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 1540, 
          MenuCommandKey :> $CellContext`MenuKey[
           "7", $CellContext`Modifiers -> {"Shift"}], FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeText", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 66}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], CellMargins -> {{99, 99}, {2, 12}}, 
          StripStyleOnPaste -> True, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 99}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, 100}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.135 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, 18}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontFamily -> Automatic, FontSize -> 
            18, FontWeight -> GrayLevel[0], 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{81, 81}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontSize -> 17, FontFamily -> 
            "Automatic", FontWeight -> "Black", 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{80, 80}, {Inherited, Inherited}}, 
          CellDingbatMargin -> 2, 
          CellGroupingRules -> {
           "GroupTogetherNestedGrouping", 1.073741821*^9}, 
          CellChangeTimes -> {{3.8855684925344043`*^9, 
           3.885568495926271*^9}, {3.885643888233819*^9, 
           3.885643900721007*^9}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 81}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, 80}, {Inherited, 0.5 Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 85}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, 90}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Note"], CellFrame -> {{0, 0}, {0, 1}}, 
          CellMargins -> {{66, 66}, {8, 6}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameMargins -> {{14, 14}, {12, 12}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          LineSpacing -> {1.2, 1., 2.}, MenuSortingValue -> 1600, FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontColor -> GrayLevel[0.2], 
          Background -> RGBColor[1., 0.9647058823529412, 0.9411764705882353]], 
         Cell[
          StyleData["Note", "Printout"], CellMargins -> {{66, 66}, {10, 8}}, 
          FontSize -> 14]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EchoTiming"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["EchoTiming", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 100}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 125}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 80}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110586`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 66}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TextFirst"], CellMargins -> {{66, 66}, {4, 72}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 66}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 66}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SmallText"], CellMargins -> {{66, 66}, {6, 6}}, 
          LineSpacing -> {1, 3}, TabSpacings -> {2.5}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "SmallText", 
          MenuSortingValue -> 1750, StyleMenuListing -> None, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["SmallText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}, Hyphenation -> True]}, Closed]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 99}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 99}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 99}, {15, 10}}]}, Closed]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       StyleData[
       "CellLabelExpired", StyleDefinitions -> StyleData["CellLabel"]], 
       CellLabelMargins -> 6, FontSlant -> Italic, FontTracking -> 0.4, 
       FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["SummaryPanel"], GeneratedCell -> True, CellAutoOverwrite -> 
       True, CellChangeTimes -> {3.84753348107472*^9}, FontFamily :> 
       CurrentValue["PanelFontFamily"], FontSize :> 0.8 Inherited, FontWeight -> 
       "Plain", FontSlant -> "Plain", FontColor :> 
       CurrentValue[{"SystemColors", "DialogText"}], 
       TemplateBoxOptions -> {
        DisplayFunction -> (
          ButtonBox[#, Active -> False, Alignment -> Left, 
           Appearance -> {"Default" -> Image[CompressedData["
1:eJzNlk0KgkAUgKVatGzRAWohXqFty7ZFB1AyaWOgQXQozyIPZmCgxYBLQUQ6
gL2R/ElcBKWvgU+cQd/3ZhxnZmmdt8eRpmn+FC9b87r2PPO2m2Fl7/onx7UP
G/diO7a3ssbYOEcWyATJvyw/CFGECcNQRwIkQ3J4Eb4BrXqjDT55togdYFxd
OUs5ABj4fipllMdxnCdJ0gsqdoQOzC3FPIyGP1DtfXnbSCkLZ/ntGEDWZ7+7
xgGAPSo/Y4O5SxiDau5yAj/nrPZzTuDnlV9wMbhfCFH4Fep+cP9d1P2n9hOO
/z/MP+r/j3r9oV5/qfcf6v2X4vyB+XQenMo1sS/a5QlC6exw
               "], "Byte", ColorSpace -> "RGB", Interleaving -> True]}, 
           FrameMargins -> 7, BaseStyle -> {Deployed -> False}, 
           DefaultBaseStyle -> {"Pane", Background -> None}, BaselinePosition -> 
           Baseline]& ), Tooltip -> None}, 
       GraphicsBoxOptions -> {
        Axes -> False, 
         DefaultBaseStyle -> {"GraphicsNoFontOrMenu", CacheGraphics -> False},
          ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}, 
       Graphics3DBoxOptions -> {
        Axes -> False, DefaultBaseStyle -> {"Graphics3DNoFontOrMenu"}, 
         ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}], 
      Cell[
       StyleData["IconizedDefaultName"], FontSize -> 12, 
       PrivateFontOptions -> {"OperatorSubstitution" -> False}, FontColor -> 
       GrayLevel[0.15]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, 66}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, 100}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{106, 106}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{106, 106}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{106, 106}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{106, 106}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 66}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 66}, {8, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Tentative"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[
          0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
         "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
       StyleMenuListing -> None, Background -> 
       RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["PrintOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.89, 0.867, 0.99], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.89, 0.867, 0.99]], 
         Cell[
          StyleData["PrintOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Closed]], 
      Cell[
       StyleData["SolvedExampleNote", StyleDefinitions -> StyleData["Text"]], 
       CellMargins -> {{66, 66}, {8, 0}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleInput", StyleDefinitions -> StyleData["Input"]], 
       CellMargins -> {{66, 66}, {0, -10}}, 
       GeneratedCellStyles -> {"Output" -> "SolvedExampleOutput"}, Background -> 
       RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleOutput", StyleDefinitions -> StyleData["Output"]], 
       CellMargins -> {{66, 66}, {8, -9}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData["SolvedExample"], CellMargins -> {{66, 66}, {0, 16}}, 
       CounterIncrements -> "SolvedExample", FontFamily -> "Source Sans Pro", 
       FontSize -> 16.5, FontWeight -> "SemiBold", FontColor -> 
       RGBColor[0., 0.0078, 0.13], Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0, 2}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["StandardForm", "Printout"], LineSpacing -> {1.25, 0, 2}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["OutputForm"], LineSpacing -> {0.6, 1}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["OutputForm", "Printout"], LineSpacing -> {0.6, 1}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputForm"], FontFamily -> "Source Sans Code"], 
         Cell[
          StyleData["InputForm", "Printout"], FontFamily -> 
          "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FormattedFunction"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]]], 
         Cell[
          StyleData["FormattedFunction", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup["ref/" <> #]]& ), ButtonSource -> 
            ButtonContents, Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FunctionLink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["FunctionLink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "FunctionHyperlink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["FunctionHyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ResourceFunctionlink", StyleDefinitions -> StyleData["Hyperlink"]],
           MenuSortingValue -> None, FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourceFunctionlink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Closed]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineMath"], SpanMaxSize -> 0, FontColor -> GrayLevel[0], 
       CellID -> 644119144], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.94 Inherited], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["DialogElementName"], 
       CellChangeTimes -> {3.642251807158844*^9, 3.8358753610849867`*^9, 
        3.835875471581566*^9}, FontFamily -> "Source Sans Pro SemiBold", 
       FontSize -> 0.95 Inherited, FontWeight -> "Regular"], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          1.05 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          1.1 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontSize -> 0.85 Inherited, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    PaneBox[
                    StyleBox[#4, "EntityTypeLabel"], BaselinePosition -> 
                    Baseline, ContentPadding -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               Directive[
                 RGBColor[1., 0.504768, 0.], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Helvetica", FontSize -> 0.85 Inherited, FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> Directive[
                 RGBColor[0.94227, 0.703639, 0.033387], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "14.0 for Mac OS X ARM (64-bit) (December 12, 2023)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"e07a9611-81be-425e-b242-3476875a3fa4"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[692, 24, 395, 7, 111, "SectionDoubleDigit",ExpressionUUID->"f9a6b797-267e-4aca-9fe4-bf8242dc7e65",
 PageBreakAbove->False,
 CounterAssignments->{{"Section", 9}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
 CellID->1066132550],
Cell[1090, 33, 795, 12, 138, "Text",ExpressionUUID->"6521c5b6-1d38-4e21-a75d-b3e9f3c20ae8",
 CellID->2033700929]
}, Open  ]],
Cell[CellGroupData[{
Cell[1922, 50, 594, 8, 57, "Subsection",ExpressionUUID->"0e3035d2-db0d-492b-b661-3442fb133d1f",
 CellID->1061788051],
Cell[2519, 60, 483, 8, 63, "Text",ExpressionUUID->"d2e15949-2c38-4923-9c36-a43878a2b37c",
 CellID->2030150234],
Cell[3005, 70, 1274, 38, 39, "Text",ExpressionUUID->"a86f0369-db5d-4488-a393-50bf014c1ab1",
 CellID->1514799302],
Cell[4282, 110, 720, 17, 39, "Text",ExpressionUUID->"3e27be8e-7740-406d-8efd-fd16cf635cbd",
 CellID->813233529],
Cell[5005, 129, 1745, 44, 165, "Text",ExpressionUUID->"6387577b-b899-4d8f-8cd6-bc9c94ed1d82",
 CellID->1429992395],
Cell[6753, 175, 486, 8, 63, "Text",ExpressionUUID->"ee2ed6f5-7c78-412a-8d8b-7bfd61f57f30",
 CellID->1392689188],
Cell[7242, 185, 944, 26, 39, "Text",ExpressionUUID->"4d8d391d-9b0f-4fff-afb2-555b22715e30",
 CellID->1502914063],
Cell[8189, 213, 1090, 24, 65, "Text",ExpressionUUID->"7510c00b-e8c0-4137-addf-ed483ef9b182",
 CellID->774000827]
}, Open  ]],
Cell[CellGroupData[{
Cell[9316, 242, 357, 5, 57, "Subsection",ExpressionUUID->"b7cefa4d-cc40-487f-bb70-82ed8cbb1ca8",
 CellID->1323449510],
Cell[9676, 249, 927, 14, 113, "Text",ExpressionUUID->"395ad1ce-7600-4b58-b438-6dbfac1c8068",
 CellID->1727782591],
Cell[10606, 265, 452, 7, 70, "Text",ExpressionUUID->"75c2dca3-bb23-4db1-8f32-b43fbb0494f4",
 CellID->568132203],
Cell[11061, 274, 882, 23, 70, "Text",ExpressionUUID->"2a611482-0731-4abb-bb22-746c7da19745",
 CellID->885641259],
Cell[11946, 299, 746, 15, 70, "Text",ExpressionUUID->"7a183c82-7360-4d34-85a8-72c2b99b4788",
 CellID->763482656],
Cell[CellGroupData[{
Cell[12717, 318, 42767, 711, 70, "Input",ExpressionUUID->"4f24e0fb-ac1b-4d0d-a6d7-270cab94ce2a",
 CellID->223408541],
Cell[55487, 1031, 42648, 709, 70, "Output",ExpressionUUID->"236a81f5-1c54-4cb0-bde1-fe4d4f9ef032",
 CellID->268819566]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98184, 1746, 544, 7, 70, "Subsection",ExpressionUUID->"76b7da40-a916-4f0b-b428-39ba793dd37f",
 CellID->638208567],
Cell[98731, 1755, 1504, 33, 70, "Text",ExpressionUUID->"c3a82708-f27f-474f-ab49-c6e18c8c9648",
 CellID->1838052451],
Cell[100238, 1790, 1154, 30, 70, "Text",ExpressionUUID->"7f49d719-80c1-493c-914e-ac1dc0372463",
 CellID->595281862],
Cell[101395, 1822, 252, 3, 70, "Text",ExpressionUUID->"c4976cc7-6861-4ebb-b978-3f304b6fcb7a",
 CellID->1923426908],
Cell[101650, 1827, 856, 21, 70, "Text",ExpressionUUID->"c2143601-b3ce-4b77-a211-7e6a6e92f1b5",
 CellID->964704465],
Cell[102509, 1850, 1690, 36, 70, "Text",ExpressionUUID->"e3ae91d7-5c9b-4e71-9f9e-a50695527981",
 CellID->286408405],
Cell[CellGroupData[{
Cell[104224, 1890, 2799, 53, 70, "Input",ExpressionUUID->"8b5f37da-2cbe-4614-aee1-fee0e4f6aa53",
 CellID->1155209908],
Cell[107026, 1945, 3334, 62, 70, "Output",ExpressionUUID->"32056209-9fd9-402f-bee8-18ef13960715",
 CellID->336734127]
}, Open  ]],
Cell[110375, 2010, 783, 12, 70, "Text",ExpressionUUID->"e718049d-bd1a-488b-89f9-720ede2a640b",
 CellID->213271229]
}, Open  ]],
Cell[CellGroupData[{
Cell[111195, 2027, 179, 2, 70, "Subsection",ExpressionUUID->"76c60dc5-5613-47ed-ae50-4c3c715e1de2",
 CellID->299338960],
Cell[111377, 2031, 1212, 18, 70, "Text",ExpressionUUID->"d3d8f34e-296a-4306-bc82-2846a44092f5",
 CellID->1583199446],
Cell[112592, 2051, 953, 27, 70, "Text",ExpressionUUID->"c2a7d299-814f-4fb7-b8ac-9012f286cbf7",
 CellID->1510702592],
Cell[113548, 2080, 1414, 25, 70, "Text",ExpressionUUID->"f8cb32bd-9007-422c-a88f-085ceb6a3862",
 CellID->679305263],
Cell[CellGroupData[{
Cell[114987, 2109, 3321, 59, 70, "Input",ExpressionUUID->"3f2bbe08-ebc2-40a4-8b6b-c5cadad1cd49",
 CellID->296925958],
Cell[118311, 2170, 2327, 46, 70, "Output",ExpressionUUID->"7e743566-eeb3-41c7-9333-b645b9a4a820",
 CellID->111412891]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120687, 2222, 359, 5, 70, "Subsection",ExpressionUUID->"6bb7911c-273f-4e1d-a929-b2e863d9c22f",
 CellID->1060487789],
Cell[121049, 2229, 821, 17, 70, "Text",ExpressionUUID->"b6ffa6e0-4d60-44dc-ba96-b0803bc33d8d",
 CellID->1651483270],
Cell[121873, 2248, 1201, 37, 70, "Text",ExpressionUUID->"a34fd5fd-0763-4136-83cb-8210b47dbb31",
 CellID->253181415],
Cell[123077, 2287, 1902, 45, 70, "Text",ExpressionUUID->"fc00b513-eb2b-4b08-9cfe-99914b43d88d",
 CellID->1054937198],
Cell[124982, 2334, 494, 11, 70, "Text",ExpressionUUID->"4e471c71-1c6d-4e96-9b61-d5d6f65b35d4",
 CellID->704497154],
Cell[125479, 2347, 1387, 37, 70, "Text",ExpressionUUID->"891225ed-9877-4ec0-acb9-e53b48a3e871",
 CellID->1406321367],
Cell[126869, 2386, 390, 9, 70, "Text",ExpressionUUID->"97d0debc-330d-42ba-bee7-f48dd6df91ab",
 CellID->838196287],
Cell[127262, 2397, 1546, 43, 70, "Text",ExpressionUUID->"c94b3b5a-f576-46ea-b4c7-5ad9045aa122",
 CellID->72271289],
Cell[128811, 2442, 350, 9, 70, "Text",ExpressionUUID->"394a93a4-4b09-4e21-83d8-d35328b2bb95",
 CellID->1335293668],
Cell[129164, 2453, 1539, 40, 70, "Text",ExpressionUUID->"3c9c4d63-8331-4093-bc55-228d3add2cb7",
 CellID->1076566926],
Cell[130706, 2495, 612, 12, 70, "Text",ExpressionUUID->"8d2ebe31-133c-46db-91b5-e713253b3ba3",
 CellID->1310599307],
Cell[131321, 2509, 1695, 43, 70, "Text",ExpressionUUID->"0cf15f1d-58f1-49db-968a-7e1ea331dc34",
 CellID->502785470],
Cell[133019, 2554, 396, 7, 70, "Text",ExpressionUUID->"277abcd0-cffd-4bb3-b5ce-d902af9ad59d",
 CellID->2114726992]
}, Open  ]],
Cell[CellGroupData[{
Cell[133452, 2566, 542, 7, 70, "Subsection",ExpressionUUID->"8029a7a4-8dad-4206-8657-a7290a051ee0",
 CellID->1362196694],
Cell[133997, 2575, 1446, 34, 70, "Text",ExpressionUUID->"ebc208b9-a474-4a23-8e8b-3ba9acb2b795",
 CellID->116675391],
Cell[135446, 2611, 959, 26, 70, "Text",ExpressionUUID->"60988a32-7763-43e8-bfb1-c12e3b94f31a",
 CellID->310726826],
Cell[CellGroupData[{
Cell[136430, 2641, 217, 3, 70, "Subsubsection",ExpressionUUID->"5de12b1c-ca6b-4814-b643-773f845bf1ff",
 CellID->1853018725],
Cell[136650, 2646, 640, 13, 70, "Text",ExpressionUUID->"d5db835a-7169-4af5-8553-e503e1085183",
 CellID->877862281],
Cell[CellGroupData[{
Cell[137315, 2663, 1090, 27, 70, "Input",ExpressionUUID->"7db473fc-0048-4e93-94f6-317546e7789c",
 CellID->1018701877],
Cell[138408, 2692, 529, 11, 70, "Output",ExpressionUUID->"057336b9-9193-4cbc-85ae-46a18b880565",
 CellID->452923894]
}, Open  ]],
Cell[138952, 2706, 421, 10, 70, "Text",ExpressionUUID->"dd01ebb7-7988-4e4e-9fd0-711fbd5c2a00",
 CellID->1582812855],
Cell[CellGroupData[{
Cell[139398, 2720, 1782, 37, 70, "Input",ExpressionUUID->"a0ecb938-615b-46e1-a4fe-a90ecb9883ba",
 CellID->1455718596],
Cell[141183, 2759, 25351, 553, 70, "Output",ExpressionUUID->"2fc1b417-46d5-4301-b36d-4acf93a917a8",
 CellID->104536998]
}, Open  ]],
Cell[CellGroupData[{
Cell[166571, 3317, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"3b2e1913-da18-4709-9083-abafbacf9586",
 CellID->2128736348],
Cell[166735, 3321, 934, 16, 70, "Text",ExpressionUUID->"2e23cdac-7fa0-466e-9af2-2078062d60a0",
 CellID->594241816],
Cell[167672, 3339, 1240, 32, 70, "Text",ExpressionUUID->"d152a73e-043f-452a-9c5d-53fe00e29c65",
 CellID->1623242962],
Cell[168915, 3373, 794, 16, 70, "Text",ExpressionUUID->"83558f9a-effa-402d-ba3b-e017d16b997f",
 CellID->212210846],
Cell[169712, 3391, 1209, 28, 70, "Text",ExpressionUUID->"e880cef6-e77b-45fb-a003-e2a9dc34472a",
 CellID->1804834702],
Cell[170924, 3421, 1319, 31, 70, "Text",ExpressionUUID->"2660f347-55a6-4b27-a014-d110bda7d643",
 CellID->650322639],
Cell[172246, 3454, 1388, 32, 70, "Text",ExpressionUUID->"e8b84dbe-681e-4773-8a2e-9c9078e26b82",
 CellID->1428314090],
Cell[173637, 3488, 202, 3, 70, "Text",ExpressionUUID->"c15aea80-ed53-4155-a528-2aef6166c357",
 CellID->1102704464]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[173900, 3498, 590, 8, 70, "Subsection",ExpressionUUID->"6b5bce33-c34d-4886-b17f-050250dd65be",
 CellID->370052838],
Cell[174493, 3508, 1335, 29, 70, "Text",ExpressionUUID->"4667c141-3c4e-4f8c-af5b-bad46d5fb6b2",
 CellID->365406554],
Cell[175831, 3539, 1164, 33, 70, "Text",ExpressionUUID->"f7932127-5690-43b6-9fde-2bc4c608ed4f",
 CellID->1732206305],
Cell[CellGroupData[{
Cell[177020, 3576, 217, 3, 70, "Subsubsection",ExpressionUUID->"b1604aa2-f28b-45a4-9c23-b022a9b6bae2",
 CellID->1903049403],
Cell[177240, 3581, 705, 14, 70, "Text",ExpressionUUID->"b66a6836-1bbd-484d-9692-65e48ca15c45",
 CellID->2077361450],
Cell[CellGroupData[{
Cell[177970, 3599, 1139, 30, 70, "Input",ExpressionUUID->"0a93bfbe-2710-4ec6-b074-10e6ee9d2df8",
 CellID->424757224],
Cell[179112, 3631, 692, 15, 70, "Output",ExpressionUUID->"7e6a0d21-3ac3-49af-9b5a-081e2476e1e8",
 CellID->69304788]
}, Open  ]],
Cell[179819, 3649, 420, 10, 70, "Text",ExpressionUUID->"92b3d9ba-cc91-45fc-8b83-f2b68f3a8877",
 CellID->659021140],
Cell[CellGroupData[{
Cell[180264, 3663, 1839, 39, 70, "Input",ExpressionUUID->"1868e212-e9ad-4a95-bcfc-3f61dd7bcfa2",
 CellID->1595132401],
Cell[182106, 3704, 23588, 524, 70, "Output",ExpressionUUID->"bd3ddbc0-084c-42e8-abc0-18d11e621f29",
 CellID->576954319]
}, Open  ]],
Cell[CellGroupData[{
Cell[205731, 4233, 160, 2, 70, "Subsubsubsubsection",ExpressionUUID->"abe6233f-1d34-4290-a2cd-b29f16c2845b",
 CellID->204414459],
Cell[205894, 4237, 935, 16, 70, "Text",ExpressionUUID->"a54ed0fc-46ab-45a5-9666-ba45d570114d",
 CellID->1767460860],
Cell[206832, 4255, 969, 21, 70, "Text",ExpressionUUID->"5a2ff46b-40ed-48e3-a042-339682aed8e6",
 CellID->1720868716],
Cell[207804, 4278, 696, 15, 70, "Text",ExpressionUUID->"81a06bec-7158-4550-91be-a443d7467b9f",
 CellID->330752016],
Cell[208503, 4295, 1142, 24, 70, "Text",ExpressionUUID->"706da941-225b-465d-b714-befbb4976fa1",
 CellID->1261454476],
Cell[209648, 4321, 1196, 25, 70, "Text",ExpressionUUID->"72a31799-5053-4688-8a40-9af07e71c299",
 CellID->1306814948],
Cell[210847, 4348, 1147, 24, 70, "Text",ExpressionUUID->"58dce830-2b8a-4cd2-84e0-2e6cdae91503",
 CellID->1323573167],
Cell[211997, 4374, 1145, 24, 70, "Text",ExpressionUUID->"6833aeab-72f8-4057-8c5f-a2b5420a66d2",
 CellID->1658602143],
Cell[213145, 4400, 202, 3, 70, "Text",ExpressionUUID->"57fff9a9-0f0c-42b3-852c-dfd5acb824d4",
 CellID->1788479341]
}, Open  ]],
Cell[CellGroupData[{
Cell[213384, 4408, 108, 1, 70, "SummarySection",ExpressionUUID->"228d3a38-4e2f-4b48-997b-5c69da92c70c",
 CellID->643677128],
Cell[213495, 4411, 640, 10, 70, "SummaryNote",ExpressionUUID->"149f85f1-5da3-4cd4-9b7e-e1593fdd60fd",
 CellID->1406360357],
Cell[214138, 4423, 329, 5, 70, "SummaryNote",ExpressionUUID->"4b7e400c-bf92-4d2b-9956-ce913bab76e0",
 CellID->1493501217],
Cell[214470, 4430, 7501, 172, 70, "SummaryNote",ExpressionUUID->"6c528365-e822-4d2a-9b0e-8d4950cb3610",
 CellID->1486087983],
Cell[221974, 4604, 7448, 170, 70, "SummaryNote",ExpressionUUID->"2af70652-6018-4025-8c82-2527c8fefeb9",
 CellID->1445915671],
Cell[229425, 4776, 704, 11, 70, "SummaryNote",ExpressionUUID->"db8f3be8-a6d8-409c-858b-011c8c7c6226",
 CellID->579733045]
}, Open  ]],
Cell[CellGroupData[{
Cell[230166, 4792, 111, 1, 70, "ExerciseSection",ExpressionUUID->"6ba10263-6931-46dd-b111-8561d073739c",
 CellID->439980876],
Cell[230280, 4795, 912, 28, 70, "Exercise",ExpressionUUID->"a18b2bcc-e6ba-4441-ac05-9d04fa9376e0",
 CellID->972386311],
Cell[CellGroupData[{
Cell[231217, 4827, 170, 2, 70, "Exercise",ExpressionUUID->"a3987ecb-6316-4539-af70-98bc9f0e5039",
 CellID->546175307],
Cell[231390, 4831, 494, 12, 70, "ExerciseNote",ExpressionUUID->"72b232a3-1cce-478c-909b-f81006025059",
 CellID->138784315],
Cell[231887, 4845, 1513, 34, 70, "ExerciseNote",ExpressionUUID->"d8bafd31-62b2-4bb6-bf3a-567541f18e4f",
 CellID->181970589]
}, Open  ]],
Cell[CellGroupData[{
Cell[233437, 4884, 174, 2, 70, "Exercise",ExpressionUUID->"7e12edba-8b18-4340-aaa6-bab6bf0bf06a",
 CellID->1223277471],
Cell[233614, 4888, 637, 17, 70, "ExerciseNote",ExpressionUUID->"853f6de5-f30c-427a-b1db-54c8458cb19f",
 CellID->111742113],
Cell[234254, 4907, 1485, 34, 70, "ExerciseNote",ExpressionUUID->"00256121-3f50-4485-a962-553c8c7da167",
 CellID->87485674]
}, Open  ]],
Cell[CellGroupData[{
Cell[235776, 4946, 759, 20, 70, "Exercise",ExpressionUUID->"5077d729-0605-47ae-86e1-dc023cab99ca",
 CellID->43492384],
Cell[236538, 4968, 628, 15, 29, "ExerciseNote",ExpressionUUID->"c0744604-631c-448d-92fd-543e54f06ec2",
 CellID->244220582],
Cell[237169, 4985, 968, 27, 33, "ExerciseNote",ExpressionUUID->"07834398-0f3e-4e33-bcc4-3361e32eded5",
 CellID->432239463]
}, Open  ]],
Cell[CellGroupData[{
Cell[238174, 5017, 495, 11, 29, "Exercise",ExpressionUUID->"02db8abb-c05b-4c80-a7cc-84e802039b55",
 CellID->1763502366],
Cell[238672, 5030, 1376, 33, 29, "ExerciseNote",ExpressionUUID->"1568625e-2968-4d72-861d-59751fa3596f",
 CellID->86264469]
}, Open  ]],
Cell[CellGroupData[{
Cell[240085, 5068, 830, 22, 48, "Exercise",ExpressionUUID->"f19b3187-d305-4e69-894f-5d5f31ff2632",
 CellID->1762453115],
Cell[240918, 5092, 1096, 27, 33, "ExerciseNote",ExpressionUUID->"588080f8-c543-488a-aacc-b4a743bbd264",
 CellID->50770850]
}, Open  ]],
Cell[CellGroupData[{
Cell[242051, 5124, 860, 24, 48, "Exercise",ExpressionUUID->"3602ed5f-b759-49d9-89e5-9552518131f0",
 CellID->1307560734],
Cell[242914, 5150, 1662, 44, 29, "ExerciseNote",ExpressionUUID->"5b41596e-813e-46ef-9774-1d0fcba8e456",
 CellID->480891019]
}, Open  ]],
Cell[CellGroupData[{
Cell[244613, 5199, 1259, 36, 67, "Exercise",ExpressionUUID->"980e855e-1f17-4afb-8b40-538de605f2bf",
 CellID->38139717],
Cell[245875, 5237, 1042, 23, 33, "ExerciseNote",ExpressionUUID->"9eb189e8-94e9-4b7e-b93c-09097a071b17",
 CellID->106857559],
Cell[246920, 5262, 994, 18, 30, "ExerciseNote",ExpressionUUID->"77b9a180-ecc1-4e14-a270-c2262686a281",
 CellID->109590416]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[247965, 5286, 310, 6, 135, "SmallText",ExpressionUUID->"82099fe5-ccbe-41b1-8a23-dd532f020ea8",
 CellGroupingRules->"SectionGrouping",
 CellID->1402660677]
}
]
*)

(* NotebookSignature XRWNRivLJxFpplYQh#yJse#T *)
