(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1425996,      26674]
NotebookOptionsPosition[   1257773,      23248]
NotebookOutlinePosition[   1402201,      26207]
CellTagsIndexPosition[   1402158,      26204]
WindowTitle->15. Continuous\:2010Time Fourier Transform | Signals, Systems, \
and Signal Processing
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Continuous-Time Fourier Transform", "SectionDoubleDigit",
 CellChangeTimes->{{3.875785172766713*^9, 3.875785174335588*^9}, {
  3.915808899713814*^9, 3.915808901160999*^9}},
 CounterAssignments->{{"Section", 14}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellID->1640225589,ExpressionUUID->"f88b082e-fffc-49c3-89d0-275fdcb40a49"],

Cell["\<\
The Fourier transform may be viewed as a natural extension of the Fourier \
series by considering an aperiodic signal as periodic with the period \
extending to infinity. As an illustration, consider the following \
demonstration showing a Fourier series line spectrum of a square wave as its \
period is increased:\
\>", "Text",
 CellChangeTimes->{{3.402873097*^9, 3.4028731179375*^9}, {
   3.465316165890625*^9, 3.465316178375*^9}, {3.4654734820625*^9, 
   3.465473558875*^9}, {3.465473598796875*^9, 3.4654736804375*^9}, {
   3.465473717875*^9, 3.465473781515625*^9}, {3.465558089671875*^9, 
   3.465558099609375*^9}, {3.6131430987202425`*^9, 3.613143127720888*^9}, {
   3.654358162281142*^9, 3.6543581834876733`*^9}, 3.801825484588957*^9, {
   3.811464551789223*^9, 3.8114645552016497`*^9}, {3.814114786533769*^9, 
   3.814114799005148*^9}, {3.891106564532117*^9, 3.8911065921761065`*^9}, {
   3.891106626216619*^9, 3.891106630663619*^9}, {3.891106665911674*^9, 
   3.891106715835202*^9}, 3.892299485176936*^9, {3.915813059859293*^9, 
   3.915813065780663*^9}},
 CellID->23897784,ExpressionUUID->"e8681450-7299-4e6b-a571-1b2f0c7f4673"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["3", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["3904", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    GraphicsRow[{
      Plot[
       Evaluate[
        Sum[
         UnitBox[
         2 ($CellContext`t - $CellContext`k $CellContext`T)], \
{$CellContext`k, -2, 5}]], {$CellContext`t, -2, 5}, Exclusions -> None, 
       PlotRange -> {-0.5, 1.5}, Ticks -> {Automatic, {0., 0.5, 1.}}, 
       AxesLabel -> Automatic], 
      ListPlot[
       Evaluate[
        Table[{(2 Pi) ($CellContext`k/$CellContext`T), 
          
          If[$CellContext`k == 0, 1/
           2, $CellContext`T (
            Sin[$CellContext`k (Pi/(2 $CellContext`T))]/($CellContext`k 
            Pi))]}, {$CellContext`k, 0, 100}]], Filling -> Axis, PlotStyle -> 
       PointSize[Medium], PlotRange -> {{0, 50}, {-0.2, 0.6}}, 
       Ticks -> {Automatic, {0., 0.5, 1.}}, 
       AxesLabel -> {$CellContext`\[Omega], None}]}, Spacings -> 50, 
     ImageSize -> {440, Automatic}], {{$CellContext`T, 2, "period, T"}, 1, 5},
     ControlPlacement -> Top],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.5284015572838*^9, 3.528401605612601*^9}, {
   3.5284017237358*^9, 3.5284018122346*^9}, {3.5284019101714*^9, 
   3.5284019197654*^9}, {3.5284019774074*^9, 3.5284020545182*^9}, {
   3.528402140443*^9, 3.5284021473538*^9}, {3.5284021929058*^9, 
   3.5284021934674*^9}, {3.5284022323114*^9, 3.5284022400958*^9}, {
   3.5284024135053997`*^9, 3.5284024994614*^9}, {3.528403461685*^9, 
   3.528403483244199*^9}, {3.5284035288118*^9, 3.528403561447*^9}, {
   3.528403612303*^9, 3.5284036356562*^9}, {3.5284038634006*^9, 
   3.5284039174702*^9}, {3.529074334129033*^9, 3.5290743710542984`*^9}, {
   3.5290752957567225`*^9, 3.5290753887328854`*^9}, {3.590360403605219*^9, 
   3.590360406896825*^9}, {3.591695730313861*^9, 3.5916957307609053`*^9}, {
   3.654358240885139*^9, 3.654358263515849*^9}, {3.7801530940550013`*^9, 
   3.7801530952140017`*^9}, {3.800636530393731*^9, 3.8006365362585793`*^9}, {
   3.8108318741290545`*^9, 3.8108319419540005`*^9}, {3.810831973191875*^9, 
   3.810832034950703*^9}, {3.811459510966241*^9, 3.811459511701791*^9}, 
   3.811459660831089*^9, {3.811460073909743*^9, 3.811460084723294*^9}, {
   3.81146083968488*^9, 3.811460845480271*^9}, {3.811460928607455*^9, 
   3.811460928697904*^9}, {3.811460988976593*^9, 3.811460989007395*^9}, {
   3.811462277690005*^9, 3.811462295363264*^9}, {3.811462407286547*^9, 
   3.811462408193713*^9}, {3.8114628020940523`*^9, 3.811462802328968*^9}, 
   3.811463034546568*^9, 3.811463191016207*^9, {3.8114632329079475`*^9, 
   3.8114632584478273`*^9}, 3.811463306013147*^9, {3.811463443730568*^9, 
   3.811463516657563*^9}, {3.811463566589017*^9, 3.811463567968527*^9}, {
   3.811463718440503*^9, 3.811463806145843*^9}, {3.8114638738773003`*^9, 
   3.811463895753081*^9}, {3.811463989189893*^9, 3.81146398925988*^9}, {
   3.812640340630699*^9, 3.812640353888237*^9}, {3.812640445656091*^9, 
   3.812640515932098*^9}, {3.81264057564851*^9, 3.812640618153598*^9}, {
   3.812640651203841*^9, 3.812640652666934*^9}, {3.8544653028890347`*^9, 
   3.854465323048434*^9}, {3.8544653973955173`*^9, 3.854465474735998*^9}, {
   3.892299492225079*^9, 3.892299532669285*^9}, {3.893951537722119*^9, 
   3.893951548316879*^9}, {3.893951625975919*^9, 3.8939516439137154`*^9}, {
   3.8939676257563243`*^9, 3.89396763908361*^9}, {3.895871486651847*^9, 
   3.895871557462829*^9}, {3.899548404731015*^9, 3.899548431055064*^9}},
 CellID->70613699,ExpressionUUID->"6382d507-c1af-4ccd-88ee-ce378fbde8dc"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`T$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`T$$], 2, "period, T"}, 1, 5}}, Typeset`size$$ = {
    440., {51.53713597386851, 58.76955804593637}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`T$$ = 2}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> GraphicsRow[{
         Plot[
          Evaluate[
           Sum[
            UnitBox[
            2 ($CellContext`t - $CellContext`k $CellContext`T$$)], \
{$CellContext`k, -2, 5}]], {$CellContext`t, -2, 5}, Exclusions -> None, 
          PlotRange -> {-0.5, 1.5}, Ticks -> {Automatic, {0., 0.5, 1.}}, 
          AxesLabel -> Automatic], 
         ListPlot[
          Evaluate[
           Table[{(2 Pi) ($CellContext`k/$CellContext`T$$), 
             
             If[$CellContext`k == 0, 1/
              2, $CellContext`T$$ (
               Sin[$CellContext`k (Pi/(2 $CellContext`T$$))]/($CellContext`k 
               Pi))]}, {$CellContext`k, 0, 100}]], Filling -> Axis, PlotStyle -> 
          PointSize[Medium], PlotRange -> {{0, 50}, {-0.2, 0.6}}, 
          Ticks -> {Automatic, {0., 0.5, 1.}}, 
          AxesLabel -> {$CellContext`\[Omega], None}]}, Spacings -> 50, 
        ImageSize -> {440, Automatic}], 
      "Specifications" :> {{{$CellContext`T$$, 2, "period, T"}, 1, 5}}, 
      "Options" :> {ControlPlacement -> Top}, "DefaultOptions" :> {}],
     ImageSizeCache->{484., {98., 105.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.5290753460668106`*^9, 3.529075412569727*^9}, 
   3.590360409330429*^9, 3.591695732027032*^9, {3.654358251653001*^9, 
   3.654358264124241*^9}, 3.7801530972470016`*^9, 3.800636538605269*^9, 
   3.81083185873104*^9, {3.8108319226179676`*^9, 3.810831942697016*^9}, {
   3.810831975849903*^9, 3.8108320356097*^9}, 3.811459512513169*^9, 
   3.8114596620862164`*^9, {3.811460910821098*^9, 3.811460930583199*^9}, 
   3.811460989848944*^9, 3.811462297193723*^9, 3.811462409701539*^9, 
   3.811462804037155*^9, 3.811463035841329*^9, 3.811463193268912*^9, 
   3.811463259267141*^9, 3.811463309027532*^9, {3.811463444624146*^9, 
   3.811463517419097*^9}, 3.811463568799639*^9, {3.811463720592935*^9, 
   3.811463754004762*^9}, {3.8114637878271804`*^9, 3.811463806961491*^9}, {
   3.811463877841258*^9, 3.811463896479236*^9}, 3.811463990893835*^9, 
   3.812641121734187*^9, 3.854465329668005*^9, {3.854465419992007*^9, 
   3.85446543901724*^9}, 3.854465483852624*^9, {3.892299511956422*^9, 
   3.892299534420198*^9}, 3.893951551345137*^9, {3.8939516193949795`*^9, 
   3.8939516470015616`*^9}, {3.895871525612378*^9, 3.895871559390271*^9}, 
   3.897571868469091*^9, 3.899548418933918*^9, 3.899548460433536*^9},
 CellID->484819639,ExpressionUUID->"effca984-4267-42b2-9b31-0f54c64757dc"]
}, Open  ]],

Cell["\<\
Observe that as the period increases, the frequency resolution of the Fourier \
series coefficients diminishes, and in the limit, it approaches a continuum.\
\>", "Text",
 CellChangeTimes->{{3.891038262200974*^9, 3.891038277513166*^9}, {
   3.891038376843266*^9, 3.891038504860231*^9}, 3.891038548880938*^9, 
   3.891106770747882*^9, 3.915813510208667*^9, 3.916219972258795*^9, {
   3.916220041115284*^9, 3.916220041866619*^9}, {3.9162358404630337`*^9, 
   3.9162358431212673`*^9}},
 CellID->36609945,ExpressionUUID->"cdfb9f20-dc0e-4dc3-aea2-ddeb15bc0e7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition", "Subsection",
 CellChangeTimes->{{3.399309488578125*^9, 3.39930950215625*^9}, {
  3.399678300640625*^9, 3.39967830415625*^9}, {3.402873020140625*^9, 
  3.40287302415625*^9}, {3.465765204171875*^9, 3.4657652093125*^9}, {
  3.8018255252553*^9, 3.801825526944784*^9}},
 CellID->1393465949,ExpressionUUID->"a6b5f963-1857-4a1b-b8a0-a5567e19b523"],

Cell["\<\
The continuous-time Fourier transform (CTFT) is defined by the following pair \
of equations\
\>", "Text",
 CellChangeTimes->{{3.613143152232347*^9, 3.613143156693954*^9}, {
   3.801825541573654*^9, 3.801825551284752*^9}, 3.916220086782093*^9, {
   3.918644185310938*^9, 3.9186441872782135`*^9}},
 CellID->1673034308,ExpressionUUID->"978b3d7f-f23e-4b0e-ad92-49953975dc36"],

Cell[TextData[{
 "\t",
 StyleBox["analysis:",
  FontSlant->"Italic"],
 "\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      RowBox[{"x", "(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"c3e4e8c4-b04e-477d-8339-235c1ad42d0a"]
}], "Text",
 CellChangeTimes->{{3.4653162636875*^9, 3.465316293265625*^9}, {
   3.4655584311875*^9, 3.465558431375*^9}, 3.750981017345863*^9, {
   3.8339886933178773`*^9, 3.833988720040407*^9}, {3.931269164103973*^9, 
   3.931269164104039*^9}},
 CellID->1684224385,ExpressionUUID->"0196fe6f-4e80-49f2-9ca7-4ee0426399bb"],

Cell[TextData[{
 "\t",
 StyleBox["synthesis:",
  FontSlant->"Italic"],
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
      RowBox[{
       RowBox[{"X", "(", 
        RowBox[{"j", " ", "\[Omega]"}], ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"j", " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"3f911e35-6600-4548-8d36-9e5e5bb5c6f5"]
}], "Text",
 CellChangeTimes->{{3.465316262390625*^9, 3.465316288578125*^9}, {
   3.4655584269375*^9, 3.4655584276875*^9}, 3.803429498550911*^9, 
   3.811464478084218*^9, {3.8339886635255566`*^9, 3.833988680988883*^9}, {
   3.833988974198505*^9, 3.8339889741994977`*^9}, 3.9162200614440594`*^9, {
   3.9312691663429413`*^9, 3.93126916634301*^9}},
 CellID->777287588,ExpressionUUID->"f9f547f8-8c15-443b-a698-68b4d2ebda41"],

Cell[TextData[{
 "The function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", 
    RowBox[{"j", " ", "\[Omega]"}], ")"}], TraditionalForm]],ExpressionUUID->
  "67be7896-1107-4652-9190-c5a8436e7a97"],
 " is called the ",
 "Fourier transform",
 " (or Fourier spectrum) of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "9b2d4ba0-60a5-47f5-9ddb-c083c0a19307"],
 ". ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", 
    RowBox[{"j", " ", "\[Omega]"}], ")"}], TraditionalForm]],ExpressionUUID->
  "1300d78a-d4fd-426f-ab9f-bd9e6ace22f3"],
 " is a continuous function of frequency ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]],ExpressionUUID->
  "bee8b781-b6a5-44a1-95a1-ed6a3b09c2ad"],
 " and is generally complex. "
}], "Text",
 CellChangeTimes->{{3.46531630628125*^9, 3.465316347203125*^9}, {
   3.465316407234375*^9, 3.465316413671875*^9}, {3.465558435921875*^9, 
   3.465558436078125*^9}, {3.654375253276478*^9, 3.6543752648827286`*^9}, {
   3.654375303819829*^9, 3.654375311370133*^9}, {3.810833065453461*^9, 
   3.810833065911446*^9}, {3.833988569719497*^9, 3.8339886367651796`*^9}, 
   3.834072627336641*^9},
 CellID->729466815,ExpressionUUID->"1522aa19-fd5d-4d8f-965f-e95cd7985e45"],

Cell["\<\
The conditions for the existence of the Fourier transform are similar to \
those for the Fourier series. Signals with finite energy are guaranteed to \
have a Fourier transform\
\>", "Text",
 CellChangeTimes->{{3.813273314079909*^9, 3.813273339119613*^9}, {
   3.8132765197617207`*^9, 3.8132765203107133`*^9}, {3.813276643026165*^9, 
   3.813276691929159*^9}, {3.891038587737296*^9, 3.891038591568119*^9}, 
   3.91622009030373*^9},
 CellID->164618982,ExpressionUUID->"2b099a0a-1a45-47c7-82ae-b8f99c43ee74"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[LeftBracketingBar]", 
        RowBox[{"x", "(", "t", ")"}], "\[RightBracketingBar]"}], "2"], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "<", "\[Infinity]"}], 
   TraditionalForm]],ExpressionUUID->"b3dc92c9-10ea-4ac3-8b2c-e0608521946a"]
}], "Text",
 CellChangeTimes->{{3.675424172339537*^9, 3.6754242060381083`*^9}, {
  3.675432134704359*^9, 3.6754321606830263`*^9}, {3.813272761156353*^9, 
  3.8132727613913555`*^9}, {3.813276564205688*^9, 3.813276631612153*^9}, {
  3.833989041359619*^9, 3.833989044272825*^9}, {3.931269171277801*^9, 
  3.931269171277858*^9}},
 CellID->792293138,ExpressionUUID->"e57c218d-a748-4be4-a79b-998cd3e88028"],

Cell["\<\
Therefore, all bounded, finite-duration signals have a Fourier transform. \
Also, the following Dirichlet sufficiency conditions apply:\
\>", "Text",
 CellChangeTimes->{{3.81327749967762*^9, 3.813277519855625*^9}, {
  3.891038625107068*^9, 3.891038662310237*^9}},
 CellID->1672158966,ExpressionUUID->"d3567b31-7971-43ee-a20d-d6e631b4e1cf"],

Cell[TextData[{
 "On any finite interval, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "2fed7788-3a99-4064-8f31-8306c74a5910"],
 " is bounded, has a finite number of maxima and minima, and has a finite \
number of discontinuities"
}], "Item",
 CellChangeTimes->{{3.654470989334456*^9, 3.654471005498849*^9}, {
   3.812880463202884*^9, 3.812880475630653*^9}, {3.81288051024268*^9, 
   3.812880510549899*^9}, {3.812880607091842*^9, 3.812880635012166*^9}, {
   3.813017076672347*^9, 3.813017099366195*^9}, 3.918646944500864*^9},
 CellID->2004736920,ExpressionUUID->"c75ff204-53da-4424-b179-0caf6bd966f6"],

Cell[TextData[{
 "Signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "d42cdb51-e9cb-45e5-b987-c567ec8c2b15"],
 " is absolutely integrable"
}], "Item",
 CellChangeTimes->{{3.6544711547206726`*^9, 3.6544711752206726`*^9}, {
   3.812880450127325*^9, 3.812880453405596*^9}, {3.813017080648709*^9, 
   3.813017096489938*^9}, 3.916220102319992*^9},
 CellID->1742476657,ExpressionUUID->"825716d7-3a24-41f4-ac29-33a951f85f3a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      RowBox[{"\[LeftBracketingBar]", 
       RowBox[{"x", "(", "t", ")"}], "\[RightBracketingBar]"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "<", "\[Infinity]"}], 
   TraditionalForm]],ExpressionUUID->"966f9917-44b1-4186-931b-0308a594f5f7"]
}], "Text",
 CellChangeTimes->{{3.6544691475240393`*^9, 3.6544692065240393`*^9}, {
  3.6544692842800393`*^9, 3.6544693155890393`*^9}, {3.931269174384921*^9, 
  3.931269174384975*^9}},
 CellID->570680060,ExpressionUUID->"1bc607fe-3f2d-4a86-a1ba-66ca6fafd03f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection",
 CellChangeTimes->{{3.399309959765625*^9, 3.39930997340625*^9}, {
  3.39967830984375*^9, 3.39967831284375*^9}, {3.402873186671875*^9, 
  3.402873190171875*^9}, {3.402874457875*^9, 3.40287446528125*^9}, {
  3.465147466578125*^9, 3.46514747*^9}, {3.465316527953125*^9, 
  3.465316532734375*^9}, {3.6131432527927322`*^9, 3.613143260226604*^9}, {
  3.68607484761526*^9, 3.686074854109347*^9}},
 CellID->757800918,ExpressionUUID->"a8019496-d54b-46c8-a257-47f0afa7dc2a"],

Cell["Obtain the Fourier transform of the unit pulse signal", "Text",
 CellChangeTimes->{{3.654374130465273*^9, 3.654374164332439*^9}, {
   3.7746303733987007`*^9, 3.774630382403971*^9}, {3.810833152701454*^9, 
   3.81083315332051*^9}, {3.8114647303525887`*^9, 3.811464752073022*^9}, 
   3.9162201052978473`*^9},
 CellID->1782002116,ExpressionUUID->"4003087e-7b83-478d-b6cf-32d75573f2fc"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{"{", GridBox[{
       {
        RowBox[{"1", ","}], 
        RowBox[{"|", "t", "|", 
         RowBox[{"\[LessEqual]", 
          FractionBox["1", "2"]}]}]},
       {
        RowBox[{"0", ","}], "else"}
      }]}]}], TraditionalForm]],ExpressionUUID->
  "f7ce25ca-2ed6-4d13-9652-03cb2c3eef22"]
}], "Text",
 CellChangeTimes->{
  3.46531652478125*^9, {3.833989071796955*^9, 3.8339890742742743`*^9}},
 CellID->1302622550,ExpressionUUID->"c8f3f566-0068-4b7b-93e2-22e164a91e96"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.686074884091888*^9, 3.6860748855582905`*^9}},
 CellID->1728900332,ExpressionUUID->"b8eeb237-52da-4674-a00c-ca08d0dbfa1e"],

Cell["\<\
The Fourier transform exists because the given signal satisfies the absolute \
integrability condition:\
\>", "Text",
 CellChangeTimes->{
  3.613143280209868*^9, {3.6543614871747108`*^9, 3.6543615203454876`*^9}, {
   3.6543741781382613`*^9, 3.654374236965107*^9}, {3.686074859792386*^9, 
   3.686074900721517*^9}, {3.8007002702331114`*^9, 3.8007003014008226`*^9}, 
   3.800700765021633*^9, {3.8018256506491823`*^9, 3.8018256670673094`*^9}, 
   3.810833163702505*^9, {3.814115051882902*^9, 3.8141150761326284`*^9}, {
   3.814115130663852*^9, 3.814115140609251*^9}, {3.8339891037784147`*^9, 
   3.8339891049572983`*^9}},
 CellID->26652367,ExpressionUUID->"ed4c5be3-0a79-4703-aaf2-49902c89b77c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"UnitBox", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.801826499290431*^9, 3.8018265173960495`*^9}, {
  3.8114649416366463`*^9, 3.8114650030134664`*^9}},
 CellID->1269733593,ExpressionUUID->"5fdedbf4-4070-4494-a85e-8d7a3d302842"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.8018265182288227`*^9, 3.8114649700792866`*^9, 
  3.811465006354805*^9, 3.8975718745268745`*^9},
 CellID->213638193,ExpressionUUID->"89bd3386-70ac-444f-b7ad-9f9037a16b63"]
}, Open  ]],

Cell[TextData[{
 "This returns the result using the ",
 ButtonBox["FourierTransform",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FourierTransform"],
 " function with ",
 ButtonBox["FourierParameters",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FourierParameters"],
 " matching the definition given earlier:"
}], "Text",
 CellChangeTimes->{{3.774630425387077*^9, 3.7746304292465878`*^9}, {
  3.814114877608755*^9, 3.814114878092465*^9}, {3.814114915404359*^9, 
  3.814115007424176*^9}, {3.82544650703512*^9, 3.825446507644308*^9}, {
  3.8339891371103945`*^9, 3.833989144067707*^9}, {3.8340727073128853`*^9, 
  3.834072731418083*^9}, {3.8910387114978104`*^9, 3.891038727428925*^9}, {
  3.923568728794935*^9, 3.923568750298048*^9}},
 CellID->867497312,ExpressionUUID->"7a186b38-1a01-4228-b8bf-c96767ba2fd5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourierTransform", "[", 
  RowBox[{
   RowBox[{"UnitBox", "[", "t", "]"}], ",", "t", ",", "\[Omega]", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774630434534247*^9, 3.774630476655412*^9}, {
  3.774630511175705*^9, 3.774630513772238*^9}, {3.811459701955059*^9, 
  3.8114597226106153`*^9}},
 CellID->760843301,ExpressionUUID->"c9b53bbc-b329-42da-9ef5-42a466c83ed0"],

Cell[BoxData[
 RowBox[{"Sinc", "[", 
  FractionBox["\[Omega]", "2"], "]"}]], "Output",
 CellChangeTimes->{
  3.774630450728981*^9, 3.774630514709474*^9, {3.8114597027742133`*^9, 
   3.811459723701689*^9}, 3.897571878382174*^9},
 CellID->111348218,ExpressionUUID->"5a746253-50a9-496f-9cd4-adbeb7180c65"]
}, Open  ]],

Cell["\<\
Here are plots of the time function (left) and its Fourier transform (right):\
\
\>", "Text",
 CellChangeTimes->{{3.654374300206697*^9, 3.654374313903321*^9}, {
  3.6543774764491744`*^9, 3.654377482455097*^9}, {3.654377536383606*^9, 
  3.654377536945199*^9}, {3.810833225931681*^9, 3.810833246688264*^9}, {
  3.834072735121172*^9, 3.834072735433537*^9}},
 CellID->1375725669,ExpressionUUID->"3d0fa574-1347-4ebd-8d36-49e163dd5e01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"List", "ListIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["List", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1160", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   {
    Plot[
     UnitBox[$CellContext`t], {$CellContext`t, -2, 2}, 
     PlotRange -> {-0.5, 1.5}, Exclusions -> None, AxesLabel -> Automatic], 
    Plot[
     Sinc[$CellContext`\[Omega]/2], {$CellContext`\[Omega], -30, 30}, 
     PlotRange -> {-0.5, 1.5}, AxesLabel -> Automatic, PlotRange -> All]},
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.654374316227691*^9, 3.654374370639794*^9}, {
   3.654377399464161*^9, 3.654377460584178*^9}, {3.684443889615403*^9, 
   3.684443906416603*^9}, {3.6861428347838*^9, 3.686142845128549*^9}, {
   3.6861429158945723`*^9, 3.6861429328206024`*^9}, {3.6861429978903046`*^9, 
   3.6861431216584225`*^9}, {3.686143159020488*^9, 3.686143164137297*^9}, {
   3.6861432014520802`*^9, 3.686143203657314*^9}, {3.686143248436786*^9, 
   3.686143255756906*^9}, {3.686143299341857*^9, 3.686143317097319*^9}, {
   3.6861433498337536`*^9, 3.6861433763966436`*^9}, {3.68614355477202*^9, 
   3.686143579906315*^9}, {3.774630557607062*^9, 3.774630587176015*^9}, {
   3.800709843975204*^9, 3.800709861739694*^9}, {3.814115473417489*^9, 
   3.814115481417098*^9}, {3.892299579619692*^9, 3.89229959348368*^9}, 
   3.893951654300923*^9, 3.893952205131199*^9},
 CellID->2012375281,ExpressionUUID->"98705f04-bbf3-432a-8088-55fa1781b4cb"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox["t", HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{1.1479035532646549`, 11.212890502437972`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {125.6591639001779, -78.225}, 
     ImageScaled[{0.5, 0.5}], {235.37138491137173, 149},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwUW3k8lN8XtlSESkJk3/exzti7N1GhbGWJkoR8JS1SCKWFFkmRLUSyL1ln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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {"WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwUW3k8lN8XtlSESkJk3/exzti7N1GhbGWJkoR8JS1SCKWFFkmRLUSyL1ln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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-29.999998775510203`, 
               29.999998775510203`}, {-0.5, 1.5}}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-29.999998775510203`, 
              29.999998775510203`}, {-0.5, 1.5}}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwUW3k8lN8XtlSESkJk3/exzti7N1GhbGWJkoR8JS1SCKWFFkmRLUSyL1ln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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-29.999998775510203`, 29.999998775510203`}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox["\[Omega]", HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{4.0819752680338155`, 15.944335634447668`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-29.999998775510203`, 29.999998775510203`}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {380.81025012392314, -78.225}, 
     ImageScaled[{0.5, 0.5}], {243.03690175815058, 149},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[149]},
  PlotRange->{{0, 510.3021724474905}, {-156.45, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.893951666120079*^9, 3.8939522074393096`*^9, 
  3.8975718816536646`*^9},
 CellID->275226895,ExpressionUUID->"e6b4d4ee-f68f-421d-8478-505afb3c373e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1271391164,ExpressionUUID->"6c4d38f7-a5d6-4c6b-a044-c64d0b9473a9"],

Cell["The Fourier transform analysis formula is", "Text",
 CellChangeTimes->{{3.814115223420905*^9, 3.814115233897932*^9}, 
   3.916220112644319*^9},
 CellID->809005698,ExpressionUUID->"1f1b3da1-3653-42bf-a4a7-0a2b5a6be890"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      RowBox[{"x", "(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"e69312e3-65fc-4394-a74a-f70a26755a95"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.8122889419524803`*^9, 3.812288955402125*^9}, {3.812291389371261*^9, 
  3.812291389371261*^9}, {3.812291469534463*^9, 3.812291469534463*^9}, {
  3.833989274528846*^9, 3.8339892840055037`*^9}, {3.9312691850136747`*^9, 
  3.931269185013728*^9}},
 CellID->1239797129,ExpressionUUID->"8b872573-ff52-4656-afa5-866d520875cd"],

Cell["\<\
Substitution of the signal into the Fourier transform integral reduces to the \
following definite integral\
\>", "Text",
 CellChangeTimes->{
  3.613143280209868*^9, {3.6543614871747108`*^9, 3.6543615203454876`*^9}, {
   3.6543741781382613`*^9, 3.654374236965107*^9}, {3.686074859792386*^9, 
   3.686074900721517*^9}, {3.8007002702331114`*^9, 3.8007003014008226`*^9}, 
   3.800700765021633*^9, 3.8018256506491823`*^9, {3.814115271023473*^9, 
   3.8141153250388446`*^9}, 3.9162201155344477`*^9},
 CellID->236520262,ExpressionUUID->"eb966562-44fd-4af4-9c97-6679067155c0"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], 
      RowBox[{"1", "/", "2"}]], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"8b472b92-90c4-42c7-ba82-8540aa940eb4"]
}], "Text",
 CellChangeTimes->{{3.812291410350488*^9, 3.812291412496641*^9}, {
  3.812291461569185*^9, 3.8122914622754374`*^9}, {3.833989357924811*^9, 
  3.833989368594266*^9}},
 CellID->203812837,ExpressionUUID->"8cb1909b-2c34-4dc7-b829-250bccefa450"],

Cell["Integration yields", "Text",
 CellChangeTimes->{{3.814115347288061*^9, 3.8141153538724833`*^9}, 
   3.91622011976692*^9},
 CellID->245934494,ExpressionUUID->"fe5a294f-cd1e-4c88-87ca-fad6c2765c50"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"j", " ", "\[Omega]"}]]}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t"}]]}], 
     SubsuperscriptBox["\[VerticalSeparator]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      FractionBox["1", "2"]]}]}], TraditionalForm]],ExpressionUUID->
  "5d8cd1f8-b77f-46ee-89d1-766790a5bf6f"]
}], "Text",
 CellChangeTimes->{{3.81229142174097*^9, 3.812291422980579*^9}, {
  3.81229145495202*^9, 3.81229145495202*^9}},
 CellID->1662503830,ExpressionUUID->"a7bea3bc-208d-48b8-8e91-84bf3a04f664"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"j", " ", "\[Omega]"}]]}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "j"}], " ", 
         FractionBox["\[Omega]", "2"]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"j", " ", 
         FractionBox["\[Omega]", "2"]}]]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"6a894f10-d7d1-4d19-9537-39476ad73173"]
}], "Text",
 CellChangeTimes->{{3.812291434893228*^9, 3.812291442488532*^9}},
 CellID->792139693,ExpressionUUID->"b1dca42b-16c7-4f40-9473-ba0421498028"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"sin", "(", 
       FractionBox["\[Omega]", "2"], ")"}]}], "\[Omega]"], " "}], 
   TraditionalForm]],ExpressionUUID->"715b0246-2aef-4318-8423-d18f11f6f072"]
}], "Text",
 CellChangeTimes->{{3.8122914456525407`*^9, 3.812291449080499*^9}, {
  3.8128810524478607`*^9, 3.8128810524478607`*^9}},
 CellID->1240692498,ExpressionUUID->"d5bcc448-4ce0-4d89-9431-5726b44daa47"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{"sinc", "(", 
     FractionBox["\[Omega]", "2"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "3bb1d05c-ebaf-4f61-bc10-0716a381cd9f"]
}], "Text",
 CellChangeTimes->{{3.812881056546429*^9, 3.8128810777497587`*^9}},
 CellID->252601516,ExpressionUUID->"2fbd1124-ae8c-4094-b1b7-3d2919b90fc0"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection",
 CellChangeTimes->{{3.6131436819995604`*^9, 3.6131436895394783`*^9}, {
  3.613143737431562*^9, 3.6131437455022206`*^9}, {3.6543616643266497`*^9, 
  3.654361665559034*^9}, {3.654375056422601*^9, 3.6543750569685946`*^9}, {
  3.686074918649019*^9, 3.686074918747024*^9}},
 CellID->2045992940,ExpressionUUID->"144ea7da-ba9e-4b15-9ccb-9ba8a084f869"],

Cell[TextData[{
 "Obtain the Fourier transform of the signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]], 
     RowBox[{"u", "(", "t", ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "30258b37-c5ab-495e-9fc0-ac125bfd16e0"],
 "."
}], "Text",
 CellChangeTimes->{
  3.613143759781906*^9, {3.6131437994701085`*^9, 3.613143809516815*^9}, {
   3.654374840942564*^9, 3.65437484752568*^9}, 3.686140863677016*^9},
 CellID->1495186816,ExpressionUUID->"f01f4a6f-55ff-4972-8062-cce6c2e34ee7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.654361673530532*^9, 3.654361674984313*^9}},
 CellID->1898662965,ExpressionUUID->"7249553a-fd1a-4678-8c43-cc93bb2cc2ab"],

Cell["\<\
The signal is absolutely integrable and so it satisfies the existence \
condition:\
\>", "Text",
 CellChangeTimes->{{3.6131442381523952`*^9, 3.613144264085372*^9}, {
   3.613144302358076*^9, 3.613144303418878*^9}, 3.686140874566443*^9, {
   3.686140906797914*^9, 3.686140936225299*^9}, {3.801825911073272*^9, 
   3.801825922925631*^9}, {3.8018260838426433`*^9, 3.801826097475421*^9}, {
   3.801826456514783*^9, 3.801826495176426*^9}, {3.801826570099264*^9, 
   3.8018266011362767`*^9}, 3.812881127627204*^9, {3.8128811847508*^9, 
   3.812881206287442*^9}, 3.833989432067563*^9},
 CellID->1368941982,ExpressionUUID->"244384de-2927-4659-bef9-d2479431e5ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{"UnitStep", "[", "t", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.801826499290431*^9, 3.8018265173960495`*^9}, {
  3.811500895555731*^9, 3.811500905791994*^9}},
 CellID->1815581163,ExpressionUUID->"89ed1c8b-2e3e-4b4b-88ba-63043d16818c"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.814115399010737*^9, 3.8975718860576057`*^9},
 CellID->412909794,ExpressionUUID->"5467f455-a91c-4824-b769-5b76ff2fdb51"]
}, Open  ]],

Cell[TextData[{
 "The Fourier transform of the signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "b0ebcd8a-82b5-4ebc-a734-19375f5786a0"],
 " is:"
}], "Text",
 CellChangeTimes->{{3.6131442381523952`*^9, 3.613144264085372*^9}, {
   3.613144302358076*^9, 3.613144303418878*^9}, 3.686140874566443*^9, {
   3.686140906797914*^9, 3.686140936225299*^9}, {3.801825911073272*^9, 
   3.801825914906031*^9}, {3.812881131359255*^9, 3.812881166372136*^9}, {
   3.812881246227128*^9, 3.812881246414624*^9}},
 CellID->877466318,ExpressionUUID->"d2556e03-9d81-4998-a144-4833e718709d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourierTransform", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], 
    RowBox[{"UnitStep", "[", "t", "]"}]}], ",", "t", ",", "\[Omega]", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774630434534247*^9, 3.774630476655412*^9}, {
  3.774630511175705*^9, 3.774630513772238*^9}, {3.7746306510544143`*^9, 
  3.774630663515992*^9}, {3.8018258196266375`*^9, 3.801825833531479*^9}},
 CellID->806202677,ExpressionUUID->"a548dcf2-7c4b-4561-8827-0060acee239c"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["\[ImaginaryI]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], "+", "\[Omega]"}]]}]], "Output",
 CellChangeTimes->{3.814115415462756*^9, 3.897571890666717*^9},
 CellID->150360892,ExpressionUUID->"b4a19b33-1320-4330-8805-7a0e9cfdbe29"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1374063416,ExpressionUUID->"08fec22e-a981-4010-a689-1f411e1d105f"],

Cell["The Fourier transform analysis formula is", "Text",
 CellChangeTimes->{{3.814115223420905*^9, 3.814115233897932*^9}, 
   3.916220127853382*^9},
 CellID->1992176521,ExpressionUUID->"0e7b31be-7b68-4670-b953-f3ab8b7dfcb1"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      RowBox[{"x", "(", " ", "t", ")"}], " ", 
      SuperscriptBox[
       RowBox[{"\[ExponentialE]", " "}], 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t", " "}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"ab720a12-421a-4ff8-9c74-8aba1bd2f7c3"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.8122889419524803`*^9, 3.812288955402125*^9}, {3.812291389371261*^9, 
  3.812291389371261*^9}, {3.812291469534463*^9, 3.812291469534463*^9}, {
  3.931269204443357*^9, 3.931269204443424*^9}},
 CellID->1093248070,ExpressionUUID->"4e2f007b-232e-4544-9453-0557a061001d"],

Cell["\<\
Substitution of the signal into the Fourier transform integral reduces to the \
following improper definite integral\
\>", "Text",
 CellChangeTimes->{
  3.613143280209868*^9, {3.6543614871747108`*^9, 3.6543615203454876`*^9}, {
   3.6543741781382613`*^9, 3.654374236965107*^9}, {3.686074859792386*^9, 
   3.686074900721517*^9}, {3.8007002702331114`*^9, 3.8007003014008226`*^9}, 
   3.800700765021633*^9, 3.8018256506491823`*^9, {3.814115271023473*^9, 
   3.8141153250388446`*^9}, {3.814115561450031*^9, 3.814115561669457*^9}, {
   3.814115893800022*^9, 3.8141158978222647`*^9}, 3.9162201319170628`*^9},
 CellID->350228758,ExpressionUUID->"f45535a6-af6f-4f49-8e33-11623b016cf1"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t", " "}]], 
       SuperscriptBox[
        RowBox[{"\[ExponentialE]", " "}], 
        RowBox[{
         RowBox[{"-", "j"}], " ", "\[Omega]", " ", "t", " "}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}], "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[ExponentialE]", " "}], 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"j", " ", "\[Omega]"}], "+", "1"}], ")"}]}], " ", "t", 
         " "}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"6426612d-bbb8-4bee-b840-8d6f6c961b6b"]
}], "Text",
 CellChangeTimes->{{3.812291410350488*^9, 3.812291412496641*^9}, {
  3.812291461569185*^9, 3.8122914622754374`*^9}, {3.814115550381643*^9, 
  3.8141155572243*^9}, {3.814115946161954*^9, 3.814116014064865*^9}, {
  3.931269207591138*^9, 3.931269209545103*^9}},
 CellID->42059279,ExpressionUUID->"ae7177ce-69b7-4d67-9844-b7895f6907cc"],

Cell["Integration yields", "Text",
 CellChangeTimes->{{3.814115347288061*^9, 3.8141153538724833`*^9}, 
   3.916220134646055*^9},
 CellID->368182290,ExpressionUUID->"5bce320e-143c-4216-8062-96dec214db11"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{
         RowBox[{"j", " ", "\[Omega]"}], "+", "1"}]]}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"j", " ", "\[Omega]"}], " ", "+", "1"}], ")"}]}], "t"}]]}], 
     SubsuperscriptBox["\[VerticalSeparator]", "0", "\[Infinity]"]}]}], 
   TraditionalForm]],ExpressionUUID->"c6b41560-d7cb-4a46-9f46-7d2f5d684643"]
}], "Text",
 CellChangeTimes->{{3.81229142174097*^9, 3.812291422980579*^9}, {
  3.81229145495202*^9, 3.81229145495202*^9}, {3.814115926001081*^9, 
  3.8141159335538983`*^9}, {3.814116027988643*^9, 3.814116041625196*^9}},
 CellID->1139361023,ExpressionUUID->"b332339d-719d-480a-8b6e-0c9574f935eb"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"j", " ", "\[Omega]"}], "+", "1"}]]}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"j", " ", "\[Omega]"}], "+", "1"}], ")"}]}], " ", "t"}]], 
       
       SubscriptBox["\[VerticalSeparator]", 
        RowBox[{"t", "\[Rule]", "\[Infinity]"}]], 
       RowBox[{"-", "1"}]}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "0d8c9d17-9461-47c5-a23f-273ae1f994cd"]
}], "Text",
 CellChangeTimes->{{3.812291434893228*^9, 3.812291442488532*^9}, {
  3.814116069345153*^9, 3.814116069660259*^9}, {3.814116119488702*^9, 
  3.814116153421921*^9}, {3.81411621340576*^9, 3.81411622866096*^9}},
 CellID->129033262,ExpressionUUID->"8f3599e4-14c1-4e6b-96f3-22b8c9e1f976"],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], "\[Rule]", "0"}], TraditionalForm]],ExpressionUUID->
  "b6cfa8dc-87f4-4b2d-9e2b-4fe65152292e"],
 " as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[Rule]", "\[Infinity]"}], TraditionalForm]],ExpressionUUID->
  "fefe56b8-3453-48ed-be16-961354bd0a57"],
 ", the result reduces to"
}], "Text",
 CellChangeTimes->{{3.814116234200267*^9, 3.814116273489363*^9}, 
   3.834072795482724*^9, 3.9162201377060966`*^9},
 CellID->1851034611,ExpressionUUID->"133a022c-65e6-4f1f-97c6-e675ef94030e"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"j", " ", "\[Omega]"}], "+", "1"}]]}], 
     RowBox[{"(", 
      RowBox[{"0", "-", "1"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "0a610795-3383-4578-a20f-cb9124a791e0"]
}], "Text",
 CellChangeTimes->{{3.8122914456525407`*^9, 3.812291449080499*^9}, {
  3.8128810524478607`*^9, 3.8128810524478607`*^9}, {3.814116289104596*^9, 
  3.814116296546918*^9}},
 CellID->1890596635,ExpressionUUID->"5273de49-48db-45f7-ac1e-36ee9392ab7d"],

Cell["Finally", "Text",
 CellChangeTimes->{{3.814116454032245*^9, 3.814116455316826*^9}, 
   3.834072797882709*^9, 3.916220140014065*^9},
 CellID->1089603433,ExpressionUUID->"96f36cf9-72ee-4c6f-8a87-fbcf5b40b758"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"j", " ", "\[Omega]"}], "+", "1"}]]}], TraditionalForm]],
  ExpressionUUID->"ef337018-e5b8-4ed8-8a7b-00933ae219b2"]
}], "Text",
 CellChangeTimes->{{3.812881056546429*^9, 3.8128810777497587`*^9}, {
  3.8141164644912887`*^9, 3.8141164644912887`*^9}},
 CellID->1371840462,ExpressionUUID->"22d99522-3075-4ac1-a228-00adc2d9104e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualizing Fourier Transforms", "Subsection",
 CellChangeTimes->{{3.65436142054856*^9, 3.654361427401275*^9}, {
  3.6844431061475635`*^9, 3.684443111404898*^9}, {3.8339894571594048`*^9, 
  3.833989459272799*^9}},
 CellID->1138210642,ExpressionUUID->"7fc2aeed-a337-4f74-963e-67f48501b14c"],

Cell["\<\
The Fourier transform is generally complex; therefore, plots of the magnitude \
and phase, or, less frequently, the real and imaginary parts, are used. \
\>", "Text",
 CellChangeTimes->{{3.40287930390625*^9, 3.4028793170625*^9}, {
   3.402879402328125*^9, 3.402879435953125*^9}, {3.402879777890625*^9, 
   3.402879779875*^9}, {3.40288078878125*^9, 3.40288085596875*^9}, {
   3.465324504984375*^9, 3.465324529796875*^9}, {3.6131641384900055`*^9, 
   3.613164140237208*^9}, {3.613164179003276*^9, 3.613164196412907*^9}, {
   3.654361739429843*^9, 3.654361796788512*^9}, {3.654375375719308*^9, 
   3.654375460847416*^9}, {3.803429683712799*^9, 3.8034296860633135`*^9}, {
   3.834072807690974*^9, 3.834072820715238*^9}, {3.9158147480265384`*^9, 
   3.915814753666209*^9}, 3.9186470720531826`*^9},
 CellID->121932618,ExpressionUUID->"08bbe328-4a25-4966-8d70-59aa6d699b9a"],

Cell["\<\
Use the following Fourier transform to illustrate all the visualization \
alternatives:\
\>", "Text",
 CellChangeTimes->{{3.800655982283589*^9, 3.8006560008589125`*^9}, {
   3.81284568840784*^9, 3.81284575238973*^9}, 3.833989474448212*^9},
 CellID->622111488,ExpressionUUID->"464797cf-1a29-43f3-887e-d0a9a0a75db1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "\[Omega]_", "]"}], ":=", 
   FractionBox["1", 
    RowBox[{"1", "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.800656004636779*^9, 3.800656024410135*^9}, {
  3.8006561108450527`*^9, 3.800656111338756*^9}, {3.80183287607512*^9, 
  3.801832893869565*^9}},
 CellID->1877385220,ExpressionUUID->"eda370ed-d3ae-46b3-b5f9-58f2647303b8"],

Cell["This shows the magnitude and phase:", "Text",
 CellChangeTimes->{{3.6543618799205256`*^9, 3.6543618897066555`*^9}, {
  3.654362456377279*^9, 3.65436245878699*^9}},
 CellID->236167169,ExpressionUUID->"9b2ed0a7-4bdc-4e04-bab2-79c489e7ec35"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"List", "ListIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["List", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1712", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   {
    Plot[
     Abs[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], -10, 
      10}, 
     Sequence[
     PlotRange -> {-0.5, 1.5}, AxesLabel -> {$CellContext`\[Omega], None}, 
      PlotLabel -> "magnitude"]], 
    Plot[
     Arg[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], -10, 
      10}, 
     Sequence[
     Exclusions -> None, PlotRange -> (1/2) {-Pi, Pi}, 
      AxesLabel -> {$CellContext`\[Omega], None}, PlotLabel -> "phase"]]},
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.402269619078125*^9, 3.402269651*^9}, {
   3.465326882234375*^9, 3.465326886359375*^9}, {3.613164318271165*^9, 
   3.6131643289883842`*^9}, {3.6131643696878858`*^9, 
   3.6131643702182865`*^9}, {3.654361902893865*^9, 3.654361982886349*^9}, {
   3.654362441105458*^9, 3.65436244413174*^9}, {3.654425595970423*^9, 
   3.6544256021791434`*^9}, {3.686141088342671*^9, 3.6861411358338537`*^9}, {
   3.800656041558324*^9, 3.800656041833587*^9}, {3.801832887571407*^9, 
   3.801832910969866*^9}, {3.810833320797525*^9, 3.810833355806267*^9}, {
   3.810833445394225*^9, 3.8108334658589907`*^9}, {3.810833557757965*^9, 
   3.810833564028148*^9}, 3.8922996150033107`*^9, {3.892502273042145*^9, 
   3.892502310554752*^9}, {3.893951680004678*^9, 3.893951688996563*^9}, 
   3.893952194332599*^9},
 CellID->711829727,ExpressionUUID->"d8f62c48-e1cf-44b3-a4dd-af8efc5b9e1d"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJw1mHc41m/0x+29I6uBhzJKSZJR54OshoT4oiIrqZCVMkokpGFnJaNCMjMe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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJw1mHc41m/0x+29I6uBhzJKSZJR54OshoT4oiIrqZCVMkokpGFnJaNCMjMe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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJw1mHc41m/0x+29I6uBhzJKSZJR54OshoT4oiIrqZCVMkokpGFnJaNCMjMe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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{4.0819752680338155`, 15.944335634447668`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"magnitude\"", TraditionalForm],
      PlotRange->{{-9.999999591836735, 9.999999591836735}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {128.01299438275115, -77.24752852010215},
      ImageScaled[{0.5, 0.5}], {240.02436446765842, 147.13814956209933},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwt2Hk0ld3bB/DjmI55Hk5RcqtkataTaG9KkpIUDdJgSkKGZCYZolQyVUKo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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwt2Hk0ld3bB/DjmI55Hk5RcqtkataTaG9KkpIUDdJgSkKGZCYZolQyVUKo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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-9.999999591836735, 
               9.999999591836735}, {-1.5707963267948966`, 
               1.5707963267948966`}}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-9.999999591836735, 
              9.999999591836735}, {-1.5707963267948966`, 
              1.5707963267948966`}}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwt2Hk0ld3bB/DjmI55Hk5RcqtkataTaG9KkpIUDdJgSkKGZCYZolQyVUKo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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-9.999999591836735, 
            9.999999591836735}, {-1.5707963267948966`, 1.5707963267948966`}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{4.0819752680338155`, 15.944335634447668`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"phase\"", TraditionalForm],
      PlotRange->{{-9.999999591836735, 
       9.999999591836735}, {-1.5707963267948966`, 1.5707963267948966`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {384.03898314825346, -77.24752852010215},
      ImageScaled[{0.5, 0.5}], {240.02436446765842, 147.13814956209933},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[149]},
  PlotRange->{{0, 512.0519775310046}, {-154.4950570402043, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.8141166631654973`*^9, 3.8925022827992973`*^9, 
  3.89250231313806*^9, 3.892586347961057*^9, 3.892729948603084*^9, 
  3.8939516948022785`*^9, 3.893952196185928*^9, 3.897571901808886*^9},
 CellID->32834574,ExpressionUUID->"acf0c569-d4e6-4670-a67b-aac5fd466707"]
}, Open  ]],

Cell["Here are the real and imaginary components:", "Text",
 CellChangeTimes->{{3.654362004887692*^9, 3.654362015730398*^9}},
 CellID->90824252,ExpressionUUID->"72cffcdf-a0de-49b3-ab57-323c030b9e18"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"List", "ListIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["List", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1456", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   {
    Plot[
     Re[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], -10, 
      10}, 
     Sequence[
     PlotRange -> {-0.5, 1.5}, AxesLabel -> {$CellContext`\[Omega], None}, 
      PlotLabel -> "real"]], 
    Plot[
     Im[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], -10, 
      10}, 
     Sequence[
     Exclusions -> None, PlotRange -> {-1., 1.}, 
      AxesLabel -> {$CellContext`\[Omega], None}, PlotLabel -> "imaginary"]]},
   
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.402269619078125*^9, 3.402269651*^9}, {
   3.465326882234375*^9, 3.465326886359375*^9}, {3.613164318271165*^9, 
   3.6131643289883842`*^9}, {3.6131643696878858`*^9, 
   3.6131643702182865`*^9}, {3.654361902893865*^9, 3.654361982886349*^9}, {
   3.654362024992747*^9, 3.654362031762583*^9}, {3.654362446918434*^9, 
   3.654362449149148*^9}, {3.654425612256614*^9, 3.654425617108152*^9}, {
   3.686141154701607*^9, 3.686141217469014*^9}, {3.800656057089795*^9, 
   3.800656057263328*^9}, {3.801832918184587*^9, 3.801832927770973*^9}, {
   3.81083337589135*^9, 3.810833387195713*^9}, {3.810833482304023*^9, 
   3.810833528775054*^9}, {3.81083357065386*^9, 3.810833576237894*^9}, 
   3.8922996215613465`*^9, {3.892502315745386*^9, 3.89250233081841*^9}, {
   3.893951699294707*^9, 3.893951708115615*^9}, 3.8939521863030367`*^9},
 CellID->1769813994,ExpressionUUID->"93d5f946-18dc-42dc-92ea-957b7ca9261f"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJw1WWc413/UtvcmqxJ+CAkhDXQ+KFJISKWhkCT5l0qKaCBJZI8oe28lJN+P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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJw1WWc413/UtvcmqxJ+CAkhDXQ+KFJISKWhkCT5l0qKaCBJZI8oe28lJN+P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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJw1WWc413/UtvcmqxJ+CAkhDXQ+KFJISKWhkCT5l0qKaCBJZI8oe28lJN+P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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{4.0819752680338155`, 15.944335634447668`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"real\"", TraditionalForm],
      PlotRange->{{-9.999999591836735, 9.999999591836735}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {128.01299438275115, -77.24752852010215},
      ImageScaled[{0.5, 0.5}], {240.02436446765842, 147.13814956209933},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwtWHc41u/3t7MJDS3jKWmoJFLKeUfSFCop9YnQR/iUkB0NGQ2yd8iKprQe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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwtWHc41u/3t7MJDS3jKWmoJFLKeUfSFCop9YnQR/iUkB0NGQ2yd8iKprQe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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-1., 
               1.}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-1., 
              1.}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwtWHc41u/3t7MJDS3jKWmoJFLKeUfSFCop9YnQR/iUkB0NGQ2yd8iKprQe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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-9.999999591836735, 9.999999591836735}, {-1., 1.}},
            "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{4.0819752680338155`, 15.944335634447668`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"imaginary\"", TraditionalForm],
      PlotRange->{{-9.999999591836735, 9.999999591836735}, {-1., 1.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {384.03898314825346, -77.24752852010215},
      ImageScaled[{0.5, 0.5}], {240.02436446765842, 147.13814956209933},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[149]},
  PlotRange->{{0, 512.0519775310046}, {-154.4950570402043, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.814116665396531*^9, {3.892502324195177*^9, 3.892502333949644*^9}, 
   3.892586349964245*^9, 3.892729950388109*^9, 3.893951709349744*^9, 
   3.8939521881759453`*^9, 3.89757190374162*^9},
 CellID->282322313,ExpressionUUID->"4335a298-58cb-484e-aa05-f93d519a7767"]
}, Open  ]],

Cell["\<\
The plots reveal the following well-known symmetry properties of the Fourier \
transform of a real signal\
\>", "Text",
 CellChangeTimes->{{3.825446588720085*^9, 3.8254466478328953`*^9}, 
   3.916220148640637*^9},
 CellID->467802561,ExpressionUUID->"beee90b6-6d30-491c-a9cd-5c21e2aca80a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"|", 
     RowBox[{"X", "(", 
      RowBox[{"j", " ", "\[Omega]"}], ")"}], "|"}], "=", 
    RowBox[{"|", 
     RowBox[{"X", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]"}], ")"}]}], "|"}]}], 
   TraditionalForm]],ExpressionUUID->"59b00526-76ca-49d3-852a-a83463fc2e5e"]
}], "Text",
 CellChangeTimes->{{3.489473523546875*^9, 3.48947355096875*^9}, 
   3.48947363959375*^9, 3.6543611214641843`*^9, 3.654361249028751*^9, 
   3.6543870197041907`*^9, {3.80194532306107*^9, 3.80194533741973*^9}, {
   3.834072840348398*^9, 3.834072842052551*^9}},
 CellID->420011060,ExpressionUUID->"26fd2d75-ac9f-4d9c-a7ba-97d1c5bda6f1"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Angle]", " ", "X", 
     RowBox[{"(", 
      RowBox[{"j", " ", "\[Omega]"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"-", " ", "\[Angle]"}], " ", "X", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "j"}], " ", "\[Omega]"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"9a2527f2-4b25-4d37-87f3-eaa111b2a304"]
}], "Text",
 CellChangeTimes->{{3.48947356878125*^9, 3.4894735694375*^9}, 
   3.654361121479784*^9, 3.6543612499813395`*^9, 3.6543870342588034`*^9, {
   3.834072846388957*^9, 3.8340728480368633`*^9}},
 CellID->347137731,ExpressionUUID->"d1b2a212-f0bf-438f-b096-b85a5b60e3c8"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Re", " ", "[", 
     RowBox[{"X", 
      RowBox[{"(", 
       RowBox[{"j", " ", "\[Omega]"}], ")"}]}], "]"}], "=", 
    RowBox[{"Re", " ", "[", 
     RowBox[{"X", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "j"}], " ", "\[Omega]"}], ")"}]}], "]"}]}], 
   TraditionalForm]],ExpressionUUID->"cc3bd798-f2c1-4990-99fe-10302280296b"],
 " "
}], "Text",
 CellChangeTimes->{{3.4894735815625*^9, 3.48947358221875*^9}, 
   3.654361121479784*^9, 3.654361251541319*^9, 3.654387044585871*^9, {
   3.834072852052752*^9, 3.834072852716965*^9}},
 CellID->1778259665,ExpressionUUID->"c2b73dba-5229-4f4d-844d-2cf9bd145d54"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Im", " ", "[", 
     RowBox[{"X", 
      RowBox[{"(", 
       RowBox[{"j", " ", "\[Omega]"}], ")"}]}], "]"}], "=", 
    RowBox[{"-", " ", 
     RowBox[{"Im", " ", "[", 
      RowBox[{"X", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "j"}], " ", "\[Omega]"}], ")"}]}], "]"}]}]}], 
   TraditionalForm]],ExpressionUUID->"77da7ed3-db2b-4879-8090-d2aaec242154"]
}], "Text",
 CellChangeTimes->{{3.489473616234375*^9, 3.48947361709375*^9}, 
   3.654361121479784*^9, 3.654361252742503*^9, 3.6543870555213323`*^9, {
   3.834072855525021*^9, 3.834072857435825*^9}},
 CellID->680274356,ExpressionUUID->"bbebb34c-913c-42ff-96cd-7d045b79566a"],

Cell["\<\
Due to these symmetry properties, the Fourier transform is typically plotted \
over positive values of frequency only:\
\>", "Text",
 CellChangeTimes->{{3.6544256324271555`*^9, 3.6544257257139597`*^9}, {
   3.654425776772105*^9, 3.654425777879691*^9}, {3.8130172505511484`*^9, 
   3.813017263170491*^9}, {3.813322519050205*^9, 3.8133225216398463`*^9}, 
   3.813324316399975*^9, 3.813355797590657*^9, {3.813355950674555*^9, 
   3.813355957019477*^9}, {3.81335601643049*^9, 3.813356017261523*^9}, {
   3.813356055204263*^9, 3.813356076269764*^9}, {3.813356123832778*^9, 
   3.8133561514325604`*^9}, {3.8141165216115894`*^9, 3.8141165446135225`*^9}, 
   3.834072864725549*^9, {3.891106870265483*^9, 3.8911068704155207`*^9}},
 CellID->168164664,ExpressionUUID->"bdbcef35-d623-46ae-82ef-10d3516b5663"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"List", "ListIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["List", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1512", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   {
    Plot[
     Abs[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], 0, 10}, 
     
     Sequence[
     PlotRange -> {{-1.5, 10.}, {-0.4, 1.4}}, 
      AxesLabel -> {$CellContext`\[Omega], None}, PlotLabel -> "magnitude"]], 
    
    Plot[
     Arg[
      $CellContext`X[$CellContext`\[Omega]]], {$CellContext`\[Omega], 0, 10}, 
     
     Sequence[
     Exclusions -> None, PlotRange -> All, 
      AxesLabel -> {$CellContext`\[Omega], None}, PlotLabel -> "phase"]]},
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.402269619078125*^9, 3.402269651*^9}, {
   3.465326882234375*^9, 3.465326886359375*^9}, {3.613164318271165*^9, 
   3.6131643289883842`*^9}, {3.6131643696878858`*^9, 
   3.6131643702182865`*^9}, {3.654361902893865*^9, 3.654361982886349*^9}, {
   3.654362441105458*^9, 3.65436244413174*^9}, {3.654425595970423*^9, 
   3.6544256021791434`*^9}, {3.654425737710206*^9, 3.654425743014138*^9}, 
   3.6861412378842945`*^9, {3.686141875532919*^9, 3.686141895402915*^9}, {
   3.686489252495237*^9, 3.686489259339168*^9}, {3.800656076773168*^9, 
   3.800656089691617*^9}, {3.801832938180166*^9, 3.801832942159537*^9}, {
   3.810833604501575*^9, 3.810833677456365*^9}, {3.810833713135297*^9, 
   3.810833773229003*^9}, 3.892299632029341*^9, {3.892502249017315*^9, 
   3.8925022618900785`*^9}, 3.892502299021009*^9, {3.8939517341745143`*^9, 
   3.89395174286163*^9}, 3.893952175016137*^9},
 CellID->255028396,ExpressionUUID->"931126c1-01c8-4602-97e7-ba9806e4eddb"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwV0Xk01PsbB3B7kdwrqSgMo7huqW5aLe9PSYv6qW5JocWEqZSiSFJKJD8U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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwV0Xk01PsbB3B7kdwrqSgMo7huqW5aLe9PSYv6qW5JocWEqZSiSFJKJD8U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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.5, 10.}, {-0.4, 1.4}}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.5, 10.}, {-0.4, 1.4}}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwV0Xk01PsbB3B7kdwrqSgMo7huqW5aLe9PSYv6qW5JocWEqZSiSFJKJD8U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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.5, 10.}, {-0.4, 1.4}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 15.94433563444764}, {1.4805345073118161`, 0.5}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"magnitude\"", TraditionalForm],
      PlotRange->{{-1.5, 10.}, {-0.4, 1.4}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {124.52340645852786, -71.2774655855114},
      ImageScaled[{0.5, 0.5}], {232.91473862726485, 135.7666011152598},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwlzXk81PseBnBSTrZK4paYxa8IIemc0uL7rWlP3Yic6FAKJUuWEdJyYix3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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwlzXk81PseBnBSTrZK4paYxa8IIemc0uL7rWlP3Yic6FAKJUuWEdJyYix3
4iiOpY4cspw2leUUMZ/sJsu0ka0ay3BGg2HM/JikO/d1/3hez+v9z/PQPQMd
veYpKSkFKfK/zrrsqWp9mm23/v/NqXtHs3ehnUW67J+MHGln4XsDJ5pGi0Dv
C0t6NWgRkPUykbqAloB2an1iFVMTwG8b05+kZqKq8XLqI0omvPt6JlVMvYd2
/5bEa9K/Bz/09JuMUsvRMr5a+2mNcsh5lR30hcpFO7Ods9fymqDocUKPn2U3
Cu+QeRp0d4IPepMpCh5AnY+d3vMi+kApV1bRwx5AmXQP3hy7DzLmG/S+yhtA
Lq7VNvQ7fdDE9abc6xhAqyDKDtf0wRqn2VyvzYPIYR+fPazWD/+cMXn4SVmA
+OW9g71p/eB78xLndfIQ8jF6ORFWOAABAtOB0iIhym9K+eiUJwC+e9fCaq4Q
JS31YlWXCuBIZ7xl66AQnWcsz6XVC2BT83CEQH8ENf/y1fVvgQBUnuYv0Ysb
QR0vSkqw8RBkRNHtLnh8QZ+6tUM784agWmdFpu2SUcSJs9BxzBgGdXqMyedN
YuRw6yyf6SqEpq03rC7vEqPXP1qFDngLIfbnOxsNHcWopDbMbk+IEOYlP9/j
dk6MZsdEv0+whSCfE/l8yBIjg6di87eVQvjS6/wXb94Eyq263MI1GIGWDBPT
ly0TaMeb/L3c9hFIWtJslnNCgsKqd30usRBB+UbDskMBEmSast22YZMIBt0D
0exFCYq2MTnIY4hgyyMdJ5d0CZrjcBrqj4ngn33HL2m1SVBxCH12J0sEjOhR
XsSWKZT2JXB9arcIpqWLmY56UpRbgqOLL4+CZ48TqLTIkLq5TWJV0Rio3+7z
D+qSocPPc5anPxuDYtcAg89DMpStovbw7MsxUOmOi6hQJpEq2qkqfzMGeZ0V
NkEbSZTZw97TNDUGQ+20vz7lkkhAfcan2Y6D72tRcnnENAqOuW0trhyHoPoY
z0ATOXKYi2SsOyYGyuBuVZmNHLX5Z7lkHBdD8zy1+1FYjvjKWGvOQwyrceJE
wjE5mn/qvleNtxi6Kn6/mseWow17DH+wChXD9icFd7rG5ci39pUgM0kM2reb
uhnPvyL/RbsC66rF8PS85pHl+76h80SIehd9AnIunhtZ56KEi7K2bV3bNQHX
smcdpkTKOMaOeiDHdxKU3vFxZaQKHk67HvVWMAnGod7hTmYLsN/B1Xcbj0lg
UJp+VKNKFU9Nr0uxfy6B/QLfSzeDFuKjmiX6gUun4NBgsjmFoo4psVEPY05M
wUit59WmRxo491KXjJUzBZbaHYYMDy0cbFx5hMufAnUkPdkrWYTzah78rKQn
hT2jrqSR8xLMt+7zWL9fCp01p5Vd12rjxknTwYJwKZTF17nTpNpYg0wyZfwp
Be8FTH5b21JMxI2q5TdK4VTwxTLNWzo4sFwzhCmUgpWPeZv9yWWYe93Cz3ih
DHhL12owbXVxh9WLwm/GMnhRdO32WhU9XNmkZlu2XQYXlc0Ot3zUw1V+G00K
jstAvTdyb0Dpv/DHC5wcBlMGggJ6anbUcvzJmnWP8x8ZpK5ZMb/ceQVWWVC/
KPVPGSTf8m48SdPHgWxtsqxEBq6pv7RpDuvj3kLjbq96GUzvzJ/J5qzEG0Ym
Yy9/kMGAYEd4TZwBDuHYmwcOyyB3m/XK1pOGmN7BFtaRMnjEYmr7WFCw7lHr
ExtUSYhzPnVARUrBrcM3zAt0SPixN+deXCsVv/dzf3aFTkKG6e1HrQdouN3/
yb+5FiRceZmYcaCchrdUSPtCN5NwcKVz/qtVdNygm754/24Stgc0umkn0PEO
8aJnbw+TkG3guapFSscxYSPBL9xIWFVbmHbIzQjXRM9GXfAiIdmixuwtxwh7
dyd6ZAWQ4C2Z/4ZrRuCo+CAxNZwEz6eTtITfCNxPmKnkXiXB79qR2f03CNzd
Wb2lUWHmkdIPmikEdvKt9BcpHC9lJiWnEdh/TV/VT7+SUGQ78zU9i8BtuvqL
mxWeqf7eUfCAwHXtvLDJa4r/t5qJdY0E/uObm89WFgm37vqfieUSeMjvPu+E
wndD2xh7mwkcU3nTmqXw33rJ8uY2AluWbexvVbjXVefMu3YCR8qUSfdYEkwG
VjD6Bwg8RdcSX4kjYV1pJCVPQOCMuerJuwpvZvXMeA0TuP2Y+XijwvYmWU+E
IwRmUY3aF8eTEHyORpmYIHAKr9U5W+Gorb/OFEsILLzuZFyrMEur/32olMA9
/D/EQwpnPL7Lnp5W7LWGB1smkJB7db5PhZzAywoWmzkq/MDBa0fULIE9UgJ6
mAqXGjUY2s0RWGSTHpupMEdiPPP9O4FPrGabVyn8X2jSyEo=
                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {All, All}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {All, All}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwlzXk81PseBnBSTrZK4paYxa8IIemc0uL7rWlP3Yic6FAKJUuWEdJyYix3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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {All, All}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox[
          TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{18.63275143919627, 15.944335634447611`}, {
       1.4805345073118161`, 0.5}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"phase\"", TraditionalForm],
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {382.6365950951817, -71.2774655855114}, 
     ImageScaled[{0.5, 0.5}], {251.04749006646108, 135.7666011152598},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[149]},
  PlotRange->{{0, 516.2263772733077}, {-142.5549311710228, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.893951747709586*^9, 3.893952177071174*^9, 
  3.897571908792321*^9},
 CellID->60733066,ExpressionUUID->"31d65842-d783-4521-b94a-9467c8b0a134"]
}, Open  ]],

Cell["\<\
Frequently, a logarithmic scale, the so-called decibel scale, is used to plot \
the magnitude values:\
\>", "Text",
 CellChangeTimes->{{3.6543758530091877`*^9, 3.6543759266246443`*^9}, {
   3.65437615394493*^9, 3.6543761702623205`*^9}, {3.654376233831506*^9, 
   3.654376399563781*^9}, {3.654376471946853*^9, 3.6543765774795*^9}, {
   3.6543766928712206`*^9, 3.654376745114952*^9}, {3.6544258115284595`*^9, 
   3.654425853179925*^9}, {3.6861420420545616`*^9, 3.686142047358571*^9}, {
   3.686142088012243*^9, 3.686142091569048*^9}, 3.6861421426435385`*^9, {
   3.686142279198027*^9, 3.68614234655445*^9}, 3.7801532915330014`*^9, {
   3.801826768167975*^9, 3.8018267923762445`*^9}, {3.801826846797827*^9, 
   3.8018268775945244`*^9}, {3.80182693368564*^9, 3.801826934114495*^9}, {
   3.801827039342303*^9, 3.801827040081331*^9}, 3.810834668631904*^9, {
   3.812881297944636*^9, 3.812881298392437*^9}, {3.813356201689515*^9, 
   3.813356203264748*^9}, {3.834072873116314*^9, 3.8340728798766527`*^9}, {
   3.891106895912701*^9, 3.891106902663469*^9}},
 CellID->2032375807,ExpressionUUID->"e1b8aba8-f0cb-40d0-b1a6-235531642b48"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"20", " ", 
    RowBox[{"Log10", "[", 
     RowBox[{"Abs", "[", 
      RowBox[{"X", "[", "\[Omega]", "]"}], "]"}], "]"}]}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["480", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`\[Omega], 0, 50}, PlotRange -> {-40., 0.}, 
     AxesLabel -> {$CellContext`\[Omega], None}, GridLines -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.654375952099118*^9, 3.654375973907638*^9}, {
   3.654376584281013*^9, 3.654376661890018*^9}, {3.675598106947107*^9, 
   3.675598210394106*^9}, {3.686142175871597*^9, 3.68614219840411*^9}, {
   3.801832952426097*^9, 3.801832960999202*^9}, {3.8034297907445235`*^9, 
   3.8034297908322816`*^9}, {3.8108338019839973`*^9, 3.810833811764945*^9}, 
   3.8115012230404987`*^9, {3.892299922524687*^9, 3.892299950655545*^9}, {
   3.892502339078761*^9, 3.892502349867768*^9}, {3.893951753756931*^9, 
   3.893951759237426*^9}, 3.893952142692537*^9},
 CellID->265299067,ExpressionUUID->"05a0b3af-02c7-4619-83b3-5c4610f139cc"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwVz3s01PkfBvChwSg2ZUhWuU1+OJJxv3/eSL6rlUtWKO1uJVMi91S23HLL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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJwVz3s01PkfBvChwSg2ZUhWuU1+OJJxv3/eSL6rlUtWKO1uJVMi91S23HLL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             "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{0., 49.99999897959184}, {-40., 0.}}, 
          "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0},
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{0., 49.99999897959184}, {-40., 0.}}, 
         "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
         "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwVz3s01PkfBvChwSg2ZUhWuU1+OJJxv3/eSL6rlUtWKO1uJVMi91S23HLL
XahMUhuiwopFlu9bSSmrmnRVq9YluxZDZWQN6/fHc57zOuf559Hcc9grUJLB
YGQt5f+tlSP+uXT9L/bfqat7qg4VtDWx9NRDeDlk/wp6eVmrB90RW3NFl3eR
jHwdk9rXEkYXmA/tks+uJN2CrhH13kS6yyg8SJpXS04YXC+ouplLxyktNi+W
3SQ+loMTP686TxflO9vPZzWRLskVoU/bL9O1KzPvzB5rJVX+u1iCo1X0/UwB
9TmIJgpzJrO/ltTRwmS5D7HVHSTJR64udq6B/ulOrZ6o7A7xZv/9tupFC71c
cvuh6OK7RKvr+clSLk0XwUzNx6x7xN72aYBj0m1a++S5qfDkbvJ3DyvUpPou
Xddmayo89pC4e3/TWCTXTXdbJ7X8E/SI8AdP8kvIY/qareIJs9rHZPSVoU/6
FgE91b/vYlT1E+J6OTTnEa+PPqHK+nO67Ckp2jeVenv+Jd3Z4rfMmN9HdnAH
ZFaH9NPL/a5xwoufkS5/9VuMmbd0cfG2oMmsF8Rm+pVGSOV7+g/zsjTD9JdE
rjreovKrQZrzfKoqJPkVsfHNf3grfoiuYxf+M3asn7CzQ1KFSR/oB3n94aNB
A8St0jOcMz9Op50t6i7gviMGhWM2bbWTtAGP+JvUviM9a61G+Y1COkIm73hE
9XsiG+MzYRk3TS84m7YLywYJY/h1kip3hla5c8xpPOsD2XU1Vr5BaYF2bZPZ
NhI0SdiTBRkzh2WQu7jns7JwklRY9Q8/WcbCTI3ve7VthUTNaF1KTTELo/bc
ivbuFJLvrc1knGhZ3DwS1tnYN0U09+dkvZSTwz/H3/4Y+/kjuZph+TzHTQE1
xE18sfksIdKjkg11bGSXBgqVjs8SUdt92bxPbGQRxc2G9Cxxd+Md0bJUwsn4
0LHdLl+I64XqiB/albCducEad8yRwMND2Xb3lDFALv9FYuw8kZhxMHB9oIK/
y5vLMgMYsL5DWXqqUA0FW1ef7Y1jwG2+iuPWHjV8mT6hc47PgGcV2t37JNfh
kFTlZsM3DHg+V/rxecg6nBeviffdKQHn9H+6jg7rUX/iy8x1P0nY3bl3+ee3
6pjW2zb0nQ8TmiuHvTdFa2K23PlIjRgmqIjTDSsyNfGMa4zkWCET/nHPcJO8
ookXuww14p8x4Y3IVzFYoIm/tl/cWe0tBR60YusyQy0crkkQLHhJQ5H+Ih37
Tgsdc5yx0p0Fmw65ZF404WC8a0OVIJQFzyXf5dxw4WC7lHaBOIsFVo2G4oqd
HLSOY+zf3sOCEQvPK7uSOGhyoHXFIiULk875Ei+ecJDjxN3h47gcVjfKSuoE
b0BpkdoE00wOhIrbn67M1cHATXPyXHkFyHUwlt5VpYvf9qeWq6xXAJ2cqNas
W7pomqpkx9ikAHO/qafWPtRF5oDRoUceCnA+waL3zrguXs4OehByRgECT56T
Mubq4cB4X0r116ugSMG0wqZRD/2u1y5q668GUR4n63q9PrrpBU4pu7DhmRXj
xtVUA5w7Hd361ocNC7F5ByvOGODViVOnruxnQxc1/uL8JQNkNlSsNU5hg+2n
wU9BrQZ4y37Uwe0uG6TY2UVnJgxQxzs4P8lJCcp+G9Rw3L4RGSfDTYREGRQv
D4vslQ2xvu+n6G5LFage3C2z7NQmtFmtX8s8qQapz9apVGpzMejf/Avlvhpw
Kdc/4aO7MR7u+mBS66YFyU2ukWsoE8zwl94gPsSBHwV54+FWprj33vH9XJ4O
5E8O5yZJmWGHzFrPYD9d2MUf1VnWZobcVfFFf0Xpg/ej6uzwKHP84aOdwbZD
BiD3R8e2ZYoWeKn0rpooyxBSzkZmrLppgTezrfsFXkbQQDL67jpbYtQtO48L
33LB7ith8IEuS6QflE+n7zQG43Kei4yrFR5wsWo74GsCUQVW+XbtVsi/ym0M
PmgKIUdXFNeYWWPex7aEsCNmsC034Dqr3BpHqqNjeBHmwP/iq6vBssHOLfln
ExMtIPuJIbM31AYl3F//mRNvCTecmo+ceWCDDIdfJcqOWoGkcl2QtKYtpq0R
uQlSrQFZUk91j9timP/e26IkGyjduJCn2mOL7xNM95FCW/gSyrxzScMO2QXn
XqdfsoO8uI0nSsLssEJB/+i9EnuIkyrC+mY77IhQd/7fNQIDJZTvdqY9lmqU
qdl5A/T11OrfoOyxLW6OwXsMUK9VotqQbo+aW2XmtXc4wN4zniMbe+2x4ZHe
6Vd9DuAvETRpKUcws2vBSCPAEcYESqqFbgQLIv86+MMbR/BuVEobTyMYp7R+
pZafE/h7BL7ldxCs0pN6EPXOCeoNzEmimKD0J4m1Hbs3Q6iKlGhhLWCl0S8n
Sj9shsRkFa/75oB6e6q3iUOcoan5cIyPF2D/Ny313405Q5oD9XdYMKDg52Mb
SeQWiHR8JSebAjh709NWa3oL/JbiF+1WCrjYHNGYEuoCkPpZWNQIuNVoi3Pc
ZxfoNA1o9ugFvBew6UBwJAWcmUOTI0OAq/fyWi9EU2Ds597hOgy4m3dJ/vER
CsJM7DJqljwToVhvGre0b3GQiBkB5KSJ5sTJFLAHVZOZo4Dx9XRmbhEFnUqR
f6iPAVrLeNQ1tlDQeP+R0H0KMEUuXXK0lYIOXbPK+iU/WXXbW7WdgidZL72V
pgF5aqZfTtymoJw/UPh6ycVcFUfqIQU5G1Vr930C/LTz3dPXbyg4fO88OSIC
hB/X6sgPUJD44dzBV0s+vd8rlryn4MrNyUybWUCt8E61K8MUnA0ub1pcsmfK
1cCQCQq2MveVp84B8k+/b7oopKCB63T6ryWP5qouF0xT0GZxirf136U/JZk1
5iIKdr+xkF05D9hTdpdx4AsFrgnXesKWvKZiwavkXwqSVqSlCpa855pF+e9i
CszFvVamYsCaujDR4iIFui8TBguX/B8/oUEy
          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {{0., 49.99999897959184}, {-40., 0.}}, 
       "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox[
      TagBox["\[Omega]", HoldForm], HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 49.99999897959184}, {-40., 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.893951764354972*^9, 3.893952145468987*^9, 
  3.897571911429436*^9},
 CellID->2722495,ExpressionUUID->"d10b37a1-da6b-4369-82d3-c3d4f2380b38"]
}, Open  ]],

Cell["\<\
It is also very common to use logarithmic scaling of the frequency axis, \
which results in the so-called Bode plot: \
\>", "Text",
 CellChangeTimes->{{3.654376787109613*^9, 3.654376858010703*^9}, 
   3.6543771031459603`*^9, {3.654425873490864*^9, 3.654425945967536*^9}, {
   3.6861419699356346`*^9, 3.686141975302044*^9}, {3.686142211246679*^9, 
   3.686142232803546*^9}, {3.686142378349121*^9, 3.6861424368629665`*^9}, 
   3.8018269314276743`*^9, {3.8018271223634553`*^9, 3.8018271986446147`*^9}, {
   3.801831588784735*^9, 3.801831611671573*^9}, {3.801831672661591*^9, 
   3.8018316852000914`*^9}, {3.8018317234239426`*^9, 3.801831768159405*^9}, {
   3.8018318124640155`*^9, 3.801831845211505*^9}, {3.810834676207889*^9, 
   3.8108346797519417`*^9}, {3.812881303126788*^9, 3.812881321118652*^9}, {
   3.813356223752138*^9, 3.813356239937049*^9}, {3.8141166006585326`*^9, 
   3.814116624880807*^9}},
 CellID->705367897,ExpressionUUID->"dceb54f0-e20b-4837-8dbf-ad2547586177"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"20", " ", 
    RowBox[{"Log10", "[", 
     RowBox[{"Abs", "[", 
      RowBox[{"X", "[", "\[Omega]", "]"}], "]"}], "]"}]}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["512", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`\[Omega], 0.01, 100}, PlotRange -> {-40., 0.}, 
     AxesLabel -> {"\[Omega]", None}, GridLines -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.811501080628707*^9, 3.811501084507481*^9}, {
   3.811501127289298*^9, 3.811501217308156*^9}, {3.8922999649675827`*^9, 
   3.892299975556931*^9}, {3.892300244269935*^9, 3.892300255206068*^9}, {
   3.892502356834197*^9, 3.892502367992402*^9}, {3.893951768097802*^9, 
   3.893951772095851*^9}, 3.893952131886057*^9},
 CellID->1008513439,ExpressionUUID->"c3b3c35b-e940-411a-949a-29663eb8f69f"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwdk3c8Ff7/xe+97jXuNe69qYhEIalUki3XXlFRRiVklhkShWRlkxmyk5Gd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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJwdk3c8Ff7/xe+97jXuNe69qYhEIalUki3XXlFRRiVklhkShWRlkxmyk5Gd
lJHXm4qS7BFlkxGyV+L7+f3OP+dxHs8/zvnn8N1y1LXEYTAYLSwG83+uzclR
XGpLRfyRUsTxe7LgEAQi32yoSHaiql84TRai1q2KpiypKFwl60nhZ1no6n5T
eMiUitrzjDusueXgWrReQfgVKqowO/ilskEOrEiRebflqKiRraqV76g8eP8j
vOBjoyIi+xDvF2YFSLcrPCLHTEWcHNXGfgIKUPfjSpYhExVFXf/gZnZeAfBV
WZmRdFREJ5DBEuKkACFuChn/1iloRvf40+geBYj/45naN0xBTjbB2JI8RSge
WX72tIyCjNw2vbLtlSEqir/VoZiC1jqZBj6FK4Oz/FXChQIKSgs+XsdRpAzi
KRV36V9SkNvDfn2DP8pQY+ih+TCRgtTWxwJprirQ1Lrz18KHgsanCftIQaow
/p7JRFKHgsTZ3A8N9KlDg5103F4tCsLNxU0vYjQgh8v265IaBTURmISUhTTg
jkezRKECBYm2YQMy72vAolgk+fA5CoqR5HO7zKkJO6/Y60ncFPRbLfx3q40W
cCYdEhiaJqMndf5MIjI60JxsHLH4i4wSVWzqI611wCcleZ1unIxUBa0zRGN1
YCp9f5PQIBldG3hzSW5eBypy2BydO8jIxMWZ+W72RdB9s/uOUE1G6bcvq12J
ugQhbUMXToSRUXTDGc84QV0433Gw4nwwGQnyXBmTVtCFxc7rhy4HkpHomYvW
DDd0wbC3d/GeDxm9qKx6tS9aFwQHW+PBlYw2BA182TF6UP8bhnWNyeiEMrdZ
3Zge/KVPd/UQIaM/UXjm6K9X4UE+e3TScTIad3v9+c/MVdjSDi6uFiIj85S7
OQ+I+rAR6zzz7zAZ+acfa+XQ1Ie1wyqmvvvJSGXJYcPrqz4snZ/RCsWQkY8K
u4tgrwF0zdmoSmezoXH7WqP+PdegU0z3sWcaG6IljHmZSV2DjocyNbWJbOga
cTedx+QatDGxiipFsKGjsSe5ZF9dg2aB1wcv3GdDrAdCPZhVr8NH438rxhps
6HyctqBG4A14/e1p1uM5VmQ2mfDR86wJiMaGa6lNsiIei1o5MQsTKLsWvMw8
wopydGU/SMSZQMmkj9KzLlaEeZrcwr9hAgVYp7GialYkZRzP0GFqCi/P6Rz5
GcyKnmyKu7afMYOkFGKWuCAr6ruZtBazfAs4Lei1tg+xImGyfK0wxRyeCeOW
6zhZUe665Js/IuaQ8HZTUZuFFeGvtV0m2JpDbPvUqPkKC7qEqVG0njCHcELj
4af1LIjDbtFKbcwCfOz9Mn/fZEEFz4/eeE6whqy+xBIuo/8y9yckcNQaGlRK
arX0WNAI2+jfIXVrYOYZ6H+lxoK2xi9Qp8Ks4VmL+B670yyIpumbprPfBopP
zfjNYllQ1D3LmDfnbsPg4iXLuRfMaDj2JSc+2RawN61dDqYxI0+FESHpD7bA
3+T1WDuRGfUVTX3M/20LdzLzUwrDmdH6VPyGrJwdrOnie+zdmJEJl1ytyJgd
sJa/VZ1XY0ZRjt+HY6UdQM6NR+jPDAldbKkrXg9zgmEztazMcRLyLqo5yZnj
BP7aTjz6gyRUt2A6ZV7nBE389ezv20noRM0BDrc1J9DvtMSGviOh0EViQuyt
u+B0urBfMJCEGutInKuKzpA1IxN+k4+EkvaK1IgKuoJqjwUjlYuEfkrXDmFV
XWGmLtzvEzsJzX3TP0tn5QqnE4c8TjCSUKyWV07KS1eoUfOz2ponIuI2XbC0
8D3oedEkH19DRHEaDTvXZdyAycRo6ZsBER04TdJNeOIOyhF/ulMvE9GLtEaZ
pEJ38HkfUOmoRURFeG7c9053WOMq86HIExHuuchTAp8HjH4nsl0VJKIAP+02
0VoPqNKtOf5zhQnV6GtaCuEfgp3qIcuZp0xoOUCL/2ydF+Tce6NeHcqEyBJs
e7X/eMHoC60TYQFMCFtMsig66A2GdO7LJz2YUHt9YI/6Q29QQW2P75oyoU8O
LWrTUo+AR9o3dUOECUn41Iil3vKB1pMTvfTNjChfIjTuHckXinDxfIoNjGg/
p2hRk4AvhPWq2nohRkQ6hbXG0XxB83HuznI5I/I8LxQ95uoLDV22AiMpjGig
mr/VedgXah4uOVc7MqJIRum51Vo/yP+yy+K0hxF1K0ZOHU0OgODUEoNXLIxo
vnCG37gqAGxczDJ+MTAifrcWK+gLAMGDH8SMtxlQumH5DokzEDKcAq9rTjCg
Oy8JBc2JgfBsP0se/1sGdJqj/LngiycQYHlAue8aA+IdQv8EBoNhvHJgK+EK
A8Ic/TabRx8CyqwZpfo6DGjf8Jak/akQwL09eqhLgQEdsg91ff04BLwZz221
CDEg3PcZO41joeD26mLJxzV61Fkjx7TqHwY2i/7cJdH06FG+WrTU3UhoVFHv
dAijR83tFSWumZEgmEQKORlIj5JIynXbnZEwrhi9nu9BjzQkbjVvcUWBaWxa
R7YpPWJSk3rz9XEUGElUBSWL0CNqh7QQ/upT0PT6sxLYREDOz7Xz4rliQPv+
N0rJRwLai01N9JGIgUt3X4n01RIQ59dH0jF6MaBvaW1z/DUBvan0e3A2LAbM
tId+tCYTUNM+qrfVbgy4H2yt57AnoGeBFfjmuVjIfl8Ulc9GQAIy+9n0ZuMh
921YYScTAW1g94g0syRAfumdpm06AlouM2NxO5UAJdmC+IsbeCTcMXrU2CUB
asJT7y8P45HcW4E0n38J0GEccVO2DI/85Y753OBKBMyO/YmWK3i0sUvU83qU
DMkylaXsF/FobYY7s+tlMoh74CWua+BRtxA7i0VLMtiuJClMyeFRZ6X4vRM8
z6FnplEfdxSPFEXMbtih51DQy/dYfJMOyZNU7BbYUsGwtLs7NYUOsV+Ycixx
SIfled7rEwl0yD/qrvypwHSIOGE3fDyaDsk83w5sTUmHDzm43+8C6VDHm1SZ
e9/SQST1FKbTkQ5tz8q5XxPJAHxosDCDIh16eU+S8HYtA0os5B45/sIhn0D/
Ce6sLPjKl3xXahiHGGXub0TWZcGvwQ1zun4cij36lFl0OAu4jcrVE77h0LCs
miGe5wUEaR+nQjkOndPrvjed/AJMxTmzWf1wCDNEWl1LzwYy42pT4SEc2vsp
64d8Rw4c/6T7/j4nDjUL3ZkWXM8BVd+SYoU9ONT0rL1DlTsXPLdtY7vpcehb
YVKMqHUuTC2MGv+bw6IiMrf1h91cQH1tCxdqsMiUIbqXQzYfHF8V7Js1xKKJ
Kru1w+MFIMIq4Mirh0UPAk2ielkKYdYppfGKNhY10Yw3GyUK4Y54hPt7BSzi
nb4XahxWCBZ1jv0RwlgULJPGailZBNd6RVPPbGPQWrkRSfR5MajSVQrcT8Mg
zTMHndI1S4Fgdcb7VSIG9VUnykWYl8LHz3k9QzEYVOfr8TrNsxQUIpKeqAdh
UCSHvZlIcSnIcnpOc97FID025yuYfWUgekq+sEYRg4KOqMxnzZSBbEXIbXzz
LpwK17E1Ly2HqgfpKy6wCw7Mz/YUt5eDpHzFo7GyXfB7si//xFI5iH0eiatP
3AVyA7699uwbONEvWe9jvQurbIJ31CrfANfOrwP/cLtwXkrRQKSlArZUlJpX
pXZAXvCzdSRfJbgTjQwsT+6AImufRLl6Jay1OIx28e5Au4aOzl6nSlgySNp4
zbADjMUhleFQCTO3F/mdu//BeHp7jJlZFfSHp3nNO/2DmrhrNydLqqGy+6/I
ZM42KJN+Pd7vWwtWfLMhT5O3gbpGtEgvqQV2+5+/ZCK3gceaQdVxqBac8O9T
o9y2QV7lZtawHIDQWW9WaZVt2H9WZ//BHYD4KMx82OhfaHjiXHCiAYGzFqFQ
9OBfoL80FO10tx54E1YZB8h/gePrRIZXeD20jE5YPMH/x1fTX5Tn1cOxBw3c
P39vgXHir/sZo/UwnPskLKBqC0bWDYhe+h9Ah55o991gC/4ur0Y7q34E4TrW
497Rm9BDfS/Go9EAhwzF9P4FbkLQmN3hFJsGYP9j9NDz4SbUDP8uVAtqgF3u
7K8PLDbhYsvZQN7PDdDlLmN3X3wT5M5qZU5qNIL3aZtCp/4NqK92fbF79TN0
ptWdMj+8AVWhOlH00U3wWXzSYHTfBliQhjoc3jZB7TdmHzPSBugqXfQkDjRB
7l+DNpOVdVjoTyUPCH0Fb4N5pxsN6xAo8yVvrf4rCLFxlV29sw4cYUc3JLDf
wNPbVUy9bA143Qqv/cppBWd2EG/JXoMk8TZxhu+tYJPPJHUlcQ0+luvGSuDb
QK8nVc7UZw2+CzjMEs+1gbDIF1V3nTUYPjeQb/GsDb4PHDTKnVkF57j8FrJV
O4jJNXoxHlmFt5Vn8qp5OkG4k+ITsW8VhnQvl2bIdALv7Ru+7MRVwFx1/lVq
2AmkuMVA3sUVCCi3rLkc0wmjs1xRkrACFvSTlnHELoh67pRpc30FNCldWybY
bpj9y9n4OWYZjP52bOdReuHYQGLckaBlWJcvP755phesajktvD2XoWIqt9pF
txdGfDixYpbLECIY3Pk7phd6CJwyaeLLYFAaBnMc3wGxcRTf61sCetsVdpvj
fRB7ZF/C4UNL4EBILH/v8gPa8fGWXnuWYDv79fBY4g9g/bVX7DvDErxcNXCT
RT8gOHdve/jCIpSVjTYHsPwE75N7SZt1i0CgH373KP8n2EiwP2q1WISqvmef
VOYHQFaLau2ZvwCCUiFB1heH4cHxt2yDKQvQ89ihutZ6GN6RbryTf7oA+Z8f
8kv6DMPZ5mwmOvcFuHFMQSG6dBiEtaUKglUWgG9GW3Vq7wicTkWjJ+v+QN+6
yCptYgQms2+s3zo5D97djx72po3BLauX6oLs8+D5ku/2l5oxGBRcSJzemoM0
vCLrWN8YdOX4yTp9noMATJxEBPs41OflP/Yyn4M8C1XOL6HjkFq4QXqWOAt0
hqnkrccToP8mlvcb4Tds2h21jo+YhDP+MXvo52bgkDO2TLpkEpj1ounlu2aA
/rwDI6ljEuoXImdLMmeg/G10zOl9U3DqROi7WPkZEIstV49NnwLGrMeXbnhM
g8jQVurk+2moinLw+T07CUTN2Kss3LMQZ2Lvwt81CSfkgm5GKs2Ck4idlXH1
JBQIqrko2c6CYPPtC63Bk6CdeNpfsXoWYhgsOV4LTsL6jl1mhvEc2HlfL3lg
+gue3Zr7xVowDwft1IeZusZBVDRm/NG7BQhqL7WdrRmHPwW/dfEtC7AkzrXe
kj0OdV3xEhljC9CAnWeJvT8OyYl+5fxsi+CQECPDwzUO7jE9JVesFwHqB+NF
b43BgrbDxTvcS2DGeU/7+sIIiOu0PNxIXIZm78Hvcn0j4P21MbGsbBnEx9Us
eOtHILXvQNGTr8tALD7wcCJmBD5apDD6/VuGMmWU6ygxAuZStFfo1grQOZHw
/t7DYJGdDjaiq6ARrnTPiHMQ4k0juZZ//ffjK/krUpMDYO3D2BRDWIe1AxTX
A28GINwj4Z8+/zpk5g46/7g0ACI8RF2VW+uw9cHDyTjoJ7B8yD3/cWgd8reK
bc3W+0GJFQxNRjaA2Yb71u3uXljC1mfk7G5Bm+KqjsfTdvi9FrG6p3AXPoqf
2S241Q4Whn18Rh278E7Yvnj4bDtE2b37jtZ3IZ06wabe0wbOuu9YPPkw6O5o
V9s+rjb4pP+w1M8eg/jxt7NtNL5B2oA5vp8Ri3J9JwsGHRthPOngj68XcOjW
7uf7cR5vwfHO85BuIgGdVjRTpdRXgC7bhvEjPgLa8d9kDydWwAL5wJS0JAEl
EoXL/JPLISLT69ikJQG17Q2ddXlfCpJLzkns9QTkaZhU/wKXC+8WXjd+9KJH
tCPHr03zmcF0J5+IH44RiWgLjrpZV8jf28o/6adAQmuW9PmqpA75H8Qpz+5U
CuJdlLAayxmQvxpkzOs3vhdNyb3Z6eCZkA/SIr1WJnEhg9/EAa0Lv+U11gxY
KpR5kd8D40vFTxbkR5txrAV/DyNZWBXyzVmWtwg4kFfLIoj2isqs8EWvyW+n
3CVy4o6hze+DQSwOm/I8sWS+6bXjCEAxVjFoW36pLnrRRfIUyu7Si1a235V/
Sf+lRkTgDKqIjaZTV8fSVKVt3NU7RJFwz2WJK4CjCb+T5sBaiqGsM+gi/Sk8
zcI230Jo8RxiKYw4MvCeQJsVw9hMpEmgJ/Da6YAoA02y6iBjrKgUWlqU9PD8
xEgrcYkOdZmURubn7a38LxNp4jghjzexsmicb6N5qZ5Ec+dq/2wocB5dFRib
D9Bjobm8Xf420yuPeoA/5NEXVhp/6UTrQAUNiVQRA9i4ybTpQemAdi8FdJv/
debiKJmm2Z+pWnZVEZ3op/8X+JxCW3scE3f0kBISOtSa8yGNQqOTmTv26rAS
ErBI0MVkUWj+rt61IoJKiGf+aK5HHoV2mU516txJJUTGaejZVVBoK1Mm55Vl
lNDKsdC8y20U2rS1y4qpgRJ678Gmz42n0uTD+gKSIpVQVW0vxoiBSruo58PL
E6OEKujSX8URqTTGu1eqM+KVUEn4aSwbhUqzDfNbzE1RQpkZlwuwPFQal+mq
ydtXSijwSwxuUoJKezYwrdzVqIR8WW8UHpGh0m58VB41+KqEHunxG5qep9Is
sj8/+tGihNwHygv7lP/r19GsHu1WQncWuw2bL1NpAQdExBbHlJCVeCod01Uq
DRV/6XCdVELmD62KVAyptE2psLsbM0roBmGdDm7+t0c0oHh3UQkZakLRXzMq
TYC/WsdvVQldjXxiJGlJpQ1S9s/Tbyoh3a6L+Hs2VJpu7bPwkG0lZJbDkf7C
lkrD/L+U0f8AhUKgZQ==
             "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-4.605169998021961, 4.605169998021962}, {-40., 0.}},
           "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {-4.797052081272866, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Exp[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
          "Primitives" -> {}, "GCFlag" -> False|>, 
        "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{-4.605169998021961, 4.605169998021962}, {-40., 0.}}, 
         "Frame" -> {{False, False}, {False, False}}, 
         "AxesOrigin" -> {-4.797052081272866, 0}, 
         "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Exp[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
         "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwdk3c8Ff7/xe+97jXuNe69qYhEIalUki3XXlFRRiVklhkShWRlkxmyk5Gd
lJHXm4qS7BFlkxGyV+L7+f3OP+dxHs8/zvnn8N1y1LXEYTAYLSwG83+uzclR
XGpLRfyRUsTxe7LgEAQi32yoSHaiql84TRai1q2KpiypKFwl60nhZ1no6n5T
eMiUitrzjDusueXgWrReQfgVKqowO/ilskEOrEiRebflqKiRraqV76g8eP8j
vOBjoyIi+xDvF2YFSLcrPCLHTEWcHNXGfgIKUPfjSpYhExVFXf/gZnZeAfBV
WZmRdFREJ5DBEuKkACFuChn/1iloRvf40+geBYj/45naN0xBTjbB2JI8RSge
WX72tIyCjNw2vbLtlSEqir/VoZiC1jqZBj6FK4Oz/FXChQIKSgs+XsdRpAzi
KRV36V9SkNvDfn2DP8pQY+ih+TCRgtTWxwJprirQ1Lrz18KHgsanCftIQaow
/p7JRFKHgsTZ3A8N9KlDg5103F4tCsLNxU0vYjQgh8v265IaBTURmISUhTTg
jkezRKECBYm2YQMy72vAolgk+fA5CoqR5HO7zKkJO6/Y60ncFPRbLfx3q40W
cCYdEhiaJqMndf5MIjI60JxsHLH4i4wSVWzqI611wCcleZ1unIxUBa0zRGN1
YCp9f5PQIBldG3hzSW5eBypy2BydO8jIxMWZ+W72RdB9s/uOUE1G6bcvq12J
ugQhbUMXToSRUXTDGc84QV0433Gw4nwwGQnyXBmTVtCFxc7rhy4HkpHomYvW
DDd0wbC3d/GeDxm9qKx6tS9aFwQHW+PBlYw2BA182TF6UP8bhnWNyeiEMrdZ
3Zge/KVPd/UQIaM/UXjm6K9X4UE+e3TScTIad3v9+c/MVdjSDi6uFiIj85S7
OQ+I+rAR6zzz7zAZ+acfa+XQ1Ie1wyqmvvvJSGXJYcPrqz4snZ/RCsWQkY8K
u4tgrwF0zdmoSmezoXH7WqP+PdegU0z3sWcaG6IljHmZSV2DjocyNbWJbOga
cTedx+QatDGxiipFsKGjsSe5ZF9dg2aB1wcv3GdDrAdCPZhVr8NH438rxhps
6HyctqBG4A14/e1p1uM5VmQ2mfDR86wJiMaGa6lNsiIei1o5MQsTKLsWvMw8
wopydGU/SMSZQMmkj9KzLlaEeZrcwr9hAgVYp7GialYkZRzP0GFqCi/P6Rz5
GcyKnmyKu7afMYOkFGKWuCAr6ruZtBazfAs4Lei1tg+xImGyfK0wxRyeCeOW
6zhZUe665Js/IuaQ8HZTUZuFFeGvtV0m2JpDbPvUqPkKC7qEqVG0njCHcELj
4af1LIjDbtFKbcwCfOz9Mn/fZEEFz4/eeE6whqy+xBIuo/8y9yckcNQaGlRK
arX0WNAI2+jfIXVrYOYZ6H+lxoK2xi9Qp8Ks4VmL+B670yyIpumbprPfBopP
zfjNYllQ1D3LmDfnbsPg4iXLuRfMaDj2JSc+2RawN61dDqYxI0+FESHpD7bA
3+T1WDuRGfUVTX3M/20LdzLzUwrDmdH6VPyGrJwdrOnie+zdmJEJl1ytyJgd
sJa/VZ1XY0ZRjt+HY6UdQM6NR+jPDAldbKkrXg9zgmEztazMcRLyLqo5yZnj
BP7aTjz6gyRUt2A6ZV7nBE389ezv20noRM0BDrc1J9DvtMSGviOh0EViQuyt
u+B0urBfMJCEGutInKuKzpA1IxN+k4+EkvaK1IgKuoJqjwUjlYuEfkrXDmFV
XWGmLtzvEzsJzX3TP0tn5QqnE4c8TjCSUKyWV07KS1eoUfOz2ponIuI2XbC0
8D3oedEkH19DRHEaDTvXZdyAycRo6ZsBER04TdJNeOIOyhF/ulMvE9GLtEaZ
pEJ38HkfUOmoRURFeG7c9053WOMq86HIExHuuchTAp8HjH4nsl0VJKIAP+02
0VoPqNKtOf5zhQnV6GtaCuEfgp3qIcuZp0xoOUCL/2ydF+Tce6NeHcqEyBJs
e7X/eMHoC60TYQFMCFtMsig66A2GdO7LJz2YUHt9YI/6Q29QQW2P75oyoU8O
LWrTUo+AR9o3dUOECUn41Iil3vKB1pMTvfTNjChfIjTuHckXinDxfIoNjGg/
p2hRk4AvhPWq2nohRkQ6hbXG0XxB83HuznI5I/I8LxQ95uoLDV22AiMpjGig
mr/VedgXah4uOVc7MqJIRum51Vo/yP+yy+K0hxF1K0ZOHU0OgODUEoNXLIxo
vnCG37gqAGxczDJ+MTAifrcWK+gLAMGDH8SMtxlQumH5DokzEDKcAq9rTjCg
Oy8JBc2JgfBsP0se/1sGdJqj/LngiycQYHlAue8aA+IdQv8EBoNhvHJgK+EK
A8Ic/TabRx8CyqwZpfo6DGjf8Jak/akQwL09eqhLgQEdsg91ff04BLwZz221
CDEg3PcZO41joeD26mLJxzV61Fkjx7TqHwY2i/7cJdH06FG+WrTU3UhoVFHv
dAijR83tFSWumZEgmEQKORlIj5JIynXbnZEwrhi9nu9BjzQkbjVvcUWBaWxa
R7YpPWJSk3rz9XEUGElUBSWL0CNqh7QQ/upT0PT6sxLYREDOz7Xz4rliQPv+
N0rJRwLai01N9JGIgUt3X4n01RIQ59dH0jF6MaBvaW1z/DUBvan0e3A2LAbM
tId+tCYTUNM+qrfVbgy4H2yt57AnoGeBFfjmuVjIfl8Ulc9GQAIy+9n0ZuMh
921YYScTAW1g94g0syRAfumdpm06AlouM2NxO5UAJdmC+IsbeCTcMXrU2CUB
asJT7y8P45HcW4E0n38J0GEccVO2DI/85Y753OBKBMyO/YmWK3i0sUvU83qU
DMkylaXsF/FobYY7s+tlMoh74CWua+BRtxA7i0VLMtiuJClMyeFRZ6X4vRM8
z6FnplEfdxSPFEXMbtih51DQy/dYfJMOyZNU7BbYUsGwtLs7NYUOsV+Ycixx
SIfled7rEwl0yD/qrvypwHSIOGE3fDyaDsk83w5sTUmHDzm43+8C6VDHm1SZ
e9/SQST1FKbTkQ5tz8q5XxPJAHxosDCDIh16eU+S8HYtA0os5B45/sIhn0D/
Ce6sLPjKl3xXahiHGGXub0TWZcGvwQ1zun4cij36lFl0OAu4jcrVE77h0LCs
miGe5wUEaR+nQjkOndPrvjed/AJMxTmzWf1wCDNEWl1LzwYy42pT4SEc2vsp
64d8Rw4c/6T7/j4nDjUL3ZkWXM8BVd+SYoU9ONT0rL1DlTsXPLdtY7vpcehb
YVKMqHUuTC2MGv+bw6IiMrf1h91cQH1tCxdqsMiUIbqXQzYfHF8V7Js1xKKJ
Kru1w+MFIMIq4Mirh0UPAk2ielkKYdYppfGKNhY10Yw3GyUK4Y54hPt7BSzi
nb4XahxWCBZ1jv0RwlgULJPGailZBNd6RVPPbGPQWrkRSfR5MajSVQrcT8Mg
zTMHndI1S4Fgdcb7VSIG9VUnykWYl8LHz3k9QzEYVOfr8TrNsxQUIpKeqAdh
UCSHvZlIcSnIcnpOc97FID025yuYfWUgekq+sEYRg4KOqMxnzZSBbEXIbXzz
LpwK17E1Ly2HqgfpKy6wCw7Mz/YUt5eDpHzFo7GyXfB7si//xFI5iH0eiatP
3AVyA7699uwbONEvWe9jvQurbIJ31CrfANfOrwP/cLtwXkrRQKSlArZUlJpX
pXZAXvCzdSRfJbgTjQwsT+6AImufRLl6Jay1OIx28e5Au4aOzl6nSlgySNp4
zbADjMUhleFQCTO3F/mdu//BeHp7jJlZFfSHp3nNO/2DmrhrNydLqqGy+6/I
ZM42KJN+Pd7vWwtWfLMhT5O3gbpGtEgvqQV2+5+/ZCK3gceaQdVxqBac8O9T
o9y2QV7lZtawHIDQWW9WaZVt2H9WZ//BHYD4KMx82OhfaHjiXHCiAYGzFqFQ
9OBfoL80FO10tx54E1YZB8h/gePrRIZXeD20jE5YPMH/x1fTX5Tn1cOxBw3c
P39vgXHir/sZo/UwnPskLKBqC0bWDYhe+h9Ah55o991gC/4ur0Y7q34E4TrW
497Rm9BDfS/Go9EAhwzF9P4FbkLQmN3hFJsGYP9j9NDz4SbUDP8uVAtqgF3u
7K8PLDbhYsvZQN7PDdDlLmN3X3wT5M5qZU5qNIL3aZtCp/4NqK92fbF79TN0
ptWdMj+8AVWhOlH00U3wWXzSYHTfBliQhjoc3jZB7TdmHzPSBugqXfQkDjRB
7l+DNpOVdVjoTyUPCH0Fb4N5pxsN6xAo8yVvrf4rCLFxlV29sw4cYUc3JLDf
wNPbVUy9bA143Qqv/cppBWd2EG/JXoMk8TZxhu+tYJPPJHUlcQ0+luvGSuDb
QK8nVc7UZw2+CzjMEs+1gbDIF1V3nTUYPjeQb/GsDb4PHDTKnVkF57j8FrJV
O4jJNXoxHlmFt5Vn8qp5OkG4k+ITsW8VhnQvl2bIdALv7Ru+7MRVwFx1/lVq
2AmkuMVA3sUVCCi3rLkc0wmjs1xRkrACFvSTlnHELoh67pRpc30FNCldWybY
bpj9y9n4OWYZjP52bOdReuHYQGLckaBlWJcvP755phesajktvD2XoWIqt9pF
txdGfDixYpbLECIY3Pk7phd6CJwyaeLLYFAaBnMc3wGxcRTf61sCetsVdpvj
fRB7ZF/C4UNL4EBILH/v8gPa8fGWXnuWYDv79fBY4g9g/bVX7DvDErxcNXCT
RT8gOHdve/jCIpSVjTYHsPwE75N7SZt1i0CgH373KP8n2EiwP2q1WISqvmef
VOYHQFaLau2ZvwCCUiFB1heH4cHxt2yDKQvQ89ihutZ6GN6RbryTf7oA+Z8f
8kv6DMPZ5mwmOvcFuHFMQSG6dBiEtaUKglUWgG9GW3Vq7wicTkWjJ+v+QN+6
yCptYgQms2+s3zo5D97djx72po3BLauX6oLs8+D5ku/2l5oxGBRcSJzemoM0
vCLrWN8YdOX4yTp9noMATJxEBPs41OflP/Yyn4M8C1XOL6HjkFq4QXqWOAt0
hqnkrccToP8mlvcb4Tds2h21jo+YhDP+MXvo52bgkDO2TLpkEpj1ounlu2aA
/rwDI6ljEuoXImdLMmeg/G10zOl9U3DqROi7WPkZEIstV49NnwLGrMeXbnhM
g8jQVurk+2moinLw+T07CUTN2Kss3LMQZ2Lvwt81CSfkgm5GKs2Ck4idlXH1
JBQIqrko2c6CYPPtC63Bk6CdeNpfsXoWYhgsOV4LTsL6jl1mhvEc2HlfL3lg
+gue3Zr7xVowDwft1IeZusZBVDRm/NG7BQhqL7WdrRmHPwW/dfEtC7AkzrXe
kj0OdV3xEhljC9CAnWeJvT8OyYl+5fxsi+CQECPDwzUO7jE9JVesFwHqB+NF
b43BgrbDxTvcS2DGeU/7+sIIiOu0PNxIXIZm78Hvcn0j4P21MbGsbBnEx9Us
eOtHILXvQNGTr8tALD7wcCJmBD5apDD6/VuGMmWU6ygxAuZStFfo1grQOZHw
/t7DYJGdDjaiq6ARrnTPiHMQ4k0juZZ//ffjK/krUpMDYO3D2BRDWIe1AxTX
A28GINwj4Z8+/zpk5g46/7g0ACI8RF2VW+uw9cHDyTjoJ7B8yD3/cWgd8reK
bc3W+0GJFQxNRjaA2Yb71u3uXljC1mfk7G5Bm+KqjsfTdvi9FrG6p3AXPoqf
2S241Q4Whn18Rh278E7Yvnj4bDtE2b37jtZ3IZ06wabe0wbOuu9YPPkw6O5o
V9s+rjb4pP+w1M8eg/jxt7NtNL5B2oA5vp8Ri3J9JwsGHRthPOngj68XcOjW
7uf7cR5vwfHO85BuIgGdVjRTpdRXgC7bhvEjPgLa8d9kDydWwAL5wJS0JAEl
EoXL/JPLISLT69ikJQG17Q2ddXlfCpJLzkns9QTkaZhU/wKXC+8WXjd+9KJH
tCPHr03zmcF0J5+IH44RiWgLjrpZV8jf28o/6adAQmuW9PmqpA75H8Qpz+5U
CuJdlLAayxmQvxpkzOs3vhdNyb3Z6eCZkA/SIr1WJnEhg9/EAa0Lv+U11gxY
KpR5kd8D40vFTxbkR5txrAV/DyNZWBXyzVmWtwg4kFfLIoj2isqs8EWvyW+n
3CVy4o6hze+DQSwOm/I8sWS+6bXjCEAxVjFoW36pLnrRRfIUyu7Si1a235V/
Sf+lRkTgDKqIjaZTV8fSVKVt3NU7RJFwz2WJK4CjCb+T5sBaiqGsM+gi/Sk8
zcI230Jo8RxiKYw4MvCeQJsVw9hMpEmgJ/Da6YAoA02y6iBjrKgUWlqU9PD8
xEgrcYkOdZmURubn7a38LxNp4jghjzexsmicb6N5qZ5Ec+dq/2wocB5dFRib
D9Bjobm8Xf420yuPeoA/5NEXVhp/6UTrQAUNiVQRA9i4ybTpQemAdi8FdJv/
debiKJmm2Z+pWnZVEZ3op/8X+JxCW3scE3f0kBISOtSa8yGNQqOTmTv26rAS
ErBI0MVkUWj+rt61IoJKiGf+aK5HHoV2mU516txJJUTGaejZVVBoK1Mm55Vl
lNDKsdC8y20U2rS1y4qpgRJ678Gmz42n0uTD+gKSIpVQVW0vxoiBSruo58PL
E6OEKujSX8URqTTGu1eqM+KVUEn4aSwbhUqzDfNbzE1RQpkZlwuwPFQal+mq
ydtXSijwSwxuUoJKezYwrdzVqIR8WW8UHpGh0m58VB41+KqEHunxG5qep9Is
sj8/+tGihNwHygv7lP/r19GsHu1WQncWuw2bL1NpAQdExBbHlJCVeCod01Uq
DRV/6XCdVELmD62KVAyptE2psLsbM0roBmGdDm7+t0c0oHh3UQkZakLRXzMq
TYC/WsdvVQldjXxiJGlJpQ1S9s/Tbyoh3a6L+Hs2VJpu7bPwkG0lZJbDkf7C
lkrD/L+U0f8AhUKgZQ==
          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {{-4.605169998021961, 4.605169998021962}, {-40., 0.}}, 
       "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {-4.797052081272866, 0}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Exp[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
       "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\"\[Omega]\"", HoldForm], TraditionalForm], None},
  AxesOrigin->{-4.797052081272866, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      MachinePrecision, RotateLabel -> 0], 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->FrontEndValueCache[{
     Charting`ScaledTickValues[{Log, Exp}], Automatic}, {{{-4.605170185988091, 
       Directive[]}, {-2.3025850929940455`, 
       Directive[]}, {0., 
       Directive[]}, {2.302585092994046, 
       Directive[]}, {4.605170185988092, 
       Directive[]}}, Automatic}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Exp[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Exp[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-4.605169998021961, 4.605169998021962}, {-40., 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->FrontEndValueCache[{
     Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
      MachinePrecision, RotateLabel -> 0], 
     Automatic}, {{{-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.01\"", ShowStringCharacters -> False], 0.01, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}}, {4.605170185988092, 
       FormBox["100", TraditionalForm], {0.01, 0.}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      0.6931471805599453, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.0986122886681098`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.3862943611198906`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.6094379124341003`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.791759469228055, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.9459101490553132`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.0794415416798357`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.995732273553991, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.4011973816621555`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.6888794541139363`, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.912023005428146, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.0943445622221, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.248495242049359, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.382026634673881, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.499809670330265, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.298317366548036, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.703782474656201, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.991464547107982, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.214608098422191, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.396929655216146, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.551080335043404, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.684611727667927, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.802394763324311, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.907755278982137, 
       FormBox[
        TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, 
     Automatic}]]], "Output",
 CellChangeTimes->{3.893951776404444*^9, 3.89395213397527*^9, 
  3.89757191380347*^9},
 CellID->611949984,ExpressionUUID->"fb4daee0-52d2-49b2-892f-3f5bab905265"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse Fourier Transform", "Subsection",
 CellChangeTimes->{
  3.686143685370058*^9, {3.833989656444832*^9, 3.8339896568757105`*^9}},
 CellID->2144427149,ExpressionUUID->"24411bc8-16d7-4ea7-8947-5849f5f3e606"],

Cell["The inverse Fourier transform is defined", "Text",
 CellChangeTimes->{{3.465316262390625*^9, 3.465316288578125*^9}, {
   3.4655584269375*^9, 3.4655584276875*^9}, {3.686143768787384*^9, 
   3.686143928422095*^9}, {3.686144004001638*^9, 3.6861440053138547`*^9}, {
   3.8034298669893456`*^9, 3.803429878062605*^9}, 3.8108442278815784`*^9, 
   3.916220171317148*^9},
 CellID->169045642,ExpressionUUID->"32b4e633-282a-4b66-aac1-4e6aacd28877"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
      RowBox[{
       RowBox[{"X", "(", " ", 
        RowBox[{"j", " ", "\[Omega]"}], ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"j", " ", "\[Omega]", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"8c4a1b48-6961-461b-8314-f22c9136d75f"]
}], "Text",
 CellChangeTimes->{{3.465316262390625*^9, 3.465316288578125*^9}, {
  3.4655584269375*^9, 3.4655584276875*^9}, {3.686143768787384*^9, 
  3.686143839937872*^9}, {3.833989662456783*^9, 3.833989676264839*^9}, {
  3.9312692282950573`*^9, 3.9312692282951193`*^9}},
 CellID->29240113,ExpressionUUID->"8c1b2a74-692e-45ce-8afb-f3e358858021"],

Cell[TextData[{
 "The inverse transform allows the computation of a time signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "3c4d7f0b-5a88-4728-8bb4-e5404914f2bb"],
 " from its Fourier transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", 
    RowBox[{"j", " ", "\[Omega]"}], ")"}], TraditionalForm]],ExpressionUUID->
  "fabb5a50-945a-4f27-ad9e-2a1c101bfa73"],
 ". Recall from an earlier example the following transform pair"
}], "Text",
 CellChangeTimes->{{3.465316262390625*^9, 3.465316288578125*^9}, {
   3.4655584269375*^9, 3.4655584276875*^9}, {3.686143768787384*^9, 
   3.686143928422095*^9}, {3.686144004001638*^9, 3.6861440053138547`*^9}, {
   3.8034298669893456`*^9, 3.803429878062605*^9}, 3.8108442215065393`*^9, {
   3.812845884750147*^9, 3.812845891485623*^9}, {3.8910389460576625`*^9, 
   3.891038950896764*^9}, {3.8910389959875174`*^9, 3.891039024771021*^9}, 
   3.916220174636593*^9},
 CellID->1812307675,ExpressionUUID->"53f62305-95f9-48da-92d7-20973ae9aac0"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], 
    RowBox[{"u", "(", "t", ")"}], " ", 
    OverscriptBox["\[LongRightArrow]", "\[ScriptCapitalF]"], 
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{"j", " ", "\[Omega]"}]}]]}], TraditionalForm]],ExpressionUUID->
  "89241ccc-5d4e-4873-882a-b98f253d0e40"]
}], "Text",
 CellChangeTimes->{{3.810845231705306*^9, 3.8108453235387564`*^9}, {
  3.833989706190798*^9, 3.8339897273262715`*^9}, {3.8544649775873613`*^9, 
  3.8544649780728874`*^9}},
 CellID->1694528324,ExpressionUUID->"3d691632-78c7-4d64-ab8d-e9a038463f9d"],

Cell["\<\
Now, with the following inverse calculation, the time signal can be recovered \
from its Fourier transform:\
\>", "Text",
 CellChangeTimes->{{3.8018323832231827`*^9, 3.801832385291674*^9}, 
   3.8018327612469654`*^9, {3.801832791650681*^9, 3.801832868238068*^9}, {
   3.8108453763177457`*^9, 3.8108454882157974`*^9}, {3.834072921349218*^9, 
   3.83407292985238*^9}, {3.9162201771114807`*^9, 3.916220181922352*^9}},
 CellID->9414954,ExpressionUUID->"5cb28aec-45de-4694-b360-3e7f2f9f27a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseFourierTransform", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]"}]}]], ",", "\[Omega]", ",", "t",
    ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.801832393576518*^9, 3.801832442682491*^9}, 
   3.801832550975766*^9, {3.801832672312619*^9, 3.801832681904983*^9}},
 CellID->1470825647,ExpressionUUID->"e20439b3-1964-4eb4-a956-adb7b663ca5c"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", "t"}]], " ", 
  RowBox[{"HeavisideTheta", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.814116680658718*^9, 3.897571919173976*^9},
 CellID->348709352,ExpressionUUID->"03f61161-b70b-401f-b6ec-3e76eda465ac"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsection",
 CellChangeTimes->{{3.3993190765*^9, 3.39931909240625*^9}, {
  3.399679771859375*^9, 3.39967977509375*^9}, {3.402874559328125*^9, 
  3.402874570875*^9}, {3.465147493*^9, 3.46514749640625*^9}, {
  3.4657652318125*^9, 3.465765237171875*^9}, {3.613165775296679*^9, 
  3.6131657821606917`*^9}, {3.686143691001668*^9, 3.686143694355674*^9}, {
  3.686144309534753*^9, 3.686144310080754*^9}, {3.8006605406031995`*^9, 
  3.800660540692914*^9}, {3.8018330978827953`*^9, 3.80183309836948*^9}},
 CellID->482388512,ExpressionUUID->"4d88813f-5322-4104-83bf-a6d82eaa8a0f"],

Cell["\<\
Obtain the inverse Fourier transform of the following function of frequency: \
\
\>", "Text",
 CellChangeTimes->{{3.4028746340625*^9, 3.402874647328125*^9}, {
  3.465262460765625*^9, 3.465262475578125*^9}, {3.613165813978777*^9, 
  3.613165880496583*^9}, {3.65438619062162*^9, 3.65438620619022*^9}, {
  3.6861443772388716`*^9, 3.686144527327469*^9}, {3.801833119785269*^9, 
  3.801833162136801*^9}},
 CellID->752953759,ExpressionUUID->"8db3cafd-e90f-4290-94e6-cf208e525aaa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"UnitBox", "[", 
    FractionBox["\[Omega]", "2"], "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["424", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`\[Omega], -3, 3}, PlotRange -> {-0.5, 1.5}, 
     Exclusions -> None, AxesLabel -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.800656463902409*^9, 3.8006565012530303`*^9}, {
   3.8115086827873683`*^9, 3.811508682953718*^9}, 3.812845945790602*^9, {
   3.892299984128341*^9, 3.892300000038544*^9}, {3.892586400201357*^9, 
   3.892586424561876*^9}, {3.893951781020983*^9, 3.893951784889357*^9}, 
   3.8939521124985933`*^9, {3.894656398693229*^9, 3.894656403246444*^9}},
 CellID->1920179389,ExpressionUUID->"b77402f7-eb94-4dba-a6be-e4e7284936b1"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
             "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 
           1.5}}, "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 
          1.5}}, "Frame" -> {{False, False}, {False, False}}, 
         "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
         "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
         "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 
        1.5}}, "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
       "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
       "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\[Omega]", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.893951791080857*^9, 3.8939521144901*^9, 
  3.897571921863944*^9},
 CellID->356116241,ExpressionUUID->"067db3fe-0eb6-4f66-80b4-0616af93f65f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.6861445374362864`*^9, 3.686144539043089*^9}},
 CellID->70743807,ExpressionUUID->"51a6edea-1713-4060-865a-07d027daf112"],

Cell[TextData[{
 "Using the ",
 ButtonBox["InverseFourierTransform",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InverseFourierTransform"],
 ":"
}], "Text",
 CellChangeTimes->{{3.800709957050835*^9, 3.800709968719654*^9}, {
  3.8141167043211317`*^9, 3.814116716871837*^9}, {3.834072948453766*^9, 
  3.834072953966414*^9}, {3.9235687798303833`*^9, 3.9235687798503838`*^9}},
 CellID->1432707458,ExpressionUUID->"e48ab696-de13-44aa-8271-91b0e5f9c533"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseFourierTransform", "[", 
  RowBox[{
   RowBox[{"UnitBox", "[", 
    RowBox[{"\[Omega]", "/", "2"}], "]"}], ",", "\[Omega]", ",", "t", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.774631475157876*^9, 3.7746314834320955`*^9}, {
  3.774631638151877*^9, 3.774631673921015*^9}},
 CellID->1927596442,ExpressionUUID->"e7589caa-e24e-42b2-8f95-8f1d40c07786"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Sinc", "[", "t", "]"}], "\[Pi]"]], "Output",
 CellChangeTimes->{3.7746316748650455`*^9, 3.8018321553823276`*^9, 
  3.897571924515468*^9},
 CellID->10904196,ExpressionUUID->"cc91817f-b7df-44e9-b5e3-2e3aecbe56f9"]
}, Open  ]],

Cell["\<\
Here are plots of the Fourier transform (left) and the time signal (right):\
\>", "Text",
 CellChangeTimes->{{3.654374300206697*^9, 3.654374313903321*^9}, {
  3.6543774764491744`*^9, 3.654377482455097*^9}, {3.654377536383606*^9, 
  3.654377536945199*^9}, {3.810833225931681*^9, 3.810833246688264*^9}, {
  3.814116759642393*^9, 3.814116778617183*^9}, {3.834072957524579*^9, 
  3.83407295788583*^9}},
 CellID->175102052,ExpressionUUID->"f5f49501-4efd-4d8b-b67f-c0d1926f6247"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"List", "ListIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["List", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1232", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   {
    Plot[
     UnitBox[$CellContext`\[Omega]/2], {$CellContext`\[Omega], -3, 3}, 
     Sequence[
     PlotRange -> {-0.5, 1.5}, Exclusions -> None, AxesLabel -> Automatic]], 
    Plot[Sinc[$CellContext`t]/Pi, {$CellContext`t, -20, 20}, 
     Sequence[AxesLabel -> Automatic, PlotRange -> All]]},
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.37060157875*^9, 3.370601682703125*^9}, {
   3.3706018715625*^9, 3.37060188378125*^9}, {3.399318449140625*^9, 
   3.39931846759375*^9}, {3.399318516546875*^9, 3.39931853009375*^9}, {
   3.399318578984375*^9, 3.399318603703125*^9}, {3.399679584828125*^9, 
   3.399679593609375*^9}, {3.3996797595625*^9, 3.399679760109375*^9}, 
   3.402874809703125*^9, {3.40287484503125*^9, 3.40287484515625*^9}, {
   3.40287501503125*^9, 3.40287502684375*^9}, {3.402875312203125*^9, 
   3.4028754665625*^9}, {3.46514767475*^9, 3.4651477340625*^9}, {
   3.465147787125*^9, 3.46514779809375*^9}, {3.465147844484375*^9, 
   3.46514796340625*^9}, {3.46531832990625*^9, 3.4653183719375*^9}, {
   3.46531849496875*^9, 3.465318604828125*^9}, {3.465599687625*^9, 
   3.46559969228125*^9}, {3.61316639053459*^9, 3.6131663983190036`*^9}, 
   3.686145238016397*^9, {3.686145314464827*^9, 3.6861453274272966`*^9}, {
   3.774631700403477*^9, 3.774631743358931*^9}, {3.8006602636846347`*^9, 
   3.800660278297004*^9}, {3.811508744796609*^9, 3.811508829013705*^9}, {
   3.814116790275974*^9, 3.814116832981499*^9}, {3.892300013930368*^9, 
   3.8923000166873674`*^9}, {3.8939517955081778`*^9, 3.893951803998385*^9}, 
   3.8939521029123645`*^9},
 CellID->887591574,ExpressionUUID->"686a7e5f-1b6c-49d7-b15d-bc40d066e086"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-2.9999998775510206`, 
               2.9999998775510206`}, {-0.5, 1.5}}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-2.9999998775510206`, 
              2.9999998775510206`}, {-0.5, 1.5}}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox["\[Omega]", HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{1.2444635614796624`, 15.944335634447611`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {128.07316647029023, -78.225}, 
     ImageScaled[{0.5, 0.5}], {240.19939005159637, 149},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJwUV3c81e8Xp+zslb2vvS7RkJ6nhJSVhK/ISCpKRiRkh2zXHlfGtecthOR5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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJwUV3c81e8Xp+zslb2vvS7RkJ6nhJSVhK/ISCpKRiRkh2zXHlfGtecthOR5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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {All, All}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {All, All}, 
             "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwUV3c81e8Xp+zslb2vvS7RkJ6nhJSVhK/ISCpKRiRkh2zXHlfGtecthOR5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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {All, All}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         TagBox["t", HoldForm], TraditionalForm], None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{3.985415259818808, 11.212890502437943`}, {5.5859375, 
       5.5859375}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {383.22425269403544, -78.225}, 
     ImageScaled[{0.5, 0.5}], {238.20889661792586, 149},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[149]},
  PlotRange->{{0, 510.3021724474904}, {-156.45, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.893951808940364*^9, 3.893952105222645*^9, 
  3.897571926685149*^9},
 CellID->430536912,ExpressionUUID->"4c341185-4443-498c-893b-80a68b272f5e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1330172156,ExpressionUUID->"f79dc070-7448-4d17-bc38-77ba455fe45e"],

Cell["The inverse Fourier transform integral", "Text",
 CellChangeTimes->{{3.399318281890625*^9, 3.3993182919375*^9}, {
   3.40287466659375*^9, 3.402874687*^9}, {3.4028755139375*^9, 
   3.40287551478125*^9}, {3.4653220448125*^9, 3.46532208096875*^9}, 
   3.654386215175705*^9, {3.6544261516196995`*^9, 3.6544261584680114`*^9}, {
   3.803429971420251*^9, 3.803429972725785*^9}, {3.814116868704716*^9, 
   3.8141168736425066`*^9}, 3.916220192636404*^9},
 CellID->898660622,ExpressionUUID->"3927b042-4db1-4a48-9569-1d39d8c10a2d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
      RowBox[{
       RowBox[{"X", "(", " ", 
        RowBox[{"j", " ", "\[Omega]"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"\[ExponentialE]", " "}], 
        RowBox[{"j", " ", "\[Omega]", " ", "t", " "}]], 
       RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"2e171e20-d91e-46a9-bd33-a3baa55ca5e2"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845658349691*^9, 3.810845665637617*^9}, {3.9312692381390657`*^9, 
  3.931269238139105*^9}},
 CellID->536584603,ExpressionUUID->"ddcea1e3-0d24-4de8-94f7-83729ba1aa2c"],

Cell["Substitution yields the following definite integral", "Text",
 CellChangeTimes->{{3.814116881152438*^9, 3.8141168985268874`*^9}, 
   3.9162201955469894`*^9},
 CellID->1093588868,ExpressionUUID->"a80f55cf-c086-40a5-beaa-90606d0ae418"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "1"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[ExponentialE]", " "}], 
        RowBox[{"j", " ", "\[Omega]", " ", "t", " "}]], 
       RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"6d4cf278-3065-4bc7-8e1d-9ac70d49c8be"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845692079429*^9}, {3.834072971639165*^9, 
  3.83407297163926*^9}},
 CellID->1783053450,ExpressionUUID->"d35b3964-1cb3-4796-9d10-7e9a9744c0c1"],

Cell["Integration returns", "Text",
 CellChangeTimes->{{3.8141169159182982`*^9, 3.81411692080766*^9}, 
   3.9162201980699043`*^9},
 CellID->1792523912,ExpressionUUID->"cc574ed3-ba45-473e-b584-8645b0e83492"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      FractionBox["1", 
       RowBox[{"j", " ", "t"}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"j", " ", "\[Omega]", " ", "t"}]]}], 
     SubsuperscriptBox["\[VerticalSeparator]", 
      RowBox[{"-", "1"}], "1"]}]}], TraditionalForm]],ExpressionUUID->
  "06752585-b1c1-40c0-87b3-37524329811c"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845706096455*^9}, {3.812845981537949*^9, 
  3.812845981537949*^9}},
 CellID->2048788868,ExpressionUUID->"cb8a2dbe-ec02-4d2a-8949-b0deae67a208"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", "\[Pi]"}]], 
     FractionBox["1", 
      RowBox[{"j", " ", "t"}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"j", " ", "t"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "j"}], " ", "t"}]]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"d6872a43-958d-4eb1-a3ab-3876e847d34d"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845671337662*^9}, {3.8108457146084533`*^9, 
  3.8108457146084533`*^9}, {3.810845758491834*^9, 3.810845758491834*^9}},
 CellID->1241708478,ExpressionUUID->"9599ac4b-eaa9-4435-bbbd-7fe6034a8f48"],

Cell["Simplification gives the following result", "Text",
 CellChangeTimes->{{3.814116954249131*^9, 3.814116963160148*^9}, 
   3.9162202010215282`*^9},
 CellID->148308200,ExpressionUUID->"a997e539-e850-439b-88b0-619ce215feee"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     FractionBox["1", 
      RowBox[{"j", " ", "t"}]], 
     RowBox[{"(", 
      RowBox[{"2", "j", " ", "sin", " ", 
       RowBox[{"(", "t", ")"}]}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "4ab291b8-70d7-44ca-8dba-2f504f3da5fd"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845671337662*^9}, {3.8108457146084533`*^9, 
  3.8108457458388186`*^9}},
 CellID->1534886880,ExpressionUUID->"1dd3d32b-2063-4f34-81b5-fdd290743079"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"\[Pi]", " ", "t"}]], "sin", " ", 
     RowBox[{"(", "t", ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "bd4c8ac9-23b4-4a72-8649-046345bd9166"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845671337662*^9}, {3.8108457146084533`*^9, 
  3.8108457343508425`*^9}},
 CellID->1270224396,ExpressionUUID->"1b67e289-18e0-450d-a2b0-bb641cd415ad"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bandwidth", "Subsection",
 CellChangeTimes->{{3.465325339796875*^9, 3.46532535190625*^9}, {
  3.613164601161947*^9, 3.6131646045535975`*^9}},
 CellID->526488745,ExpressionUUID->"39cd1a1c-86b7-4e23-83ac-e5c6e0c76eaa"],

Cell["\<\
The bandwidth of a signal may be defined as the range of frequencies where \
the signal magnitudes are relatively \[OpenCurlyDoubleQuote]large.\
\[CloseCurlyDoubleQuote] To develop an intuitive understanding of bandwidth, \
compare the spectra of the following four pulse-shaped signals\
\>", "Text",
 CellChangeTimes->{
  3.465325397*^9, {3.465475883859375*^9, 3.465475888*^9}, 
   3.613164613632814*^9, {3.61316465743769*^9, 3.613164699566054*^9}, {
   3.8340729912225637`*^9, 3.834072993174816*^9}, {3.891039122390373*^9, 
   3.8910391589910555`*^9}, {3.891039194197222*^9, 3.8910392258379154`*^9}, {
   3.91580958459953*^9, 3.9158095871786*^9}, 3.916220205203035*^9},
 CellID->1063711575,ExpressionUUID->"415979ec-1ffb-47a7-8bbe-17372adabca2"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 0.5}, {0.5, 0.5}},
      ImageSize->120,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{{}, {}}], {64.8, -38.93614129124337}, ImageScaled[{0.5, 0.5}], {120, 74.16407864998737},
     
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJxN1wk0VesXAPBrqFBJCpVklm5KSYbKf6vw6jUY4tEzNyAU7jOV0iUZShGS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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxN1wk0VesXAPBrqFBJCpVklm5KSYbKf6vw6jUY4tEzNyAU7jOV0iUZShGS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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxN1wk0VesXAPBrqFBJCpVklm5KSYbKf6vw6jUY4tEzNyAU7jOV0iUZShGS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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 0.5}, {0.5, 0.5}},
      ImageSize->120,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{{}, {}}], {194.39999999999998, -38.93614129124337}, 
     ImageScaled[{0.5, 0.5}], {120, 74.16407864998737},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJxN2Xk4lF/YOPAJFZKklBJJshNRonKTQoslCaksFZUtVJYICdnKUNmyhmxl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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxN2Xk4lF/YOPAJFZKklBJJshNRonKTQoslCaksFZUtVJYICdnKUNmyhmxl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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxN2Xk4lF/YOPAJFZKklBJJshNRonKTQoslCaksFZUtVJYICdnKUNmyhmxl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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 0.5}, {0.5, 0.5}},
      ImageSize->120,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{{}, {}}], {324., -38.93614129124337}, ImageScaled[{0.5, 0.5}], {120, 74.16407864998737},
     
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[
      InterpretationBox[{
        TagBox[{{{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
             Opacity[1.], LineBox[CompressedData["
1:eJw12nc0V3/8B3AkRCGl1FdIVKTMlPlCMiNkb8qIQmWEskJGRkR2VvbeK29k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              "]]},
            Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
         {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
        DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
          Slot["HighlightElements"], 
          Slot["LayoutOptions"], 
          Slot["Meta"], 
          Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
              Annotation[{
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJw12nc0V3/8B3AkRCGl1FdIVKTMlPlCMiNkb8qIQmWEskJGRkR2VvbeK29k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                 "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
               1.5}}, "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
              "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
              "DefaultStyle" -> {
                Directive[
                 Opacity[1.], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> ({
                  Identity[
                   Part[#, 1]], 
                  Identity[
                   Part[#, 2]]}& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> Plot, "GroupHighlight" -> False|>|>]]& )[<|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
              1.5}}, "Frame" -> {{False, False}, {False, False}}, 
             "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
             "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                Opacity[1.], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> Plot, "GroupHighlight" -> False|>|>],
         ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
          4.503599627370496*^15, -4.503599627370496*^15}}]},
       Annotation[{{{{}, {}, 
           Annotation[{
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJw12nc0V3/8B3AkRCGl1FdIVKTMlPlCMiNkb8qIQmWEskJGRkR2VvbeK29k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              "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.5, 
            1.5}}, "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {120, 120/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 0.5}, {0.5, 0.5}},
      ImageSize->120,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{{}, {}}], {453.6, -38.93614129124337}, 
     ImageScaled[{0.5, 0.5}], {120, 74.16407864998737},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[480], 
    UpTo[75]},
  PlotRange->{{0, 518.4}, {-77.87228258248675, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.813357999553423*^9, 3.81335806093648*^9}, 
   3.892729978644994*^9, 3.8939518242977543`*^9, 3.893952094879549*^9},
 CellID->122065701,ExpressionUUID->"a8d7777b-d42a-4d05-8e73-667dd6f891ce"],

Cell["The four signals and their Fourier transforms are:", "Text",
 CellChangeTimes->{{3.465558807671875*^9, 3.4655588255625*^9}, {
  3.613164752742654*^9, 3.613164759658123*^9}, {3.8007100816278152`*^9, 
  3.800710084249803*^9}, {3.8018351137820573`*^9, 3.801835148031533*^9}, {
  3.811502722193928*^9, 3.811502738449938*^9}, {3.811502888089151*^9, 
  3.81150290184966*^9}, {3.813246233121966*^9, 3.813246233999003*^9}, {
  3.813358667334195*^9, 3.8133586862163534`*^9}, {3.916220240361042*^9, 
  3.916220241982241*^9}},
 CellID->2146563397,ExpressionUUID->"492c71f4-e187-4a3d-a89a-3cbc4966ef65"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2152", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    Map[{#, 
      " \!\(\*OverscriptBox[\(\[LongLeftRightArrow]\), \(\[ScriptCapitalF]\)]\
\) ", 
      FourierTransform[#, $CellContext`t, $CellContext`\[Omega], 
       FourierParameters -> {1, -1}]}& , {
      Sequence[
       UnitBox[$CellContext`t], 
       UnitTriangle[$CellContext`t], ((1/2) UnitBox[$CellContext`t/2]) (
        Cos[Pi $CellContext`t] + 1), Exp[(-2) $CellContext`t^2]/Sqrt[Pi/2]]}], 
    Sequence[Frame -> True, Spacings -> 1]],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.465325568859375*^9, 3.465325636140625*^9}, {
   3.46532608603125*^9, 3.465326165703125*^9}, {3.65547089597099*^9, 
   3.655470952374471*^9}, {3.655471032445653*^9, 3.655471060657491*^9}, {
   3.81324624238997*^9, 3.8132462720957317`*^9}, 3.813246439550639*^9, {
   3.813246499847054*^9, 3.813246503741381*^9}, {3.813246929628131*^9, 
   3.813246937497137*^9}, {3.813357243177969*^9, 3.81335728269192*^9}, {
   3.813358133781133*^9, 3.81335814082984*^9}, {3.854465224818443*^9, 
   3.8544652566658163`*^9}, {3.893967529166344*^9, 3.8939675706566405`*^9}},
 CellID->1713227426,ExpressionUUID->"b7e5e9fa-572c-40c9-bce7-1eff5564fa76"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
     "UnitBox", "[", "t", 
      "]"}], "\<\" \\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\) \"\>", 
     RowBox[{"Sinc", "[", 
      FractionBox["\[Omega]", "2"], "]"}]},
    {
     RowBox[{
     "UnitTriangle", "[", "t", 
      "]"}], "\<\" \\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\) \"\>", 
     SuperscriptBox[
      RowBox[{"Sinc", "[", 
       FractionBox["\[Omega]", "2"], "]"}], "2"]},
    {
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Pi]", " ", "t"}], "]"}]}], ")"}], " ", 
      RowBox[{"UnitBox", "[", 
       FractionBox["t", "2"], 
       "]"}]}], "\<\" \\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\) \"\>", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sinc", "[", 
         RowBox[{"\[Pi]", "-", "\[Omega]"}], "]"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sinc", "[", "\[Omega]", "]"}]}], "+", 
        RowBox[{"Sinc", "[", 
         RowBox[{"\[Pi]", "+", "\[Omega]"}], "]"}]}], ")"}]}]},
    {
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["t", "2"]}]], " ", 
      SqrtBox[
       FractionBox["2", 
        "\[Pi]"]]}], "\<\" \
\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \
\\(\[ScriptCapitalF]\\)]\\) \"\>", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], "8"]}]]}
   },
   AutoDelete->False,
   GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.655470939510236*^9, 3.655470952873665*^9}, {
   3.6554710351730175`*^9, 3.6554710618274775`*^9}, 3.81324627338679*^9, 
   3.8132464407166233`*^9, 3.8132465059153557`*^9, 3.8132469410730963`*^9, {
   3.8133572605396996`*^9, 3.813357283716904*^9}, 3.813358141473812*^9, {
   3.893967560678794*^9, 3.893967573261536*^9}, 3.897571939069106*^9},
 CellID->32592075,ExpressionUUID->"057232ad-2858-49f3-a2fa-ee602eb4bcb4"]
}, Open  ]],

Cell["\<\
This shows and compares the magnitude spectra of the four signals:\
\>", "Text",
 CellChangeTimes->{{3.8018351681757083`*^9, 3.801835178347521*^9}, {
  3.80183550997975*^9, 3.801835555061283*^9}, {3.813247002004551*^9, 
  3.8132470028596125`*^9}, {3.813358753202462*^9, 3.813358772207203*^9}, {
  3.813358863009862*^9, 3.813358865803994*^9}},
 CellID->752609806,ExpressionUUID->"cc1a4979-8fae-42aa-aeb1-a9bb4ff611a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["6", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["2928", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[
    Evaluate[
     Map[20 Log10[
        Abs[#]]& , {
       Sinc[$CellContext`\[Omega]/2], 
       Sinc[$CellContext`\[Omega]/2]^2, (1/2) (
        Sinc[Pi - $CellContext`\[Omega]] + 2 Sinc[$CellContext`\[Omega]] + 
        Sinc[Pi + $CellContext`\[Omega]]), 
       Exp[-($CellContext`\[Omega]^2/8)]}]], {$CellContext`\[Omega], 1, 100}, 
    PlotRange -> {10, -80}, GridLines -> {Full, Automatic}, AxesLabel -> 
    Automatic, PlotLegends -> 
    Map[Style[#, Small]& , {
      "pulse", "triangle", "raised cosine", "Gaussian"}]],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.465325403140625*^9, 3.4653254130625*^9}, {
   3.4653254446875*^9, 3.465325505671875*^9}, {3.46532565428125*^9, 
   3.46532566271875*^9}, {3.465325711078125*^9, 3.465325712203125*^9}, {
   3.465325756*^9, 3.465325756078125*^9}, {3.465325832921875*^9, 
   3.465325864890625*^9}, {3.465558692359375*^9, 3.465558718890625*^9}, {
   3.46555876540625*^9, 3.465558769421875*^9}, {3.613164732072614*^9, 
   3.613164740122229*^9}, {3.71840628888705*^9, 3.7184064413283644`*^9}, {
   3.718406503047936*^9, 3.718406508699967*^9}, {3.80183556860505*^9, 
   3.8018356249501324`*^9}, {3.801835813000344*^9, 3.801835924908841*^9}, {
   3.801837623380119*^9, 3.801837640589259*^9}, {3.8108460502302537`*^9, 
   3.810846055445259*^9}, {3.811503125061571*^9, 3.811503125487924*^9}, {
   3.8115033372718067`*^9, 3.8115033567042704`*^9}, {3.813246284001783*^9, 
   3.8132463213317347`*^9}, {3.8132464468800564`*^9, 3.813246473538082*^9}, {
   3.8132468119173193`*^9, 3.813246911171143*^9}, {3.813246955096705*^9, 
   3.8132469551626368`*^9}, {3.81335738321069*^9, 3.813357459415413*^9}, {
   3.813357543416083*^9, 3.8133575456540875`*^9}, {3.81335873782763*^9, 
   3.813358740578825*^9}, {3.8133587873602176`*^9, 3.8133588008925905`*^9}, 
   3.854465079278848*^9, {3.8923000469791837`*^9, 3.892300051104769*^9}, {
   3.892300124421879*^9, 3.89230015442974*^9}, {3.89230029362442*^9, 
   3.892300295769266*^9}, {3.892300830779365*^9, 3.892300852297679*^9}, {
   3.892300890584446*^9, 3.892300932404499*^9}, 3.8925023889617033`*^9, {
   3.892502422014746*^9, 3.892502434818303*^9}, {3.892502526764348*^9, 
   3.892502571721469*^9}, {3.893951833494209*^9, 3.8939518396143265`*^9}, 
   3.8939520761410418`*^9},
 CellID->434328612,ExpressionUUID->"10272b42-099a-4329-ae37-f2cf261cbf71"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[
    InterpretationBox[{
      TagBox[{{{}, {}, 
         TagBox[{
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2], 
           Opacity[1.], 
           LineBox[CompressedData["
1:eJwVlmc81Ysfx61cMpKVGR1HyiiRVfLNvCqFSFaFomhcKpEyKjfjllFGpSsz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            "]], 
           LineBox[CompressedData["
1:eJwVV3k0Ve/3PueeG5IGpNInRUo69+JyjRnOlrFCkiRNGgyhlErlE8qUKUIq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            "]], 
           LineBox[CompressedData["
1:eJwVlXk01dsbxg3fIUqDKXSTVBoUzvccxxjvOeYS4qBQuobIUFHkCkVR0kCm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            "]], 
           LineBox[CompressedData["
1:eJwVU3s01fkXZYrv59uLqUGqKSWvSknf772u63Jc7/JLQ4kYiano5ZG8azCK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            "]], 
           LineBox[CompressedData["
1:eJwVVGk4lWsXRuTs560UJUVIaSPEFu9rm5Yhc4NoUMYkihBSOggZMksqnaQo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            "]], 
           LineBox[CompressedData["
1:eJwVk3s41Gkbx8ckev2eSgcSRbQOiaKT328O5mYmh5qyO6FWSGfKqVeUadF2
0GrVpFarVMral422rEyodA/m6uSQklOYnEqJV0lF5P29fzzXc93X/dzPffh8
b/MtEbLtXA6HE8Ge/9+7RvofmPxOwaQfx5NLfKT4cf2r7+UXKFgYsql/uMsd
99WvCQnOoMBvaMS0L80NR7wLf/bNpGCofM4Jv/MrMe7ZnPOSPym4IW/aNKtS
ghzZkX+W5FBQHP/JvMtUgoef9D6al0vBZye7q+okMep4reuc8jcFz0xs9MZ1
xJhUVfJ19AbrP/T4QN5pVyRSi5m9BRT4e4SpKVtXVDxKsmtSUqB5EvTC4LEL
Tvd8L7lfTMFN/ZtGrntdMPX+hoDCO+z7cFNp0HcuaOSG0X/co2Cnrr7OwWbA
9ArrkyllFBTmLfikSQU0FSv+k6CmQCtOtLnDB3A+BDZsfExBy8UeSWG5CJvn
KPj8agpcbhhopvmL8NTwvQzjWgqki+4r3Eac8ds/5sFN9RR0RxmaSN2csVAh
qyxqoiB23uzwtYNCDA097JDWQsHM7r+yE7OE2GzZ/cW3gwKfwtpr+6YLMYVr
GLCimwLvHKv3BdUC9NC4qQx62Hqez662PSlAZVpOUl0fBeMXdwVMMxRgWHRT
X8EABZwMSa1DGx+/k+nJzgxS8FOPYtWbHD6epkKNZcMUOK0sDcpdyUfPngvx
jqMsH2FoY/wsPnLUVR364xQYyjkx8b08DI9fnFujTSBa0z987RwPLTcGTb2u
S0Cxa8nSoigetjilRJ3UI6DbatCZ6cXDVe8/8NfoE3AyneHVRnioVT3/st0M
Ajbj0UEz+xksuuqtTQwJPHeYGjT0hMGIY0eDe40IMG2c5JhCBq22KSsfmRA4
JembeDKdwVZ47XDVlMDyJ+KyJYcZ/G2uUWqSOYEFL3bG+ocyqNUQG+BhTSBy
a5rIXMz+X3BVZW1LYJ3utvnXHRgMP/XCUteegHZ60e/ZZgxahpHjrxYTqKkJ
jpuoz2CLp7BfvYSA3Oy/ggotBs9Yhcv+XE5g66Xhe5qPNK6akKE8QhM4wi/d
7f2GRq2XNcbb+ASOTdGdY6ahsegOJ0HsTECg7DEV1tMYcc6x08KFwO1uQ8e8
ahqtYra4cyUE7Myr5Lse0NgqO5Pb7kbgXKD4REw5jb8trpiq8iTQ+Dg7qOYe
javJUNRlKYGu4DTZ3rs0ct9YNiZ4EUg+YGS5/Q6NxWpfwSYZgflW42NXWDsy
89hlZx8C+ZmtOxaW0midUKRtuoHAsnr/NVwVjW0b3wSP+bG8zGZo26hpTKWN
q1oCCDjK68SXHtEoNVjteCeIwGvPg/Y7a2mc8OFAavpWlveeH6RHm2gsqc4b
lu8gkKhUpn3toHFPbmuAXwiBG+9LDlT10Wjzy5QyJpRAnbXOs2/DNGq2iaxm
R7DziTo0dEaXwbMukce/7GHzZ+YXpRgyuMb0Sn/DXpZHTlnMmBWD2l9rZbf2
Efj8636DVprB2w3cW2flBNTbPk92kjL475tLTWLiCDSvUERP38ygJiy1c9lh
Avafix3CFAzW6wlTZIkEPD1iMvm5DFZmdzlHJhEoeOxhMfKAwXJJ8rsTyQQ4
9rwsZQ+DJe1Lz+cqCByVCUIO6vEwP/6F+8PTBII+D8wNXsTDHJPDQ69SWb0d
LB1L8ObhWZ+n31tcYPlEB7xLyebhiQ+x30QZBLw4GWXFdTw8ojDPC8gkcNN8
bUWYNh/3PIzUPZdDIFTPtmJgNx+DdxgVKnNZ/n5MPjeLj4ETcEvd3wQWz7sS
ba3ho1Q4tXRqIat/32kqv00CFDcrd9sXEbD1rLhbnSVA3r7A2atvs/3lVulb
9AvQJv/a3kQVgfX17f+KOyFEs7U+FlkVBFI+NdlYdwnRsHe0RnWfANeK//WL
yBknWEoXjlWx8TPdJ72ZJMIR1WCjcS2B+Fm3VpjvE+FAYHoiXUdAM/ft8bvv
RPj6q+sy3wYCGfLL7e7LAdvS3rZHNRNoWqYgD/cDPl9+WpHSSuBhYoNdrAqw
8ikjvP6S9ad1HNfXd8HyiPa3lZ2s/v3iw6O2u2AJSUp7+4qAyL9onarMBfP/
cnCb9JZA5kXbdbsXuGKOW+OgZR+Bdq0OsW+6K17qTLgiHiAwzcv1qb6JGFMP
WnttHmT3JV0nzD5PjMlza0bjP7F6nbh24OU6CR4qibl6YZjlefbXfAfjlRi7
3nRDySgBj6PVEeHEDSM/qic2jhMIuegX6ix2x50pYQVD3Mkwe8eV0OKPHhi4
yGDzDJ3JEELkP9qrV2P3+Z+//MTa3F/2p8/3luL/ALkHJ7c=
            "]], 
           LineBox[CompressedData["
1:eJwVVH081fcXl9hanG/6zUNLHhMiuclDfb73ci6i/Ag3Wh5+ktSw9WAiLTaF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            "]], 
           LineBox[CompressedData["
1:eJwVknk0lXkYx0VJp/q9E2os05UkSwuXm/C+132unaGxJm10FSnLDUnJHEtk
m8ThSiNkCslQqC4m85CaJMmSpEzE2JtxhhmcLHPnj+c85/vPc87n833UBcEu
J6SlpKTcJPP/XvDesI1jS+DaxvD2DncHvKic0KpgT8DuTdMLE8Ye+zWy000d
CVQZCI22Kdqi1e4S92NOBARZTmXORdZYalyjnOhK4GiVhfNophUSixd95fsJ
5HZGN0vVWWKo4/ubbzwJhLLd28xkLbHHY/LEwmECvVfv9WgHWCBXsKij4U2A
CZurNxw2x8IA8qedD4GZgZI+aaE5rj6nVin0JWCQF38tUdYcA2L0w7P9CfCT
4jJSi/nYnsI3rQ8gICceKjnuzEcjkcvSUDCBNSxFXrM0H68X+DSuDSWwjs3R
rKkFXC4NSzAIJ3Bz5Zn3vhGAxx/E23ueJ7DJK6ZiBw34/FcRib5IgDx6+dP3
0oAZXWJRaywBL84zkaEpD2d/bz44E09Ap9GX+Hw0w8NjvSzVJAJBt8Xf9Ceb
YcP0xCd+KoGRO33AYcxw+9JC0ck0AqIdw5rzf3MxRY6cTsuQ8FTOL74p5+KU
vJrewywCSUVZJ6KCuVijxX8kk0vAtmwwVnOJQZaBS6RuPoGnSY7ihy0MxjI+
POdCAg5jKafZNxgcsQ6TibhNILBPd09gCIMOzvG/5ZUQ2GBzJ976WwbvHxKl
PL1LoMCkQjVPi8FNvsXfTZYTED4WXT2wmsFIoVhBoZLAqtno2SPjNPZfaH5r
8kDSv8FcSs5rGq3ie3/0FhNITa4NnK+hsTRtwutyHYHRH574BRXRSK4vaJTX
Eyjdub5hIovG0FvrR7saCBSeatvol0hjTzmr7EsTgQxlG+OeKBqZGj3h1ucE
alv4SibhNN58Ahy7FgLlfb334s/QKPvKeS74FYHstYtf6oJpzDfaKZfYTgDv
Li62CWk0zpdVKugi4JofHFUdRmP76gEt8VsCPtP2yoGRNJ4S1u193UtglzVv
3/IlGmXeZdmM9kl8NVbGhaTTmMsXekgNELgvI816XUAjp9TeT2lI4m/kpEij
isZWec1z+iMEpLPUci48p9E3cjnBdpxA9aSX7h/9NC4NvhN5f5b8a9vezrML
NGY7VBdFTBHg1Fu/5asyqP/gysOr0wTObnkZdozLYPNm/2cl/xKIHmvUnxIw
KEiw6MZ5yb0cDnt9KoOZHnP/TC0TCBPXusWNMbgLO1atkaGgv0dLic3i4jPt
nzeqy1IgFEpVfO3BRa/0y5omayhQ1itOFmZycW7+2B7ndRS460X2XuzmYrqA
sfKnKAjiq7xK2GyGui2b3GPkKbjGprcM+pvhodyWsPtKFOSwq/22K/JwZmXR
pWZVClidczrLITxMDYzOHGBRsMvmxl3FdzzU7D54a16dAtPvG3xTNQDrzfZU
b9CkQGWgTOOvo4AexVSTjjYFvA9SSfr5gFPUeCd/BwX63EcfRocAkyKaBj13
U2D5laWwQ5+PWwfyps+wKRg39onqiuNjnd15mWQOBcYrWn6R/8hHt0pXhcK9
FHw6OHNqpaU5flbZrVFrSoFBytGg7GpzTIiTM+zgUrCf3ck5aWiBapOfzMeB
grHhxVFWkwWK3R67SFtSMCGgihQDLNHpcbZAxUbiZ3LfizRDKxzTDAkxsJfw
71cz99G2xtgrDrH2jhJezxjjI8dtUGV2e4bAiQLf1IrWFep2WOW1ovCCKwWz
hoeqhuUd8IBRiekdSU58YtzNc3PA/wCh6VoQ
            "]], 
           LineBox[CompressedData["
1:eJwVVHs01HkcHa9Ohf3+jjwiZWqStvfjiPL7jc+M8X4k5Fkh0kYdj0nbpkb0
IDIeu0XsRB2WJYbiNFH5oOeOWCmlh04j4qjxLJJdO/vHPffcc/+4f9x77tK9
0V771Fks1nYV/mfBu806lQEEeC+CZt7vdEPRpayO5l0EnLqc2y87OKORetT7
V8EEXhdl+G0+6YjVkfajY3sJPG78KXkdOKBzp5madgQBTnjvo8vO9qiwmaY4
BwhMNUujcpIEmFD8jG1zkEBmjci+vtsO9XWlG7yjCdTl1ybnONthZfw5iIoj
MLI9+liRnI8OPWGep+IJXKubjVy5i489DtyQgqMEfjyUOJI0xcOfpQtjbiQQ
sLFpKb55mYfUwvFEuYjAK29jsbs7D8tOPsnsTSKwdosLa7EGD3mDpYXfTxPo
M/quzjQCvtqRLF2QSiDONXjP2ElAYf2uxtXpBN7iYHKxI6AOx6rdTkxA8gO7
6LkeIHdiSCn8jcDdTms3QaQtas2/JffNJbB6jqXWBVNbbDU7W7Y1X+U3+xgm
PuPir5beZ0wlBATnh3PLsrkY6MreO1tIQPhxU0iLNxeXhn7mKq4S+FI8xE83
4eLAkfpF90sI6PopS+71MSg9nzJVWkZgok7b36aOwSNXfZ6nVRBQHuz9vSmV
QUa29PqhKgI+1eyw9SEMarYpxZ41BD69JpJQGwblvQ1Rm2sJLBM61m01YTDn
W6qT4U0C4RYJJpIZGgOIr/m3WwQO5uf3HFbQyDbnqL+5TaA1c01EpZzGj9tG
eu42EvAS/mK+RUZjleedhivNqn6leQfUymiMj0jLO32fACvz9WrNAhrp437x
+x8ReHgxXGmZTaNGznIvFzkBnJktykqj8a/S0XVr2wj4GWRkUCk0Zt+5q011
EKjvSnCtPUujf2f6wFgngcSLpP74ORrNBv3vP+8isOURX+1QJo39/5pflXUT
uFfseSktj8ZK/XFRwRtVv5N6AW+LaTy8CoNE7wgMiDPSo2tptIEM61AFgZr+
9boeD2lU9w00EPQROHwqLTb1LY2PoyzGVgwQiB2I27RxksaspIm2eUOqvKfd
g7v1GfTLbar49Fm1V8lwroUlg0sqxantIwQgpHCyPIDBvuagfdfHCfw5NNI7
N5nBay9X8i98JVB6KaMjoopBofLLkqPfCJjtTwwZ7mFwm2bL98AZAu7/7Nbu
XMBFNZOsl8wsgVu3s6ad3Ln4IbcqkFKjQBetNLPSuVhRmWA1rkHB19Z0Wb2R
LYqtFSXhWhRsY1144xFhi3EtTvpdcyiY46O10bjBFn09pMmOcykonFDOumoD
bu02GJXNo2Bec5OXlAY0DT8evEqbginZiWW6cYCsYcWTAh0K+vNPj8srAB9q
VpeLCAWcsMj5Met4WJ5paDxCUdDuPDstOcpDscmJlFA9CjT8aK2/H/MwrqT3
y9MFFKT6NOmyOXzcucElXGBAQYtAcWPyDB+tG6qf1hlSkLg7OGTjBB9NHYx4
FgspaIvJFrnF2CGr44Q0z5iC29X+0y3/2GFv0IfF8xdRUHBMwv7jigAf9Luc
TzClIIyzZvRGmD2Wx9ZMf1pMgce5wQmZpwOKZ4wO7DGjoDX6yaKVqj+KTRG9
aGdT4G1hJb623Bl99Prsecso2BG8VqjT6YpTD3QaYlTaY8XcaU8fN/wPHqpF
Fg==
            "]], 
           LineBox[CompressedData["
1:eJwVk3001QcYx+/uNmYmz0Qa5ziUSnNdipiX3+8+98VL11WmEnWndlEWXdfI
e0rn5m1RIR3EzGKi7nqjl5vjGS1Zm7eUZtVIEs3UFCctdvfHc54/vn98n3M+
z8dGERsUyeVwOBLd/L+V5b3ff70MsDduocPUJhlxKz1sl9sBMiFHtJsf+ZJe
rvxS00pAZVNM2NmDPmSQkCH1tQfUS3buOpPhTR9tq3rQzwNsuqjx4Z2WEEhb
VVF8QIX44vsBb8W0cM3jd187AhqFZ/JkUWJaZK13PHcV4DM/txjOqIgsDO0+
tXAGHBDZdfjsEZHV9NrmehdAD/0WS1cQkc1QdKCnK+BJVdweTaOQbH/NH77l
BnjfZM3Eoggh2V36MVHuDnjWhl/pYiEkXnWPwYQHYJ0oZTn0IznmT53Y6wU4
6j/+ZLgUaXWymdMCVnev/O9WYwWSa7hbW6UA8Lj8RTw4InmsCw12FAKeEbcK
UzhIjHvaWIsI8OmAHT1sEBDaVqQHSgBlYwOjsjABSYxbjIe8Ab2c8wa05gLy
mx2sjvMFDBtfPdPcz5L/CNeVuxZwdaz1s1cVLK3rtu0olAJmqTV8010sBWl9
5EtlgPVWbXp3PFkKro2avBCgyx95TsyZsBR6NO+AZD0gzyhI+uUkQ/L002Z3
AgE37y5Q3u5maPvOzrrIIMCa4jfkfImh8KDnntMbAA2X+i/eWc3QDsakK2sT
4IeaZ24hhQztsnNRmG/W9RV0Rs9kMbR7YfCrH0IAC7nzrMd+hlRzSTmfbdHx
mJFKLTMYShgrtezYCph0l/9JmS5P6tNqQr8AzPcysNVmM5Ta8kA4HgZoX7ft
z+wihjLq5/tStwNa1jQPLjjJUOYxmyhDBeBzx0yLiCsMqfeL35SHA05Kf3b6
7jZDOdGRBbxIQP5cxfjIPwwdCs62ad4BOJb58fUQc5YOC09dDIjS/afZT7Ur
hCwV8m75PvwK8Lf9K3tyVCyVmE8MKKMBf696Oa2tYamMa6ycjwEsdxfXGQ6x
VDHh9M4RJeCF1r0mXUsEVHUvqNhaBSiKqHWOiRbQybaEFefiAO+KllVv0Qqo
TlNyVRgPGJ321zdFBkgNpZcDehMAY/Ifc665I2nUA4OKRMDO0prLuUqk87H/
xk8lAcpP7UyNr0Nq2mKlr04BVL9wMTZ4inTFG8tM03S8ntTEzToI6ZqTwqEm
HXDfiF6vTZqQyFJNazIAXy5WDR3tFtJ1vdoNN/YBDveobtY7iqj9RfuT4EzA
lsrDo+5lIvrl/ljK6AEdv5uZXQ0mYupsNzRKVuv8uN70bdgJMfWcd6j6IAtw
NvW9zlVeEuqrWO9cmg04rj0Ixa8ldC8n7sbKXMDBkgD9c4Pe9Ed8UejVPMAh
+1z2mL4vJTbyNzgd0vkQa2s6lu5HMNMhq83X+fj5CL+xUUpvJ49s3VgA6Af8
JREbZfQf2DLkoA==
            "]], 
           LineBox[CompressedData["
1:eJwVk3801QcUwN/8mjqcrjB7G2/VRvlRc6gx5vvue34ev2o0P/bCM6MXq0R+
5qgxauXHZIhCpdLy3qE9jPzoZuEJE0ok89sx+XGWZlOWfffHPffcc/+4934+
52796qhXqBKHwxGy8X+Ovu/j4JMDaJp2I0TNx50S//3EMjkXMDogQs0pyYV0
+H1mL38ELIismJ7a4EyVpw4bhecD5nI+Try54kiuLepbxgoAY3MOj4j0HWlK
+RrXpxAw1NbfdpvEgZId+dpdRYBHjhkEO/XYE/f0Uw3hJcDUwCEtnps9VSti
1OqKAXlteda2T4TkuVGLs6sUcFv2cZX0SCHNuklXyy4DVjO+mqQjpNRM52Xu
VUDx7KFa2xYB8Xom5rPLAE9/9LCgMk5AdZA8o3od8JsNFePc3QLy8uKOnbgB
6Kyvuk+2grSQWz30ZzmgisRQ734z0pnHe/sP/gR4Nme4YuAc0ja9510jtwAv
vlThxQQgNfqlt3lLAd9UeuwRWiL5Fm2lDhmgJNGwY0kD6cVwYz2/EvBRyevl
uEd8yjDwk9dUAWqH7zL4PY9PRkHLUtOfAU82yvLkAXy6dznrxhU5YFWvicNN
Uz4dmDC+rFcDuBh8PTB+naGVD1sLM2sBFyqs2ucGGfohVJyrXAfITJo19/zC
kGn564yEesBjGz8bXL/IUNtsfvrSHfaeTK6ZKI0hsYnFqdBGQJl7l0wRzdCr
iO6E4SbA25zrVXsOMpQnk0R/fhdw/OCls3lBDJkvKR9uJ8BZifiL8QMMPTAv
DbNrASzZVPhAj+1/HWUjlv8K2OiiYmMXxtC6/LG/cSvgvFy1UBTFUNFfkd6l
bYART/nSlFSGdltpeOgqAF+NdrsrChn6Lb7c6VwHu4+0t9OlhqFDd4T4Vidg
SK1P/PYBhlTWRj6N6wIseo/nkb3GUIldguVCN6CnYqZbvoNP1id1dob0AN6K
8ef1fcmnfqo0GnoIuMQ1E1vk8umIktuWvX2AnbpV4cZ9fFJ3mOG29gNeuGaW
qMn6uZr2rbbtY9ZPzZPtzRZIdu36mrcHAN+PGn0ZwfodVK9T2z4IePfenmlJ
BlKUqzeneAgwrEql/h1C0shYXN08zPKz3dE19w9Seff3y2eeAdaUNjhHWwlI
uMlw4c0IYG91tXVgkoCe7aOZ46Msn0Xzo6kKAcWeF43NjQFaccpyXugLSevR
ypB4AjBrPLrh7RNCkuqe7x+YBDTZryE7OyUkJ9+d3e7TgE2xks5RkT2NXVC0
tcyw82xK6/2m7OnE0xCyngXcvB5WQSkOZN45GVT+B6DdQP6Evw37fw0h67rP
AVdbtLONuU5UKJ0s+W4e0PuDMN7fFs7kWRzCLC+w/FKSFkVVLqSUNTkSvARY
eaUpqXfNld4dj/FfYOtwyxrPhP3u9B+t+/UN
            "]], 
           LineBox[CompressedData["
1:eJwVUntM1AUcP4QA8ZTfFw5CnsKCQ+Shx2Mgj9/3d8d5p9BkQHpTyHvAoLkU
b/LwkchZZyeNV2CFhLdgIsUGCEFjNb9ljWVxgyQWGnX3wwJlpOGEwCO6/vjs
8+fnGao9mVu8SSAQpDvwP9d9nip9ssRg4A8h5oBD2TSZM3s08DmDwrzq9v4K
JZk43Ysryww2twZk9gsVlCGZbV1dYTD446Fo/b9yWgrT7S1dZdA/55FXl1hO
N7xnp6fWGIwb29e9uyKTjrrozsjtDJ5LrVy59buMmOe83+A6g+I9TZUDhTL6
9g/tF2EbDMaXjPlYF6RUNcUfbhQA9q9/2Se5LKWYUe3KhhPgrscGqoqREj/M
Xz3hDFiWECbaOsPR1ZvapBkXwF6dubanmaMDH/E/Z7kCZj00cUfyONowactH
3AAxuW8124+jwbO8aOdmwM3C8QKeRyo9rh38wAOQdictt9xCCizg81yFgCrj
9YE1I9JEtvbZ6a2AMZdkQUPHkIzpfNPsNsD5jq5vzqch7Y3VSnIZwCbDjbc9
g5D+CuYnCABz7PaLKU5IHZ7aU3HegIV37y20TbCkEvBMuwiwrzXBKa+LJeHf
mj6hL6D+wpRUdYklstkOnnsZcHqjY/FsMUvlP2mePPIDFJb1KN5/laWoO7Y6
lT9ghthl0JDK0m8DmtjRAMDWuttO8XEsNXXaxhKDHP380rDYEsmSokXzZmcw
4IcHJeOdYpbs79iE3jsc/oxPy9XRLPVVaHpqQgG7TZeDJpJYKiqxZT0Nc+Sx
SNtdFSxtV2kWXn8FcHzaY9ivkCWL0nZlLBxwtH7OJD7DkiFFE5UmBnygNe8v
uMZSUpTt+08jAX0vjoQ+vsPSgr/mje1RgLmNhUWez1gyb7G5v7sLsBReGGtF
SPl29c3laMADXNCRmHgk90WrojjWodcRUP3Ja0hfzajn7sUBDujCS6LOI+kt
VqN0D6CXe/1nTBdSxG11RL8EsMNZPNQ7hXS/1/pdSAJgiKqYO72Fo3qzurgu
EXCkqvIlXs5RZqPVZT3Jse8mPbQaOfqnRt15PBkw/7Bbs87CUY/eKrufAmj5
MVmZHCwljU49q0wFfG/J561DlVLyzbcahtMAE+ZrhAUPpHQ3Ux0WkQFYO+cc
XpYtowuJ1q+bWcBT2yIeGsdkFB+h1jhzgCXBDW2T2kya97UK9FLA1PmGyete
cmpzU5utMscfbbwP/6ecylTXik7IAdcN/ietHgqSd09F2vcBSgJFx0rblOS/
BosmJSCP6p3pgVnUL9rxq+t+wJaC7uqG/Gz6D2nyqg8=
            "]], 
           LineBox[CompressedData["
1:eJwVkX1MzAEcxm/nrk3YfE1GXpO1qU2nS5To+7tX5TZdCrtGFo1iZYY0V9SV
16tpTjVJo1AXuhQlK1/uKl3jOmXxO73p7dYhbykvi/PHs+ev59k+z+MRmxQR
x+VwOEKn/jv0zVX/LQJsyhn3VmxTkK5sBqstBiyK3syzSkJp/0/ZNffrgJFM
b9TKU3IKDsuILbsB+JB37JurWEZQ2OAVUAqYZkgI2hsupWHH5KjxJuBI4k5c
ny2h+mD/SuVtwOwPcQMhDjF5DdrfmsoAT44ccE1JEFPuhSLeOr0zrytN0v8S
0R+/CN+KCkD+74AFDwpEtJ91US25C9itll/aLhJRZ/rjzNx7gJMbLP0D4wyF
rDxUyTMAfmla4TnnPkP69hVschXgGtm+zIGjDM07/pbnuA/ofnj7ZA4ylLE0
x3dXDeD61EDeEWDoY7NIZX0AaJ7ecALsSDsSJzIltYDS0fh3U0Ykk9udyto6
wOSoE0dHSpEEDbtZ73pAxZ78jtPnkQr3uvGvPQZMLfjgdusIkstMsy80OPnT
S8YW7EE6XJ2mymwEPJPS5fM0CqlHJcyaeAK4enxTvkaBFMq1VyY8dfIbXYKV
cqSa8qts9zPAuvGOfg8Z0jKlkq80Aco8+G3fNyFpJ/kCUxNgS4yuvH0L0kRx
vWptC2C8rq7NqEKKlSdl6Z8D5i5szhiMR3r5ydOw2Az4Z2rIrExFCsp7w15s
c/7Brd7ofxnp5oZsPu8FoHgif9+TKqTZQ4wg+SVgfU+FRtiBpNb+UI1aAP/G
fR3s/YlkF1Zk7bQCdm5mlnh5MRRpizG0vwIMSa8OS9vBEGXMtYk7ATVSy3t1
LkM+3q382teAU8e0FtbKUJ41VeDdBcjhOCyn3EXETfGLLnoDeE6/+kv+QREl
LhvJms06+wIXud5oFRHbUmjQ2ACXc3N2FQvFJEsKt/1459x/VeNw2F0xVc3j
uyT0AKZ8nt56MkhCixofCbp7Aa9sDPEb65PQ2bjE6PB+QOUYo0kvl9L3mZ6n
je8BdZ/q1BElMoqp6TIEDALO35rXHOiQkzlaaysfArxgN/tPM4WS1HP5ub5h
wFsXZ42ZIhX0D269hZk=
            "]], 
           LineBox[CompressedData["
1:eJwVkG0s1HEcwKU/dy7R7xc7hLAoYVxuWiW+/7ujSJRKS3d6GiFKnRqdXNfD
ufWgUojJSLWih90pGqYvpVK9KFTS1RpFHsaYZ0Z68dnn1efNx3H/kfBoQwMD
A485/rt6rOtoezeBEZ/E1IMRIZgyEaU+0UugqlXOa1kXhL+LFmu7+wj4hA4s
eHN9A27Z+Pa7tJ/AD6v0YN/oQKweSDP+ODDX84MUaYoAdMkVCMSDBDLI/Zq9
tRLM8uvcXTFEoFmdnvDJQYIzf/LVrsMEnLb2jHTnizHucpi2YISAMrl39cXl
YmwRMnrzMQJFsrII75ciBP1z47PjBLqu+X/Yd0iED88mCkYnCKzQvu/0sxch
381JGjdFIKFUqYppY/FM0xe1fppAvKlnzOtCFvtTL2rDZgislWeymngWIx1B
Xz9LgOa4VRquZ7Hh7bCxzzwKhX335z+xZNEr6YHggSGFv0Kb247DgAX8KKkt
Q+Fx0+cZphXQZm29tsqIwuSxQaitBcyTunB2cSj0mXwrLykDtFJekI5xKXhk
zg6qCgFzivu12TwKLwq+xK/OBbR4Fc4RmlKoy576qcsGzOqskDYtpHAnxOzm
UB7gIpMluiRzCqdLMYi5A3jFTckxJxQeeYryjJ4CmoV2SB9RCrcag3Y6vwO8
lLRBt8mCgrB08YW7nYC862WcHksK4ZwbJ3+asKh5Zi7T8CmUqHh8sZBF41a5
zsWaQrF7ldvBGBbPT37lNNhQyCrf7sstZpGx85UdsKXAq78msvkz99O/SDfP
nsIvhx2xbd4iNNjPcIuWUtBfVWzuzRRh+rlYmZ8jBbvD771V4yKcvvdBp3ei
II/nMqVyMSoavbiKZRSuPjV1bWQkONl7Q2btQsH7mESp0EkwxWxCV7mcwo41
ZpX7MgJw1EvGjXCl0HHKwlWQE4jJ2+pkwyspRDYFhNQwG3HouHN5ljuFPTGX
NauEwajqluarPSg0/8j3aN8egv8AO90/kA==
            "]], 
           LineBox[CompressedData["
1:eJwVkGtMUwcYhk9QhMmlfK4KCYh4gjaBzHrZBrhhv3NaaqjlslaQq2gZuELR
gXZUKMIwOBWoMKQdkIm4ZZQNnU6oeP8QdoGo45ZFJ7E6mMzQyYYiw0xZ9+PJ
myfvv2elZo8qy4VhmLec/L+ix7/3uisBfdnK39YnKsni6InYEAOYX19ybPJu
NOki519SLOCW4udUZN9MaNp4IzYe0PvW38bnn8hJaNcfGn3P+YfztaEVUfRY
fE6RowacnfaKv2KT0bUyh/c/WwHdS89H+XvK6NNB0XBFIuDuxpCA08VSymYz
La8nAZ57sfRJxjxP7+w9kdqSDKiXdEJQHU8+vXdXiFMBFagyC97kaVy4dPxK
GuD5lrBm3wccdWXFWxXbAQeHRJta6zmqtlXq7mQAush2CSrVHGncflybvRNQ
F/aD/7AfR28nucw81QBet+SldY8jLW6LvPjx+4Dd1wZOX7Uh2ecMJYJsQIZl
Y2JMSB2KDu7zXYDB1RabZy7S4aYp11At4Nf6G6JvlEhpjpD+rhxAbe6SLRPr
kdZFZpvkOsBe+clLVcuRFplaVCN5gF+8YWMLPJF+vT+6TLMH8EDYwOWpVxI6
I/a7N/Uh4Oq8jgdef0qovEzdXFIAOC0IPhk0JqHEQVOmxz5A9pe0Ub+HEgpl
+0UNesC48snpmUcSYva6OlYXAqq1N9u/fyahkR4822EAXLBKrlS5IlmFxn18
kdNls9oMIZIx60L4QDFg1XK71SpCirdN/5teAjj8av+dBAnSKrc13ZMHAJXp
X2kaUpFebNNW7C8DtPoEM98ZkW5bv4x2Kwfs7+PmHaeQTs3ZveoPAl6YXRTb
dhupUOE/xFYA1qasrUllOFI2JZrPHgKcL/2jvS6coyBHbcqmw4BPJtoNCw0c
PXv3VuDNI4ACn3yj6TpHfdXuY8mVgPKQQEOcD08n7ktbJ6oAG1d8oL6Yy1OB
uDRXbwIsishf0znMk7zsknhBDaA5hQ++p5CS/+DM05pawB2sNPnnESn9tXJd
V2Cds1cOTD76SEa9BTpj+3FAe1JNV2ZEFH3W04obzYAJzNHtS0LklCccW/iT
BVDFDHl3ajYTnxXYl9AAmN78WsC3AdG0zJZcPdYI6GU+HjPnoaQmj7i6l04/
WOjb2bZVSf8BQNR46w==
            "]], 
           LineBox[CompressedData["
1:eJwVT2lIkwEY9khyS01eU7MSSqtB5JEusyb5frvaTMu5Gl47OtSYmrGKQint
MNQfSrbAzCMKkcQI3beNCvP1yMpsQYnrMmlmjrTCChPUav14eHh+PNe6g0Vp
OR5ubm4bXfjPv7vCLlREA9rT3W0XVcl0dFRhKtwC+EVWG7lckUTTf83ePrGA
zY+zSwZXykgftkrTxgdMMijfnWuVklN81iSLAzxe4L+wtE5CeXkO78ltgBXV
JuOpPjF9rpRqyrcD8lTDnuYgMR1ubzOFCwDbX5xY/HFJRA6bH6c3wZUXY58r
9RWRbsag0e0EjBJK9N9bhPQhwG76kwgY3KCuiU4RkjpOwGlkAKeM+1b7uwvp
fXqzRiACxLuFs9+6Gcos8WTfiAFNGWGGqxUMvW7M45yWApJFag3KZEhFzzRB
MsBR49xMVyxDw44olpUDFk+HXncPZEjpZeQodwPecY73FC8iveTNaWaSAaWO
fr+xaaTUpGy2Zg/g5tpg64IDyVZAnMhUQNvNZRPWMaTkmvXaIQVgD88p54wj
DXZUsHqla//bStOiyy8fnuZw9gP+WjN7zeLKfzKbqm1VAc5NtZjyXf3SEDMr
SQfM3NXyoJDPUL8ghPspA3C+FO9tymJIqDmjPZ8FqMxqTuFXMURlH9m1ate/
gWOjsl6GEm9JuN0awMav4T91S4T08NFtrVoH2EDjoX0KISU4fc3zB1y67BU/
rF1I97kGbv0hwKoVV7yeB4ooPmJEG58DWF3De7pwWUSWvTvMI7mAiU0D5eoN
YtpqaOKePALYKU8r8rGLiTV66AL0gJV+dfU3OiUUY801d+QDWiayIyaHpPQP
tk4T1g==
            "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
         TagBox[{
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[2], 
           Opacity[1.], 
           LineBox[CompressedData["
1:eJwdj2k41Asbh4W0WFIoazRGsiaylTz2bGEiKSoUhepQOUSWyslyylJZSkfW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            "]], 
           LineBox[CompressedData["
1:eJw1Vwk0lVvY/oYTksqQSpci5SpUhorvHL7XTOYhSZMGErq6KpUbypQpU1SU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            "]], 
           LineBox[CompressedData["
1:eJw9Vmk0llsbJs9+nkMzUhRJRVKGFIlT9/O872uevYZQOoYMUVHkFIpSSYlM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            "]], 
           LineBox[CompressedData["
1:eJw1lgk01nkXxx9T/H//NmYapBopWUtJSfV4uMP//yx6sjxPC5FEhWosjZBH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            "]], 
           LineBox[CompressedData["
1:eJw1VXs01dkXv0TNPd9KURLyarhI4pbcqWT3GOfe63ldPZRHkihCSI/xLuTd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            "]], 
           LineBox[CompressedData["
1:eJw9lXlQ1FcSx4cj4PLrlfGAIEQQDIcEInihQaR1CP5+MwMDw7EpBDIqKlEu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            "]], 
           LineBox[CompressedData["
1:eJw9lHs0FXgQx1W0bcwtJ9ELsUIk70f0GLbV9rv3ug+P8lghCb1IVBulIqGX
59ZNYhOlqCilbAaVRFKhUqkbDlqV0NvV3t0/ds6ZM3/MOXNm5jPz1QnYIF41
WkFBYZnc/40L9A2OoBagwn/mRmrq4kYFbUAN6QMptbqScumXbVq6gJKWxIW/
/+xKo4W5s+fPAmy38Hq4uVpMX/p+feRpCFghmlzXJRBTf2J/3GZjQKMW0+kq
vSLq1j9skTEXMCQjMe91sojaaxa9LDEHHC6BEzIbEbX4de9vsgKMupwWO6VX
SA2yAw5vbQGXRpml8HOFVC2x6VV2ALz77VjZc18hldu2Z85eCFgpDR1joiOk
883xi5c4Am7rEy+JvCeg/HCTgcDFgAkvZAPWgQJKPxPNz2Hy/txaIvpyXaj8
g/rtvXzATfdrCrYIXKh90QWncCFg9iqtoCujXMiwucvWyQOQdabYTI7gE18r
tsTIE7DkQc+fheZ82hg8zWSSD6C42fucdJBHFcMuup3+gEKlzZVhu3gkde7N
aggE1Bxp3hfhwqOxKbs1Lq0GHChP56/V5JHxU83UY6GAmWdO7LB/xyXhrCsq
e9YBjjHTbaMaLkVuECesDwO88WzbYKeES5LyvlHLIgDdc8RDBzZxqYOv88lg
K6BWoN3JmaZcGnf4WvjEaMCJRTXLOyZwac4r977P2wH/smTZ0gFGojn9QdKd
gHsa9efBY0ZRUUnSujjAyZf0/D0rGR0lPZ+SBMDreSz/6ilGNL6yVZIE6LXF
47F+OqMuN0/R7v2AOQZR79N3Mhp/fLB+zSHA+u7nY2RhjEx79zu7pcnnefl6
9vIARm6WhlXzM+V8TA5uyXFntDWm2mHWEcB1ZvcGmxij7FqfMsgCzO/Rie9y
ZFSj+snsYzbg+egDg232jHq8U86058rvY3vw82JrRpBvrF+bJ8/rpJWusGBk
0X8z51wBoFrivLI+M0bL7P2mHy4ETJO9G3A3ZxQd9zUjtgjw+IjN4ixLRrmN
6RNDzgN+5/mKq2wZ3ZpimiwqBbRTrs+oXcDo74A6JfsyQD3T014lvzCaWLQy
VrccULVp8q14ASPrT7Kv4ysA+btbnjl7M/JyPBw5eB1Qe8b55G/BjHYkW/Q/
rZL/y9uUC4VbGOW1NITeuAHoI5YY+yQxqtNe3XW2FhC6lnRMyWb0NmSUX8Yd
wPhvw+2vSxlNuni0LeYuYN4+Xffn9YzsRqzdg5oAyw8tqB7uYrQrNZTZtgLq
GvLWf5vJpYJnije1nwD2lC+QfXXkUoP+8UXjngHOCPBdE7yKS+/D5l3tb5fv
R+AdtDyZS+rXHlo9kcr5FV8gaSmXHJTWn6vqBPT7aXSR5gsu+QnGGRV2Azb2
to42BB4VdszX3vYG8G2x8gb9jTy6Z/LoyMp+OQ9J5K6A0zwa2hyuxhuU1/cv
7pZ18GhqtfJBq4+ASnNWZBro8mmhSv6Pml8AFZc4q6kF8mmlB8YpDQOqNCu7
jJzm096ctpE3I4BJc12zDIf4dN9qwtB1RQ5OGFDJj8h0IZtFM690/cDBhuRN
g18+upBkqXm0ijIHM3ilKxx8BfTd1QktORwsKi781N4goEBfV0UvVQ6GZp58
2CzXg7rgwNuxahysmKP+pNpfSHMjIvcVaHDwrEaex618IaXF7BE2TuPg2Jna
CUnvhfQ54Q+1D5oc5FaaxbxyEtFvqaceT9fhoJHEOqb1qIiqs8qznPQ4GBI5
NfKyTET6BXf8Qgw4ePFNvfP8UDElX3iqd8iIg+pvBHHnOuT6d62vp8yEg1Wx
qjPs17nSsrV2qSfMOP/r6z8aWIIR
            "]], 
           LineBox[CompressedData["
1:eJw9VHs0lAkcnUXolN+3Sa2yjcqZPHqYYSrE+k1bpO8bZobW9tgURcrjq6ZS
0hGN8tj1OBlpC6mQWpVVDXbtj/Rw9GZLNhuxeaRdu2xx8li7f+w955773z3n
3nPPnRMYqdqqJxAIVo3zX40w+dPv3VpAwX/woyb/3q3DGwCb06402YT5klvg
iK3VJkBX9WCV42sV5YfB715BgANtRS16vIqM9lmW8sGADjmaE8cMVRR2WLw3
KxRQlhifkVKopMfJMpeqMEBjXUfRFqWSlmhVox2RgBOFZu51eko6mRdUM2k3
4GSJVFReoaCxYnWCw17AMwY7fwmOUtCWa5rVa/cDTg84fHn+MgXd/UkLsQcB
4ca9s4f0FJTRqNPejwMMkN7WOrr40Ptf69YNaABta4Ih6KU3behuFlokAkac
133amuRN1f1vXslSADsvtKDU1ZvmjQ4XbEsF1M5/LRr6S07JxrAjNWM8T+nQ
yM8lcuoztbS/ngmYWJC5NSZSTuXWshv6pwBXXWqPE41yJHRQRdvlAt5KlOuu
13MU5xrkrswH5LqTd0hOc9TpodaPOg8Y3mK3OHwXR5xScyenCHCK5wWNB8vR
1fXa5FsXAfOcL1vkWHM0PbjQp7cEkP9Rm/alEUfRvG7q1FLACe9j33/Vw1Lr
gbpnztcAvRwGk7MfsbRS0/ztJh1gSlJF+FA5S8WpbwKOVgJ2fX0zJKKAJTg5
bFVSBVi8wKT6TSZLu8+ZdDVWA+Zvfzgt5BhLTSXCSx9qATNmeDo1xbDkWm7P
z70LWFEvM3fey9KZmyj1qgcsaWm+otnJkuED5WDkA8CsSSMfKiNZyl2ywPjY
Y0C6ODLykGfJKdfQPK8R0Dc3MqZMzdJjozZr3TPAoP7VM8KjWdrOVy591Ay4
0MPde+wIS/rPMz27Wsb7qimN35XO0ikZ7y9oA7yqryd8lMeStHh1iHnHeH+d
27RW37N031S0T9wJqJdpmX3gLkvB0WMJq3oAy3oD7H5rZWm0/bl209vxvT5c
2rBnmKUsrqwgqg9QWuXxTGbBkfjaN9fT+gH3zL6n3uzGUd2s0NtF7wBju2vE
fYEcBSZ8/pSGxv2ypRKTFI6O+w/+3TcGqNZV+MV3c7SQnkyYqM9ga5O1uUQo
p9s2302bY8ggzwsuf+Ivp4D0oyLniQzOsC9M4o/LaXBo82LlZAbX2Ec3H3wq
p/RA15WhDIMRspkPEmZ5k1399DWHTRk8IVk2uz3Um9afqldfNWcwW1IWMs/M
hwYMCo7UWTAobBi0HdvlQynhscfbhAwu9Dx90ey5D4merjs3NIdBl0PVwSlW
Cqr6bHHZFBGDM9suWf2xUUH+hUytrQ2D7i8EieJcBfUxPQ2y+QyK3W686OpQ
UGJUbfvaRQyu+HgF/0SspLltOf07JQz2OAXFNMYrqdJrv36SlEGnj+p/MH2p
JL9S36n5Sxl8tW5gu8EKFb2duciqwoVBh+SNEVllKkqIN3Z84sbgF5IG6TZH
X7LsfbW8Bxnsfj3SJaz1pTv8obMGy5n//+YfQ7wLSA==
            "]], 
           LineBox[CompressedData["
1:eJw1VHsw1QkYvZ6TZL/f5BVrQ9Zqsz13lFfmS7aU3+8+LVIWkWZTQx5tu0Kk
iFyPXRF7lzUMS1yK6UbxIVPtFVuqScnOsMSoSx55pLV3d2bPzJlvzpw/zh/n
m2N9OEJ8RJPH43mo+e91njc+fyEckPcfvCmu7LGVy3HArPqEr5r6JGRkIN8i
iQBsLGxIzt0noZrYixgeBTgpiPihRCmmPQMhwnOxgFcbl4+tPySmgT1uQUWn
AT8/kTiZNC+i7+RrIq/HAbq4dJTd+EVEzJrpRGUC4HOJmZTjRFR59kHWUBLg
xu37eZ9oiWjXWEXx+xTAYdP3mjtbhfRclCw3TAOM8gr8ZuqskKKbDrXaZwC+
pLHksr1CWmWzo2e3FFD2kVXJk9VCcpsZV0X/BNjS68h6HBOQzsqbSp98QHtd
B508CwF1WV6odCpU++3eJomP+fSjg+S8hQzQ49JEfmUOn/y9rA4vFwNGv9oW
1CHhk3XwG7fBUsDZsnH3DHM+jZ5q+rizHNDAV1V+Z5gj+aXU+YpKwJlGfT+X
Ro5OlXo/Sa8GVB0f+rktjaOdCutrJ2oBveusQjYHcaTdrZIK6wFfvwBZsAtH
yqHm8C8bANdF7210MucodyHN0+QGYKhdnLlsiaUD4GO7cBPweGHhQMwgS1a2
Npr9twC7sr4Iq1Gy9Mp5cqClFVAc/b3tdgVLtcLbzb+2A9rIC77VqGQpNiy9
IKVT3W/WC3vtIpZcz/jGHr0HePdyqMohhyWt3E/F+5WAtLRckp3O0u8Vbzdt
7Ab0Nc7MZFJZyrndos88BGx6GufVcIElv96M0alewMTL0HTmIkuWY36dT54C
br/nrnEii6WRv21LFX2Ad8qEV9ILWKoxmk4o6lf3O7f6wMsylmI20MGEPwFH
pZkZEQ0suWCmY/AgYP3IZgP+XZY0ffyNPYYBY86ln0x7ydL9cLupz0YBT45G
bds6x1J20ky33rg671HfWIARR775bdWv36j/VTaRb+fA0doaaVrPJCAGFc9V
HeBouP3gkWvTgL+NTw6tSObo6rP17nnvACuuZD4Mq+UoWjW79vQCoOXRxKCJ
AY6ctTve+y8Bch8C9HsN+aRhnv1s5zLgzVvZi54cn/7Kr/VnNBg0oB3a2Rl8
qq6J2zGtxeC7rgxFk6mApI6D5aE6DDrz8vr5YQKK6vA0eqrLoK63zlazZgH5
8OXJe1cwWDyjWvbSF5JTn/FbhR6Deu1tYrmrkCxCzwRu0GdwXhG/ziBKSLyJ
wQdFqxgcKUyZVlYL6a52XVUCMGgTcmxl5CYRVWWZmE0yDPbsW16UnRaR1Dw+
NXg1g1q+rjp/3BdRVPnQ7CNDBtO82wysbMT09Zb9oR7GDHZ4DF6fOy8mx+a6
R40mDCYGBAZtnRGTxR7TXXZrGOyOzElgIyXEexgvLzBj8Fad32LHBwllC94p
ZGr9/178A5399V0=
            "]], 
           LineBox[CompressedData["
1:eJxFUn0s1HEcttudrdYfPi1tVCJmxZbXXhT5IK/Z+v7uGLuKIhM1mpHMS+HU
KixLWJKtVNwl72Nn+MghLOc6DXdoQm6opuWlMnX6p2d79uz559mez+exiIgX
RvEMDAz267mpZ8WVcrOXgAb/EERyV+caTu/zFqOm3RdEZD2jG1NUAt6Yu7w1
JVZEBffK+EelgBmFFfHSX0JadxTayWSAgt+HTZpKhHRJYyg2qwacSPN9EOIp
pOHMVknBa8A1N+XU9DJH7geu1vBrAZe6rSy313MkHbLSJNcBHvKJlkwncbTz
+hh/oR7QNCFkLR85ytqbbxfWCHg83YWfCBx96fEUq5oA+7e0pYKOUWjcquRk
M6D3fMz4RhcjhfGrmuYWwOTg1KS5Ckb2bec1NnLAwMhi9a27jEovGguetAKm
lywav0hkZLit3w7aAHWZz76ZRDJKaMgQS9oBb6eM2HYGM5oUO+WsdgA6LPsV
Zwcy8ufpamI79f27DF05X0aNVY81E28AW5bVUxY+jMw5TsApAH0sBAM//Bjl
rgnsFd2AveGFVUOnGa2Wy8VHegFjClsGusSMInzjc6RvAQt29WTNxDAa/GpZ
u6cfcH1jtp9LZ3SsaFRzf0D/D17DCeeHjJ675Qn47wC9VoujO+oYGc162CcP
AsonZdlOakZpuSvieSXgn6jvMx9/MtI5yXLOqQDVpzzMrK05CtKG1w69B3TP
bAjICOWIsnZovYYBs72Vn9IKOLK16RM0fwDcuJar1Kg4KlKl29uMbO5jQXnT
VEi8FMczZaOAd6QOS8VXhBRnPpdjpNHnueze+rRPSJre0tpsLeA+Xn5YuZOI
fOKZdmVcf/+D7Z8DqkXkf+GRx9DE/739BXjdL1Y=
            "]], 
           LineBox[CompressedData["
1:eJwBIQLe/SFib1JlAgAAACEAAAACAAAAbpGsUxHzEUAAAAAAAABUwP7lmoYp
9BFAIlHq9emaU8BpjU+xnPURQH906zeLJ1PA1DQE3A/3EUCgXatWM8NSwEDc
uAaD+BFA55E/zGFrUsCsg20x9vkRQCixy+Y+HlLAFysiXGn7EUBsqn+BZtpR
wILS1obc/BFAagwvZsaeUcDueYuxT/4RQDpzjkGIalHAWiFA3ML/EUASliu3
Aj1RwMXI9AY2ARJAnuyoA68VUcAwcKkxqQISQOc0GqIh9FDAnBdeXBwEEkCu
0tX+BNhQwBo6wrG6BRJA+nLxQL6+UMCZXCYHWQcSQOwJ2bOjq1DAGH+KXPcI
EkAtjv/xgZ5QwJah7rGVChJAv5zWajeXUMAUxFIHNAwSQMKV+96ylVDAkua2
XNINEkCkTA6Y8plQwBAJG7JwDxJAgKrASQSkUMCPK38HDxESQK0vQpkFtFDA
Dk7jXK0SEkCdyUlXJcpQwIxwR7JLFBJANKoTiqXmUMAKk6sH6hUSQFIHlHre
CVHAiLUPXYgXEkCjgQoXQzRRwAbYc7ImGRJAoSy6K2dmUcCF+tcHxRoSQJKz
VDwIoVHABB08XWMcEkAKwpFCGuVRwII/oLIBHhJA4CBVaNozUsAAYgQIoB8S
QNyQe03rjlLAfoRoXT4hEkAdbsszgfhSwPymzLLcIhJAc2oIBKpzU8A2VUNe
bSQSQAAAAAAAAFTA/wLifw==
            "]], 
           LineBox[CompressedData["
1:eJxFk3tQlAUUxTeacIjBvaGIsTMMmxRUuEs846HdBXwtfN9++22tQBvZAkIu
wjKgyENknQ3QAhNNBxQyhqUVantoqK0MN6CQLF6+ascMRMCFCEmESQva+qc7
c+bOmfPH+eM3R6zN4dOdBAJBpEP/fr/SOZlWAij4714lkHfqMx1eG3v2CeZv
Fa0IvfP4n1JAt1RDQEKmilb5OB8/8BLg1ObwLMEET16u/i94BQPaYvx7N+7i
yXt+S3tLCGDksg5RGPAkHtFxUWGATfrcXZavlOT7Q9Xo5XDAm+6h06vSlOR/
7rPdmgjAz8WShhAvJQU0DrpMRwKaYwqfgxscSavun9wbDTgRPzk+WstR0B6P
wOXrAds0v3cKtRyFpYZ3NbwCeFwzmwdSjiLZJLVUBvhpbKesUMDRuohie0cM
4F2bP91qVRD61pdwcYAJdttEQoqC4oQdwpENgNHBB21WTwVtfjjcmLsJMGUy
aKH9BkvxY05hTlsAg3J8ph7Us8QO+PbWyAHLjRbJyh0s8daNmjUJgC3eXc7X
olhSN2fOnGEc+e2o6UV3lpIOH9wfpwAMcOPlb80wpCn5xOMaB7h1Z3X2lQGG
tmX0mdN5QNPRRxR8jqFU/l7UvArQdU386oxGhravc+8vfw3wSctUeGINQzv8
Q7SeWx191X26hXKGdq5QP/g4EbDGaWl9ZBlD+sWCypeTHTwW5HJRKUP59lpR
7+uABdclT9c58oKrVkvSG4BV0S6+1gqGijp+kU2mAL5ofvPXiiMMlbYsXS3a
BigytQ8vb2LI8IE401ULeE9q8Eq7wJCxLPbRiVTAGfm3gR9dYahSl14dkA4o
WayfHPuDoffUFeL27YB2w1PdiZ4sHZKdPstkAg55fNPsJ2OpJuDypltvA/5Y
9vxgpZ6lY57Ttmwd4M+n5uatJpbqnITZS1mAJyJiza4jLNVPBz72fjbgmc69
7v3PKOjUT/xRHz1gTFpzcJZOQU1d+X5f5AJej3m2MdmqILPl2NeyPEBd8W/v
HnHhqLX2PDOUD5hVdUdwMYIji9E2rN0N2FdrOn8gm6Mvc/7Ku18AqDmdUZRn
5qgt2XuZsRDQOBsidLnL0YUNWLey2MFr3JT7cK2SLgZq15pKAPeNOQ+Ji5VE
IiOFlgLOrdaPHB5QUrdzs+q7fYCjg/pLLVKeemZ7xtUGwI6GQxMRdTx9f9Ne
OLHfwe+Sob/VXUV9Pa5ue4yOfXS3fZhyUkW3ebfO3Hf+3+M/DJqcSg==
            "]], 
           LineBox[CompressedData["
1:eJxFk39QkwUYx5cOMxvHQ0jcCnZpIfJDj0NpBCHPcQYW8L7vNgoMxZkBU8of
IALaacWJiiAptxJURhJSsh2zbQQ64ZFiDNlCfspE5IdKHAlcYpTKSW/903P3
3HPPPX88z/f7uWfZR7vkKQsEAoGUz3/rm3+9eCe+DFDwX8TTwXci3Gx8v3OP
19aoDgWJj9wSRZ4FzEt2uEpiFGS0Zi2qPwcosahDwm7KiVniKlitAVxevFeY
v1tO4zHax5UVgMZ1Cc60VE55RdEz4vOAyvHtdWHNMpJ0jD4orgQ88saNb2qz
ZVQPB8ecqgA/eaFmRLxWRnK5ePjABcBoTydON8vRZInR8Uc1oFDl7fFLI0dH
e9nutB8AC04O1PQd52i5x++2wYuAZx4JJVmbOTIn5lsUWsBntXHBkWs4Sihb
Rm06QNV+77ZpEUcPB8wNEbWAPeVPZ7J7WCr0SjSY9IBuO1Z73VGztGLLjNb/
R8BDZp3asJmlaxUnLnxrANR3+q3/3p+lTaO+FR4mwKmtVck58wzNvt5SWlQH
OFkjbZ3oZ+irFGXJwnrAdXcDGjt+Ysi/+mlhbgPgniVv98+fYcgy/nX+9GVe
T5E4IOkwQ0q/oM9TzIC6WJvOmsnQk3R77sBVwEuCKn1wGkNqnSpT1gQ4kna2
QL2FocDphZ+2EuC4Svn+yCaGrgdqUsObActdSq978POPM0KVhp8BzRuEoeGp
DM0bejf6tgA+MDiVJmUwVPbnboXGAph+K0L7ZR5Da6WiOHcr4JMhe6y1lKFf
c6qjjrfx92g72zeYGNp+ORKfawfcVvdBjk8fQ8K5wbeybYBlr0jiiucYKg/P
XTNpB2SsY3bDSpZCDi1dta0D8GLWRknXhyx1U+0Kxw3AaXGAMqiEpZ0LYl5j
uwDb3fU7fLtYWrx+TNzSDXj6u4D9zjyf84e/cAvr5fmYbvo0BnEU3urpfKkP
8NWMoUfpPN/+xfWLfPoBm64F31cVcpTxnkJwzgGYqhc2vEwciQqnHr80wPsX
ttI28TdH1fZjM0dvA5o0V6IzpTKKdPGefDYI2Gk0hiR/JqPbHI3tHeL9mQrc
lWeV0b5TScMTw4BSQeXJh55ycu2ZdShHAU+MZF55/oCctO6nuvvuAvrFi3QF
9+QUlbDKHnsf8Oo+VftQkoKGT1stzWP8vlBNQ+I9BTW9O+ci/O3///oHwTuf
/Q==
            "]], 
           LineBox[CompressedData["
1:eJw9U3tMU3cYLYKAWuV+ioi6gpBBtQrMAg0M1A/UgMDyu71FaRRc760NLmYT
iQx8zEnVasWAIKhji5KViG5EEIgYssVvU4Mz0oBmZGqYvVcXVMLmI8NXCdb9
sZOcnD/PIzlR0lbBNkmlUul9fK9hY87rY285VP2HfNoQYN2x2svhrrTylx33
TcT9q4R3jXOoXVpX3llkoqt/SZeiJzhMLO6b7RkRqGJQKahVAV4Y/6ldf1Cg
uF7p5YQf4OIndqqIE0jpVo5/4Q9YkhQdOn3ISMfPSoahAMA2a1NVa72Rcr5R
fs8NBMx96MxYbzLShFMq6wkCxJT213nhRuraqYQumgI4Rd1fqCg8bd4idZ2Y
CkgfGcYaOnj6oFAxBaoBCxynO984eBrIk15snw4Yt2+l5uKnPDmWKXUPZgA+
crX8ujudp4/jJb3AAdbZz+wP0fD0d4QyQADIe717U/14coVI2xJmARbduD3y
3QAjs0rhToUCnm9M8jO1MFI/E9vVYYClewYzzfsYkSyzXXMA70y4RnfaGJXd
Ev95HA6oLmnNOvYJI90Vudo8D3C5NqDLnsboz04xvnc+YGP1Zb/EBEZ1zXJf
ssa3zx9HRxsWMspqED9vjgA8yfT9zVpG3gOyetYCXz7H0zLLEkbtX4qtlVGA
55wHNQMGRpuK5dyn0b4+7sxTgVmM5prFkY0fAvbfmdodXsTInS0f7osB7K0Z
dmp3MLKnirp0LeA9qWlN4beMDDr5tx8WAobt7Yl6coXRyDzxs7k6QKG2aFPI
C0ZN0+TgQ4sBN8NbR1UoT/ley9mxJYA5GZr1cYk8BY96smzxPj/X/K+/X8vT
z0OW4dsJgJ3WmGLdbp5K3R5H5lLAmcE1P3ItPMVetsRe0AO6/LUX2wZ5utvm
uRaZBBhptmVsn2akmiaLrToZsKeifLKy2kiraj0B4wZA86RSaHQY6VWlpXlL
CmB+QVC91W2k1lLPyrupgO6bKdkpEQKJVsuD7DTAI89nf7WuXKCwfI+9Ox0w
6VGluvCeQDdWWaJjlwNWDfvHlOSZaE+y55f6FYDbZsQ+dPSZ6DTb0MEh/P+H
d9C4W1k=
            "]], 
           LineBox[CompressedData["
1:eJxFkn0s1HEcx28Krdj5lEqTh264pRW1Fq3w8bDbuk73vd9FnkqdXF1IyJxn
aVoNN5dhspRqOUVTcR568FHKspLrrCmGxtJGNA8z1kj903t777X3f68/3tsU
8Vy0CY/H277Sv9TdjVduCQLk/ctRum4QGvOCAc/fcN1aly4npSCqbEMI4OPF
jZORyxwdSKoMrwoFTPZpBMdijqw6vji4hQOKkSvl7+Vo1Hrj6PMIwKdVHrc2
D8uoOZrpxCcADZ+E3tUlMirU58f2RQKaBJzh58tlpDDvdFeeAoz1eGtrtJHR
vhCTuRkFYFtZXET7KKO1NV4tl04Dtr/sqXuhZzS0oM7kK1d8BYLAQA2jBnGD
780zgE6FZXqLGEZXK6ZMd6gAHyS/Ej6UMIqYcO1qPgeoill/eGwPo91eSo0o
FrBDdLu1wI6RmaaK640DvLtTL0i0YPR1cGCTIh4wy6Pn2dSSlB652fRPXQB0
iWsYtvwppdwc+a3MRMBpvtNtxxEpBRs0UesuAgo+RwzYfJPSDkGXsDwZUJo7
Pj33XUq8JNMJlxRAuep97ZtZKfW+xvoGNeAqZ5GEM2Wks8646Je2sgPmVZHW
jDKimzx70gEL7IZ0OiEjpp/+fTwT0LiU2hfkw8jZfFf7eBag5Ph9RXk4o8Vj
qrzUHECdlRPvSQajbt29Q+a5gF3vfJcn7jC6szBkWXIZsGne7EhNN6MUse0n
QR6gNsy9KJwnI0lFcGn9FcDl7B+1xZ4ycpzQhnlfBZwcq1WvVsto9uAH+/fX
APlWCRmaNhm9K1wzEpoPKHK1V0utOKoc9K8eKwAsdzgrb4nhKNEtOyZZA5i2
P2FXo5EjUU6r26oiwNIwP6d+sZxsDXMzRVrAkwL/0I+9curcm/ZrUfv/f38A
81YhWQ==
            "]], 
           LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQfd8j+MIxSyEHBjAIOZCyZtVmZWshhzXnS/5+ags+
8OgcH+chGyEHL6PrP+p5gw8kfCyKS7ATctB3cs16vzTowD3h65v/2Qs5iM+J
7TfwDToQa2bNOddRyOH1lBBpAcagA3ci5sdZOws5OKzP/fZuf+CBqGrmLTdd
hBw2RyoVTe0IPHBjbjpnhZuQw4FtbtvFogIPhB04HSfmIeRwd8qPj3uNAw9c
eaS/ZYunkEPVG9nZjKKBB4JZp3AGews5rH3x+GDV34ADl9R/xH30EXJwe3SE
7/6bgAMBXjFb+v2EHHQmiW//8yjgwLmcA5x6AUIO5xZxP91+P+CAT79K/JlA
IYeD6i88OR8HHDi1sWNLVjDQ/bc6N/8F6ve88oaTM1TI4YvMt5nbgOaf+BYQ
vzxMyOHH66Wbs4H2u0lu3eIaIeQQ5b50d65J4IEj1pJcTyKFHH7XO+zUig48
4BRXG98ULeQQHD3f16Qr8MCBhodbFGKB/jtWcNfjUOAB+8WuXPvjhBzmvlX+
nMASdGDf0ZXxsQlCDnMOPJY9HBh0wOYF79bfiUB+w2UTpTVBB3ZxFXHNShZy
6BKZzHpWNPiAhe61eItUIYe+fvWTfyYGHzjvyrIyNw0RfwDSTtGL
            "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
         TagBox[{
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[2], 
           Opacity[1.], 
           LineBox[CompressedData["
1:eJwVj2k41IsbhlFkCRXZZY+islQovPaISKmsRYXTrhJFqZCtk6WQcJwoSSha
iDr9XkIKJUtCBmNfmoYZZsb8Rv/+H57ruZ4v93PdaofP7AkQ4OPj6/yT//ej
nKyUsG2XLORD27etdaAS67cGPA3SPACKcbFTl/ZRiTnpUNMtmkGwCPQjXYep
hFfM4qKiZhj4Nwl+fHaFSoi/rfWX1IwDcUtbg64XVGK0S1NKRPMuuBlTmELq
Q0T7SOeUoGYhBBa4O6sIDRMfT270WKpZCR937Zyh0UaItBS5277xldB1y7pr
J98o4fdSoLliuhImTjdnvFw5Ssxzv8GxV6+BfzjhS/nmUUL95lXtz/bV4BRy
6qh7xChxuah1/u6x/+DjvL6ardgYIXe+6lN6Vw0EOyusVN06TjQ98z62TrkR
9KhGNy5XTxK30yI6BZwboZrufsPu8yThdSnb6kd4I/wQmHFVpk4Sk9a98snf
G2FvN3GWIzJFCH/z+sS88xGm5Cu0ArymCFvSUxdFm0BPtNxHenGKeOfg8XM/
u+WPj6yXpttPojv4iUntxFd4Oz19/KA0naC4C+6q4muDKkn7R5KqdIJq4udf
JtsGd0a8Ln/UpROTfDKJuXZtYPq2dNUBGzqxkHK9NzyvDTa5tuX2nKMTSuUe
kUae7TB2nUHGt9OJgzNCdQ8bO6BtYULrefYMQT17xDWusAtYU01krQODGDkQ
8iwYu0BRidYv4MEgxs1vSHp1d4HNI+3fLkEM4pdI4Rc9se+QPrFXYXksgyDz
Jl3bTn8HCYnCAYU6BrG67exu5a3dcEPK7cUdaybhYHjN7UVdD+xZ4RVt5jhH
PJ3N2ds/2AffjxZxeq6yCHVrG0UVTh94i8qds0xlERmpE9SDKyjw+1W60It8
FnFVf+s5igUFeodelxD1LGL36S8pfdkUKB72kri4nE3MTPB/7t3XD2JG5x1P
57CJrGAjzemjA7BEaD7mTQOHoARl5o5/H4S1ealtLjtIIjPF/vH1kUHgWcu/
lT5IEm5VzHKF2UGQVT5x5GcISdSJutU7i1EBp8Z0u/JJorhUZLrMnAr236aO
J/0miYuMcNNL+VTYeDxMOOstj1h11bdD5OQQmEdHbc6x+03YZ6iL6v4ehiUJ
+5Wznfix1XjeOkFsBCzNN/R6ePKjV/fHiDHZEdDsUW1VC+LHU0pnfz7QH4HU
WyKxnVH8mJZPtCodHgHutlTD+mp+HHrqc1eifgTCX1YaftYTwGsfMjRnE0dh
n1bVZIv8Eqxii0KVzDgkO965TJEXRNKlqNhafRwuOG8ov7dOEC0Kdsg1bxiH
JfYg5G8qiLVuMTMU23FQuPzJVNpTEJuf8B4sPT8OYw9iBsTvCSLFhy68+8s4
TN1qVzygKIQCNZ1to3ETsPjh9vvEdcvQOeF+oDRnEiIutl8YPi2CSQPynAzB
KdD+ZdlzL1rkj++dm/KrpiDrVEOrX6YI7h29UbZGdwqaNlNeatSKoJfNiQUd
3yk4UXdS/aqMKB7jbUkyr5mCSVMLmexaUYw92/QqMGEaBJi9W/t1lmON5/zS
KnkaiKh+YGcYSOLbgG1NgVo0yEiOt45zlMSKs5Gp0gY00KgVGE30l8QnCUJr
gh1oYNcedbU5VRLTqmSMtcNokO8UPLqNIYmB8sbH0jtooMqvJjzpswJFu8Na
zib/gm/usWvMdFfi+hJyZ3oUHWpFjA3Gx1dh8unyepd4Onx+uqjjzFqFTP1A
S+EkOly8+qn1jaAUEq++bIm4R4de5Szvd+pS6E7kq/qX0cHGji/ZzVcKI9sc
5vUodHi7IUe5ukMK29hpeXWmM3Cd1rNiuFkaw+02sBn0GXj/826S04gMHor/
IrieNQM2RyROhrNl0LbprJQfbwbEb79/Uy0mixJuFRubRWbhvm8gecZQFvN9
IOCh+iw0L2aufHZNFj+dd2tzd5+FjdsbvVJU5VAh/0LJq8pZSIw1TD5xWh7f
LP7nFxbJAAHHxwOOO5SQzLYTtolhwA2l86K9vkpoYdryTCKRARqcGItrIUqI
538sFqQzYCz5m9KyfCVsGF/I6ShhAHniPyWRRSVsbTPuNuhlQKNP3tRMlTIO
Pyp3mzZmwmZevjhppYJatqacSnMmvFaN8NjurYKBg3g/2oYJNdPBxakhKjih
2PpLwZUJzLUx7dGFKkhLod1yDGSCrIzGLctlqsgO1/30KI0Jbp1qNRHBqrjc
tcDaf4YJbGpxvouzGracVLhSxGJCpneqbbG3GiYlJlfO8Jjwd71ruuwJNVzR
cEkvSnQODByPZagkqqG0uYvMA405EH5uEfCrUQ2VdFkTw/vmgHzE3JDnqI4b
ljmm/lU9B9kPnUxoBzSQpvmuqQznoKb4vdzJYxpYZm0kxGmYA2pIXhoZroGG
kcoRCe1zUJCs/HFfrgZunZs5+mR6DpyOnFecHtFAi6Esk+k189D11bsHL2qi
CzHdfyZ6HqqVtK/0lmph2D1meVbCPFDFXzNja7Tw/nkyuj55HvTq9wk6dGrh
rPZyHcWceZCLZoeK8bTwbopucMPLedgVPe6WvWstDvgf51MenYcsmmsBb3Yt
nls6rvrJgQX3jrxW73TVwWzKr1mmCws2PCoqDA/UwbrXrDqVfSz4EbYse9sV
HZQ5tezYBX8WqNkKR4sW6+CbzrXlquEsiEsxPPVr2TpcWhhgFVbMgmGpHB6r
YR2mOw75a0qw4c6GMfkQb11UiGxtGZZiA8uc6ikQoov3n/9nWiDPBmex5SGl
f+viE8XMlWu12KDf5y7q/U4X8adzjbYZGzL7Jh7La+jhZGqFqu5xNpSt91yz
f1YPLXsS+g0a2PCiL1PvStFGbJAIc5ptYsNplTIJhYaN6GRztPL5VzZ0UpQb
eqkbcX+JRbJRHxsM257QPittwhORDIstTDawg7LmL9/ehBnqvrkm6hx45Jy1
Ks9aH6eP6/tCJAeiyKTyaDsDnFER87kcwwGtg9N7xg4Y4HzHiFdVIgf2b2jq
DzpugHyQ7WF0lwOynik8TDbA1VJC7tplHJgfex7wo9cALd707pSkcmAi/yi/
ULgh2gRXODqPcyAp+JK1f5IhOmilOiTQOCBX0aPfn2+Ie5Lt7ZdwOcD3WPWD
bbMhBh0pt2JJLUDS7/cG71WNMEUszqTfbgEyFWtqWa1GmI7+xkrOC1CgUvXP
qzEjzLpgttVzzwJ0WChK5C4a4cP+GaP2gwvwjRoqOaO3Gate+Gz6ELYAlMqt
v8tubkaqt+HaZ0ULUK83QtPfswU3l/RJXRXnQs9OaXmWsDFmvPmnxE2KCz7x
qXEJmsbI+uRrpynPBbuUD2OelsZYPdEX+lGTC+6hs3OvLxojaFO6pcy4QOjg
pdRpY9yZT/n38XEu3Mp2kfg2aIIl5bkmEcFcaHBIvz/Ib4riNQe/7grlQqw2
o8hK3RRb+ykCjOtcaO5TihU6aor7lPsDzO9x4c6B0vGeKVP0y+zXbfvAhXKz
ysUSie1YW/hv3cOWP38Z7QFCW7ajRuUh37B2LjiZOJzp9d6Oo539SUr9XOj3
OCMsVLwdT0gNzATOc6E7XftUvasZNqvfTzQluXDN8rzykXAz3Gjop7FcgAS3
tyyxnAIzpO8ecC8XJ2FKoHkLg2eGoUkDlVxNEsTjnip9rjDH7//c3/15PQnP
NmtX9I6ao2mp38R9fRLi7dNmn8taINk0oGBvRgJK19B6IyzwusjglZS9JNy8
kZbC5wpIlcuTOeJJgkXpYKRVLKCtjv+zLYdI2DMUZZn2DlBox+BAz3EShg60
pLvKW+LfMYM2WlEk0M8mvxpJs8RT0slnQuJJeGw7K+b62hJdHpplv08igeMW
eC3vhyWuqLs765/9Z9feeGSiY4Uze+3WlOeRcPF6ES/b1QrbhmYd+R6ToGd9
atXai1aYvsQlL/clCSW2lGpesxWG3uE2/6wmgWwp3X6RY4UeGkVssxoSlnzp
Zp7XtkYFm6W7e1tIeN9Z+jgo3hq5beUR6ztI2Dz0796CN9b44/Chwks9JChH
CI7S6daYG1W9KDtGwrCTt3PoYRu8uuqv9UE/STjgdK9O818b9Mtfvb+CQcL1
T7Y3Wig2aGX4/rrgAgnRp+RYdWq2qF4bXOrOx4PcYXbE6b9sccmeNd0PhHjg
R3cxsnxhi8ODTUsZy3kwNqYq0Chgh4X82j6p8jyIoZgs73huh/GpHXEDKjy4
daVKxXi1PR5Xi3qxaS0PKPmH1226Zo9O5Zv6I/X+8KZ6ckPn7FHPqk/0syEP
FGR2WvmG7UDxr4lblU15cHR7+6iUiAPS/EwOnwQe0BtEz2565oBf6CO33tjx
QL6w4kp2sCOWXbtTJerMA4Ons0ZxHjsxdYXViOceHpRI+Qy1hzvhufu0FUUe
PCiYvCRyiG8X7tXPMWMf5MGWcAfHgn2u2Li6e/6nPw9mm99svZm4G/8HwQ/n
7A==
            "]], 
           LineBox[CompressedData["
1:eJwdlAlYjVsXx9+3CSlDFFLSIBUiJUNq7XPqnIbTfHBpJtRNqUsTSoMkjboK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            "]], 
           LineBox[CompressedData["
1:eJw9lns01WkXx3me4zqUSzRiGnQhNW4pwtROv985OMf1zYxMSnKrU5k0KBnV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            "]], 
           LineBox[CompressedData["
1:eJw1lQtUzHkbx1O/36BVyOUgYSmLqKa0MVFPif7/manGTEnKSppuWyLGJPQm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            "]], 
           LineBox[CompressedData["
1:eJw9VXlQ1GcSRcTvx7EiIIbZAQTFCzEccomy2FyJ8M0FMyB4RTnkjBzZiNwC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            "]], 
           LineBox[CompressedData["
1:eJw9VHs01HkUl+T73V6EJEqsV9pqaFMabLcHevj95jejolJR2LY6jaTHUC1K
KEkylIzSg5ijbBRmSncK7eo1Fa1WNok40m6ttDXC/nb/2HvOPffcc8899/O5
n3Ov7XqpJExfT08vmPd/46KWh7g0gYDef7YM40IiWx0TCYTeqjg9LMYfP+R7
xY85ROCUbpb0TpsEw7vp119SCDQFCo6rpBJ85lqveX2UgKbzmwgzYwn67Tod
8iidQK0y5+H3N8VYdX3TkOtyAtoRf8ZoZWJ01Z+Vl3+CgJ3iik+NpxjP+w6Z
d+wUgZUXbicmGopx3JF7LTG5BPrKLX552sDhocdZseF5BPJ+HbO8ppDD/nEb
bMTnCXgLXAcUcRxGrJmOHgUEjCxKEp8Ecfjq7Od1jkUEgoLKVb1CDld0Vg8a
FxO41jdKV2jFocf21XNfXyGw5tkIXeAdEV6qcHyhvUqAMbwaaioXoc3A+33q
CgI5neYu9uEiPL7ghnW+mkDuzMM6EIrQMDmpKq2KwMXKyqfOY0Qoe+C/NkZD
QJVfFFXQxWK36aSBsGoCPqkpl5JrWXyce9XLo46ArTxzT+MBFr3bYpsd7vO5
Itl7MJzFCme/vcZaAkmp6WX9S1icIh03se8xgZKIPz5UurCoKGu93t5AYHbG
m78nWLBorCsO0jYSSFSttjQZwmL8XNkXVROBW9KoxoNvGNxYZ+SZ9pJASIK5
16VqBpuMmpqi2wiIqmtDF5YyyC7PjwnrINDo/OqJzTkGNdnbrLguAuVRkmT3
DAZntniqhW8JDHv5pzzuIIMFDnS1wzsCHSd69HtkDFpufqIz6iHgYFWjPrCV
wZSS3GxdLwHBdVW0IJTBwd4fhO2fCDy/u7aiexWDkR5uvz3sI+C/ti3nmoTB
tli9aNUAgQz9Az2JSxkMqL07/sIQCsd+PDApyJvBuhFZlUcNKHB7b5gIgEEv
8fqV0YSCz7ebvPs9GCzJnPY5dDiF3ZOcL992Z9Du+acTolEUZl0coflxFoOZ
ttXuQmMK7nJFsMCN768JtDc3pbA8PG+LdiY/f+Nbo7/GUrikWacJ5OuHR8b3
3begkLLwufwO3z+jxLyj0IrChe9M4yfMYfCZv/JxgjWF90K6L8CTwdi/51aF
2FLolke93M3jczxVX+hlT8G0xyw0jsd//7sf5OOdKCyWZ1pH8vyiWvtje50p
FDQ4pfjx/C0Ppm95NJXCF/gpxYTfj8bZKbBYwOfcze9r1/P63VcvSJ5B4WiA
k3bTFgaNtnGCMDcKS013dOrvYvCaWbvlPHcK5addF6XHM2gQNPqvT158PZVT
FuQwqBw821wPFLL2P9gwW8mg5NzsX0oWUKjb+PHFIxWDn33ulaX4UIg+Wbp9
710Gz3QFn9m4mML4Ny6T5jUz6Jvae3ihH4V3U6UK+3cM/uF6aJeNiMLYbL0d
LgYseshK2cZlFKZJ16g6BCy2TlgkLAug8Ku4peuiL4tJ+NwhbRWFwuyPLlXB
LD4lhv2+wRRu1uTrJmaxuFeZ3Wm3gYKVS+PDpDIW7UWC+sEwCoG7OzRJT1iM
zAxUlm+mMGw4Y5prLsLxwreZx7fy8045PWrj7w+b4+Kl2yhku7VNtQ8R4WgH
5UqnXRQq5iuizcpEePXnud5DoymAMOWK2UsRBm2pd3mxh0KuXXvzCsphYWk/
yYqn0FMakeXrySEXkN4TmcDjXZ6eUBLI4Ued4ws2idevvTLo/U4OFbnquimH
KTR5W9p4ZXG4cD53zTCVwhmDlVnaSg7ftLfltaZRuK3c/OHD7xymJ8uOVB2n
UJSREDGUiHHOtNGy7Ex+vx3FyzbNEGOL9mzozpMUNtT6TS4LEWNi1GxOkkNh
cufTOelyMU63uOcx/TSv/0XbjO4HYmxQBzsNP0shYdDAum+0BPes6zV5fZ7C
/NfFX0kDJGg39NCApoCCus7CTV0kwbp86y5FEYUSk3HOOSP9cduS0gZZMa/f
WtlW1/3++EWSNufZZfr/v/8HlUDBnA==
            "]], 
           LineBox[CompressedData["
1:eJw9VH0w1HkYN0X3+x4lrlDaWt2WQ7LpKG/nQS9c+P52l7QyqtWGJEok7tSW
Ti9WhQt7ZDrVxu2iGOOclyfiSprInKPcJXr10plVIk63d3/cM/PMM8/M8zyf
+TyfZx4LSYxQOktHR4fV+r/xk/YNiWVNDOj8ZwF4PXybvfg2A09vNUhzukVI
9Uc4Dr8yEH365OPeIBE6xkwIaSsDqYp3XgWvhLikc/apyPsMSH1cr62UC3H2
OsO6E+3a/mXjv9S7C3FQsVhT0MnAMfNZTX9MC7BjZoVldRcDo9b69naNAqyW
rAl52MOA8XKzggUZAixscb0w3MuAh6/vQckOAX5n7d0yp4+BnIwxKycHAUZn
iKa4Awx83NSaMzJPgAGaUL7LCwaqnxi0TQ6x6Lx1rzTwNQMuPnTu2D0WLWri
FTHDDDwpy5w+Xsois1T24PRfDJwza2+UZLH4Rpaue0XDgNvqC7lBSSzW+hTt
755gYPVU11SjH4tF6tIizRQDaZfVocNOLJ4xquk2+MjA9YuGQ3JLFmPjm+da
ziJQMhkXKDdhMain3dNDj4ClKvl+5xwWv3LrPbydIfA6oKdfMUqRd/mlKl6f
gFuIeU3HbxT19caenptH4DOrzB9s6yhqImZMSowIvOmdW5Z1jWJPG/G9vYDA
1KZsv+ELFJG/UPanKYFBTo9i+VGK17K5VROLCaxx7LPj7acon7AZMl5KYHFr
fmdfKMVDIeu4thYE/PoN3b8WUAxGz8DNPALyrpFB0UaKHjz/M7ssCXT6Oj/X
OFP84pS4IdmagO5DhZpjT9FwePfb720JdFfuMG2zpjhOY63K+QSig+P573kU
eyuSQ1vXEsh7nbsqj0uxyTQt65kjgV1uvgFqDsWS5Mw7M04Ehvy57+2WUDz/
pOBvMzcCiyx0dy3V5oe9iu3XAoH0G+KHCdr6UGVluJ8XgWVHipLWa+dt1Mf8
8E0EXnqq4sO0eKti7nXIfAg8c110b8KKonFn15x8XwIDl8NiP/ApTjr2u1RR
AlG3NvhFOVHsU4zEtgsJ0HGVJ/Wi2DIzcXUwkIDN7/u+/Mmfolqi+1hXTODb
FXcWntxOMbvFcP6yEALe0a6TA5EUk63NNzrtIHBE+ejz9iMUJRkrk0QSAgaZ
Kp7oLEVvzZqyaCmBbTp1o4cvUbTb6vYsLUK7nwdHdbdUUDSp8V70YxSB2Qmp
Zx/dpTjNCfCv3a/Vh5t7zrGfYuvzvdWjh7T6xH2MowYs3vBJGPk0kYB/TnBU
lDmLuWrZ8hXJBC4Gc7PybFhMMZIHuacQ6FPtrnvlyqI0PjddLCMwusWpIZKy
6NtTdCsulUBFxNFmuzAW7d3KxuVpBDwOkDo2kUUdvZadjXICTWN8MwMliwtN
bkuU57V8LbxKzRtYtLZs3J2eRWD9fIerzd0suq/HPQcuEthTcpOxe8tigE99
xNY8AjxZ2OYTRgKMDK7d65JPoMu5qvodX4ApUTX7uIUECvXWFjYJBaiUV8UO
XtHi95RnF18SYO2lyoMPlAQcXOaHn70rwPaym4cqSwjU0+LSiAkBPsfyhDy1
9n78agLf2QjxQ0dpYko5gWlPI3uOVIiGA6qksAoCM+fbHnGuCpH3tuQb7yoC
LyQ20hsjQnTSK06x/ZmArJkfIPYQob+J8phxLQGxh9p0uEiEqXd3Tm+pJ///
u38AV2g9LA==
            "]], 
           LineBox[CompressedData["
1:eJw9lH1Mk3cQxztKJc/NGUDHBKW+xFpFJgpBy0A4RUXwZb/naYWBL4ANaLEb
jKGgtr4wXxAqCDpgSpzyogiKBVEUEU9xRN3wpSJDZEABJyvqmIqZM4F1+2OX
XO6Py33ve8knN2ldvBBjIxKJgqz5b/W+nXk1tJVD0X+hIun1Q4dtH3O4gCoi
QrqV5GXKzv39CYey+yeFbTolLenJyr/bwWFu1MKmErmS1rw5cOS8mcOmlFdL
PToFSpQYCvJ7Ody51Fw1/bhA+5zSj+mfcdhmXGp7ZINABfK04+ssHLps7c92
nitQpWJvYdALDg3vhoQTIFBj8O5i9wEOF89zq4nr5ulJROpJh9ccRowX+7Zf
5Wlg487St4Mclu9J+ElXwJNEv73syV8cjmjIDunX8+SSqTtD7zns7pIYW6N5
CjSmGNM/AJw4vjNnziyevri+uSreFvDESydFoAtPWlNStcoOsPaFZop4BE+7
ehIv+gBgWos5bOVrRrlvEi5JPwKUFSza6trNqFwSXyu2B3zc6OYYaGJETl/W
9TkCzl9y5qmxgdEj+cb6po8BbYr6t6ouMrIoNFQ1FjDfZ3Klaxmj4eD1N/LG
AZ5d3KsdOsZozKqYmzopYJWvQWk5zGi6Vt0YPQlwbezVnJYMRv766FuLpwC+
TCmqvPwtI2Vm5J0ZcsDTN8bHZegYbfhhzc/2boDuGeq0hZsZ6Y2r7g66A57z
db7fkcAo53r4/TYPwIAA01OVltEpU5jpmifgSm2CX+EGRnU9K5uLvQFjL9VL
GmIYPXijbNmvAGyO65BVqxn9JhFav/IFVNz7dPo36xi9d2JtSn+r3qDabyia
kf20Fe2K+YAWzdmpKmt/is+yDteFgOEdRYuSrPM+ISFdNkGAf4y0y1hr1c8c
d23G1BDAjRdhONS6v/u5V3LwcsC48gqHAKu/ufWlN7QMsOycxNb5a0aGLNdR
B5WAKHMaeGa9zxyVE34+FLC+dvbDc3pGczztSlrCAY33Lh3dtIdRhlg38G41
oFRz4bOATEZdzQO+rlGA1zTtl0fnM/I+GbMP1YDJBRWh7wsZpSe3mdSxgM7m
0qLhCkYdSz6X7tMAqqJqjDPqGHm53NSUaQF3JKX4Ge4wSutXXGiKB/TWsgGP
NkbtdWdFfyYCDjlaTsv7Ge2NzMubuwVQ7t33q9rByu+skT0ROsCHYdKa1qk8
zbLZNXP7DsByUe0BsT9Pux8ObjmRCqjOjSy2C+PpcXHcjzf3AOaZPRNGJfI0
c3OnfV8aoN/yMRCcxVNqkGr1hwYrz7Mbx7yq4OmXsbdPzcwCdBwtC2IPeHK3
zHvN5wDalSSbL7+18nylyn/Td4DTPsne9v0EgVoM8vT8fMBU98i2pGUCua0t
eHTlKOCtdwuev9ULtMPDYVLnMSv/sRNah6oFahbt1doUAlbohg/WvBJomunv
GlkJYJN44qZ6hZL0RfHi4FLAQ0fWe8buV5IpqXeFthxwzeQtzl59SmpIkTmO
PgP//5d/ALBTAKc=
            "]], 
           LineBox[CompressedData["
1:eJw1UwtQlHUQP5Q5574/M5g85eCOO+MRyiMEDixyeT8U8f8dESHQIA8BkRPu
pBjQk3QAHejKI+EaECjAR1MGY+FcYGugCYoERpGEEpq8lOHCORQQ+2qmndnZ
+c0+Zve3u5K9CjZjDY/HC+T0Xztlpv0juJ8B3n8Sh4XK6cp5DrtJEyUR03K8
GZoyYjHIwN1tDZZFp+ToaH1nk+wXBh7mn52diJSjajJCkfgbAxnn5+fjBXLs
vdypP3yXi6/6fPnSIIuik6/zm8YYcLDpiVU3sqjc00p7xhlQHaILDSoWb2wR
1k8+YOB8m298eAyL9quaKWaSgZ0DYeKh11jMHzD18ZhhYPZW/IfXBCxebyxS
0ycMFEo8xZ2PKdoVzPWp5hnwURo60ocoKkLSrGsXGPD9IuuHEj3FHsuR1O+N
DDhat0r7mylufLTzq3vPGRDYjc24fEIxr+PqM5MXDDi/ZyzMVFP8scIv1IlH
IP7KT5IsBUWbxC81kWsJlGsqZK+kUszd7Di6n0+gVco4R8dRxJVqZ42AwOGJ
rb+vRlK0ui0oaDcjcOWlPEC0nWJOw5GuYXMCVHmuW+dH8YnDo+HuDQSudo9t
HfakeLAuZq7NioDrQJjI3Y3igt23/EZbAtPj/JLPnCgW6uzFHwkJrL+YXmYj
pfjc5risRERgMjP4TIOYYsnp2dgcCYGv8576e4oorlrKsxJeJeCj1Q92O1As
1eqPhrsQuH5z3/09nN90g1Tn40Yg1Xai38jll318ok3qTsCkMmy5mqsvMDf0
rvcisClQe1nmTLGyKmFi1ZvAd0GGmD+5/szNcOmxL4HTx+rXfOpF8dRJF4tR
fwJ1eMf1HRk3v0CzufcNAsW2Ag93bv7acmNIx1sEXorXfePA8SPkpyS1BBG4
79RY48VSPHP8mkobSiA63BCgSKYoWeteVRpBYEGdX/owm2JzaXWLIprj2/aA
Y/37FF14K13JMQTM9jMDZ8soXjiS9uuO3QSqk+tqrGooXiz2XucaT0Df5Vue
20nRe0kntn6XwNKNdufyQYqXPjDxN00iEByzJMyeoihbzNr9dwqBjtzlPj8T
FvWHfs4aTyUQlxMlEdqzGPhUVno7nUCLZKNjVACLWNCg69xHgDG1+OtFAosh
Bn77hRwC22ZWMo4Vc/epyOurPcDxF8z38GliMWpueKLsIIF7/VE1R/tYvJUb
uKxScvvZZRtmXGQxdrbZIq2QwJtQ4bTDTY5D2WZbaBGBHCryzNsrx7enlKHb
SwgoHiyONjXJcSRzNMldTaDJ5Jn1Oe4/84OMu4wc/v9//wE69qgc
            "]], 
           LineBox[CompressedData["
1:eJw1kw1Mk2cQx0tlY/F5pk4ZaWA167A0ITAsyXBLRS9TO0q2ked5wcgIiAYj
Li0NRUKWRVgsaMoWC0PxA5PiiMIgAzdGV4TCVUFGx4daBitCYA4VJSAIMvne
uyW75HL5J7/c/3K5Uxw28iNSiUQSJea/1eTnrtv/PQHJfxGP5jsT7rdrCCzU
nox29gn4apzw14ZaAu2ZxzWp5wW0dN9YWr5OYNJjmis8JCD9+B3/iXoCCnfV
4WG1gFa3JcxrJ3BpSa1O8BNws25mb0cjgdFST2LEnxzPdRxIbmgmsEE+H/Z7
C0eZFrMrWgncHUta7LVxLGtTnSm+KfIxTheaOW7dY72W107gw5ZR42efcyx3
zbcYfiXATDtuJwscgyFlIOk3Ao2Dxw6V7uI4+JZVo+khUBC8u0cdxrFoodUW
eJfAwZWKPlsQx4/6p9ctegg01fgG3aIcV39SpHv7CRy5mNNwco1hg5V3ObwE
yqQ7szpnGer15u0Xhgj8sVjFCp4wDNb9fDZnhECLc5VUjjIcVD58uf+BuA/J
PZfCy7BYGpAc9ZBA6qOjdU/vMYwZ0breHCdA9KfmXnYzXGvKUb54SkD7QdDR
fW6G9gtVlr5JAtIsl9HdwdCQ7Z2snyYw1lU7Zb7NcBtfz0tmCZgi51RGUd9/
V2M3zRPYLY+zF4r8t0QfyBcIpByk+f2dDHXjl3PVywSy8x2dgugnae9+sGmN
QM2zos2viPP8cmVVO+1D4dONI9qpAYYZuRE1vb4U8jy2Zv8Rhsqk1I11fhRu
Ncri8h4zHNpRnHVmPYW67/blRs0wLPG/OWB4ncJzS9r5vcsMY2eeaz7ZRCHd
mjDe8BpHn57g8rAtFL6UyiQXAzg6quN9aYDYLz5jbVXJ0Xi6IH1CRkH/o31l
KYpjSJq9yx1EwSfk2OlKHcdheLy9eisFVcKlaHkKx7Ny2TmLQuSvl5WfOM4x
djFmIX0bheEfnFuefSP6DXyRHKOiEBo6H26rFP3qq12qUAqJT1qz2to4ZhTd
V/qFU9hpsFWUj3FUGmjhowgKpX9HeszifQ7poqfaIyngictNd8IFLAnJ4Fff
o7Aya3NLDwgYu85mz3+fQqMzc8J+SkCf0d7ANA0FeeLXVxw3BHQ0S/L27KKQ
VJSpC3ghoPyNrzqaRf3/P/0D9smXnQ==
            "]], 
           LineBox[CompressedData["
1:eJxFUnss1XEc/YUkfcptMylNMTUpU6HFXH3IVAur7w/TA3kriSt5TjWPG3XN
rsU8cyukoXZXuGPuPubdSEw0hm6aPFoPj0rUuvVPZzs7O/+cnX0+xyQwioVo
cBxnoeZfrbiiaMoRAXL/4En5TtG3f6j9ibzzqa++8+RufP/TcCygc177du92
nrRW+llDPOB4nbKstICnpmGNhvwkQG1Bql5rNE8xz62N4lIAj/daVRi682Qu
Db7hdRPQMyjUcIslTxOReZM2aYD2/ZsdeQFPQ7pCKRMDHuRadEMXGfU8eu8Y
nQW4M+KG3Z1RRq0uko/ZEnWebOOm5HZGjSrrouocQImrYP2KnJH8+uix7lzA
oYRk81EZoyqjtKWpPMC22KnxBSmjMoXFQ61CwACnSYlZBqN8r4FTpiWAk0GN
PiyJUfZ84u8jZYCRpvpuYSJG6TkmNb4PAJ8tpVSevsQoaV/3meQKwHvtSh/N
EEai7uh1hVWAoBkuEwUwCg81rKuvBrQKkjTf9Wfkp0mBg08Az+7xVoapvZcs
TDAvB1zMKPCdvsDITain1KsD3H1ROm8QzOjoSH2EpQIwwYUTfQtnZB/vt/Vk
k/oevDRREsXogL52Z7hS/Q+9hGRVPCNzeW2suAXQ8bLGDJfKaIeHl2l5G2A8
p5O6nM3IYG61r6UTsCgkUTFWzAgyy1MmXgB+zTSzbatmpLnLbe+vXsA+Z4eM
rmZGP1sW3mzrB6zxqF7dMMDoi1+x+PAgoM8hh/H6aUYfVpxtvIcBS7q4d8tr
eBovmFVdHVH3V4iFAmOeXtvm5kjHADM6ZIHOQp56BuyET98CnqucaZvx56k1
SjXbMwk4svazaZyYp0bIKpidAiyvbTa6JudJ/ni/q84sYMzLXr9SFU/ptwaW
O+b+7/EPBYs2ww==
            "]], 
           LineBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAANwOmR+8pDUAAAAAAAABUwPCJ8IR3
Kw1A+sdsNAXqU8DnJpgylS4NQM4r9E+2wlPA3sM/4LIxDUCce1brDKBTwNVg
543QNA1A2aU6anaBU8DM/Y477jcNQPf0lQeAZlPAwpo26Qs7DUD1aF+wzk5T
wLk33pYpPg1AiM9+Xxk6U8Cw1IVER0ENQA1DDB4lKFPApnEt8mREDUAFZlQf
whhTwJ0O1Z+CRw1AvBqcockLU8CUq3xNoEoNQJd7t1ocAVPAufUWyIhNDUDY
CNcBIflSwN4/sUJxUA1A3ZxERv/yUsADiku9WVMNQP3pybqq7lLAKNTlN0JW
DUCLirY6GuxSwE0egLIqWQ1A1LQRqkfrUsByaBotE1wNQA1YZMsv7FLAl7K0
p/teDUBvrsIo0u5SwLz8TiLkYQ1AOfvUDjHzUsDhRumczGQNQOedmZlR+VLA
BpGDF7VnDUBalI7TOwFTwCvbHZKdag1Ao7P06PoKU8BQJbgMhm0NQGZpDHKd
FlPAdW9Sh25wDUB286HYNSRTwJq57AFXcw1A0i0o39ozU8C+A4d8P3YNQLya
OlKoRVPA400h9yd5DUADkgXxv1lTwAiYu3EQfA1AVhFWnkpwU8As4lXs+H4N
QFhP1/N5iVPAUSzwZuGBDUALfcRciqVTwHZ2iuHJhA1A7bWP78XEU8CbwCRc
socNQArFDVuI51PAGjNLn4iJDUAAAAAAAABUwA5q9iA=
            "]], 
           LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvVqq2fjjVV4HBjAIOdA0KcvL/Bqvw6Qvf3y1/wYf
WH6H5aj8TV6Hpb9KQzc+Cj5wRm2+PccdXgdhM4YpZaeDD3wssNz14R6vg4XY
EwWT7cEHxHZfNrn5kNfBONN634alwQesWfPWH3zC61B/J0po37TgAwn+HFqr
nvM6/MlYP9esK/hA68xFSya94nVQ5WUz/1MffGDVYxv56re8Dj7cvK++lQcf
OK97fWbyB16Ha+W58iJFwQe+lBeK+HwGuvdC/1/XvOADkoe4+02+AfmcGd+a
coIP2PEs45T9yevQtSa96iiQnxzm0ML6h9dhT3f9ae784AMdC279e/uP1+FN
it/b8OLgA2telVReY+RzaHWr3ri+MvjARRP+L/tY+ByO7P3/QKYp+ICZvcKO
p+x8Ds90l+qs7A0+MMvTsIaHm89Byjuy88Ls4AP/g50cjPn4HK5Mjc3ZtCb4
QEpcMEuUIJ9D0Lfw12UHgg+czEg50SDC56DzOb4i4HrwAb3i0p7l4nwOxWvW
Otd9DD7A8LOIz0CSDx7+AI5asvQ=
            "]], 
           
           LineBox[{{3.81058158486345, -80.}, {
            3.810791124320506, -79.97055633877497}, {
            3.8123299081282966`, -79.80222516933871}, {
            3.8138686919360874`, -79.67973258124746}, {
            3.815407475743878, -79.60158471623667}, {
            3.8169462595516688`, -79.56678185266651}, {
            3.8184850433594595`, -79.5747755726298}, {
            3.82002382716725, -79.62544531840481}, {
            3.821562610975041, -79.7190922869899}, {
            3.8231013947828316`, -79.85645013314662}, {
            3.824313335192483, -80.}}]}, 
          Annotation[#, "Charting`Private`Tag#3"]& ], 
         TagBox[{
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[2], 
           Opacity[1.], 
           LineBox[CompressedData["
1:eJwVj3k81AkfgL3jvkoNmSlW7LgjUeMIX7lWJaXUxrLLrmNRobRTKjnawpYj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            "]], 
           LineBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAomfwmfVt/T9mFh7Enn5FwB7JhfIh
HP4/xF3/txFnR8BoFca1UyL+P9HEgZ03eUfA+q1GPLcu/j+pO7SrrZ1HwB7f
R0l+R/4/+cWLB0TnR8BoQUpjDHn+P1RT724jfUjA/AVPlyjc/j+yLQJV/LNJ
wCOPWP9gov8/z5pg7q5QTMDINX5cKKj/P8PCSmEqZUzAbtyjue+t/z93RSOl
tHlMwLgp73N+uf8/NdCFyvWiTMBOxIXom9D/P9mPEbor9kzAevmy0db+/z9a
Wwa2b59NwOmxBlKmLQBAiVWlEqb9TsBBHGEkHIoAQKqu8YWr9VDA1K9qHD6N
AEBU1OEB+QJRwGZDdBRgkABA7oX87FAQUcCMaocEpJYAQMe4dDEgK1HA1rit
5CujAEAfKC9aPWFRwGpV+qQ7vABAbM8YdnnPUcCUjpMlW+4AQMuGGI40tFLA
4fHijeUxAUAAAAAAAABUwJ7dsAY=
            "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], {}}, {}}, {
       "WolframDynamicHighlight", <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
      DynamicBox[
       (Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVlmc81Ysfx61cMpKVGR1HyiiRVfLNvCqFSFaFomhcKpEyKjfjllFGpSsz
kYwkofp9c6msjMjIXlkdznGcg3OO/v0fvF+fR+9nnwfvTV5/Hfbm4eLiGvzN
//fp40cJQbuumpRq1U58cusi1PW9i06Tj0I0s8ih61wXsSh5xUiPfBpsv67Y
L4R2Ea6Rq6vy5CBICvXdYp/RRYi8rfFcR46CHGKzVe54FzHRRZYQJKdC399R
+RUXu4mv450za8h5EPvShqhP6SHqz21z5iNXQKObxdkRgT4iKUHm3rHoCmgI
Wn6gpNRHeLziaXo9WwE8avSHF/T6CAbrG/iWvwFql6KdmVcfQfonXO2LVRUw
XpVvqXnbR1zPb2Wk+r6Daw1z8dqB/YTMpcqG5K4PoHFdm1eXPkA0Frv5blX8
DJRPKYlbNgwT95KudfLYfIZ1nRm23SrDhOvVNNO+kM8wzW2Xmqg9TEybfZeN
7/4MfhEiw8r7hwmBb64N9Pv1wPnmqVUWOkxYsF00cG0jvL2lavhiYph4b+38
02mpGR6FZrRo4gjR419gWDPVBn7FFxgK98eIAcc1Byu52uH2rAaPctYYMWLo
4VmyoR2u0+21tpWOEdNc0rHplu0w1tLLe65ljFhJuPE9JLMd2oUvZV4QHicU
Sp3DdF2+wmYpE53U6HHiOJW/NudzB1S1lr8ti5kgRgJO2kbldUG8YWOYSukk
MX70crE/doFDyUje+9pJYnLP3+tce7ogtpVd6Ns9ScwJ5rVoCnXDDpOIiLlf
kwQ7c9q2/UI3ZLKcaqttpwip9gA7Rf0e8Myoz/aiTRHWOhH2ZbW9EOr58vIB
ixmiiPbYYXC4H7pdrrI/KFIIkpm5vNJyP8ye3KWnvpNCpCROjRwXG4BqO8fr
2fspRLi2/sUBkwEQLZk7Wx9EIewutCT0pw3AF5tR27F2CkGd4v7y/cggcFv+
2O91Z4545K9Lnj01BBUnc60Dbs8TA6cfpE92D8M6Jrfzvyo04kGC1bMb48Nw
8kR4va0OjbCvpJfK0YZh/zaTq6KmNKJ2rX2djdAIPDBNf19ynEY8fyE4W7Jn
BH6WC6yPfUQjghdCjK5mjcDMi6jgh5ILhHj4sQ7Bc6Mg9mCoNEScTlilkNZq
/BqDHSO5Qz8MGESrAcMsRmgcBH5IKpTuYxCuPfXXfmwYB4VotkSMG4M4rxDw
M1t7HLoNr5/3DmcQSVlEq4LXOJjeFjRs+8QgRovcU0XrxuH1QZ/+CDcmEfEp
hUyLnQAt+tznjLglonJpLVRKT4JutP2wlBqLYB/Kf25GmgRfOdPQyN0swiT3
T5kmrUnQOJpK5rVjETX2kdQBi0mQcdrbpH2VRTQVcLL5Lk1ChA+D27aJRQy4
zwvYtUyClGPGn9mBbILnQ2f7RNQU1KgIbxXr5BA2MRk+ksvTIJ/+VFDdmwvj
hmSXU9bMQE/x0ZSCi1zYanD/H1nxGWjcVNKrH8GFDhN/l2zUmAHvPPeKi2lc
6Gp+dmXLsRlQk0xbDW7nQl+OXtyeDzOwKHV8sN6MG28HNJb7xMzCvNd0VKsm
D35wYfBVylLAta3S0mQrH7713tXoo0qBHR9tq+YM+fB1QFii5A4K9N/N2FVk
zYcFMfwb/a0pMB6eFX/4DB8mVUobqAVRoAuSJ4ye8aGPrIFvcgcFDsZaOMSp
r8G1PUHNAfFzsBq+KTXfiB/VC9n7k2/OQ7TBcnJVpADGXyitOxQ9D6QyyaGK
VAGka/vsFYibh4ddbcp1BQJIlLfoXXs4D1VaTbXr2gTQkchS9iyZh7wwC/vT
GwUxrN2aoTkwD18SWxK13gpi+1JSZq0RFRy3GWX8wyeEBtX7FMKACmFD5ffy
ZIXwcehqioElFQ5S4EHnNiE8zXPmToEdFTjuA6pnXISQLbQ7KOE0FfofGB/2
LRbCzUrDNu7JVJAK2Rs8e1wYQyy1lhbmqb//sj4mvEkET0S3rFFnUmGtbBWF
d0IELRoDJDw4VBjKzY7N+CWCovavtzUJ0sA3QauDpCuKWe7gnUOiwcORVeJQ
mig2XLJvd3Skgc0znQ3H/NehXFZgYXkFDVoun2OJp4rhr7ENVTPvaBC2uksy
MFcMx9SqPm2qpYF2r/728TIxLHqxOnK3lQZ+5hLFc61iaFYZJeszRQPLH2Nl
xULr0a/14W1p+QXIU7ssN3NrPVavvvMICluAKPWDb1rCxZGdZilgHrkAniHz
WZw4cTQxai4WjV2ANcxtdUbp4oiX+lZzkxeg+0z/Qt9bcfw4ufK4o3ABcifz
ulpXxLG13aBnx/cFkAkA3rCrEjj2tNR+1oAOzOpvXhduSqKqhdFyxR46XFy9
KHT7viT6DGPGLXM6uJ1rgqIcSZySb52Ts6XDe67BdO1PkkhJoNzd50OHyfDC
yF/CUrgUotHwNIkOlu4Tfd1pUihsm2vmSaVD8vZrQbKfpLH5nFxoPpMOLWn2
JNE+aYyLja+gcuig+Kz8mSxVGsU+XtW8uXYRzrN9mwPlN6DknkPS2SqLMNv1
XN0qYAMqaDCnxo4sAn1YutZ7kwxq/bEv8UzVIohSsuZzkmSRQn7fWIKLECb5
TbO6UBZLzHT5lz8uwufwWN6ftbKoE6Z4LebrIlj8Hbk9Z1EW9ReppwpmF6Gu
L9jT21kOTUYfGc5uZEDRRGa0m4o8HiJmB/+6xQBZC0u/gFYFDHpIL30UwwAn
mWDRzhkFzLjEvlUXz4DYXKa3yx+KSFMT3iL/mAErnFPr6kwUMTVBw//jKwYw
H5+M31asiEOeflyKEww4ZXvDLixlI17km1RusGbC+ahnab57lTFtYI5GP8SE
rflHRr3slLH2DbNW6QgTuIt+5vh7KKP0+T98Az2ZEFFvrdsQoYzVnZtLlUOY
EG01NXq1Rhn58rxNg54zwZfx4Pj8vk2YvG/Ukyy6BE92P391zY+EcmGtzWMS
S5AfpJwrcZ2EGS/fGeXKLgFpiBFdc5eEBfIP1m9WXYL98jkT3qUkxJ82H9SM
lyAXi/d8XibhdOJrZQ2/JYiutQhVi1fBvb0xgzs+LsFMpPmFzmYyfhQNOkBr
XIIQ9e9bykbIeMD8VMXLtiV43KnMX8wko1OhSbxu/xJcCE+34iGp4tmwBRM9
+hIcFV6c3hisiimkY+mGpGVQOnsdL6tvxlk/7WMQtgwlN3Sa6PlqSFUScr8e
uQwj3+5MudepIaNj3LUydhm4Z94NLg6pIRekOeumLsO3jpPFb2W2oJQEv6Na
yTI4KYlPFcVuQZPq7/vXjSzDbVEDrzfBW9Hc//U+m8lluH78QG1I6la0Vk20
jqEsw7Hsxrbg11vxcLyVFS9rGXy476poLG7F0ydLTZkSK8BKKOGPCFTHBKEo
w0HLFRDKFCovv6mByehpoGCzAusVS189ztXAR4HG+i6HV4BmOX32y2cNzBmk
6n49vgI374/elRbTxMoy9+2fglYgiVdqjVvW7+Jx09lcnL8CiQeVnvd808Kd
hf0S4SIs4J3W2n3WUhtTqv8ttJdgAZdto4K3mzYyG45ZkmVZcM9c6FFqgDZW
TfVfqSez4HVnYV1BujaC2kCPhDELnojMORWwtHF/1sCTZ34sIHJF7HVqdmBh
abrhNX8WmA6119n07UCRD8fbDl5hwafgitlyxg5sHRzgWbjBgnevElOvaerg
EcVB7z0PWaDaMSgp9FgHPR4MarR/YoGUw950nbu6WJP3pDanmQWxqm//2P1C
F1UqThwL+sqCwDCX9jfNujjRORinMMiCgV5xQZLYTjwrMUT1YbDgAL1MXTxt
JzaRMmKN2Cxwm/42qUHsxG06HirCPGxgfFXy6B3difN2Q46lImzQey8zJbBd
D6/EDVWwyGwwyS1uMGvWw+5/M+y+qLMhhtlrm8rQQ6MXHlMZ2mzY41VbUKSs
j+zGITkrYzY4TfU6mQfp4w3B4dAEh99+DlludpsBjshkSp90YUPB97YI4xMG
aLHFs1jvBBtiWc0ZqQkGyP/n8FCvHxsCpQra/2UY4J3IYXPVm2xQvaVd6Ntm
iOcl4/+6HM2GloTovcFiRngoxzjtvzg2lFXouNjZG6FYbSrNM40Nmj1/5jV0
GyHVwXJjaSYbGqL1hQuUdmH7KG0f1zM29IhVcZrP7MJk3kOZ6a/YkDR+pPcG
z268cp/V9LOKDe7ZprfOOuxGZ5X8JeMPbHgr5Bx4KG83ypnz2X1vZoOMQ4gG
1dkYWe2l19Q72KCok6pjXGGMfV4n8q72suFZ55qnD2X3YPrNqtUNP9jwKO/Z
c8nZPRgufkb99E82sFI6TssfM0GPLCmn1wtsyH7CkRTpMEFTnf9urFlhwzv2
5OV79oCkGv8XjlwccD4Xs/viN0Dewxt7svk50OTcc6Bpx14cG27kWxDmwCbh
p5lioXsxj1vNPVGWA+9Pvam/TTbF6MSOqCElDpi/fHEy9aYp+m26WbZ9Mwem
t1JHDKZM8UDp9sEwTQ6Ini9+RXI1Q03T/rVfdDiQVxGRmNdlhiJtsfqKRhy4
Uz9ixTxljhQPQ69zwIH194pePOW3wJb58bvVlhy4JNrtmvmfBZZE3K9ca8OB
Na73zknnWWKimOm4y2EOzPSGbP1Ra4UXMyhi+c6c3/3NzU+1tEYH7cfGS8c5
YG+4kFaSsh8/S/UwfnpyoCbwr8Ncjjb4P4CfSdw=
               "]], 
              Line[CompressedData["
1:eJwVV3k0Ve/3PueeG5IGpNInRUo69+JyjRnOlrFCkiRNGgyhlErlE8qUKUIq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               "]], 
              Line[CompressedData["
1:eJwVlXk01dsbxg3fIUqDKXSTVBoUzvccxxjvOeYS4qBQuobIUFHkCkVR0kCm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               "]], 
              Line[CompressedData["
1:eJwVU3s01fkXZYrv59uLqUGqKSWvSknf772u63Jc7/JLQ4kYiano5ZG8azCK
hERkTOEiSi8hCXFEJfKITOkxGo+UR+qGpDD398dZZ+21ztrrnL33We7mZbv7
Bykpqb8k9f9uf2vzrI9hFNR/D9yZv80a5y3JExpEUvBMFPs5Z5kVhu/y7VKP
osByjG8wFGSBI7mCiB9jKLAeSO33sTLHPYNkxfdYCpqLD46vdDLDjvVPq9+e
puDOta5/vM+ZonVAxq4niRS8m4h9GfzJBCsr9klXJFPQphOmGbzLBNf/wBHl
plKwgRdInLuEmGMhbXzmLwpUN865n+UtRKW4x29C0ikY9VGTbaSFGNN6LmyP
iIJa/yMfpq4Y46SSu8ovORSw8yrzG7cZo/eva5GfR8HNgkbhUllj7M76ulM9
n4LPWFUjVwFo/652Wv4aBWru6nsH/QH5h52M3hZSMDzVKe0oNsLrpeqdLbco
+OOfGoHj70aoMvXpWHkpBZkv3FxOzzdC2ZPRlQmVFAhNk+IcrQwxqMnOJaSa
gusvT2l9HxDg4IJlU7trKRiX91o3kCjA1vRbAn49BRk6HY2ugwZo1hP2Wq2R
AhdPkdAh3QBLtayPyrdQIBaZKIfYGeCF4q6K3naJ/rMjGnwe8NGjXs4g4V8K
jvpsXx5Yr48v5V6+DO6hYK1592Jxgj5u3pYbsruPgnUjqopujvrIvDEo1x+S
6GsdefneMA/z1IiT2kcK3or93KLu8nDR/rYJuc8UXOjd9eV9LA+nRz31e8cp
2OMQu0Gow0NfPvui+RsFx6Tk65Rm8rAnTCq4bIoCxb7MZxs79LB+9rk7p2cS
+KbS0HU2Sg9Tltfq6csTsLM3vBQg5qLgvsNKxQUE5GaFOJ9v4WKPx5CcWIGA
dPC2JVU3uKhboNh3eTGBwPd+fv96c7HD7krr8aUEGs7T/m22XAz7YlS5azkB
EfaaX2K52GjomaysQaBFVY7tnuSgX9dk2KgWgSouHW/YzcFFJxIPPFlDoP0c
q7r3EQc9GstNTuoSuC/dlDA3lYMzneeJxwUEvDe0l/ANOXhlOuv1UyDQGLbY
4JQWB22zuY8KTAgs+Dn4XbQCBzP7XTM9rAhE2XY1RwyzaBE/esrUmsALr76Q
oNcsflgfE6BiQ2BF2EztBY9Z5AcVbX6+lcBz+Uh59Sssdi2x1C/eTsD5uGlT
2l8sRuMrtYQdBGTM+nIux7L4NyU7aeFK4PMTp+k4bxaPXkl7p+pO4Grbsa87
3VlcabPu6fRuApOGo2O19iz6pjhcub2fwI3HYdJCIxaV9YdSkg4R0PoaY72d
YRFfh0d4+Uj4+boKE1os7g1XPLTJj8CtmzK6WioszlO74qgRQCBFIy6+W5HF
W3VGZjOCCTg156/SnMei84GnOp2hBGSD6UVjMixeLpqkzkVI9k+mRKu+MLhl
e+Jn3+MEOk97Vp7+yODYhHrn5mgCNYXlvJB+Bi+kl9evOiXRWyopYrCHQVPh
lhLZeAnOfKjc3cngQG+PqCuBgPaa1WdcXjKYeDIorjKJwI4Si1Muzxjkac8L
SkshsMdSo7yrjcE3LVm/+f9J4E2yak9/C4NRftwttucJTNy+2+HfxODahY/5
azMIzLl/9PcTjxlsL3fVmJVF4PaKF3XKDQyG7hyd/zaHQG2g+h2degZVZ8RM
VecRaNKNcW94xGB97tL+C/kEtp2Y6n8vwT4bi9qDrhE4O2EXESuZX/jBonpb
AYFBf6MDRRK+qjOvrq4vIhDTc+ibSyODe1if1LklBDwCLiaebmZwbodM5PtS
SZ7KOnPMWhksDk3zul9OwOv477fC2xl0UlnnJKokUCgd5mDaweAPtTXmR6sJ
fJy6qRv/msFLex10HWsJDD+SmtjZxaDN7KGf2YcE6tqqjpT1McjxGre1qSdQ
Tc3mqH1gcEnbjGjPRgJhmj8t2jDK4Ayu3N0/Wgic0lzi2fudwf60ReILbQSy
LrVHCiR+PplS0yj9m0Ckkma/gcTvUrf1zq0dBCzzZHR7lVg8scrygewbAjau
n1y42iwejLf7ptJNYGBd5axePRa3il10+G8JuD7+W9PEjMXlZUfSvAYJHDdh
biq7skiWhjefHCYQcqP1Q8ohyX+Ex87MERNYk33GsukoixVW2YeejxNQ8MBM
/3QWs69dzxZ/IxA6nn5z6AaLMT+WPZ8zLfEr9BG1+h6L2ztahMYyNJzdL3tN
9j2LhoJXAU6EhkXiuUlXJyX/Ieq7emQ2DWtXG4g1FnBQ7DGlmP8jDeWak/UF
wMGOx7R17U80kKKRqocOHEQdhfB/lGj4lKKm/dCHg3HjqwfmL6XBfOxrcnIu
BzWjHatCVtHQEpfzfukSLsoN/jaSrE1D6qfdRN2Ai2M23loFOjS8To/N2fQr
F2uUopJ6ODSceDHrm0I2F/NDEuumeDQc1L8k1fSQiwmdFyYXCmi4jQkbGoa4
6JJXvPd/JjScEwh/qRHoodlsPL/XnAZRoZ3rs716uMar4Um4FQ0eQqM57kl6
+JXTxS+xoWFFqYH50mE9PPtATn6ZMw0Z6zXECuU8DFm12Iy3kwa7TaOlrWIe
usWrB9u50bDOV8Y6d40+rrMX9ER50FDo431RJk8fFcsslbP205AWn2Ta2qeP
33/eurniEA0jzoZL9Fbzsb53X+lHPxo+SMtYB5bx8aaV/9CsQBqcDz8XFcoa
YOq18BVqITTo2WYkWtgb4O4jqbGO4TQcqs7rj5QSoHVHdvXhSBru2gpGapwE
qCu4MRYXRQM/IOBZXLkApWQeuN6LoyFg4jPPK8YQFRRr3fISaFCasB14IjbE
VRr3fotNkmCTwvNdrkZopId7fFJoaPz1tRy33Qi3WlV62P9JQ5lCCNdIE9Bz
R8U+/nkabJOcCms8AY/tLzugkkFD3H6nBTk3APPiSrz7c2ho2HVgWf9GY6xI
L/ZtzqNhmold0yMyxpYbhX7F+TRcbGWehUgJsRcL/P+8RkOM+kG+socQJ55c
DzxWQMOysVjB2RdClOu+GuxeRMNA3SDrscMEV47kh1qW0BC64eo+esAEeTKX
j2nfoUFOvGA4+IwpblbMC5tfIbm3rlzkuc0M3TUuRnyppCFFlhcUZGKOgXrZ
ka+qacjky3+t8bXAOCvRiepaSR5a7cfGfrLCrB0Z0bkPaXh1J18jomwTvsp7
H7ywjoYth6/7yG21xv8AFTB9BA==
               "]], 
              Line[CompressedData["
1:eJwVVGk4lWsXRuTs560UJUVIaSPEFu9rm5Yhc4NoUMYkihBSOggZMksqnaQo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               "]], 
              Line[CompressedData["
1:eJwVk3s41Gkbx8ckev2eSgcSRbQOiaKT328O5mYmh5qyO6FWSGfKqVeUadF2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               "]], 
              Line[CompressedData["
1:eJwVVH081fcXl9hanG/6zUNLHhMiuclDfb73ci6i/Ag3Wh5+ktSw9WAiLTaF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               "]], 
              Line[CompressedData["
1:eJwVknk0lXkYx0VJp/q9E2os05UkSwuXm/C+132unaGxJm10FSnLDUnJHEtk
m8ThSiNkCslQqC4m85CaJMmSpEzE2JtxhhmcLHPnj+c85/vPc87n833UBcEu
J6SlpKTcJPP/XvDesI1jS+DaxvD2DncHvKic0KpgT8DuTdMLE8Ye+zWy000d
CVQZCI22Kdqi1e4S92NOBARZTmXORdZYalyjnOhK4GiVhfNophUSixd95fsJ
5HZGN0vVWWKo4/ubbzwJhLLd28xkLbHHY/LEwmECvVfv9WgHWCBXsKij4U2A
CZurNxw2x8IA8qedD4GZgZI+aaE5rj6nVin0JWCQF38tUdYcA2L0w7P9CfCT
4jJSi/nYnsI3rQ8gICceKjnuzEcjkcvSUDCBNSxFXrM0H68X+DSuDSWwjs3R
rKkFXC4NSzAIJ3Bz5Zn3vhGAxx/E23ueJ7DJK6ZiBw34/FcRib5IgDx6+dP3
0oAZXWJRaywBL84zkaEpD2d/bz44E09Ap9GX+Hw0w8NjvSzVJAJBt8Xf9Ceb
YcP0xCd+KoGRO33AYcxw+9JC0ck0AqIdw5rzf3MxRY6cTsuQ8FTOL74p5+KU
vJrewywCSUVZJ6KCuVijxX8kk0vAtmwwVnOJQZaBS6RuPoGnSY7ihy0MxjI+
POdCAg5jKafZNxgcsQ6TibhNILBPd09gCIMOzvG/5ZUQ2GBzJ976WwbvHxKl
PL1LoMCkQjVPi8FNvsXfTZYTED4WXT2wmsFIoVhBoZLAqtno2SPjNPZfaH5r
8kDSv8FcSs5rGq3ie3/0FhNITa4NnK+hsTRtwutyHYHRH574BRXRSK4vaJTX
Eyjdub5hIovG0FvrR7saCBSeatvol0hjTzmr7EsTgQxlG+OeKBqZGj3h1ucE
alv4SibhNN58Ahy7FgLlfb334s/QKPvKeS74FYHstYtf6oJpzDfaKZfYTgDv
Li62CWk0zpdVKugi4JofHFUdRmP76gEt8VsCPtP2yoGRNJ4S1u193UtglzVv
3/IlGmXeZdmM9kl8NVbGhaTTmMsXekgNELgvI816XUAjp9TeT2lI4m/kpEij
isZWec1z+iMEpLPUci48p9E3cjnBdpxA9aSX7h/9NC4NvhN5f5b8a9vezrML
NGY7VBdFTBHg1Fu/5asyqP/gysOr0wTObnkZdozLYPNm/2cl/xKIHmvUnxIw
KEiw6MZ5yb0cDnt9KoOZHnP/TC0TCBPXusWNMbgLO1atkaGgv0dLic3i4jPt
nzeqy1IgFEpVfO3BRa/0y5omayhQ1itOFmZycW7+2B7ndRS460X2XuzmYrqA
sfKnKAjiq7xK2GyGui2b3GPkKbjGprcM+pvhodyWsPtKFOSwq/22K/JwZmXR
pWZVClidczrLITxMDYzOHGBRsMvmxl3FdzzU7D54a16dAtPvG3xTNQDrzfZU
b9CkQGWgTOOvo4AexVSTjjYFvA9SSfr5gFPUeCd/BwX63EcfRocAkyKaBj13
U2D5laWwQ5+PWwfyps+wKRg39onqiuNjnd15mWQOBcYrWn6R/8hHt0pXhcK9
FHw6OHNqpaU5flbZrVFrSoFBytGg7GpzTIiTM+zgUrCf3ck5aWiBapOfzMeB
grHhxVFWkwWK3R67SFtSMCGgihQDLNHpcbZAxUbiZ3LfizRDKxzTDAkxsJfw
71cz99G2xtgrDrH2jhJezxjjI8dtUGV2e4bAiQLf1IrWFep2WOW1ovCCKwWz
hoeqhuUd8IBRiekdSU58YtzNc3PA/wCh6VoQ
               "]], 
              Line[CompressedData["
1:eJwVVHs01HkcHa9Ohf3+jjwiZWqStvfjiPL7jc+M8X4k5Fkh0kYdj0nbpkb0
IDIeu0XsRB2WJYbiNFH5oOeOWCmlh04j4qjxLJJdO/vHPffcc/+4f9x77tK9
0V771Fks1nYV/mfBu806lQEEeC+CZt7vdEPRpayO5l0EnLqc2y87OKORetT7
V8EEXhdl+G0+6YjVkfajY3sJPG78KXkdOKBzp5madgQBTnjvo8vO9qiwmaY4
BwhMNUujcpIEmFD8jG1zkEBmjci+vtsO9XWlG7yjCdTl1ybnONthZfw5iIoj
MLI9+liRnI8OPWGep+IJXKubjVy5i489DtyQgqMEfjyUOJI0xcOfpQtjbiQQ
sLFpKb55mYfUwvFEuYjAK29jsbs7D8tOPsnsTSKwdosLa7EGD3mDpYXfTxPo
M/quzjQCvtqRLF2QSiDONXjP2ElAYf2uxtXpBN7iYHKxI6AOx6rdTkxA8gO7
6LkeIHdiSCn8jcDdTms3QaQtas2/JffNJbB6jqXWBVNbbDU7W7Y1X+U3+xgm
PuPir5beZ0wlBATnh3PLsrkY6MreO1tIQPhxU0iLNxeXhn7mKq4S+FI8xE83
4eLAkfpF90sI6PopS+71MSg9nzJVWkZgok7b36aOwSNXfZ6nVRBQHuz9vSmV
QUa29PqhKgI+1eyw9SEMarYpxZ41BD69JpJQGwblvQ1Rm2sJLBM61m01YTDn
W6qT4U0C4RYJJpIZGgOIr/m3WwQO5uf3HFbQyDbnqL+5TaA1c01EpZzGj9tG
eu42EvAS/mK+RUZjleedhivNqn6leQfUymiMj0jLO32fACvz9WrNAhrp437x
+x8ReHgxXGmZTaNGznIvFzkBnJktykqj8a/S0XVr2wj4GWRkUCk0Zt+5q011
EKjvSnCtPUujf2f6wFgngcSLpP74ORrNBv3vP+8isOURX+1QJo39/5pflXUT
uFfseSktj8ZK/XFRwRtVv5N6AW+LaTy8CoNE7wgMiDPSo2tptIEM61AFgZr+
9boeD2lU9w00EPQROHwqLTb1LY2PoyzGVgwQiB2I27RxksaspIm2eUOqvKfd
g7v1GfTLbar49Fm1V8lwroUlg0sqxantIwQgpHCyPIDBvuagfdfHCfw5NNI7
N5nBay9X8i98JVB6KaMjoopBofLLkqPfCJjtTwwZ7mFwm2bL98AZAu7/7Nbu
XMBFNZOsl8wsgVu3s6ad3Ln4IbcqkFKjQBetNLPSuVhRmWA1rkHB19Z0Wb2R
LYqtFSXhWhRsY1144xFhi3EtTvpdcyiY46O10bjBFn09pMmOcykonFDOumoD
bu02GJXNo2Bec5OXlAY0DT8evEqbginZiWW6cYCsYcWTAh0K+vNPj8srAB9q
VpeLCAWcsMj5Met4WJ5paDxCUdDuPDstOcpDscmJlFA9CjT8aK2/H/MwrqT3
y9MFFKT6NOmyOXzcucElXGBAQYtAcWPyDB+tG6qf1hlSkLg7OGTjBB9NHYx4
FgspaIvJFrnF2CGr44Q0z5iC29X+0y3/2GFv0IfF8xdRUHBMwv7jigAf9Luc
TzClIIyzZvRGmD2Wx9ZMf1pMgce5wQmZpwOKZ4wO7DGjoDX6yaKVqj+KTRG9
aGdT4G1hJb623Bl99Prsecso2BG8VqjT6YpTD3QaYlTaY8XcaU8fN/wPHqpF
Fg==
               "]], 
              Line[CompressedData["
1:eJwVk3001QcYx+/uNmYmz0Qa5ziUSnNdipiX3+8+98VL11WmEnWndlEWXdfI
e0rn5m1RIR3EzGKi7nqjl5vjGS1Zm7eUZtVIEs3UFCctdvfHc54/vn98n3M+
z8dGERsUyeVwOBLd/L+V5b3ff70MsDduocPUJhlxKz1sl9sBMiFHtJsf+ZJe
rvxS00pAZVNM2NmDPmSQkCH1tQfUS3buOpPhTR9tq3rQzwNsuqjx4Z2WEEhb
VVF8QIX44vsBb8W0cM3jd187AhqFZ/JkUWJaZK13PHcV4DM/txjOqIgsDO0+
tXAGHBDZdfjsEZHV9NrmehdAD/0WS1cQkc1QdKCnK+BJVdweTaOQbH/NH77l
BnjfZM3Eoggh2V36MVHuDnjWhl/pYiEkXnWPwYQHYJ0oZTn0IznmT53Y6wU4
6j/+ZLgUaXWymdMCVnev/O9WYwWSa7hbW6UA8Lj8RTw4InmsCw12FAKeEbcK
UzhIjHvaWIsI8OmAHT1sEBDaVqQHSgBlYwOjsjABSYxbjIe8Ab2c8wa05gLy
mx2sjvMFDBtfPdPcz5L/CNeVuxZwdaz1s1cVLK3rtu0olAJmqTV8010sBWl9
5EtlgPVWbXp3PFkKro2avBCgyx95TsyZsBR6NO+AZD0gzyhI+uUkQ/L002Z3
AgE37y5Q3u5maPvOzrrIIMCa4jfkfImh8KDnntMbAA2X+i/eWc3QDsakK2sT
4IeaZ24hhQztsnNRmG/W9RV0Rs9kMbR7YfCrH0IAC7nzrMd+hlRzSTmfbdHx
mJFKLTMYShgrtezYCph0l/9JmS5P6tNqQr8AzPcysNVmM5Ta8kA4HgZoX7ft
z+wihjLq5/tStwNa1jQPLjjJUOYxmyhDBeBzx0yLiCsMqfeL35SHA05Kf3b6
7jZDOdGRBbxIQP5cxfjIPwwdCs62ad4BOJb58fUQc5YOC09dDIjS/afZT7Ur
hCwV8m75PvwK8Lf9K3tyVCyVmE8MKKMBf696Oa2tYamMa6ycjwEsdxfXGQ6x
VDHh9M4RJeCF1r0mXUsEVHUvqNhaBSiKqHWOiRbQybaEFefiAO+KllVv0Qqo
TlNyVRgPGJ321zdFBkgNpZcDehMAY/Ifc665I2nUA4OKRMDO0prLuUqk87H/
xk8lAcpP7UyNr0Nq2mKlr04BVL9wMTZ4inTFG8tM03S8ntTEzToI6ZqTwqEm
HXDfiF6vTZqQyFJNazIAXy5WDR3tFtJ1vdoNN/YBDveobtY7iqj9RfuT4EzA
lsrDo+5lIvrl/ljK6AEdv5uZXQ0mYupsNzRKVuv8uN70bdgJMfWcd6j6IAtw
NvW9zlVeEuqrWO9cmg04rj0Ixa8ldC8n7sbKXMDBkgD9c4Pe9Ed8UejVPMAh
+1z2mL4vJTbyNzgd0vkQa2s6lu5HMNMhq83X+fj5CL+xUUpvJ49s3VgA6Af8
JREbZfQf2DLkoA==
               "]], 
              Line[CompressedData["
1:eJwVk3801QcUwN/8mjqcrjB7G2/VRvlRc6gx5vvue34ev2o0P/bCM6MXq0R+
5qgxauXHZIhCpdLy3qE9jPzoZuEJE0ok89sx+XGWZlOWfffHPffcc/+4934+
52796qhXqBKHwxGy8X+Ovu/j4JMDaJp2I0TNx50S//3EMjkXMDogQs0pyYV0
+H1mL38ELIismJ7a4EyVpw4bhecD5nI+Try54kiuLepbxgoAY3MOj4j0HWlK
+RrXpxAw1NbfdpvEgZId+dpdRYBHjhkEO/XYE/f0Uw3hJcDUwCEtnps9VSti
1OqKAXlteda2T4TkuVGLs6sUcFv2cZX0SCHNuklXyy4DVjO+mqQjpNRM52Xu
VUDx7KFa2xYB8Xom5rPLAE9/9LCgMk5AdZA8o3od8JsNFePc3QLy8uKOnbgB
6Kyvuk+2grSQWz30ZzmgisRQ734z0pnHe/sP/gR4Nme4YuAc0ja9510jtwAv
vlThxQQgNfqlt3lLAd9UeuwRWiL5Fm2lDhmgJNGwY0kD6cVwYz2/EvBRyevl
uEd8yjDwk9dUAWqH7zL4PY9PRkHLUtOfAU82yvLkAXy6dznrxhU5YFWvicNN
Uz4dmDC+rFcDuBh8PTB+naGVD1sLM2sBFyqs2ucGGfohVJyrXAfITJo19/zC
kGn564yEesBjGz8bXL/IUNtsfvrSHfaeTK6ZKI0hsYnFqdBGQJl7l0wRzdCr
iO6E4SbA25zrVXsOMpQnk0R/fhdw/OCls3lBDJkvKR9uJ8BZifiL8QMMPTAv
DbNrASzZVPhAj+1/HWUjlv8K2OiiYmMXxtC6/LG/cSvgvFy1UBTFUNFfkd6l
bYART/nSlFSGdltpeOgqAF+NdrsrChn6Lb7c6VwHu4+0t9OlhqFDd4T4Vidg
SK1P/PYBhlTWRj6N6wIseo/nkb3GUIldguVCN6CnYqZbvoNP1id1dob0AN6K
8ef1fcmnfqo0GnoIuMQ1E1vk8umIktuWvX2AnbpV4cZ9fFJ3mOG29gNeuGaW
qMn6uZr2rbbtY9ZPzZPtzRZIdu36mrcHAN+PGn0ZwfodVK9T2z4IePfenmlJ
BlKUqzeneAgwrEql/h1C0shYXN08zPKz3dE19w9Seff3y2eeAdaUNjhHWwlI
uMlw4c0IYG91tXVgkoCe7aOZ46Msn0Xzo6kKAcWeF43NjQFaccpyXugLSevR
ypB4AjBrPLrh7RNCkuqe7x+YBDTZryE7OyUkJ9+d3e7TgE2xks5RkT2NXVC0
tcyw82xK6/2m7OnE0xCyngXcvB5WQSkOZN45GVT+B6DdQP6Evw37fw0h67rP
AVdbtLONuU5UKJ0s+W4e0PuDMN7fFs7kWRzCLC+w/FKSFkVVLqSUNTkSvARY
eaUpqXfNld4dj/FfYOtwyxrPhP3u9B+t+/UN
               "]], 
              Line[CompressedData["
1:eJwVUntM1AUcP4QA8ZTfFw5CnsKCQ+Shx2Mgj9/3d8d5p9BkQHpTyHvAoLkU
b/LwkchZZyeNV2CFhLdgIsUGCEFjNb9ljWVxgyQWGnX3wwJlpOGEwCO6/vjs
8+fnGao9mVu8SSAQpDvwP9d9nip9ssRg4A8h5oBD2TSZM3s08DmDwrzq9v4K
JZk43Ysryww2twZk9gsVlCGZbV1dYTD446Fo/b9yWgrT7S1dZdA/55FXl1hO
N7xnp6fWGIwb29e9uyKTjrrozsjtDJ5LrVy59buMmOe83+A6g+I9TZUDhTL6
9g/tF2EbDMaXjPlYF6RUNcUfbhQA9q9/2Se5LKWYUe3KhhPgrscGqoqREj/M
Xz3hDFiWECbaOsPR1ZvapBkXwF6dubanmaMDH/E/Z7kCZj00cUfyONowactH
3AAxuW8124+jwbO8aOdmwM3C8QKeRyo9rh38wAOQdictt9xCCizg81yFgCrj
9YE1I9JEtvbZ6a2AMZdkQUPHkIzpfNPsNsD5jq5vzqch7Y3VSnIZwCbDjbc9
g5D+CuYnCABz7PaLKU5IHZ7aU3HegIV37y20TbCkEvBMuwiwrzXBKa+LJeHf
mj6hL6D+wpRUdYklstkOnnsZcHqjY/FsMUvlP2mePPIDFJb1KN5/laWoO7Y6
lT9ghthl0JDK0m8DmtjRAMDWuttO8XEsNXXaxhKDHP380rDYEsmSokXzZmcw
4IcHJeOdYpbs79iE3jsc/oxPy9XRLPVVaHpqQgG7TZeDJpJYKiqxZT0Nc+Sx
SNtdFSxtV2kWXn8FcHzaY9ivkCWL0nZlLBxwtH7OJD7DkiFFE5UmBnygNe8v
uMZSUpTt+08jAX0vjoQ+vsPSgr/mje1RgLmNhUWez1gyb7G5v7sLsBReGGtF
SPl29c3laMADXNCRmHgk90WrojjWodcRUP3Ja0hfzajn7sUBDujCS6LOI+kt
VqN0D6CXe/1nTBdSxG11RL8EsMNZPNQ7hXS/1/pdSAJgiKqYO72Fo3qzurgu
EXCkqvIlXs5RZqPVZT3Jse8mPbQaOfqnRt15PBkw/7Bbs87CUY/eKrufAmj5
MVmZHCwljU49q0wFfG/J561DlVLyzbcahtMAE+ZrhAUPpHQ3Ux0WkQFYO+cc
XpYtowuJ1q+bWcBT2yIeGsdkFB+h1jhzgCXBDW2T2kya97UK9FLA1PmGyete
cmpzU5utMscfbbwP/6ecylTXik7IAdcN/ietHgqSd09F2vcBSgJFx0rblOS/
BosmJSCP6p3pgVnUL9rxq+t+wJaC7uqG/Gz6D2nyqg8=
               "]], 
              Line[CompressedData["
1:eJwVkX1MzAEcxm/nrk3YfE1GXpO1qU2nS5To+7tX5TZdCrtGFo1iZYY0V9SV
16tpTjVJo1AXuhQlK1/uKl3jOmXxO73p7dYhbykvi/PHs+ev59k+z+MRmxQR
x+VwOEKn/jv0zVX/LQJsyhn3VmxTkK5sBqstBiyK3syzSkJp/0/ZNffrgJFM
b9TKU3IKDsuILbsB+JB37JurWEZQ2OAVUAqYZkgI2hsupWHH5KjxJuBI4k5c
ny2h+mD/SuVtwOwPcQMhDjF5DdrfmsoAT44ccE1JEFPuhSLeOr0zrytN0v8S
0R+/CN+KCkD+74AFDwpEtJ91US25C9itll/aLhJRZ/rjzNx7gJMbLP0D4wyF
rDxUyTMAfmla4TnnPkP69hVschXgGtm+zIGjDM07/pbnuA/ofnj7ZA4ylLE0
x3dXDeD61EDeEWDoY7NIZX0AaJ7ecALsSDsSJzIltYDS0fh3U0Ykk9udyto6
wOSoE0dHSpEEDbtZ73pAxZ78jtPnkQr3uvGvPQZMLfjgdusIkstMsy80OPnT
S8YW7EE6XJ2mymwEPJPS5fM0CqlHJcyaeAK4enxTvkaBFMq1VyY8dfIbXYKV
cqSa8qts9zPAuvGOfg8Z0jKlkq80Aco8+G3fNyFpJ/kCUxNgS4yuvH0L0kRx
vWptC2C8rq7NqEKKlSdl6Z8D5i5szhiMR3r5ydOw2Az4Z2rIrExFCsp7w15s
c/7Brd7ofxnp5oZsPu8FoHgif9+TKqTZQ4wg+SVgfU+FRtiBpNb+UI1aAP/G
fR3s/YlkF1Zk7bQCdm5mlnh5MRRpizG0vwIMSa8OS9vBEGXMtYk7ATVSy3t1
LkM+3q382teAU8e0FtbKUJ41VeDdBcjhOCyn3EXETfGLLnoDeE6/+kv+QREl
LhvJms06+wIXud5oFRHbUmjQ2ACXc3N2FQvFJEsKt/1459x/VeNw2F0xVc3j
uyT0AKZ8nt56MkhCixofCbp7Aa9sDPEb65PQ2bjE6PB+QOUYo0kvl9L3mZ6n
je8BdZ/q1BElMoqp6TIEDALO35rXHOiQkzlaaysfArxgN/tPM4WS1HP5ub5h
wFsXZ42ZIhX0D269hZk=
               "]], 
              Line[CompressedData["
1:eJwVkG0s1HEcwKU/dy7R7xc7hLAoYVxuWiW+/7ujSJRKS3d6GiFKnRqdXNfD
ufWgUojJSLWih90pGqYvpVK9KFTS1RpFHsaYZ0Z68dnn1efNx3H/kfBoQwMD
A485/rt6rOtoezeBEZ/E1IMRIZgyEaU+0UugqlXOa1kXhL+LFmu7+wj4hA4s
eHN9A27Z+Pa7tJ/AD6v0YN/oQKweSDP+ODDX84MUaYoAdMkVCMSDBDLI/Zq9
tRLM8uvcXTFEoFmdnvDJQYIzf/LVrsMEnLb2jHTnizHucpi2YISAMrl39cXl
YmwRMnrzMQJFsrII75ciBP1z47PjBLqu+X/Yd0iED88mCkYnCKzQvu/0sxch
381JGjdFIKFUqYppY/FM0xe1fppAvKlnzOtCFvtTL2rDZgislWeymngWIx1B
Xz9LgOa4VRquZ7Hh7bCxzzwKhX335z+xZNEr6YHggSGFv0Kb247DgAX8KKkt
Q+Fx0+cZphXQZm29tsqIwuSxQaitBcyTunB2cSj0mXwrLykDtFJekI5xKXhk
zg6qCgFzivu12TwKLwq+xK/OBbR4Fc4RmlKoy576qcsGzOqskDYtpHAnxOzm
UB7gIpMluiRzCqdLMYi5A3jFTckxJxQeeYryjJ4CmoV2SB9RCrcag3Y6vwO8
lLRBt8mCgrB08YW7nYC862WcHksK4ZwbJ3+asKh5Zi7T8CmUqHh8sZBF41a5
zsWaQrF7ldvBGBbPT37lNNhQyCrf7sstZpGx85UdsKXAq78msvkz99O/SDfP
nsIvhx2xbd4iNNjPcIuWUtBfVWzuzRRh+rlYmZ8jBbvD771V4yKcvvdBp3ei
II/nMqVyMSoavbiKZRSuPjV1bWQkONl7Q2btQsH7mESp0EkwxWxCV7mcwo41
ZpX7MgJw1EvGjXCl0HHKwlWQE4jJ2+pkwyspRDYFhNQwG3HouHN5ljuFPTGX
NauEwajqluarPSg0/8j3aN8egv8AO90/kA==
               "]], 
              Line[CompressedData["
1:eJwVkGtMUwcYhk9QhMmlfK4KCYh4gjaBzHrZBrhhv3NaaqjlslaQq2gZuELR
gXZUKMIwOBWoMKQdkIm4ZZQNnU6oeP8QdoGo45ZFJ7E6mMzQyYYiw0xZ9+PJ
myfvv2elZo8qy4VhmLec/L+ix7/3uisBfdnK39YnKsni6InYEAOYX19ybPJu
NOki519SLOCW4udUZN9MaNp4IzYe0PvW38bnn8hJaNcfGn3P+YfztaEVUfRY
fE6RowacnfaKv2KT0bUyh/c/WwHdS89H+XvK6NNB0XBFIuDuxpCA08VSymYz
La8nAZ57sfRJxjxP7+w9kdqSDKiXdEJQHU8+vXdXiFMBFagyC97kaVy4dPxK
GuD5lrBm3wccdWXFWxXbAQeHRJta6zmqtlXq7mQAush2CSrVHGncflybvRNQ
F/aD/7AfR28nucw81QBet+SldY8jLW6LvPjx+4Dd1wZOX7Uh2ecMJYJsQIZl
Y2JMSB2KDu7zXYDB1RabZy7S4aYp11At4Nf6G6JvlEhpjpD+rhxAbe6SLRPr
kdZFZpvkOsBe+clLVcuRFplaVCN5gF+8YWMLPJF+vT+6TLMH8EDYwOWpVxI6
I/a7N/Uh4Oq8jgdef0qovEzdXFIAOC0IPhk0JqHEQVOmxz5A9pe0Ub+HEgpl
+0UNesC48snpmUcSYva6OlYXAqq1N9u/fyahkR4822EAXLBKrlS5IlmFxn18
kdNls9oMIZIx60L4QDFg1XK71SpCirdN/5teAjj8av+dBAnSKrc13ZMHAJXp
X2kaUpFebNNW7C8DtPoEM98ZkW5bv4x2Kwfs7+PmHaeQTs3ZveoPAl6YXRTb
dhupUOE/xFYA1qasrUllOFI2JZrPHgKcL/2jvS6coyBHbcqmw4BPJtoNCw0c
PXv3VuDNI4ACn3yj6TpHfdXuY8mVgPKQQEOcD08n7ktbJ6oAG1d8oL6Yy1OB
uDRXbwIsishf0znMk7zsknhBDaA5hQ++p5CS/+DM05pawB2sNPnnESn9tXJd
V2Cds1cOTD76SEa9BTpj+3FAe1JNV2ZEFH3W04obzYAJzNHtS0LklCccW/iT
BVDFDHl3ajYTnxXYl9AAmN78WsC3AdG0zJZcPdYI6GU+HjPnoaQmj7i6l04/
WOjb2bZVSf8BQNR46w==
               "]], 
              Line[CompressedData["
1:eJwVT2lIkwEY9khyS01eU7MSSqtB5JEusyb5frvaTMu5Gl47OtSYmrGKQint
MNQfSrbAzCMKkcQI3beNCvP1yMpsQYnrMmlmjrTCChPUav14eHh+PNe6g0Vp
OR5ubm4bXfjPv7vCLlREA9rT3W0XVcl0dFRhKtwC+EVWG7lckUTTf83ePrGA
zY+zSwZXykgftkrTxgdMMijfnWuVklN81iSLAzxe4L+wtE5CeXkO78ltgBXV
JuOpPjF9rpRqyrcD8lTDnuYgMR1ubzOFCwDbX5xY/HFJRA6bH6c3wZUXY58r
9RWRbsag0e0EjBJK9N9bhPQhwG76kwgY3KCuiU4RkjpOwGlkAKeM+1b7uwvp
fXqzRiACxLuFs9+6Gcos8WTfiAFNGWGGqxUMvW7M45yWApJFag3KZEhFzzRB
MsBR49xMVyxDw44olpUDFk+HXncPZEjpZeQodwPecY73FC8iveTNaWaSAaWO
fr+xaaTUpGy2Zg/g5tpg64IDyVZAnMhUQNvNZRPWMaTkmvXaIQVgD88p54wj
DXZUsHqla//bStOiyy8fnuZw9gP+WjN7zeLKfzKbqm1VAc5NtZjyXf3SEDMr
SQfM3NXyoJDPUL8ghPspA3C+FO9tymJIqDmjPZ8FqMxqTuFXMURlH9m1ate/
gWOjsl6GEm9JuN0awMav4T91S4T08NFtrVoH2EDjoX0KISU4fc3zB1y67BU/
rF1I97kGbv0hwKoVV7yeB4ooPmJEG58DWF3De7pwWUSWvTvMI7mAiU0D5eoN
YtpqaOKePALYKU8r8rGLiTV66AL0gJV+dfU3OiUUY801d+QDWiayIyaHpPQP
tk4T1g==
               "]]}, "Charting`Private`Tag#1"], 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwdj2k41Asbh4W0WFIoazRGsiaylTz2bGEiKSoUhepQOUSWyslyylJZSkfW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               "]], 
              Line[CompressedData["
1:eJw1Vwk0lVvY/oYTksqQSpci5SpUhorvHL7XTOYhSZMGErq6KpUbypQpU1SU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               "]], 
              Line[CompressedData["
1:eJw9Vmk0llsbJs9+nkMzUhRJRVKGFIlT9/O872uevYZQOoYMUVHkFIpSSYlM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               "]], 
              Line[CompressedData["
1:eJw1lgk01nkXxx9T/H//NmYapBopWUtJSfV4uMP//yx6sjxPC5FEhWosjZBH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               "]], 
              Line[CompressedData["
1:eJw1VXs01dkXv0TNPd9KURLyarhI4pbcqWT3GOfe63ldPZRHkihCSI/xLuTd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               "]], 
              Line[CompressedData["
1:eJw9lXlQ1FcSx4cj4PLrlfGAIEQQDIcEInihQaR1CP5+MwMDw7EpBDIqKlEu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               "]], 
              Line[CompressedData["
1:eJw9lHs0FXgQx1W0bcwtJ9ELsUIk70f0GLbV9rv3ug+P8lghCb1IVBulIqGX
59ZNYhOlqCilbAaVRFKhUqkbDlqV0NvV3t0/ds6ZM3/MOXNm5jPz1QnYIF41
WkFBYZnc/40L9A2OoBagwn/mRmrq4kYFbUAN6QMptbqScumXbVq6gJKWxIW/
/+xKo4W5s+fPAmy38Hq4uVpMX/p+feRpCFghmlzXJRBTf2J/3GZjQKMW0+kq
vSLq1j9skTEXMCQjMe91sojaaxa9LDEHHC6BEzIbEbX4de9vsgKMupwWO6VX
SA2yAw5vbQGXRpml8HOFVC2x6VV2ALz77VjZc18hldu2Z85eCFgpDR1joiOk
883xi5c4Am7rEy+JvCeg/HCTgcDFgAkvZAPWgQJKPxPNz2Hy/txaIvpyXaj8
g/rtvXzATfdrCrYIXKh90QWncCFg9iqtoCujXMiwucvWyQOQdabYTI7gE18r
tsTIE7DkQc+fheZ82hg8zWSSD6C42fucdJBHFcMuup3+gEKlzZVhu3gkde7N
aggE1Bxp3hfhwqOxKbs1Lq0GHChP56/V5JHxU83UY6GAmWdO7LB/xyXhrCsq
e9YBjjHTbaMaLkVuECesDwO88WzbYKeES5LyvlHLIgDdc8RDBzZxqYOv88lg
K6BWoN3JmaZcGnf4WvjEaMCJRTXLOyZwac4r977P2wH/smTZ0gFGojn9QdKd
gHsa9efBY0ZRUUnSujjAyZf0/D0rGR0lPZ+SBMDreSz/6ilGNL6yVZIE6LXF
47F+OqMuN0/R7v2AOQZR79N3Mhp/fLB+zSHA+u7nY2RhjEx79zu7pcnnefl6
9vIARm6WhlXzM+V8TA5uyXFntDWm2mHWEcB1ZvcGmxij7FqfMsgCzO/Rie9y
ZFSj+snsYzbg+egDg232jHq8U86058rvY3vw82JrRpBvrF+bJ8/rpJWusGBk
0X8z51wBoFrivLI+M0bL7P2mHy4ETJO9G3A3ZxQd9zUjtgjw+IjN4ixLRrmN
6RNDzgN+5/mKq2wZ3ZpimiwqBbRTrs+oXcDo74A6JfsyQD3T014lvzCaWLQy
VrccULVp8q14ASPrT7Kv4ysA+btbnjl7M/JyPBw5eB1Qe8b55G/BjHYkW/Q/
rZL/y9uUC4VbGOW1NITeuAHoI5YY+yQxqtNe3XW2FhC6lnRMyWb0NmSUX8Yd
wPhvw+2vSxlNuni0LeYuYN4+Xffn9YzsRqzdg5oAyw8tqB7uYrQrNZTZtgLq
GvLWf5vJpYJnije1nwD2lC+QfXXkUoP+8UXjngHOCPBdE7yKS+/D5l3tb5fv
R+AdtDyZS+rXHlo9kcr5FV8gaSmXHJTWn6vqBPT7aXSR5gsu+QnGGRV2Azb2
to42BB4VdszX3vYG8G2x8gb9jTy6Z/LoyMp+OQ9J5K6A0zwa2hyuxhuU1/cv
7pZ18GhqtfJBq4+ASnNWZBro8mmhSv6Pml8AFZc4q6kF8mmlB8YpDQOqNCu7
jJzm096ctpE3I4BJc12zDIf4dN9qwtB1RQ5OGFDJj8h0IZtFM690/cDBhuRN
g18+upBkqXm0ijIHM3ilKxx8BfTd1QktORwsKi781N4goEBfV0UvVQ6GZp58
2CzXg7rgwNuxahysmKP+pNpfSHMjIvcVaHDwrEaex618IaXF7BE2TuPg2Jna
CUnvhfQ54Q+1D5oc5FaaxbxyEtFvqaceT9fhoJHEOqb1qIiqs8qznPQ4GBI5
NfKyTET6BXf8Qgw4ePFNvfP8UDElX3iqd8iIg+pvBHHnOuT6d62vp8yEg1Wx
qjPs17nSsrV2qSfMOP/r6z8aWIIR
               "]], 
              Line[CompressedData["
1:eJw9VHs0lAkcnUXolN+3Sa2yjcqZPHqYYSrE+k1bpO8bZobW9tgURcrjq6ZS
0hGN8tj1OBlpC6mQWpVVDXbtj/Rw9GZLNhuxeaRdu2xx8li7f+w955773z3n
3nPPnRMYqdqqJxAIVo3zX40w+dPv3VpAwX/woyb/3q3DGwCb06402YT5klvg
iK3VJkBX9WCV42sV5YfB715BgANtRS16vIqM9lmW8sGADjmaE8cMVRR2WLw3
KxRQlhifkVKopMfJMpeqMEBjXUfRFqWSlmhVox2RgBOFZu51eko6mRdUM2k3
4GSJVFReoaCxYnWCw17AMwY7fwmOUtCWa5rVa/cDTg84fHn+MgXd/UkLsQcB
4ca9s4f0FJTRqNPejwMMkN7WOrr40Ptf69YNaABta4Ih6KU3behuFlokAkac
133amuRN1f1vXslSADsvtKDU1ZvmjQ4XbEsF1M5/LRr6S07JxrAjNWM8T+nQ
yM8lcuoztbS/ngmYWJC5NSZSTuXWshv6pwBXXWqPE41yJHRQRdvlAt5KlOuu
13MU5xrkrswH5LqTd0hOc9TpodaPOg8Y3mK3OHwXR5xScyenCHCK5wWNB8vR
1fXa5FsXAfOcL1vkWHM0PbjQp7cEkP9Rm/alEUfRvG7q1FLACe9j33/Vw1Lr
gbpnztcAvRwGk7MfsbRS0/ztJh1gSlJF+FA5S8WpbwKOVgJ2fX0zJKKAJTg5
bFVSBVi8wKT6TSZLu8+ZdDVWA+Zvfzgt5BhLTSXCSx9qATNmeDo1xbDkWm7P
z70LWFEvM3fey9KZmyj1qgcsaWm+otnJkuED5WDkA8CsSSMfKiNZyl2ywPjY
Y0C6ODLykGfJKdfQPK8R0Dc3MqZMzdJjozZr3TPAoP7VM8KjWdrOVy591Ay4
0MPde+wIS/rPMz27Wsb7qimN35XO0ikZ7y9oA7yqryd8lMeStHh1iHnHeH+d
27RW37N031S0T9wJqJdpmX3gLkvB0WMJq3oAy3oD7H5rZWm0/bl209vxvT5c
2rBnmKUsrqwgqg9QWuXxTGbBkfjaN9fT+gH3zL6n3uzGUd2s0NtF7wBju2vE
fYEcBSZ8/pSGxv2ypRKTFI6O+w/+3TcGqNZV+MV3c7SQnkyYqM9ga5O1uUQo
p9s2302bY8ggzwsuf+Ivp4D0oyLniQzOsC9M4o/LaXBo82LlZAbX2Ec3H3wq
p/RA15WhDIMRspkPEmZ5k1399DWHTRk8IVk2uz3Um9afqldfNWcwW1IWMs/M
hwYMCo7UWTAobBi0HdvlQynhscfbhAwu9Dx90ey5D4merjs3NIdBl0PVwSlW
Cqr6bHHZFBGDM9suWf2xUUH+hUytrQ2D7i8EieJcBfUxPQ2y+QyK3W686OpQ
UGJUbfvaRQyu+HgF/0SspLltOf07JQz2OAXFNMYrqdJrv36SlEGnj+p/MH2p
JL9S36n5Sxl8tW5gu8EKFb2duciqwoVBh+SNEVllKkqIN3Z84sbgF5IG6TZH
X7LsfbW8Bxnsfj3SJaz1pTv8obMGy5n//+YfQ7wLSA==
               "]], 
              Line[CompressedData["
1:eJw1VHsw1QkYvZ6TZL/f5BVrQ9Zqsz13lFfmS7aU3+8+LVIWkWZTQx5tu0Kk
iFyPXRF7lzUMS1yK6UbxIVPtFVuqScnOsMSoSx55pLV3d2bPzJlvzpw/zh/n
m2N9OEJ8RJPH43mo+e91njc+fyEckPcfvCmu7LGVy3HArPqEr5r6JGRkIN8i
iQBsLGxIzt0noZrYixgeBTgpiPihRCmmPQMhwnOxgFcbl4+tPySmgT1uQUWn
AT8/kTiZNC+i7+RrIq/HAbq4dJTd+EVEzJrpRGUC4HOJmZTjRFR59kHWUBLg
xu37eZ9oiWjXWEXx+xTAYdP3mjtbhfRclCw3TAOM8gr8ZuqskKKbDrXaZwC+
pLHksr1CWmWzo2e3FFD2kVXJk9VCcpsZV0X/BNjS68h6HBOQzsqbSp98QHtd
B508CwF1WV6odCpU++3eJomP+fSjg+S8hQzQ49JEfmUOn/y9rA4vFwNGv9oW
1CHhk3XwG7fBUsDZsnH3DHM+jZ5q+rizHNDAV1V+Z5gj+aXU+YpKwJlGfT+X
Ro5OlXo/Sa8GVB0f+rktjaOdCutrJ2oBveusQjYHcaTdrZIK6wFfvwBZsAtH
yqHm8C8bANdF7210MucodyHN0+QGYKhdnLlsiaUD4GO7cBPweGHhQMwgS1a2
Npr9twC7sr4Iq1Gy9Mp5cqClFVAc/b3tdgVLtcLbzb+2A9rIC77VqGQpNiy9
IKVT3W/WC3vtIpZcz/jGHr0HePdyqMohhyWt3E/F+5WAtLRckp3O0u8Vbzdt
7Ab0Nc7MZFJZyrndos88BGx6GufVcIElv96M0alewMTL0HTmIkuWY36dT54C
br/nrnEii6WRv21LFX2Ad8qEV9ILWKoxmk4o6lf3O7f6wMsylmI20MGEPwFH
pZkZEQ0suWCmY/AgYP3IZgP+XZY0ffyNPYYBY86ln0x7ydL9cLupz0YBT45G
bds6x1J20ky33rg671HfWIARR775bdWv36j/VTaRb+fA0doaaVrPJCAGFc9V
HeBouP3gkWvTgL+NTw6tSObo6rP17nnvACuuZD4Mq+UoWjW79vQCoOXRxKCJ
AY6ctTve+y8Bch8C9HsN+aRhnv1s5zLgzVvZi54cn/7Kr/VnNBg0oB3a2Rl8
qq6J2zGtxeC7rgxFk6mApI6D5aE6DDrz8vr5YQKK6vA0eqrLoK63zlazZgH5
8OXJe1cwWDyjWvbSF5JTn/FbhR6Deu1tYrmrkCxCzwRu0GdwXhG/ziBKSLyJ
wQdFqxgcKUyZVlYL6a52XVUCMGgTcmxl5CYRVWWZmE0yDPbsW16UnRaR1Dw+
NXg1g1q+rjp/3BdRVPnQ7CNDBtO82wysbMT09Zb9oR7GDHZ4DF6fOy8mx+a6
R40mDCYGBAZtnRGTxR7TXXZrGOyOzElgIyXEexgvLzBj8Fad32LHBwllC94p
ZGr9/178A5399V0=
               "]], 
              Line[CompressedData["
1:eJxFUn0s1HEcttudrdYfPi1tVCJmxZbXXhT5IK/Z+v7uGLuKIhM1mpHMS+HU
KixLWJKtVNwl72Nn+MghLOc6DXdoQm6opuWlMnX6p2d79uz559mez+exiIgX
RvEMDAz267mpZ8WVcrOXgAb/EERyV+caTu/zFqOm3RdEZD2jG1NUAt6Yu7w1
JVZEBffK+EelgBmFFfHSX0JadxTayWSAgt+HTZpKhHRJYyg2qwacSPN9EOIp
pOHMVknBa8A1N+XU9DJH7geu1vBrAZe6rSy313MkHbLSJNcBHvKJlkwncbTz
+hh/oR7QNCFkLR85ytqbbxfWCHg83YWfCBx96fEUq5oA+7e0pYKOUWjcquRk
M6D3fMz4RhcjhfGrmuYWwOTg1KS5Ckb2bec1NnLAwMhi9a27jEovGguetAKm
lywav0hkZLit3w7aAHWZz76ZRDJKaMgQS9oBb6eM2HYGM5oUO+WsdgA6LPsV
Zwcy8ufpamI79f27DF05X0aNVY81E28AW5bVUxY+jMw5TsApAH0sBAM//Bjl
rgnsFd2AveGFVUOnGa2Wy8VHegFjClsGusSMInzjc6RvAQt29WTNxDAa/GpZ
u6cfcH1jtp9LZ3SsaFRzf0D/D17DCeeHjJ675Qn47wC9VoujO+oYGc162CcP
AsonZdlOakZpuSvieSXgn6jvMx9/MtI5yXLOqQDVpzzMrK05CtKG1w69B3TP
bAjICOWIsnZovYYBs72Vn9IKOLK16RM0fwDcuJar1Kg4KlKl29uMbO5jQXnT
VEi8FMczZaOAd6QOS8VXhBRnPpdjpNHnueze+rRPSJre0tpsLeA+Xn5YuZOI
fOKZdmVcf/+D7Z8DqkXkf+GRx9DE/739BXjdL1Y=
               "]], 
              Line[CompressedData["
1:eJwBIQLe/SFib1JlAgAAACEAAAACAAAAbpGsUxHzEUAAAAAAAABUwP7lmoYp
9BFAIlHq9emaU8BpjU+xnPURQH906zeLJ1PA1DQE3A/3EUCgXatWM8NSwEDc
uAaD+BFA55E/zGFrUsCsg20x9vkRQCixy+Y+HlLAFysiXGn7EUBsqn+BZtpR
wILS1obc/BFAagwvZsaeUcDueYuxT/4RQDpzjkGIalHAWiFA3ML/EUASliu3
Aj1RwMXI9AY2ARJAnuyoA68VUcAwcKkxqQISQOc0GqIh9FDAnBdeXBwEEkCu
0tX+BNhQwBo6wrG6BRJA+nLxQL6+UMCZXCYHWQcSQOwJ2bOjq1DAGH+KXPcI
EkAtjv/xgZ5QwJah7rGVChJAv5zWajeXUMAUxFIHNAwSQMKV+96ylVDAkua2
XNINEkCkTA6Y8plQwBAJG7JwDxJAgKrASQSkUMCPK38HDxESQK0vQpkFtFDA
Dk7jXK0SEkCdyUlXJcpQwIxwR7JLFBJANKoTiqXmUMAKk6sH6hUSQFIHlHre
CVHAiLUPXYgXEkCjgQoXQzRRwAbYc7ImGRJAoSy6K2dmUcCF+tcHxRoSQJKz
VDwIoVHABB08XWMcEkAKwpFCGuVRwII/oLIBHhJA4CBVaNozUsAAYgQIoB8S
QNyQe03rjlLAfoRoXT4hEkAdbsszgfhSwPymzLLcIhJAc2oIBKpzU8A2VUNe
bSQSQAAAAAAAAFTA/wLifw==
               "]], 
              Line[CompressedData["
1:eJxFk3tQlAUUxTeacIjBvaGIsTMMmxRUuEs846HdBXwtfN9++22tQBvZAkIu
wjKgyENknQ3QAhNNBxQyhqUVantoqK0MN6CQLF6+ascMRMCFCEmESQva+qc7
c+bOmfPH+eM3R6zN4dOdBAJBpEP/fr/SOZlWAij4714lkHfqMx1eG3v2CeZv
Fa0IvfP4n1JAt1RDQEKmilb5OB8/8BLg1ObwLMEET16u/i94BQPaYvx7N+7i
yXt+S3tLCGDksg5RGPAkHtFxUWGATfrcXZavlOT7Q9Xo5XDAm+6h06vSlOR/
7rPdmgjAz8WShhAvJQU0DrpMRwKaYwqfgxscSavun9wbDTgRPzk+WstR0B6P
wOXrAds0v3cKtRyFpYZ3NbwCeFwzmwdSjiLZJLVUBvhpbKesUMDRuohie0cM
4F2bP91qVRD61pdwcYAJdttEQoqC4oQdwpENgNHBB21WTwVtfjjcmLsJMGUy
aKH9BkvxY05hTlsAg3J8ph7Us8QO+PbWyAHLjRbJyh0s8daNmjUJgC3eXc7X
olhSN2fOnGEc+e2o6UV3lpIOH9wfpwAMcOPlb80wpCn5xOMaB7h1Z3X2lQGG
tmX0mdN5QNPRRxR8jqFU/l7UvArQdU386oxGhravc+8vfw3wSctUeGINQzv8
Q7SeWx191X26hXKGdq5QP/g4EbDGaWl9ZBlD+sWCypeTHTwW5HJRKUP59lpR
7+uABdclT9c58oKrVkvSG4BV0S6+1gqGijp+kU2mAL5ofvPXiiMMlbYsXS3a
BigytQ8vb2LI8IE401ULeE9q8Eq7wJCxLPbRiVTAGfm3gR9dYahSl14dkA4o
WayfHPuDoffUFeL27YB2w1PdiZ4sHZKdPstkAg55fNPsJ2OpJuDypltvA/5Y
9vxgpZ6lY57Ttmwd4M+n5uatJpbqnITZS1mAJyJiza4jLNVPBz72fjbgmc69
7v3PKOjUT/xRHz1gTFpzcJZOQU1d+X5f5AJej3m2MdmqILPl2NeyPEBd8W/v
HnHhqLX2PDOUD5hVdUdwMYIji9E2rN0N2FdrOn8gm6Mvc/7Ku18AqDmdUZRn
5qgt2XuZsRDQOBsidLnL0YUNWLey2MFr3JT7cK2SLgZq15pKAPeNOQ+Ji5VE
IiOFlgLOrdaPHB5QUrdzs+q7fYCjg/pLLVKeemZ7xtUGwI6GQxMRdTx9f9Ne
OLHfwe+Sob/VXUV9Pa5ue4yOfXS3fZhyUkW3ebfO3Hf+3+M/DJqcSg==
               "]], 
              Line[CompressedData["
1:eJxFk39QkwUYx5cOMxvHQ0jcCnZpIfJDj0NpBCHPcQYW8L7vNgoMxZkBU8of
IALaacWJiiAptxJURhJSsh2zbQQ64ZFiDNlCfspE5IdKHAlcYpTKSW/903P3
3HPPPX88z/f7uWfZR7vkKQsEAoGUz3/rm3+9eCe+DFDwX8TTwXci3Gx8v3OP
19aoDgWJj9wSRZ4FzEt2uEpiFGS0Zi2qPwcosahDwm7KiVniKlitAVxevFeY
v1tO4zHax5UVgMZ1Cc60VE55RdEz4vOAyvHtdWHNMpJ0jD4orgQ88saNb2qz
ZVQPB8ecqgA/eaFmRLxWRnK5ePjABcBoTydON8vRZInR8Uc1oFDl7fFLI0dH
e9nutB8AC04O1PQd52i5x++2wYuAZx4JJVmbOTIn5lsUWsBntXHBkWs4Sihb
Rm06QNV+77ZpEUcPB8wNEbWAPeVPZ7J7WCr0SjSY9IBuO1Z73VGztGLLjNb/
R8BDZp3asJmlaxUnLnxrANR3+q3/3p+lTaO+FR4mwKmtVck58wzNvt5SWlQH
OFkjbZ3oZ+irFGXJwnrAdXcDGjt+Ysi/+mlhbgPgniVv98+fYcgy/nX+9GVe
T5E4IOkwQ0q/oM9TzIC6WJvOmsnQk3R77sBVwEuCKn1wGkNqnSpT1gQ4kna2
QL2FocDphZ+2EuC4Svn+yCaGrgdqUsObActdSq978POPM0KVhp8BzRuEoeGp
DM0bejf6tgA+MDiVJmUwVPbnboXGAph+K0L7ZR5Da6WiOHcr4JMhe6y1lKFf
c6qjjrfx92g72zeYGNp+ORKfawfcVvdBjk8fQ8K5wbeybYBlr0jiiucYKg/P
XTNpB2SsY3bDSpZCDi1dta0D8GLWRknXhyx1U+0Kxw3AaXGAMqiEpZ0LYl5j
uwDb3fU7fLtYWrx+TNzSDXj6u4D9zjyf84e/cAvr5fmYbvo0BnEU3urpfKkP
8NWMoUfpPN/+xfWLfPoBm64F31cVcpTxnkJwzgGYqhc2vEwciQqnHr80wPsX
ttI28TdH1fZjM0dvA5o0V6IzpTKKdPGefDYI2Gk0hiR/JqPbHI3tHeL9mQrc
lWeV0b5TScMTw4BSQeXJh55ycu2ZdShHAU+MZF55/oCctO6nuvvuAvrFi3QF
9+QUlbDKHnsf8Oo+VftQkoKGT1stzWP8vlBNQ+I9BTW9O+ci/O3///oHwTuf
/Q==
               "]], 
              Line[CompressedData["
1:eJw9U3tMU3cYLYKAWuV+ioi6gpBBtQrMAg0M1A/UgMDyu71FaRRc760NLmYT
iQx8zEnVasWAIKhji5KViG5EEIgYssVvU4Mz0oBmZGqYvVcXVMLmI8NXCdb9
sZOcnD/PIzlR0lbBNkmlUul9fK9hY87rY285VP2HfNoQYN2x2svhrrTylx33
TcT9q4R3jXOoXVpX3llkoqt/SZeiJzhMLO6b7RkRqGJQKahVAV4Y/6ldf1Cg
uF7p5YQf4OIndqqIE0jpVo5/4Q9YkhQdOn3ISMfPSoahAMA2a1NVa72Rcr5R
fs8NBMx96MxYbzLShFMq6wkCxJT213nhRuraqYQumgI4Rd1fqCg8bd4idZ2Y
CkgfGcYaOnj6oFAxBaoBCxynO984eBrIk15snw4Yt2+l5uKnPDmWKXUPZgA+
crX8ujudp4/jJb3AAdbZz+wP0fD0d4QyQADIe717U/14coVI2xJmARbduD3y
3QAjs0rhToUCnm9M8jO1MFI/E9vVYYClewYzzfsYkSyzXXMA70y4RnfaGJXd
Ev95HA6oLmnNOvYJI90Vudo8D3C5NqDLnsboz04xvnc+YGP1Zb/EBEZ1zXJf
ssa3zx9HRxsWMspqED9vjgA8yfT9zVpG3gOyetYCXz7H0zLLEkbtX4qtlVGA
55wHNQMGRpuK5dyn0b4+7sxTgVmM5prFkY0fAvbfmdodXsTInS0f7osB7K0Z
dmp3MLKnirp0LeA9qWlN4beMDDr5tx8WAobt7Yl6coXRyDzxs7k6QKG2aFPI
C0ZN0+TgQ4sBN8NbR1UoT/ley9mxJYA5GZr1cYk8BY96smzxPj/X/K+/X8vT
z0OW4dsJgJ3WmGLdbp5K3R5H5lLAmcE1P3ItPMVetsRe0AO6/LUX2wZ5utvm
uRaZBBhptmVsn2akmiaLrToZsKeifLKy2kiraj0B4wZA86RSaHQY6VWlpXlL
CmB+QVC91W2k1lLPyrupgO6bKdkpEQKJVsuD7DTAI89nf7WuXKCwfI+9Ox0w
6VGluvCeQDdWWaJjlwNWDfvHlOSZaE+y55f6FYDbZsQ+dPSZ6DTb0MEh/P+H
d9C4W1k=
               "]], 
              Line[CompressedData["
1:eJxFkn0s1HEcx28Krdj5lEqTh264pRW1Fq3w8bDbuk73vd9FnkqdXF1IyJxn
aVoNN5dhspRqOUVTcR568FHKspLrrCmGxtJGNA8z1kj903t777X3f68/3tsU
8Vy0CY/H277Sv9TdjVduCQLk/ctRum4QGvOCAc/fcN1aly4npSCqbEMI4OPF
jZORyxwdSKoMrwoFTPZpBMdijqw6vji4hQOKkSvl7+Vo1Hrj6PMIwKdVHrc2
D8uoOZrpxCcADZ+E3tUlMirU58f2RQKaBJzh58tlpDDvdFeeAoz1eGtrtJHR
vhCTuRkFYFtZXET7KKO1NV4tl04Dtr/sqXuhZzS0oM7kK1d8BYLAQA2jBnGD
780zgE6FZXqLGEZXK6ZMd6gAHyS/Ej6UMIqYcO1qPgeoill/eGwPo91eSo0o
FrBDdLu1wI6RmaaK640DvLtTL0i0YPR1cGCTIh4wy6Pn2dSSlB652fRPXQB0
iWsYtvwppdwc+a3MRMBpvtNtxxEpBRs0UesuAgo+RwzYfJPSDkGXsDwZUJo7
Pj33XUq8JNMJlxRAuep97ZtZKfW+xvoGNeAqZ5GEM2Wks8646Je2sgPmVZHW
jDKimzx70gEL7IZ0OiEjpp/+fTwT0LiU2hfkw8jZfFf7eBag5Ph9RXk4o8Vj
qrzUHECdlRPvSQajbt29Q+a5gF3vfJcn7jC6szBkWXIZsGne7EhNN6MUse0n
QR6gNsy9KJwnI0lFcGn9FcDl7B+1xZ4ycpzQhnlfBZwcq1WvVsto9uAH+/fX
APlWCRmaNhm9K1wzEpoPKHK1V0utOKoc9K8eKwAsdzgrb4nhKNEtOyZZA5i2
P2FXo5EjUU6r26oiwNIwP6d+sZxsDXMzRVrAkwL/0I+9curcm/ZrUfv/f38A
81YhWQ==
               "]], 
              Line[CompressedData["
1:eJxTTMoPSmViYGCQBWIQfd8j+MIxSyEHBjAIOZCyZtVmZWshhzXnS/5+ags+
8OgcH+chGyEHL6PrP+p5gw8kfCyKS7ATctB3cs16vzTowD3h65v/2Qs5iM+J
7TfwDToQa2bNOddRyOH1lBBpAcagA3ci5sdZOws5OKzP/fZuf+CBqGrmLTdd
hBw2RyoVTe0IPHBjbjpnhZuQw4FtbtvFogIPhB04HSfmIeRwd8qPj3uNAw9c
eaS/ZYunkEPVG9nZjKKBB4JZp3AGews5rH3x+GDV34ADl9R/xH30EXJwe3SE
7/6bgAMBXjFb+v2EHHQmiW//8yjgwLmcA5x6AUIO5xZxP91+P+CAT79K/JlA
IYeD6i88OR8HHDi1sWNLVjDQ/bc6N/8F6ve88oaTM1TI4YvMt5nbgOaf+BYQ
vzxMyOHH66Wbs4H2u0lu3eIaIeQQ5b50d65J4IEj1pJcTyKFHH7XO+zUig48
4BRXG98ULeQQHD3f16Qr8MCBhodbFGKB/jtWcNfjUOAB+8WuXPvjhBzmvlX+
nMASdGDf0ZXxsQlCDnMOPJY9HBh0wOYF79bfiUB+w2UTpTVBB3ZxFXHNShZy
6BKZzHpWNPiAhe61eItUIYe+fvWTfyYGHzjvyrIyNw0RfwDSTtGL
               "]]}, "Charting`Private`Tag#2"], 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVj2k41IsbhlFkCRXZZY+islQovPaISKmsRYXTrhJFqZCtk6WQcJwoSSha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               "]], 
              Line[CompressedData["
1:eJwdlAlYjVsXx9+3CSlDFFLSIBUiJUNq7XPqnIbTfHBpJtRNqUsTSoMkjboK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               "]], 
              Line[CompressedData["
1:eJw9lns01WkXx3me4zqUSzRiGnQhNW4pwtROv985OMf1zYxMSnKrU5k0KBnV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               "]], 
              Line[CompressedData["
1:eJw1lQtUzHkbx1O/36BVyOUgYSmLqKa0MVFPif7/manGTEnKSppuWyLGJPQm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               "]], 
              Line[CompressedData["
1:eJw9VXlQ1GcSRcTvx7EiIIbZAQTFCzEccomy2FyJ8M0FMyB4RTnkjBzZiNwC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               "]], 
              Line[CompressedData["
1:eJw9VHs01HkUl+T73V6EJEqsV9pqaFMabLcHevj95jejolJR2LY6jaTHUC1K
KEkylIzSg5ijbBRmSncK7eo1Fa1WNok40m6ttDXC/nb/2HvOPffcc8899/O5
n3Ov7XqpJExfT08vmPd/46KWh7g0gYDef7YM40IiWx0TCYTeqjg9LMYfP+R7
xY85ROCUbpb0TpsEw7vp119SCDQFCo6rpBJ85lqveX2UgKbzmwgzYwn67Tod
8iidQK0y5+H3N8VYdX3TkOtyAtoRf8ZoZWJ01Z+Vl3+CgJ3iik+NpxjP+w6Z
d+wUgZUXbicmGopx3JF7LTG5BPrKLX552sDhocdZseF5BPJ+HbO8ppDD/nEb
bMTnCXgLXAcUcRxGrJmOHgUEjCxKEp8Ecfjq7Od1jkUEgoLKVb1CDld0Vg8a
FxO41jdKV2jFocf21XNfXyGw5tkIXeAdEV6qcHyhvUqAMbwaaioXoc3A+33q
CgI5neYu9uEiPL7ghnW+mkDuzMM6EIrQMDmpKq2KwMXKyqfOY0Qoe+C/NkZD
QJVfFFXQxWK36aSBsGoCPqkpl5JrWXyce9XLo46ArTxzT+MBFr3bYpsd7vO5
Itl7MJzFCme/vcZaAkmp6WX9S1icIh03se8xgZKIPz5UurCoKGu93t5AYHbG
m78nWLBorCsO0jYSSFSttjQZwmL8XNkXVROBW9KoxoNvGNxYZ+SZ9pJASIK5
16VqBpuMmpqi2wiIqmtDF5YyyC7PjwnrINDo/OqJzTkGNdnbrLguAuVRkmT3
DAZntniqhW8JDHv5pzzuIIMFDnS1wzsCHSd69HtkDFpufqIz6iHgYFWjPrCV
wZSS3GxdLwHBdVW0IJTBwd4fhO2fCDy/u7aiexWDkR5uvz3sI+C/ti3nmoTB
tli9aNUAgQz9Az2JSxkMqL07/sIQCsd+PDApyJvBuhFZlUcNKHB7b5gIgEEv
8fqV0YSCz7ebvPs9GCzJnPY5dDiF3ZOcL992Z9Du+acTolEUZl0coflxFoOZ
ttXuQmMK7nJFsMCN768JtDc3pbA8PG+LdiY/f+Nbo7/GUrikWacJ5OuHR8b3
3begkLLwufwO3z+jxLyj0IrChe9M4yfMYfCZv/JxgjWF90K6L8CTwdi/51aF
2FLolke93M3jczxVX+hlT8G0xyw0jsd//7sf5OOdKCyWZ1pH8vyiWvtje50p
FDQ4pfjx/C0Ppm95NJXCF/gpxYTfj8bZKbBYwOfcze9r1/P63VcvSJ5B4WiA
k3bTFgaNtnGCMDcKS013dOrvYvCaWbvlPHcK5addF6XHM2gQNPqvT158PZVT
FuQwqBw821wPFLL2P9gwW8mg5NzsX0oWUKjb+PHFIxWDn33ulaX4UIg+Wbp9
710Gz3QFn9m4mML4Ny6T5jUz6Jvae3ihH4V3U6UK+3cM/uF6aJeNiMLYbL0d
LgYseshK2cZlFKZJ16g6BCy2TlgkLAug8Ku4peuiL4tJ+NwhbRWFwuyPLlXB
LD4lhv2+wRRu1uTrJmaxuFeZ3Wm3gYKVS+PDpDIW7UWC+sEwCoG7OzRJT1iM
zAxUlm+mMGw4Y5prLsLxwreZx7fy8045PWrj7w+b4+Kl2yhku7VNtQ8R4WgH
5UqnXRQq5iuizcpEePXnud5DoymAMOWK2UsRBm2pd3mxh0KuXXvzCsphYWk/
yYqn0FMakeXrySEXkN4TmcDjXZ6eUBLI4Ued4ws2idevvTLo/U4OFbnquimH
KTR5W9p4ZXG4cD53zTCVwhmDlVnaSg7ftLfltaZRuK3c/OHD7xymJ8uOVB2n
UJSREDGUiHHOtNGy7Ex+vx3FyzbNEGOL9mzozpMUNtT6TS4LEWNi1GxOkkNh
cufTOelyMU63uOcx/TSv/0XbjO4HYmxQBzsNP0shYdDAum+0BPes6zV5fZ7C
/NfFX0kDJGg39NCApoCCus7CTV0kwbp86y5FEYUSk3HOOSP9cduS0gZZMa/f
WtlW1/3++EWSNufZZfr/v/8HlUDBnA==
               "]], 
              Line[CompressedData["
1:eJw9VH0w1HkYN0X3+x4lrlDaWt2WQ7LpKG/nQS9c+P52l7QyqtWGJEok7tSW
Ti9WhQt7ZDrVxu2iGOOclyfiSprInKPcJXr10plVIk63d3/cM/PMM8/M8zyf
+TyfZx4LSYxQOktHR4fV+r/xk/YNiWVNDOj8ZwF4PXybvfg2A09vNUhzukVI
9Uc4Dr8yEH365OPeIBE6xkwIaSsDqYp3XgWvhLikc/apyPsMSH1cr62UC3H2
OsO6E+3a/mXjv9S7C3FQsVhT0MnAMfNZTX9MC7BjZoVldRcDo9b69naNAqyW
rAl52MOA8XKzggUZAixscb0w3MuAh6/vQckOAX5n7d0yp4+BnIwxKycHAUZn
iKa4Awx83NSaMzJPgAGaUL7LCwaqnxi0TQ6x6Lx1rzTwNQMuPnTu2D0WLWri
FTHDDDwpy5w+Xsois1T24PRfDJwza2+UZLH4Rpaue0XDgNvqC7lBSSzW+hTt
755gYPVU11SjH4tF6tIizRQDaZfVocNOLJ4xquk2+MjA9YuGQ3JLFmPjm+da
ziJQMhkXKDdhMain3dNDj4ClKvl+5xwWv3LrPbydIfA6oKdfMUqRd/mlKl6f
gFuIeU3HbxT19caenptH4DOrzB9s6yhqImZMSowIvOmdW5Z1jWJPG/G9vYDA
1KZsv+ELFJG/UPanKYFBTo9i+VGK17K5VROLCaxx7LPj7acon7AZMl5KYHFr
fmdfKMVDIeu4thYE/PoN3b8WUAxGz8DNPALyrpFB0UaKHjz/M7ssCXT6Oj/X
OFP84pS4IdmagO5DhZpjT9FwePfb720JdFfuMG2zpjhOY63K+QSig+P573kU
eyuSQ1vXEsh7nbsqj0uxyTQt65kjgV1uvgFqDsWS5Mw7M04Ehvy57+2WUDz/
pOBvMzcCiyx0dy3V5oe9iu3XAoH0G+KHCdr6UGVluJ8XgWVHipLWa+dt1Mf8
8E0EXnqq4sO0eKti7nXIfAg8c110b8KKonFn15x8XwIDl8NiP/ApTjr2u1RR
AlG3NvhFOVHsU4zEtgsJ0HGVJ/Wi2DIzcXUwkIDN7/u+/Mmfolqi+1hXTODb
FXcWntxOMbvFcP6yEALe0a6TA5EUk63NNzrtIHBE+ejz9iMUJRkrk0QSAgaZ
Kp7oLEVvzZqyaCmBbTp1o4cvUbTb6vYsLUK7nwdHdbdUUDSp8V70YxSB2Qmp
Zx/dpTjNCfCv3a/Vh5t7zrGfYuvzvdWjh7T6xH2MowYs3vBJGPk0kYB/TnBU
lDmLuWrZ8hXJBC4Gc7PybFhMMZIHuacQ6FPtrnvlyqI0PjddLCMwusWpIZKy
6NtTdCsulUBFxNFmuzAW7d3KxuVpBDwOkDo2kUUdvZadjXICTWN8MwMliwtN
bkuU57V8LbxKzRtYtLZs3J2eRWD9fIerzd0suq/HPQcuEthTcpOxe8tigE99
xNY8AjxZ2OYTRgKMDK7d65JPoMu5qvodX4ApUTX7uIUECvXWFjYJBaiUV8UO
XtHi95RnF18SYO2lyoMPlAQcXOaHn70rwPaym4cqSwjU0+LSiAkBPsfyhDy1
9n78agLf2QjxQ0dpYko5gWlPI3uOVIiGA6qksAoCM+fbHnGuCpH3tuQb7yoC
LyQ20hsjQnTSK06x/ZmArJkfIPYQob+J8phxLQGxh9p0uEiEqXd3Tm+pJ///
u38AV2g9LA==
               "]], 
              Line[CompressedData["
1:eJw9lH1Mk3cQxztKJc/NGUDHBKW+xFpFJgpBy0A4RUXwZb/naYWBL4ANaLEb
jKGgtr4wXxAqCDpgSpzyogiKBVEUEU9xRN3wpSJDZEABJyvqmIqZM4F1+2OX
XO6Py33ve8knN2ldvBBjIxKJgqz5b/W+nXk1tJVD0X+hIun1Q4dtH3O4gCoi
QrqV5GXKzv39CYey+yeFbTolLenJyr/bwWFu1MKmErmS1rw5cOS8mcOmlFdL
PToFSpQYCvJ7Ody51Fw1/bhA+5zSj+mfcdhmXGp7ZINABfK04+ssHLps7c92
nitQpWJvYdALDg3vhoQTIFBj8O5i9wEOF89zq4nr5ulJROpJh9ccRowX+7Zf
5Wlg487St4Mclu9J+ElXwJNEv73syV8cjmjIDunX8+SSqTtD7zns7pIYW6N5
CjSmGNM/AJw4vjNnziyevri+uSreFvDESydFoAtPWlNStcoOsPaFZop4BE+7
ehIv+gBgWos5bOVrRrlvEi5JPwKUFSza6trNqFwSXyu2B3zc6OYYaGJETl/W
9TkCzl9y5qmxgdEj+cb6po8BbYr6t6ouMrIoNFQ1FjDfZ3Klaxmj4eD1N/LG
AZ5d3KsdOsZozKqYmzopYJWvQWk5zGi6Vt0YPQlwbezVnJYMRv766FuLpwC+
TCmqvPwtI2Vm5J0ZcsDTN8bHZegYbfhhzc/2boDuGeq0hZsZ6Y2r7g66A57z
db7fkcAo53r4/TYPwIAA01OVltEpU5jpmifgSm2CX+EGRnU9K5uLvQFjL9VL
GmIYPXijbNmvAGyO65BVqxn9JhFav/IFVNz7dPo36xi9d2JtSn+r3qDabyia
kf20Fe2K+YAWzdmpKmt/is+yDteFgOEdRYuSrPM+ISFdNkGAf4y0y1hr1c8c
d23G1BDAjRdhONS6v/u5V3LwcsC48gqHAKu/ufWlN7QMsOycxNb5a0aGLNdR
B5WAKHMaeGa9zxyVE34+FLC+dvbDc3pGczztSlrCAY33Lh3dtIdRhlg38G41
oFRz4bOATEZdzQO+rlGA1zTtl0fnM/I+GbMP1YDJBRWh7wsZpSe3mdSxgM7m
0qLhCkYdSz6X7tMAqqJqjDPqGHm53NSUaQF3JKX4Ge4wSutXXGiKB/TWsgGP
NkbtdWdFfyYCDjlaTsv7Ge2NzMubuwVQ7t33q9rByu+skT0ROsCHYdKa1qk8
zbLZNXP7DsByUe0BsT9Pux8ObjmRCqjOjSy2C+PpcXHcjzf3AOaZPRNGJfI0
c3OnfV8aoN/yMRCcxVNqkGr1hwYrz7Mbx7yq4OmXsbdPzcwCdBwtC2IPeHK3
zHvN5wDalSSbL7+18nylyn/Td4DTPsne9v0EgVoM8vT8fMBU98i2pGUCua0t
eHTlKOCtdwuev9ULtMPDYVLnMSv/sRNah6oFahbt1doUAlbohg/WvBJomunv
GlkJYJN44qZ6hZL0RfHi4FLAQ0fWe8buV5IpqXeFthxwzeQtzl59SmpIkTmO
PgP//5d/ALBTAKc=
               "]], 
              Line[CompressedData["
1:eJw1UwtQlHUQP5Q5574/M5g85eCOO+MRyiMEDixyeT8U8f8dESHQIA8BkRPu
pBjQk3QAHejKI+EaECjAR1MGY+FcYGugCYoERpGEEpq8lOHCORQQ+2qmndnZ
+c0+Zve3u5K9CjZjDY/HC+T0Xztlpv0juJ8B3n8Sh4XK6cp5DrtJEyUR03K8
GZoyYjHIwN1tDZZFp+ToaH1nk+wXBh7mn52diJSjajJCkfgbAxnn5+fjBXLs
vdypP3yXi6/6fPnSIIuik6/zm8YYcLDpiVU3sqjc00p7xhlQHaILDSoWb2wR
1k8+YOB8m298eAyL9quaKWaSgZ0DYeKh11jMHzD18ZhhYPZW/IfXBCxebyxS
0ycMFEo8xZ2PKdoVzPWp5hnwURo60ocoKkLSrGsXGPD9IuuHEj3FHsuR1O+N
DDhat0r7mylufLTzq3vPGRDYjc24fEIxr+PqM5MXDDi/ZyzMVFP8scIv1IlH
IP7KT5IsBUWbxC81kWsJlGsqZK+kUszd7Di6n0+gVco4R8dRxJVqZ42AwOGJ
rb+vRlK0ui0oaDcjcOWlPEC0nWJOw5GuYXMCVHmuW+dH8YnDo+HuDQSudo9t
HfakeLAuZq7NioDrQJjI3Y3igt23/EZbAtPj/JLPnCgW6uzFHwkJrL+YXmYj
pfjc5risRERgMjP4TIOYYsnp2dgcCYGv8576e4oorlrKsxJeJeCj1Q92O1As
1eqPhrsQuH5z3/09nN90g1Tn40Yg1Xai38jll318ok3qTsCkMmy5mqsvMDf0
rvcisClQe1nmTLGyKmFi1ZvAd0GGmD+5/szNcOmxL4HTx+rXfOpF8dRJF4tR
fwJ1eMf1HRk3v0CzufcNAsW2Ag93bv7acmNIx1sEXorXfePA8SPkpyS1BBG4
79RY48VSPHP8mkobSiA63BCgSKYoWeteVRpBYEGdX/owm2JzaXWLIprj2/aA
Y/37FF14K13JMQTM9jMDZ8soXjiS9uuO3QSqk+tqrGooXiz2XucaT0Df5Vue
20nRe0kntn6XwNKNdufyQYqXPjDxN00iEByzJMyeoihbzNr9dwqBjtzlPj8T
FvWHfs4aTyUQlxMlEdqzGPhUVno7nUCLZKNjVACLWNCg69xHgDG1+OtFAosh
Bn77hRwC22ZWMo4Vc/epyOurPcDxF8z38GliMWpueKLsIIF7/VE1R/tYvJUb
uKxScvvZZRtmXGQxdrbZIq2QwJtQ4bTDTY5D2WZbaBGBHCryzNsrx7enlKHb
SwgoHiyONjXJcSRzNMldTaDJ5Jn1Oe4/84OMu4wc/v9//wE69qgc
               "]], 
              Line[CompressedData["
1:eJw1kw1Mk2cQx0tlY/F5pk4ZaWA167A0ITAsyXBLRS9TO0q2ked5wcgIiAYj
Li0NRUKWRVgsaMoWC0PxA5PiiMIgAzdGV4TCVUFGx4daBitCYA4VJSAIMvne
uyW75HL5J7/c/3K5Uxw28iNSiUQSJea/1eTnrtv/PQHJfxGP5jsT7rdrCCzU
nox29gn4apzw14ZaAu2ZxzWp5wW0dN9YWr5OYNJjmis8JCD9+B3/iXoCCnfV
4WG1gFa3JcxrJ3BpSa1O8BNws25mb0cjgdFST2LEnxzPdRxIbmgmsEE+H/Z7
C0eZFrMrWgncHUta7LVxLGtTnSm+KfIxTheaOW7dY72W107gw5ZR42efcyx3
zbcYfiXATDtuJwscgyFlIOk3Ao2Dxw6V7uI4+JZVo+khUBC8u0cdxrFoodUW
eJfAwZWKPlsQx4/6p9ctegg01fgG3aIcV39SpHv7CRy5mNNwco1hg5V3ObwE
yqQ7szpnGer15u0Xhgj8sVjFCp4wDNb9fDZnhECLc5VUjjIcVD58uf+BuA/J
PZfCy7BYGpAc9ZBA6qOjdU/vMYwZ0breHCdA9KfmXnYzXGvKUb54SkD7QdDR
fW6G9gtVlr5JAtIsl9HdwdCQ7Z2snyYw1lU7Zb7NcBtfz0tmCZgi51RGUd9/
V2M3zRPYLY+zF4r8t0QfyBcIpByk+f2dDHXjl3PVywSy8x2dgugnae9+sGmN
QM2zos2viPP8cmVVO+1D4dONI9qpAYYZuRE1vb4U8jy2Zv8Rhsqk1I11fhRu
Ncri8h4zHNpRnHVmPYW67/blRs0wLPG/OWB4ncJzS9r5vcsMY2eeaz7ZRCHd
mjDe8BpHn57g8rAtFL6UyiQXAzg6quN9aYDYLz5jbVXJ0Xi6IH1CRkH/o31l
KYpjSJq9yx1EwSfk2OlKHcdheLy9eisFVcKlaHkKx7Ny2TmLQuSvl5WfOM4x
djFmIX0bheEfnFuefSP6DXyRHKOiEBo6H26rFP3qq12qUAqJT1qz2to4ZhTd
V/qFU9hpsFWUj3FUGmjhowgKpX9HeszifQ7poqfaIyngictNd8IFLAnJ4Fff
o7Aya3NLDwgYu85mz3+fQqMzc8J+SkCf0d7ANA0FeeLXVxw3BHQ0S/L27KKQ
VJSpC3ghoPyNrzqaRf3/P/0D9smXnQ==
               "]], 
              Line[CompressedData["
1:eJxFUnss1XEc/YUkfcptMylNMTUpU6HFXH3IVAur7w/TA3kriSt5TjWPG3XN
rsU8cyukoXZXuGPuPubdSEw0hm6aPFoPj0rUuvVPZzs7O/+cnX0+xyQwioVo
cBxnoeZfrbiiaMoRAXL/4En5TtG3f6j9ibzzqa++8+RufP/TcCygc177du92
nrRW+llDPOB4nbKstICnpmGNhvwkQG1Bql5rNE8xz62N4lIAj/daVRi682Qu
Db7hdRPQMyjUcIslTxOReZM2aYD2/ZsdeQFPQ7pCKRMDHuRadEMXGfU8eu8Y
nQW4M+KG3Z1RRq0uko/ZEnWebOOm5HZGjSrrouocQImrYP2KnJH8+uix7lzA
oYRk81EZoyqjtKWpPMC22KnxBSmjMoXFQ61CwACnSYlZBqN8r4FTpiWAk0GN
PiyJUfZ84u8jZYCRpvpuYSJG6TkmNb4PAJ8tpVSevsQoaV/3meQKwHvtSh/N
EEai7uh1hVWAoBkuEwUwCg81rKuvBrQKkjTf9Wfkp0mBg08Az+7xVoapvZcs
TDAvB1zMKPCdvsDITain1KsD3H1ROm8QzOjoSH2EpQIwwYUTfQtnZB/vt/Vk
k/oevDRREsXogL52Z7hS/Q+9hGRVPCNzeW2suAXQ8bLGDJfKaIeHl2l5G2A8
p5O6nM3IYG61r6UTsCgkUTFWzAgyy1MmXgB+zTSzbatmpLnLbe+vXsA+Z4eM
rmZGP1sW3mzrB6zxqF7dMMDoi1+x+PAgoM8hh/H6aUYfVpxtvIcBS7q4d8tr
eBovmFVdHVH3V4iFAmOeXtvm5kjHADM6ZIHOQp56BuyET98CnqucaZvx56k1
SjXbMwk4svazaZyYp0bIKpidAiyvbTa6JudJ/ni/q84sYMzLXr9SFU/ptwaW
O+b+7/EPBYs2ww==
               "]], 
              Line[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAANwOmR+8pDUAAAAAAAABUwPCJ8IR3
Kw1A+sdsNAXqU8DnJpgylS4NQM4r9E+2wlPA3sM/4LIxDUCce1brDKBTwNVg
543QNA1A2aU6anaBU8DM/Y477jcNQPf0lQeAZlPAwpo26Qs7DUD1aF+wzk5T
wLk33pYpPg1AiM9+Xxk6U8Cw1IVER0ENQA1DDB4lKFPApnEt8mREDUAFZlQf
whhTwJ0O1Z+CRw1AvBqcockLU8CUq3xNoEoNQJd7t1ocAVPAufUWyIhNDUDY
CNcBIflSwN4/sUJxUA1A3ZxERv/yUsADiku9WVMNQP3pybqq7lLAKNTlN0JW
DUCLirY6GuxSwE0egLIqWQ1A1LQRqkfrUsByaBotE1wNQA1YZMsv7FLAl7K0
p/teDUBvrsIo0u5SwLz8TiLkYQ1AOfvUDjHzUsDhRumczGQNQOedmZlR+VLA
BpGDF7VnDUBalI7TOwFTwCvbHZKdag1Ao7P06PoKU8BQJbgMhm0NQGZpDHKd
FlPAdW9Sh25wDUB286HYNSRTwJq57AFXcw1A0i0o39ozU8C+A4d8P3YNQLya
OlKoRVPA400h9yd5DUADkgXxv1lTwAiYu3EQfA1AVhFWnkpwU8As4lXs+H4N
QFhP1/N5iVPAUSzwZuGBDUALfcRciqVTwHZ2iuHJhA1A7bWP78XEU8CbwCRc
socNQArFDVuI51PAGjNLn4iJDUAAAAAAAABUwA5q9iA=
               "]], 
              Line[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvVqq2fjjVV4HBjAIOdA0KcvL/Bqvw6Qvf3y1/wYf
WH6H5aj8TV6Hpb9KQzc+Cj5wRm2+PccdXgdhM4YpZaeDD3wssNz14R6vg4XY
EwWT7cEHxHZfNrn5kNfBONN634alwQesWfPWH3zC61B/J0po37TgAwn+HFqr
nvM6/MlYP9esK/hA68xFSya94nVQ5WUz/1MffGDVYxv56re8Dj7cvK++lQcf
OK97fWbyB16Ha+W58iJFwQe+lBeK+HwGuvdC/1/XvOADkoe4+02+AfmcGd+a
coIP2PEs45T9yevQtSa96iiQnxzm0ML6h9dhT3f9ae784AMdC279e/uP1+FN
it/b8OLgA2telVReY+RzaHWr3ri+MvjARRP+L/tY+ByO7P3/QKYp+ICZvcKO
p+x8Ds90l+qs7A0+MMvTsIaHm89Byjuy88Ls4AP/g50cjPn4HK5Mjc3ZtCb4
QEpcMEuUIJ9D0Lfw12UHgg+czEg50SDC56DzOb4i4HrwAb3i0p7l4nwOxWvW
Otd9DD7A8LOIz0CSDx7+AI5asvQ=
               "]], 
              
              Line[{{3.81058158486345, -80.}, {
               3.810791124320506, -79.97055633877497}, {
               3.8123299081282966`, -79.80222516933871}, {
               3.8138686919360874`, -79.67973258124746}, {
               3.815407475743878, -79.60158471623667}, {
               3.8169462595516688`, -79.56678185266651}, {
               3.8184850433594595`, -79.5747755726298}, {
               3.82002382716725, -79.62544531840481}, {
               3.821562610975041, -79.7190922869899}, {
               3.8231013947828316`, -79.85645013314662}, {
               3.824313335192483, -80.}}]}, "Charting`Private`Tag#3"], 
            Annotation[{
              Directive[
               Opacity[1.], 
               RGBColor[0.922526, 0.385626, 0.209179], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJwVj3k81AkfgL3jvkoNmSlW7LgjUeMIX7lWJaXUxrLLrmNRobRTKjnawpYj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               "]], 
              Line[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAomfwmfVt/T9mFh7Enn5FwB7JhfIh
HP4/xF3/txFnR8BoFca1UyL+P9HEgZ03eUfA+q1GPLcu/j+pO7SrrZ1HwB7f
R0l+R/4/+cWLB0TnR8BoQUpjDHn+P1RT724jfUjA/AVPlyjc/j+yLQJV/LNJ
wCOPWP9gov8/z5pg7q5QTMDINX5cKKj/P8PCSmEqZUzAbtyjue+t/z93RSOl
tHlMwLgp73N+uf8/NdCFyvWiTMBOxIXom9D/P9mPEbor9kzAevmy0db+/z9a
Wwa2b59NwOmxBlKmLQBAiVWlEqb9TsBBHGEkHIoAQKqu8YWr9VDA1K9qHD6N
AEBU1OEB+QJRwGZDdBRgkABA7oX87FAQUcCMaocEpJYAQMe4dDEgK1HA1rit
5CujAEAfKC9aPWFRwGpV+qQ7vABAbM8YdnnPUcCUjpMlW+4AQMuGGI40tFLA
4fHijeUxAUAAAAAAAABUwJ7dsAY=
               "]]}, "Charting`Private`Tag#4"], {}}}, {}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PlotRange" -> {{0., 4.605170092005027}, {10., -80.}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
            "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               Opacity[1.], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Directive[
               Opacity[1.], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Directive[
               Opacity[1.], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Directive[
               Opacity[1.], 
               RGBColor[0.922526, 0.385626, 0.209179], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Exp[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
            "Primitives" -> {}, "GCFlag" -> False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            Plot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{0., 4.605170092005027}, {10., -80.}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0., 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[2]], 
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Exp[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
           "Primitives" -> {}, "GCFlag" -> False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           Plot, "GroupHighlight" -> False|>|>], 
       ImageSizeCache -> {{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}]}, 
     Annotation[{{{{}, {}, 
         Annotation[{
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwVlmc81Ysfx61cMpKVGR1HyiiRVfLNvCqFSFaFomhcKpEyKjfjllFGpSsz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            "]], 
           Line[CompressedData["
1:eJwVV3k0Ve/3PueeG5IGpNInRUo69+JyjRnOlrFCkiRNGgyhlErlE8qUKUIq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            "]], 
           Line[CompressedData["
1:eJwVlXk01dsbxg3fIUqDKXSTVBoUzvccxxjvOeYS4qBQuobIUFHkCkVR0kCm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            "]], 
           Line[CompressedData["
1:eJwVU3s01fkXZYrv59uLqUGqKSWvSknf772u63Jc7/JLQ4kYiano5ZG8azCK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            "]], 
           Line[CompressedData["
1:eJwVVGk4lWsXRuTs560UJUVIaSPEFu9rm5Yhc4NoUMYkihBSOggZMksqnaQo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            "]], 
           Line[CompressedData["
1:eJwVk3s41Gkbx8ckev2eSgcSRbQOiaKT328O5mYmh5qyO6FWSGfKqVeUadF2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            "]], 
           Line[CompressedData["
1:eJwVVH081fcXl9hanG/6zUNLHhMiuclDfb73ci6i/Ag3Wh5+ktSw9WAiLTaF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            "]], 
           Line[CompressedData["
1:eJwVknk0lXkYx0VJp/q9E2os05UkSwuXm/C+132unaGxJm10FSnLDUnJHEtk
m8ThSiNkCslQqC4m85CaJMmSpEzE2JtxhhmcLHPnj+c85/vPc87n833UBcEu
J6SlpKTcJPP/XvDesI1jS+DaxvD2DncHvKic0KpgT8DuTdMLE8Ye+zWy000d
CVQZCI22Kdqi1e4S92NOBARZTmXORdZYalyjnOhK4GiVhfNophUSixd95fsJ
5HZGN0vVWWKo4/ubbzwJhLLd28xkLbHHY/LEwmECvVfv9WgHWCBXsKij4U2A
CZurNxw2x8IA8qedD4GZgZI+aaE5rj6nVin0JWCQF38tUdYcA2L0w7P9CfCT
4jJSi/nYnsI3rQ8gICceKjnuzEcjkcvSUDCBNSxFXrM0H68X+DSuDSWwjs3R
rKkFXC4NSzAIJ3Bz5Zn3vhGAxx/E23ueJ7DJK6ZiBw34/FcRib5IgDx6+dP3
0oAZXWJRaywBL84zkaEpD2d/bz44E09Ap9GX+Hw0w8NjvSzVJAJBt8Xf9Ceb
YcP0xCd+KoGRO33AYcxw+9JC0ck0AqIdw5rzf3MxRY6cTsuQ8FTOL74p5+KU
vJrewywCSUVZJ6KCuVijxX8kk0vAtmwwVnOJQZaBS6RuPoGnSY7ihy0MxjI+
POdCAg5jKafZNxgcsQ6TibhNILBPd09gCIMOzvG/5ZUQ2GBzJ976WwbvHxKl
PL1LoMCkQjVPi8FNvsXfTZYTED4WXT2wmsFIoVhBoZLAqtno2SPjNPZfaH5r
8kDSv8FcSs5rGq3ie3/0FhNITa4NnK+hsTRtwutyHYHRH574BRXRSK4vaJTX
Eyjdub5hIovG0FvrR7saCBSeatvol0hjTzmr7EsTgQxlG+OeKBqZGj3h1ucE
alv4SibhNN58Ahy7FgLlfb334s/QKPvKeS74FYHstYtf6oJpzDfaKZfYTgDv
Li62CWk0zpdVKugi4JofHFUdRmP76gEt8VsCPtP2yoGRNJ4S1u193UtglzVv
3/IlGmXeZdmM9kl8NVbGhaTTmMsXekgNELgvI816XUAjp9TeT2lI4m/kpEij
isZWec1z+iMEpLPUci48p9E3cjnBdpxA9aSX7h/9NC4NvhN5f5b8a9vezrML
NGY7VBdFTBHg1Fu/5asyqP/gysOr0wTObnkZdozLYPNm/2cl/xKIHmvUnxIw
KEiw6MZ5yb0cDnt9KoOZHnP/TC0TCBPXusWNMbgLO1atkaGgv0dLic3i4jPt
nzeqy1IgFEpVfO3BRa/0y5omayhQ1itOFmZycW7+2B7ndRS460X2XuzmYrqA
sfKnKAjiq7xK2GyGui2b3GPkKbjGprcM+pvhodyWsPtKFOSwq/22K/JwZmXR
pWZVClidczrLITxMDYzOHGBRsMvmxl3FdzzU7D54a16dAtPvG3xTNQDrzfZU
b9CkQGWgTOOvo4AexVSTjjYFvA9SSfr5gFPUeCd/BwX63EcfRocAkyKaBj13
U2D5laWwQ5+PWwfyps+wKRg39onqiuNjnd15mWQOBcYrWn6R/8hHt0pXhcK9
FHw6OHNqpaU5flbZrVFrSoFBytGg7GpzTIiTM+zgUrCf3ck5aWiBapOfzMeB
grHhxVFWkwWK3R67SFtSMCGgihQDLNHpcbZAxUbiZ3LfizRDKxzTDAkxsJfw
71cz99G2xtgrDrH2jhJezxjjI8dtUGV2e4bAiQLf1IrWFep2WOW1ovCCKwWz
hoeqhuUd8IBRiekdSU58YtzNc3PA/wCh6VoQ
            "]], 
           Line[CompressedData["
1:eJwVVHs01HkcHa9Ohf3+jjwiZWqStvfjiPL7jc+M8X4k5Fkh0kYdj0nbpkb0
IDIeu0XsRB2WJYbiNFH5oOeOWCmlh04j4qjxLJJdO/vHPffcc/+4f9x77tK9
0V771Fks1nYV/mfBu806lQEEeC+CZt7vdEPRpayO5l0EnLqc2y87OKORetT7
V8EEXhdl+G0+6YjVkfajY3sJPG78KXkdOKBzp5madgQBTnjvo8vO9qiwmaY4
BwhMNUujcpIEmFD8jG1zkEBmjci+vtsO9XWlG7yjCdTl1ybnONthZfw5iIoj
MLI9+liRnI8OPWGep+IJXKubjVy5i489DtyQgqMEfjyUOJI0xcOfpQtjbiQQ
sLFpKb55mYfUwvFEuYjAK29jsbs7D8tOPsnsTSKwdosLa7EGD3mDpYXfTxPo
M/quzjQCvtqRLF2QSiDONXjP2ElAYf2uxtXpBN7iYHKxI6AOx6rdTkxA8gO7
6LkeIHdiSCn8jcDdTms3QaQtas2/JffNJbB6jqXWBVNbbDU7W7Y1X+U3+xgm
PuPir5beZ0wlBATnh3PLsrkY6MreO1tIQPhxU0iLNxeXhn7mKq4S+FI8xE83
4eLAkfpF90sI6PopS+71MSg9nzJVWkZgok7b36aOwSNXfZ6nVRBQHuz9vSmV
QUa29PqhKgI+1eyw9SEMarYpxZ41BD69JpJQGwblvQ1Rm2sJLBM61m01YTDn
W6qT4U0C4RYJJpIZGgOIr/m3WwQO5uf3HFbQyDbnqL+5TaA1c01EpZzGj9tG
eu42EvAS/mK+RUZjleedhivNqn6leQfUymiMj0jLO32fACvz9WrNAhrp437x
+x8ReHgxXGmZTaNGznIvFzkBnJktykqj8a/S0XVr2wj4GWRkUCk0Zt+5q011
EKjvSnCtPUujf2f6wFgngcSLpP74ORrNBv3vP+8isOURX+1QJo39/5pflXUT
uFfseSktj8ZK/XFRwRtVv5N6AW+LaTy8CoNE7wgMiDPSo2tptIEM61AFgZr+
9boeD2lU9w00EPQROHwqLTb1LY2PoyzGVgwQiB2I27RxksaspIm2eUOqvKfd
g7v1GfTLbar49Fm1V8lwroUlg0sqxantIwQgpHCyPIDBvuagfdfHCfw5NNI7
N5nBay9X8i98JVB6KaMjoopBofLLkqPfCJjtTwwZ7mFwm2bL98AZAu7/7Nbu
XMBFNZOsl8wsgVu3s6ad3Ln4IbcqkFKjQBetNLPSuVhRmWA1rkHB19Z0Wb2R
LYqtFSXhWhRsY1144xFhi3EtTvpdcyiY46O10bjBFn09pMmOcykonFDOumoD
bu02GJXNo2Bec5OXlAY0DT8evEqbginZiWW6cYCsYcWTAh0K+vNPj8srAB9q
VpeLCAWcsMj5Met4WJ5paDxCUdDuPDstOcpDscmJlFA9CjT8aK2/H/MwrqT3
y9MFFKT6NOmyOXzcucElXGBAQYtAcWPyDB+tG6qf1hlSkLg7OGTjBB9NHYx4
FgspaIvJFrnF2CGr44Q0z5iC29X+0y3/2GFv0IfF8xdRUHBMwv7jigAf9Luc
TzClIIyzZvRGmD2Wx9ZMf1pMgce5wQmZpwOKZ4wO7DGjoDX6yaKVqj+KTRG9
aGdT4G1hJb623Bl99Prsecso2BG8VqjT6YpTD3QaYlTaY8XcaU8fN/wPHqpF
Fg==
            "]], 
           Line[CompressedData["
1:eJwVk3001QcYx+/uNmYmz0Qa5ziUSnNdipiX3+8+98VL11WmEnWndlEWXdfI
e0rn5m1RIR3EzGKi7nqjl5vjGS1Zm7eUZtVIEs3UFCctdvfHc54/vn98n3M+
z8dGERsUyeVwOBLd/L+V5b3ff70MsDduocPUJhlxKz1sl9sBMiFHtJsf+ZJe
rvxS00pAZVNM2NmDPmSQkCH1tQfUS3buOpPhTR9tq3rQzwNsuqjx4Z2WEEhb
VVF8QIX44vsBb8W0cM3jd187AhqFZ/JkUWJaZK13PHcV4DM/txjOqIgsDO0+
tXAGHBDZdfjsEZHV9NrmehdAD/0WS1cQkc1QdKCnK+BJVdweTaOQbH/NH77l
BnjfZM3Eoggh2V36MVHuDnjWhl/pYiEkXnWPwYQHYJ0oZTn0IznmT53Y6wU4
6j/+ZLgUaXWymdMCVnev/O9WYwWSa7hbW6UA8Lj8RTw4InmsCw12FAKeEbcK
UzhIjHvaWIsI8OmAHT1sEBDaVqQHSgBlYwOjsjABSYxbjIe8Ab2c8wa05gLy
mx2sjvMFDBtfPdPcz5L/CNeVuxZwdaz1s1cVLK3rtu0olAJmqTV8010sBWl9
5EtlgPVWbXp3PFkKro2avBCgyx95TsyZsBR6NO+AZD0gzyhI+uUkQ/L002Z3
AgE37y5Q3u5maPvOzrrIIMCa4jfkfImh8KDnntMbAA2X+i/eWc3QDsakK2sT
4IeaZ24hhQztsnNRmG/W9RV0Rs9kMbR7YfCrH0IAC7nzrMd+hlRzSTmfbdHx
mJFKLTMYShgrtezYCph0l/9JmS5P6tNqQr8AzPcysNVmM5Ta8kA4HgZoX7ft
z+wihjLq5/tStwNa1jQPLjjJUOYxmyhDBeBzx0yLiCsMqfeL35SHA05Kf3b6
7jZDOdGRBbxIQP5cxfjIPwwdCs62ad4BOJb58fUQc5YOC09dDIjS/afZT7Ur
hCwV8m75PvwK8Lf9K3tyVCyVmE8MKKMBf696Oa2tYamMa6ycjwEsdxfXGQ6x
VDHh9M4RJeCF1r0mXUsEVHUvqNhaBSiKqHWOiRbQybaEFefiAO+KllVv0Qqo
TlNyVRgPGJ321zdFBkgNpZcDehMAY/Ifc665I2nUA4OKRMDO0prLuUqk87H/
xk8lAcpP7UyNr0Nq2mKlr04BVL9wMTZ4inTFG8tM03S8ntTEzToI6ZqTwqEm
HXDfiF6vTZqQyFJNazIAXy5WDR3tFtJ1vdoNN/YBDveobtY7iqj9RfuT4EzA
lsrDo+5lIvrl/ljK6AEdv5uZXQ0mYupsNzRKVuv8uN70bdgJMfWcd6j6IAtw
NvW9zlVeEuqrWO9cmg04rj0Ixa8ldC8n7sbKXMDBkgD9c4Pe9Ed8UejVPMAh
+1z2mL4vJTbyNzgd0vkQa2s6lu5HMNMhq83X+fj5CL+xUUpvJ49s3VgA6Af8
JREbZfQf2DLkoA==
            "]], 
           Line[CompressedData["
1:eJwVk3801QcUwN/8mjqcrjB7G2/VRvlRc6gx5vvue34ev2o0P/bCM6MXq0R+
5qgxauXHZIhCpdLy3qE9jPzoZuEJE0ok89sx+XGWZlOWfffHPffcc/+4934+
52796qhXqBKHwxGy8X+Ovu/j4JMDaJp2I0TNx50S//3EMjkXMDogQs0pyYV0
+H1mL38ELIismJ7a4EyVpw4bhecD5nI+Try54kiuLepbxgoAY3MOj4j0HWlK
+RrXpxAw1NbfdpvEgZId+dpdRYBHjhkEO/XYE/f0Uw3hJcDUwCEtnps9VSti
1OqKAXlteda2T4TkuVGLs6sUcFv2cZX0SCHNuklXyy4DVjO+mqQjpNRM52Xu
VUDx7KFa2xYB8Xom5rPLAE9/9LCgMk5AdZA8o3od8JsNFePc3QLy8uKOnbgB
6Kyvuk+2grSQWz30ZzmgisRQ734z0pnHe/sP/gR4Nme4YuAc0ja9510jtwAv
vlThxQQgNfqlt3lLAd9UeuwRWiL5Fm2lDhmgJNGwY0kD6cVwYz2/EvBRyevl
uEd8yjDwk9dUAWqH7zL4PY9PRkHLUtOfAU82yvLkAXy6dznrxhU5YFWvicNN
Uz4dmDC+rFcDuBh8PTB+naGVD1sLM2sBFyqs2ucGGfohVJyrXAfITJo19/zC
kGn564yEesBjGz8bXL/IUNtsfvrSHfaeTK6ZKI0hsYnFqdBGQJl7l0wRzdCr
iO6E4SbA25zrVXsOMpQnk0R/fhdw/OCls3lBDJkvKR9uJ8BZifiL8QMMPTAv
DbNrASzZVPhAj+1/HWUjlv8K2OiiYmMXxtC6/LG/cSvgvFy1UBTFUNFfkd6l
bYART/nSlFSGdltpeOgqAF+NdrsrChn6Lb7c6VwHu4+0t9OlhqFDd4T4Vidg
SK1P/PYBhlTWRj6N6wIseo/nkb3GUIldguVCN6CnYqZbvoNP1id1dob0AN6K
8ef1fcmnfqo0GnoIuMQ1E1vk8umIktuWvX2AnbpV4cZ9fFJ3mOG29gNeuGaW
qMn6uZr2rbbtY9ZPzZPtzRZIdu36mrcHAN+PGn0ZwfodVK9T2z4IePfenmlJ
BlKUqzeneAgwrEql/h1C0shYXN08zPKz3dE19w9Seff3y2eeAdaUNjhHWwlI
uMlw4c0IYG91tXVgkoCe7aOZ46Msn0Xzo6kKAcWeF43NjQFaccpyXugLSevR
ypB4AjBrPLrh7RNCkuqe7x+YBDTZryE7OyUkJ9+d3e7TgE2xks5RkT2NXVC0
tcyw82xK6/2m7OnE0xCyngXcvB5WQSkOZN45GVT+B6DdQP6Evw37fw0h67rP
AVdbtLONuU5UKJ0s+W4e0PuDMN7fFs7kWRzCLC+w/FKSFkVVLqSUNTkSvARY
eaUpqXfNld4dj/FfYOtwyxrPhP3u9B+t+/UN
            "]], 
           Line[CompressedData["
1:eJwVUntM1AUcP4QA8ZTfFw5CnsKCQ+Shx2Mgj9/3d8d5p9BkQHpTyHvAoLkU
b/LwkchZZyeNV2CFhLdgIsUGCEFjNb9ljWVxgyQWGnX3wwJlpOGEwCO6/vjs
8+fnGao9mVu8SSAQpDvwP9d9nip9ssRg4A8h5oBD2TSZM3s08DmDwrzq9v4K
JZk43Ysryww2twZk9gsVlCGZbV1dYTD446Fo/b9yWgrT7S1dZdA/55FXl1hO
N7xnp6fWGIwb29e9uyKTjrrozsjtDJ5LrVy59buMmOe83+A6g+I9TZUDhTL6
9g/tF2EbDMaXjPlYF6RUNcUfbhQA9q9/2Se5LKWYUe3KhhPgrscGqoqREj/M
Xz3hDFiWECbaOsPR1ZvapBkXwF6dubanmaMDH/E/Z7kCZj00cUfyONowactH
3AAxuW8124+jwbO8aOdmwM3C8QKeRyo9rh38wAOQdictt9xCCizg81yFgCrj
9YE1I9JEtvbZ6a2AMZdkQUPHkIzpfNPsNsD5jq5vzqch7Y3VSnIZwCbDjbc9
g5D+CuYnCABz7PaLKU5IHZ7aU3HegIV37y20TbCkEvBMuwiwrzXBKa+LJeHf
mj6hL6D+wpRUdYklstkOnnsZcHqjY/FsMUvlP2mePPIDFJb1KN5/laWoO7Y6
lT9ghthl0JDK0m8DmtjRAMDWuttO8XEsNXXaxhKDHP380rDYEsmSokXzZmcw
4IcHJeOdYpbs79iE3jsc/oxPy9XRLPVVaHpqQgG7TZeDJpJYKiqxZT0Nc+Sx
SNtdFSxtV2kWXn8FcHzaY9ivkCWL0nZlLBxwtH7OJD7DkiFFE5UmBnygNe8v
uMZSUpTt+08jAX0vjoQ+vsPSgr/mje1RgLmNhUWez1gyb7G5v7sLsBReGGtF
SPl29c3laMADXNCRmHgk90WrojjWodcRUP3Ja0hfzajn7sUBDujCS6LOI+kt
VqN0D6CXe/1nTBdSxG11RL8EsMNZPNQ7hXS/1/pdSAJgiKqYO72Fo3qzurgu
EXCkqvIlXs5RZqPVZT3Jse8mPbQaOfqnRt15PBkw/7Bbs87CUY/eKrufAmj5
MVmZHCwljU49q0wFfG/J561DlVLyzbcahtMAE+ZrhAUPpHQ3Ux0WkQFYO+cc
XpYtowuJ1q+bWcBT2yIeGsdkFB+h1jhzgCXBDW2T2kya97UK9FLA1PmGyete
cmpzU5utMscfbbwP/6ecylTXik7IAdcN/ietHgqSd09F2vcBSgJFx0rblOS/
BosmJSCP6p3pgVnUL9rxq+t+wJaC7uqG/Gz6D2nyqg8=
            "]], 
           Line[CompressedData["
1:eJwVkX1MzAEcxm/nrk3YfE1GXpO1qU2nS5To+7tX5TZdCrtGFo1iZYY0V9SV
16tpTjVJo1AXuhQlK1/uKl3jOmXxO73p7dYhbykvi/PHs+ev59k+z+MRmxQR
x+VwOEKn/jv0zVX/LQJsyhn3VmxTkK5sBqstBiyK3syzSkJp/0/ZNffrgJFM
b9TKU3IKDsuILbsB+JB37JurWEZQ2OAVUAqYZkgI2hsupWHH5KjxJuBI4k5c
ny2h+mD/SuVtwOwPcQMhDjF5DdrfmsoAT44ccE1JEFPuhSLeOr0zrytN0v8S
0R+/CN+KCkD+74AFDwpEtJ91US25C9itll/aLhJRZ/rjzNx7gJMbLP0D4wyF
rDxUyTMAfmla4TnnPkP69hVschXgGtm+zIGjDM07/pbnuA/ofnj7ZA4ylLE0
x3dXDeD61EDeEWDoY7NIZX0AaJ7ecALsSDsSJzIltYDS0fh3U0Ykk9udyto6
wOSoE0dHSpEEDbtZ73pAxZ78jtPnkQr3uvGvPQZMLfjgdusIkstMsy80OPnT
S8YW7EE6XJ2mymwEPJPS5fM0CqlHJcyaeAK4enxTvkaBFMq1VyY8dfIbXYKV
cqSa8qts9zPAuvGOfg8Z0jKlkq80Aco8+G3fNyFpJ/kCUxNgS4yuvH0L0kRx
vWptC2C8rq7NqEKKlSdl6Z8D5i5szhiMR3r5ydOw2Az4Z2rIrExFCsp7w15s
c/7Brd7ofxnp5oZsPu8FoHgif9+TKqTZQ4wg+SVgfU+FRtiBpNb+UI1aAP/G
fR3s/YlkF1Zk7bQCdm5mlnh5MRRpizG0vwIMSa8OS9vBEGXMtYk7ATVSy3t1
LkM+3q382teAU8e0FtbKUJ41VeDdBcjhOCyn3EXETfGLLnoDeE6/+kv+QREl
LhvJms06+wIXud5oFRHbUmjQ2ACXc3N2FQvFJEsKt/1459x/VeNw2F0xVc3j
uyT0AKZ8nt56MkhCixofCbp7Aa9sDPEb65PQ2bjE6PB+QOUYo0kvl9L3mZ6n
je8BdZ/q1BElMoqp6TIEDALO35rXHOiQkzlaaysfArxgN/tPM4WS1HP5ub5h
wFsXZ42ZIhX0D269hZk=
            "]], 
           Line[CompressedData["
1:eJwVkG0s1HEcwKU/dy7R7xc7hLAoYVxuWiW+/7ujSJRKS3d6GiFKnRqdXNfD
ufWgUojJSLWih90pGqYvpVK9KFTS1RpFHsaYZ0Z68dnn1efNx3H/kfBoQwMD
A485/rt6rOtoezeBEZ/E1IMRIZgyEaU+0UugqlXOa1kXhL+LFmu7+wj4hA4s
eHN9A27Z+Pa7tJ/AD6v0YN/oQKweSDP+ODDX84MUaYoAdMkVCMSDBDLI/Zq9
tRLM8uvcXTFEoFmdnvDJQYIzf/LVrsMEnLb2jHTnizHucpi2YISAMrl39cXl
YmwRMnrzMQJFsrII75ciBP1z47PjBLqu+X/Yd0iED88mCkYnCKzQvu/0sxch
381JGjdFIKFUqYppY/FM0xe1fppAvKlnzOtCFvtTL2rDZgislWeymngWIx1B
Xz9LgOa4VRquZ7Hh7bCxzzwKhX335z+xZNEr6YHggSGFv0Kb247DgAX8KKkt
Q+Fx0+cZphXQZm29tsqIwuSxQaitBcyTunB2cSj0mXwrLykDtFJekI5xKXhk
zg6qCgFzivu12TwKLwq+xK/OBbR4Fc4RmlKoy576qcsGzOqskDYtpHAnxOzm
UB7gIpMluiRzCqdLMYi5A3jFTckxJxQeeYryjJ4CmoV2SB9RCrcag3Y6vwO8
lLRBt8mCgrB08YW7nYC862WcHksK4ZwbJ3+asKh5Zi7T8CmUqHh8sZBF41a5
zsWaQrF7ldvBGBbPT37lNNhQyCrf7sstZpGx85UdsKXAq78msvkz99O/SDfP
nsIvhx2xbd4iNNjPcIuWUtBfVWzuzRRh+rlYmZ8jBbvD771V4yKcvvdBp3ei
II/nMqVyMSoavbiKZRSuPjV1bWQkONl7Q2btQsH7mESp0EkwxWxCV7mcwo41
ZpX7MgJw1EvGjXCl0HHKwlWQE4jJ2+pkwyspRDYFhNQwG3HouHN5ljuFPTGX
NauEwajqluarPSg0/8j3aN8egv8AO90/kA==
            "]], 
           Line[CompressedData["
1:eJwVkGtMUwcYhk9QhMmlfK4KCYh4gjaBzHrZBrhhv3NaaqjlslaQq2gZuELR
gXZUKMIwOBWoMKQdkIm4ZZQNnU6oeP8QdoGo45ZFJ7E6mMzQyYYiw0xZ9+PJ
myfvv2elZo8qy4VhmLec/L+ix7/3uisBfdnK39YnKsni6InYEAOYX19ybPJu
NOki519SLOCW4udUZN9MaNp4IzYe0PvW38bnn8hJaNcfGn3P+YfztaEVUfRY
fE6RowacnfaKv2KT0bUyh/c/WwHdS89H+XvK6NNB0XBFIuDuxpCA08VSymYz
La8nAZ57sfRJxjxP7+w9kdqSDKiXdEJQHU8+vXdXiFMBFagyC97kaVy4dPxK
GuD5lrBm3wccdWXFWxXbAQeHRJta6zmqtlXq7mQAush2CSrVHGncflybvRNQ
F/aD/7AfR28nucw81QBet+SldY8jLW6LvPjx+4Dd1wZOX7Uh2ecMJYJsQIZl
Y2JMSB2KDu7zXYDB1RabZy7S4aYp11At4Nf6G6JvlEhpjpD+rhxAbe6SLRPr
kdZFZpvkOsBe+clLVcuRFplaVCN5gF+8YWMLPJF+vT+6TLMH8EDYwOWpVxI6
I/a7N/Uh4Oq8jgdef0qovEzdXFIAOC0IPhk0JqHEQVOmxz5A9pe0Ub+HEgpl
+0UNesC48snpmUcSYva6OlYXAqq1N9u/fyahkR4822EAXLBKrlS5IlmFxn18
kdNls9oMIZIx60L4QDFg1XK71SpCirdN/5teAjj8av+dBAnSKrc13ZMHAJXp
X2kaUpFebNNW7C8DtPoEM98ZkW5bv4x2Kwfs7+PmHaeQTs3ZveoPAl6YXRTb
dhupUOE/xFYA1qasrUllOFI2JZrPHgKcL/2jvS6coyBHbcqmw4BPJtoNCw0c
PXv3VuDNI4ACn3yj6TpHfdXuY8mVgPKQQEOcD08n7ktbJ6oAG1d8oL6Yy1OB
uDRXbwIsishf0znMk7zsknhBDaA5hQ++p5CS/+DM05pawB2sNPnnESn9tXJd
V2Cds1cOTD76SEa9BTpj+3FAe1JNV2ZEFH3W04obzYAJzNHtS0LklCccW/iT
BVDFDHl3ajYTnxXYl9AAmN78WsC3AdG0zJZcPdYI6GU+HjPnoaQmj7i6l04/
WOjb2bZVSf8BQNR46w==
            "]], 
           Line[CompressedData["
1:eJwVT2lIkwEY9khyS01eU7MSSqtB5JEusyb5frvaTMu5Gl47OtSYmrGKQint
MNQfSrbAzCMKkcQI3beNCvP1yMpsQYnrMmlmjrTCChPUav14eHh+PNe6g0Vp
OR5ubm4bXfjPv7vCLlREA9rT3W0XVcl0dFRhKtwC+EVWG7lckUTTf83ePrGA
zY+zSwZXykgftkrTxgdMMijfnWuVklN81iSLAzxe4L+wtE5CeXkO78ltgBXV
JuOpPjF9rpRqyrcD8lTDnuYgMR1ubzOFCwDbX5xY/HFJRA6bH6c3wZUXY58r
9RWRbsag0e0EjBJK9N9bhPQhwG76kwgY3KCuiU4RkjpOwGlkAKeM+1b7uwvp
fXqzRiACxLuFs9+6Gcos8WTfiAFNGWGGqxUMvW7M45yWApJFag3KZEhFzzRB
MsBR49xMVyxDw44olpUDFk+HXncPZEjpZeQodwPecY73FC8iveTNaWaSAaWO
fr+xaaTUpGy2Zg/g5tpg64IDyVZAnMhUQNvNZRPWMaTkmvXaIQVgD88p54wj
DXZUsHqla//bStOiyy8fnuZw9gP+WjN7zeLKfzKbqm1VAc5NtZjyXf3SEDMr
SQfM3NXyoJDPUL8ghPspA3C+FO9tymJIqDmjPZ8FqMxqTuFXMURlH9m1ate/
gWOjsl6GEm9JuN0awMav4T91S4T08NFtrVoH2EDjoX0KISU4fc3zB1y67BU/
rF1I97kGbv0hwKoVV7yeB4ooPmJEG58DWF3De7pwWUSWvTvMI7mAiU0D5eoN
YtpqaOKePALYKU8r8rGLiTV66AL0gJV+dfU3OiUUY801d+QDWiayIyaHpPQP
tk4T1g==
            "]]}, "Charting`Private`Tag#1"], 
         Annotation[{
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwdj2k41Asbh4W0WFIoazRGsiaylTz2bGEiKSoUhepQOUSWyslyylJZSkfW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            "]], 
           Line[CompressedData["
1:eJw1Vwk0lVvY/oYTksqQSpci5SpUhorvHL7XTOYhSZMGErq6KpUbypQpU1SU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            "]], 
           Line[CompressedData["
1:eJw9Vmk0llsbJs9+nkMzUhRJRVKGFIlT9/O872uevYZQOoYMUVHkFIpSSYlM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            "]], 
           Line[CompressedData["
1:eJw1lgk01nkXxx9T/H//NmYapBopWUtJSfV4uMP//yx6sjxPC5FEhWosjZBH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            "]], 
           Line[CompressedData["
1:eJw1VXs01dkXv0TNPd9KURLyarhI4pbcqWT3GOfe63ldPZRHkihCSI/xLuTd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            "]], 
           Line[CompressedData["
1:eJw9lXlQ1FcSx4cj4PLrlfGAIEQQDIcEInihQaR1CP5+MwMDw7EpBDIqKlEu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            "]], 
           Line[CompressedData["
1:eJw9lHs0FXgQx1W0bcwtJ9ELsUIk70f0GLbV9rv3ug+P8lghCb1IVBulIqGX
59ZNYhOlqCilbAaVRFKhUqkbDlqV0NvV3t0/ds6ZM3/MOXNm5jPz1QnYIF41
WkFBYZnc/40L9A2OoBagwn/mRmrq4kYFbUAN6QMptbqScumXbVq6gJKWxIW/
/+xKo4W5s+fPAmy38Hq4uVpMX/p+feRpCFghmlzXJRBTf2J/3GZjQKMW0+kq
vSLq1j9skTEXMCQjMe91sojaaxa9LDEHHC6BEzIbEbX4de9vsgKMupwWO6VX
SA2yAw5vbQGXRpml8HOFVC2x6VV2ALz77VjZc18hldu2Z85eCFgpDR1joiOk
883xi5c4Am7rEy+JvCeg/HCTgcDFgAkvZAPWgQJKPxPNz2Hy/txaIvpyXaj8
g/rtvXzATfdrCrYIXKh90QWncCFg9iqtoCujXMiwucvWyQOQdabYTI7gE18r
tsTIE7DkQc+fheZ82hg8zWSSD6C42fucdJBHFcMuup3+gEKlzZVhu3gkde7N
aggE1Bxp3hfhwqOxKbs1Lq0GHChP56/V5JHxU83UY6GAmWdO7LB/xyXhrCsq
e9YBjjHTbaMaLkVuECesDwO88WzbYKeES5LyvlHLIgDdc8RDBzZxqYOv88lg
K6BWoN3JmaZcGnf4WvjEaMCJRTXLOyZwac4r977P2wH/smTZ0gFGojn9QdKd
gHsa9efBY0ZRUUnSujjAyZf0/D0rGR0lPZ+SBMDreSz/6ilGNL6yVZIE6LXF
47F+OqMuN0/R7v2AOQZR79N3Mhp/fLB+zSHA+u7nY2RhjEx79zu7pcnnefl6
9vIARm6WhlXzM+V8TA5uyXFntDWm2mHWEcB1ZvcGmxij7FqfMsgCzO/Rie9y
ZFSj+snsYzbg+egDg232jHq8U86058rvY3vw82JrRpBvrF+bJ8/rpJWusGBk
0X8z51wBoFrivLI+M0bL7P2mHy4ETJO9G3A3ZxQd9zUjtgjw+IjN4ixLRrmN
6RNDzgN+5/mKq2wZ3ZpimiwqBbRTrs+oXcDo74A6JfsyQD3T014lvzCaWLQy
VrccULVp8q14ASPrT7Kv4ysA+btbnjl7M/JyPBw5eB1Qe8b55G/BjHYkW/Q/
rZL/y9uUC4VbGOW1NITeuAHoI5YY+yQxqtNe3XW2FhC6lnRMyWb0NmSUX8Yd
wPhvw+2vSxlNuni0LeYuYN4+Xffn9YzsRqzdg5oAyw8tqB7uYrQrNZTZtgLq
GvLWf5vJpYJnije1nwD2lC+QfXXkUoP+8UXjngHOCPBdE7yKS+/D5l3tb5fv
R+AdtDyZS+rXHlo9kcr5FV8gaSmXHJTWn6vqBPT7aXSR5gsu+QnGGRV2Azb2
to42BB4VdszX3vYG8G2x8gb9jTy6Z/LoyMp+OQ9J5K6A0zwa2hyuxhuU1/cv
7pZ18GhqtfJBq4+ASnNWZBro8mmhSv6Pml8AFZc4q6kF8mmlB8YpDQOqNCu7
jJzm096ctpE3I4BJc12zDIf4dN9qwtB1RQ5OGFDJj8h0IZtFM690/cDBhuRN
g18+upBkqXm0ijIHM3ilKxx8BfTd1QktORwsKi781N4goEBfV0UvVQ6GZp58
2CzXg7rgwNuxahysmKP+pNpfSHMjIvcVaHDwrEaex618IaXF7BE2TuPg2Jna
CUnvhfQ54Q+1D5oc5FaaxbxyEtFvqaceT9fhoJHEOqb1qIiqs8qznPQ4GBI5
NfKyTET6BXf8Qgw4ePFNvfP8UDElX3iqd8iIg+pvBHHnOuT6d62vp8yEg1Wx
qjPs17nSsrV2qSfMOP/r6z8aWIIR
            "]], 
           Line[CompressedData["
1:eJw9VHs0lAkcnUXolN+3Sa2yjcqZPHqYYSrE+k1bpO8bZobW9tgURcrjq6ZS
0hGN8tj1OBlpC6mQWpVVDXbtj/Rw9GZLNhuxeaRdu2xx8li7f+w955773z3n
3nPPnRMYqdqqJxAIVo3zX40w+dPv3VpAwX/woyb/3q3DGwCb06402YT5klvg
iK3VJkBX9WCV42sV5YfB715BgANtRS16vIqM9lmW8sGADjmaE8cMVRR2WLw3
KxRQlhifkVKopMfJMpeqMEBjXUfRFqWSlmhVox2RgBOFZu51eko6mRdUM2k3
4GSJVFReoaCxYnWCw17AMwY7fwmOUtCWa5rVa/cDTg84fHn+MgXd/UkLsQcB
4ca9s4f0FJTRqNPejwMMkN7WOrr40Ptf69YNaABta4Ih6KU3behuFlokAkac
133amuRN1f1vXslSADsvtKDU1ZvmjQ4XbEsF1M5/LRr6S07JxrAjNWM8T+nQ
yM8lcuoztbS/ngmYWJC5NSZSTuXWshv6pwBXXWqPE41yJHRQRdvlAt5KlOuu
13MU5xrkrswH5LqTd0hOc9TpodaPOg8Y3mK3OHwXR5xScyenCHCK5wWNB8vR
1fXa5FsXAfOcL1vkWHM0PbjQp7cEkP9Rm/alEUfRvG7q1FLACe9j33/Vw1Lr
gbpnztcAvRwGk7MfsbRS0/ztJh1gSlJF+FA5S8WpbwKOVgJ2fX0zJKKAJTg5
bFVSBVi8wKT6TSZLu8+ZdDVWA+Zvfzgt5BhLTSXCSx9qATNmeDo1xbDkWm7P
z70LWFEvM3fey9KZmyj1qgcsaWm+otnJkuED5WDkA8CsSSMfKiNZyl2ywPjY
Y0C6ODLykGfJKdfQPK8R0Dc3MqZMzdJjozZr3TPAoP7VM8KjWdrOVy591Ay4
0MPde+wIS/rPMz27Wsb7qimN35XO0ikZ7y9oA7yqryd8lMeStHh1iHnHeH+d
27RW37N031S0T9wJqJdpmX3gLkvB0WMJq3oAy3oD7H5rZWm0/bl209vxvT5c
2rBnmKUsrqwgqg9QWuXxTGbBkfjaN9fT+gH3zL6n3uzGUd2s0NtF7wBju2vE
fYEcBSZ8/pSGxv2ypRKTFI6O+w/+3TcGqNZV+MV3c7SQnkyYqM9ga5O1uUQo
p9s2302bY8ggzwsuf+Ivp4D0oyLniQzOsC9M4o/LaXBo82LlZAbX2Ec3H3wq
p/RA15WhDIMRspkPEmZ5k1399DWHTRk8IVk2uz3Um9afqldfNWcwW1IWMs/M
hwYMCo7UWTAobBi0HdvlQynhscfbhAwu9Dx90ey5D4merjs3NIdBl0PVwSlW
Cqr6bHHZFBGDM9suWf2xUUH+hUytrQ2D7i8EieJcBfUxPQ2y+QyK3W686OpQ
UGJUbfvaRQyu+HgF/0SspLltOf07JQz2OAXFNMYrqdJrv36SlEGnj+p/MH2p
JL9S36n5Sxl8tW5gu8EKFb2duciqwoVBh+SNEVllKkqIN3Z84sbgF5IG6TZH
X7LsfbW8Bxnsfj3SJaz1pTv8obMGy5n//+YfQ7wLSA==
            "]], 
           Line[CompressedData["
1:eJw1VHsw1QkYvZ6TZL/f5BVrQ9Zqsz13lFfmS7aU3+8+LVIWkWZTQx5tu0Kk
iFyPXRF7lzUMS1yK6UbxIVPtFVuqScnOsMSoSx55pLV3d2bPzJlvzpw/zh/n
m2N9OEJ8RJPH43mo+e91njc+fyEckPcfvCmu7LGVy3HArPqEr5r6JGRkIN8i
iQBsLGxIzt0noZrYixgeBTgpiPihRCmmPQMhwnOxgFcbl4+tPySmgT1uQUWn
AT8/kTiZNC+i7+RrIq/HAbq4dJTd+EVEzJrpRGUC4HOJmZTjRFR59kHWUBLg
xu37eZ9oiWjXWEXx+xTAYdP3mjtbhfRclCw3TAOM8gr8ZuqskKKbDrXaZwC+
pLHksr1CWmWzo2e3FFD2kVXJk9VCcpsZV0X/BNjS68h6HBOQzsqbSp98QHtd
B508CwF1WV6odCpU++3eJomP+fSjg+S8hQzQ49JEfmUOn/y9rA4vFwNGv9oW
1CHhk3XwG7fBUsDZsnH3DHM+jZ5q+rizHNDAV1V+Z5gj+aXU+YpKwJlGfT+X
Ro5OlXo/Sa8GVB0f+rktjaOdCutrJ2oBveusQjYHcaTdrZIK6wFfvwBZsAtH
yqHm8C8bANdF7210MucodyHN0+QGYKhdnLlsiaUD4GO7cBPweGHhQMwgS1a2
Npr9twC7sr4Iq1Gy9Mp5cqClFVAc/b3tdgVLtcLbzb+2A9rIC77VqGQpNiy9
IKVT3W/WC3vtIpZcz/jGHr0HePdyqMohhyWt3E/F+5WAtLRckp3O0u8Vbzdt
7Ab0Nc7MZFJZyrndos88BGx6GufVcIElv96M0alewMTL0HTmIkuWY36dT54C
br/nrnEii6WRv21LFX2Ad8qEV9ILWKoxmk4o6lf3O7f6wMsylmI20MGEPwFH
pZkZEQ0suWCmY/AgYP3IZgP+XZY0ffyNPYYBY86ln0x7ydL9cLupz0YBT45G
bds6x1J20ky33rg671HfWIARR775bdWv36j/VTaRb+fA0doaaVrPJCAGFc9V
HeBouP3gkWvTgL+NTw6tSObo6rP17nnvACuuZD4Mq+UoWjW79vQCoOXRxKCJ
AY6ctTve+y8Bch8C9HsN+aRhnv1s5zLgzVvZi54cn/7Kr/VnNBg0oB3a2Rl8
qq6J2zGtxeC7rgxFk6mApI6D5aE6DDrz8vr5YQKK6vA0eqrLoK63zlazZgH5
8OXJe1cwWDyjWvbSF5JTn/FbhR6Deu1tYrmrkCxCzwRu0GdwXhG/ziBKSLyJ
wQdFqxgcKUyZVlYL6a52XVUCMGgTcmxl5CYRVWWZmE0yDPbsW16UnRaR1Dw+
NXg1g1q+rjp/3BdRVPnQ7CNDBtO82wysbMT09Zb9oR7GDHZ4DF6fOy8mx+a6
R40mDCYGBAZtnRGTxR7TXXZrGOyOzElgIyXEexgvLzBj8Fad32LHBwllC94p
ZGr9/178A5399V0=
            "]], 
           Line[CompressedData["
1:eJxFUn0s1HEcttudrdYfPi1tVCJmxZbXXhT5IK/Z+v7uGLuKIhM1mpHMS+HU
KixLWJKtVNwl72Nn+MghLOc6DXdoQm6opuWlMnX6p2d79uz559mez+exiIgX
RvEMDAz267mpZ8WVcrOXgAb/EERyV+caTu/zFqOm3RdEZD2jG1NUAt6Yu7w1
JVZEBffK+EelgBmFFfHSX0JadxTayWSAgt+HTZpKhHRJYyg2qwacSPN9EOIp
pOHMVknBa8A1N+XU9DJH7geu1vBrAZe6rSy313MkHbLSJNcBHvKJlkwncbTz
+hh/oR7QNCFkLR85ytqbbxfWCHg83YWfCBx96fEUq5oA+7e0pYKOUWjcquRk
M6D3fMz4RhcjhfGrmuYWwOTg1KS5Ckb2bec1NnLAwMhi9a27jEovGguetAKm
lywav0hkZLit3w7aAHWZz76ZRDJKaMgQS9oBb6eM2HYGM5oUO+WsdgA6LPsV
Zwcy8ufpamI79f27DF05X0aNVY81E28AW5bVUxY+jMw5TsApAH0sBAM//Bjl
rgnsFd2AveGFVUOnGa2Wy8VHegFjClsGusSMInzjc6RvAQt29WTNxDAa/GpZ
u6cfcH1jtp9LZ3SsaFRzf0D/D17DCeeHjJ675Qn47wC9VoujO+oYGc162CcP
AsonZdlOakZpuSvieSXgn6jvMx9/MtI5yXLOqQDVpzzMrK05CtKG1w69B3TP
bAjICOWIsnZovYYBs72Vn9IKOLK16RM0fwDcuJar1Kg4KlKl29uMbO5jQXnT
VEi8FMczZaOAd6QOS8VXhBRnPpdjpNHnueze+rRPSJre0tpsLeA+Xn5YuZOI
fOKZdmVcf/+D7Z8DqkXkf+GRx9DE/739BXjdL1Y=
            "]], 
           Line[CompressedData["
1:eJwBIQLe/SFib1JlAgAAACEAAAACAAAAbpGsUxHzEUAAAAAAAABUwP7lmoYp
9BFAIlHq9emaU8BpjU+xnPURQH906zeLJ1PA1DQE3A/3EUCgXatWM8NSwEDc
uAaD+BFA55E/zGFrUsCsg20x9vkRQCixy+Y+HlLAFysiXGn7EUBsqn+BZtpR
wILS1obc/BFAagwvZsaeUcDueYuxT/4RQDpzjkGIalHAWiFA3ML/EUASliu3
Aj1RwMXI9AY2ARJAnuyoA68VUcAwcKkxqQISQOc0GqIh9FDAnBdeXBwEEkCu
0tX+BNhQwBo6wrG6BRJA+nLxQL6+UMCZXCYHWQcSQOwJ2bOjq1DAGH+KXPcI
EkAtjv/xgZ5QwJah7rGVChJAv5zWajeXUMAUxFIHNAwSQMKV+96ylVDAkua2
XNINEkCkTA6Y8plQwBAJG7JwDxJAgKrASQSkUMCPK38HDxESQK0vQpkFtFDA
Dk7jXK0SEkCdyUlXJcpQwIxwR7JLFBJANKoTiqXmUMAKk6sH6hUSQFIHlHre
CVHAiLUPXYgXEkCjgQoXQzRRwAbYc7ImGRJAoSy6K2dmUcCF+tcHxRoSQJKz
VDwIoVHABB08XWMcEkAKwpFCGuVRwII/oLIBHhJA4CBVaNozUsAAYgQIoB8S
QNyQe03rjlLAfoRoXT4hEkAdbsszgfhSwPymzLLcIhJAc2oIBKpzU8A2VUNe
bSQSQAAAAAAAAFTA/wLifw==
            "]], 
           Line[CompressedData["
1:eJxFk3tQlAUUxTeacIjBvaGIsTMMmxRUuEs846HdBXwtfN9++22tQBvZAkIu
wjKgyENknQ3QAhNNBxQyhqUVantoqK0MN6CQLF6+ascMRMCFCEmESQva+qc7
c+bOmfPH+eM3R6zN4dOdBAJBpEP/fr/SOZlWAij4714lkHfqMx1eG3v2CeZv
Fa0IvfP4n1JAt1RDQEKmilb5OB8/8BLg1ObwLMEET16u/i94BQPaYvx7N+7i
yXt+S3tLCGDksg5RGPAkHtFxUWGATfrcXZavlOT7Q9Xo5XDAm+6h06vSlOR/
7rPdmgjAz8WShhAvJQU0DrpMRwKaYwqfgxscSavun9wbDTgRPzk+WstR0B6P
wOXrAds0v3cKtRyFpYZ3NbwCeFwzmwdSjiLZJLVUBvhpbKesUMDRuohie0cM
4F2bP91qVRD61pdwcYAJdttEQoqC4oQdwpENgNHBB21WTwVtfjjcmLsJMGUy
aKH9BkvxY05hTlsAg3J8ph7Us8QO+PbWyAHLjRbJyh0s8daNmjUJgC3eXc7X
olhSN2fOnGEc+e2o6UV3lpIOH9wfpwAMcOPlb80wpCn5xOMaB7h1Z3X2lQGG
tmX0mdN5QNPRRxR8jqFU/l7UvArQdU386oxGhravc+8vfw3wSctUeGINQzv8
Q7SeWx191X26hXKGdq5QP/g4EbDGaWl9ZBlD+sWCypeTHTwW5HJRKUP59lpR
7+uABdclT9c58oKrVkvSG4BV0S6+1gqGijp+kU2mAL5ofvPXiiMMlbYsXS3a
BigytQ8vb2LI8IE401ULeE9q8Eq7wJCxLPbRiVTAGfm3gR9dYahSl14dkA4o
WayfHPuDoffUFeL27YB2w1PdiZ4sHZKdPstkAg55fNPsJ2OpJuDypltvA/5Y
9vxgpZ6lY57Ttmwd4M+n5uatJpbqnITZS1mAJyJiza4jLNVPBz72fjbgmc69
7v3PKOjUT/xRHz1gTFpzcJZOQU1d+X5f5AJej3m2MdmqILPl2NeyPEBd8W/v
HnHhqLX2PDOUD5hVdUdwMYIji9E2rN0N2FdrOn8gm6Mvc/7Ku18AqDmdUZRn
5qgt2XuZsRDQOBsidLnL0YUNWLey2MFr3JT7cK2SLgZq15pKAPeNOQ+Ji5VE
IiOFlgLOrdaPHB5QUrdzs+q7fYCjg/pLLVKeemZ7xtUGwI6GQxMRdTx9f9Ne
OLHfwe+Sob/VXUV9Pa5ue4yOfXS3fZhyUkW3ebfO3Hf+3+M/DJqcSg==
            "]], 
           Line[CompressedData["
1:eJxFk39QkwUYx5cOMxvHQ0jcCnZpIfJDj0NpBCHPcQYW8L7vNgoMxZkBU8of
IALaacWJiiAptxJURhJSsh2zbQQ64ZFiDNlCfspE5IdKHAlcYpTKSW/903P3
3HPPPX88z/f7uWfZR7vkKQsEAoGUz3/rm3+9eCe+DFDwX8TTwXci3Gx8v3OP
19aoDgWJj9wSRZ4FzEt2uEpiFGS0Zi2qPwcosahDwm7KiVniKlitAVxevFeY
v1tO4zHax5UVgMZ1Cc60VE55RdEz4vOAyvHtdWHNMpJ0jD4orgQ88saNb2qz
ZVQPB8ecqgA/eaFmRLxWRnK5ePjABcBoTydON8vRZInR8Uc1oFDl7fFLI0dH
e9nutB8AC04O1PQd52i5x++2wYuAZx4JJVmbOTIn5lsUWsBntXHBkWs4Sihb
Rm06QNV+77ZpEUcPB8wNEbWAPeVPZ7J7WCr0SjSY9IBuO1Z73VGztGLLjNb/
R8BDZp3asJmlaxUnLnxrANR3+q3/3p+lTaO+FR4mwKmtVck58wzNvt5SWlQH
OFkjbZ3oZ+irFGXJwnrAdXcDGjt+Ysi/+mlhbgPgniVv98+fYcgy/nX+9GVe
T5E4IOkwQ0q/oM9TzIC6WJvOmsnQk3R77sBVwEuCKn1wGkNqnSpT1gQ4kna2
QL2FocDphZ+2EuC4Svn+yCaGrgdqUsObActdSq978POPM0KVhp8BzRuEoeGp
DM0bejf6tgA+MDiVJmUwVPbnboXGAph+K0L7ZR5Da6WiOHcr4JMhe6y1lKFf
c6qjjrfx92g72zeYGNp+ORKfawfcVvdBjk8fQ8K5wbeybYBlr0jiiucYKg/P
XTNpB2SsY3bDSpZCDi1dta0D8GLWRknXhyx1U+0Kxw3AaXGAMqiEpZ0LYl5j
uwDb3fU7fLtYWrx+TNzSDXj6u4D9zjyf84e/cAvr5fmYbvo0BnEU3urpfKkP
8NWMoUfpPN/+xfWLfPoBm64F31cVcpTxnkJwzgGYqhc2vEwciQqnHr80wPsX
ttI28TdH1fZjM0dvA5o0V6IzpTKKdPGefDYI2Gk0hiR/JqPbHI3tHeL9mQrc
lWeV0b5TScMTw4BSQeXJh55ycu2ZdShHAU+MZF55/oCctO6nuvvuAvrFi3QF
9+QUlbDKHnsf8Oo+VftQkoKGT1stzWP8vlBNQ+I9BTW9O+ci/O3///oHwTuf
/Q==
            "]], 
           Line[CompressedData["
1:eJw9U3tMU3cYLYKAWuV+ioi6gpBBtQrMAg0M1A/UgMDyu71FaRRc760NLmYT
iQx8zEnVasWAIKhji5KViG5EEIgYssVvU4Mz0oBmZGqYvVcXVMLmI8NXCdb9
sZOcnD/PIzlR0lbBNkmlUul9fK9hY87rY285VP2HfNoQYN2x2svhrrTylx33
TcT9q4R3jXOoXVpX3llkoqt/SZeiJzhMLO6b7RkRqGJQKahVAV4Y/6ldf1Cg
uF7p5YQf4OIndqqIE0jpVo5/4Q9YkhQdOn3ISMfPSoahAMA2a1NVa72Rcr5R
fs8NBMx96MxYbzLShFMq6wkCxJT213nhRuraqYQumgI4Rd1fqCg8bd4idZ2Y
CkgfGcYaOnj6oFAxBaoBCxynO984eBrIk15snw4Yt2+l5uKnPDmWKXUPZgA+
crX8ujudp4/jJb3AAdbZz+wP0fD0d4QyQADIe717U/14coVI2xJmARbduD3y
3QAjs0rhToUCnm9M8jO1MFI/E9vVYYClewYzzfsYkSyzXXMA70y4RnfaGJXd
Ev95HA6oLmnNOvYJI90Vudo8D3C5NqDLnsboz04xvnc+YGP1Zb/EBEZ1zXJf
ssa3zx9HRxsWMspqED9vjgA8yfT9zVpG3gOyetYCXz7H0zLLEkbtX4qtlVGA
55wHNQMGRpuK5dyn0b4+7sxTgVmM5prFkY0fAvbfmdodXsTInS0f7osB7K0Z
dmp3MLKnirp0LeA9qWlN4beMDDr5tx8WAobt7Yl6coXRyDzxs7k6QKG2aFPI
C0ZN0+TgQ4sBN8NbR1UoT/ley9mxJYA5GZr1cYk8BY96smzxPj/X/K+/X8vT
z0OW4dsJgJ3WmGLdbp5K3R5H5lLAmcE1P3ItPMVetsRe0AO6/LUX2wZ5utvm
uRaZBBhptmVsn2akmiaLrToZsKeifLKy2kiraj0B4wZA86RSaHQY6VWlpXlL
CmB+QVC91W2k1lLPyrupgO6bKdkpEQKJVsuD7DTAI89nf7WuXKCwfI+9Ox0w
6VGluvCeQDdWWaJjlwNWDfvHlOSZaE+y55f6FYDbZsQ+dPSZ6DTb0MEh/P+H
d9C4W1k=
            "]], 
           Line[CompressedData["
1:eJxFkn0s1HEcx28Krdj5lEqTh264pRW1Fq3w8bDbuk73vd9FnkqdXF1IyJxn
aVoNN5dhspRqOUVTcR568FHKspLrrCmGxtJGNA8z1kj903t777X3f68/3tsU
8Vy0CY/H277Sv9TdjVduCQLk/ctRum4QGvOCAc/fcN1aly4npSCqbEMI4OPF
jZORyxwdSKoMrwoFTPZpBMdijqw6vji4hQOKkSvl7+Vo1Hrj6PMIwKdVHrc2
D8uoOZrpxCcADZ+E3tUlMirU58f2RQKaBJzh58tlpDDvdFeeAoz1eGtrtJHR
vhCTuRkFYFtZXET7KKO1NV4tl04Dtr/sqXuhZzS0oM7kK1d8BYLAQA2jBnGD
780zgE6FZXqLGEZXK6ZMd6gAHyS/Ej6UMIqYcO1qPgeoill/eGwPo91eSo0o
FrBDdLu1wI6RmaaK640DvLtTL0i0YPR1cGCTIh4wy6Pn2dSSlB652fRPXQB0
iWsYtvwppdwc+a3MRMBpvtNtxxEpBRs0UesuAgo+RwzYfJPSDkGXsDwZUJo7
Pj33XUq8JNMJlxRAuep97ZtZKfW+xvoGNeAqZ5GEM2Wks8646Je2sgPmVZHW
jDKimzx70gEL7IZ0OiEjpp/+fTwT0LiU2hfkw8jZfFf7eBag5Ph9RXk4o8Vj
qrzUHECdlRPvSQajbt29Q+a5gF3vfJcn7jC6szBkWXIZsGne7EhNN6MUse0n
QR6gNsy9KJwnI0lFcGn9FcDl7B+1xZ4ycpzQhnlfBZwcq1WvVsto9uAH+/fX
APlWCRmaNhm9K1wzEpoPKHK1V0utOKoc9K8eKwAsdzgrb4nhKNEtOyZZA5i2
P2FXo5EjUU6r26oiwNIwP6d+sZxsDXMzRVrAkwL/0I+9curcm/ZrUfv/f38A
81YhWQ==
            "]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGCQBWIQfd8j+MIxSyEHBjAIOZCyZtVmZWshhzXnS/5+ags+
8OgcH+chGyEHL6PrP+p5gw8kfCyKS7ATctB3cs16vzTowD3h65v/2Qs5iM+J
7TfwDToQa2bNOddRyOH1lBBpAcagA3ci5sdZOws5OKzP/fZuf+CBqGrmLTdd
hBw2RyoVTe0IPHBjbjpnhZuQw4FtbtvFogIPhB04HSfmIeRwd8qPj3uNAw9c
eaS/ZYunkEPVG9nZjKKBB4JZp3AGews5rH3x+GDV34ADl9R/xH30EXJwe3SE
7/6bgAMBXjFb+v2EHHQmiW//8yjgwLmcA5x6AUIO5xZxP91+P+CAT79K/JlA
IYeD6i88OR8HHDi1sWNLVjDQ/bc6N/8F6ve88oaTM1TI4YvMt5nbgOaf+BYQ
vzxMyOHH66Wbs4H2u0lu3eIaIeQQ5b50d65J4IEj1pJcTyKFHH7XO+zUig48
4BRXG98ULeQQHD3f16Qr8MCBhodbFGKB/jtWcNfjUOAB+8WuXPvjhBzmvlX+
nMASdGDf0ZXxsQlCDnMOPJY9HBh0wOYF79bfiUB+w2UTpTVBB3ZxFXHNShZy
6BKZzHpWNPiAhe61eItUIYe+fvWTfyYGHzjvyrIyNw0RfwDSTtGL
            "]]}, "Charting`Private`Tag#2"], 
         Annotation[{
           Directive[
            Opacity[1.], 
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwVj2k41IsbhlFkCRXZZY+islQovPaISKmsRYXTrhJFqZCtk6WQcJwoSSha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            "]], 
           Line[CompressedData["
1:eJwdlAlYjVsXx9+3CSlDFFLSIBUiJUNq7XPqnIbTfHBpJtRNqUsTSoMkjboK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            "]], 
           Line[CompressedData["
1:eJw9lns01WkXx3me4zqUSzRiGnQhNW4pwtROv985OMf1zYxMSnKrU5k0KBnV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            "]], 
           Line[CompressedData["
1:eJw1lQtUzHkbx1O/36BVyOUgYSmLqKa0MVFPif7/manGTEnKSppuWyLGJPQm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            "]], 
           Line[CompressedData["
1:eJw9VXlQ1GcSRcTvx7EiIIbZAQTFCzEccomy2FyJ8M0FMyB4RTnkjBzZiNwC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            "]], 
           Line[CompressedData["
1:eJw9VHs01HkUl+T73V6EJEqsV9pqaFMabLcHevj95jejolJR2LY6jaTHUC1K
KEkylIzSg5ijbBRmSncK7eo1Fa1WNok40m6ttDXC/nb/2HvOPffcc8899/O5
n3Ov7XqpJExfT08vmPd/46KWh7g0gYDef7YM40IiWx0TCYTeqjg9LMYfP+R7
xY85ROCUbpb0TpsEw7vp119SCDQFCo6rpBJ85lqveX2UgKbzmwgzYwn67Tod
8iidQK0y5+H3N8VYdX3TkOtyAtoRf8ZoZWJ01Z+Vl3+CgJ3iik+NpxjP+w6Z
d+wUgZUXbicmGopx3JF7LTG5BPrKLX552sDhocdZseF5BPJ+HbO8ppDD/nEb
bMTnCXgLXAcUcRxGrJmOHgUEjCxKEp8Ecfjq7Od1jkUEgoLKVb1CDld0Vg8a
FxO41jdKV2jFocf21XNfXyGw5tkIXeAdEV6qcHyhvUqAMbwaaioXoc3A+33q
CgI5neYu9uEiPL7ghnW+mkDuzMM6EIrQMDmpKq2KwMXKyqfOY0Qoe+C/NkZD
QJVfFFXQxWK36aSBsGoCPqkpl5JrWXyce9XLo46ArTxzT+MBFr3bYpsd7vO5
Itl7MJzFCme/vcZaAkmp6WX9S1icIh03se8xgZKIPz5UurCoKGu93t5AYHbG
m78nWLBorCsO0jYSSFSttjQZwmL8XNkXVROBW9KoxoNvGNxYZ+SZ9pJASIK5
16VqBpuMmpqi2wiIqmtDF5YyyC7PjwnrINDo/OqJzTkGNdnbrLguAuVRkmT3
DAZntniqhW8JDHv5pzzuIIMFDnS1wzsCHSd69HtkDFpufqIz6iHgYFWjPrCV
wZSS3GxdLwHBdVW0IJTBwd4fhO2fCDy/u7aiexWDkR5uvz3sI+C/ti3nmoTB
tli9aNUAgQz9Az2JSxkMqL07/sIQCsd+PDApyJvBuhFZlUcNKHB7b5gIgEEv
8fqV0YSCz7ebvPs9GCzJnPY5dDiF3ZOcL992Z9Du+acTolEUZl0coflxFoOZ
ttXuQmMK7nJFsMCN768JtDc3pbA8PG+LdiY/f+Nbo7/GUrikWacJ5OuHR8b3
3begkLLwufwO3z+jxLyj0IrChe9M4yfMYfCZv/JxgjWF90K6L8CTwdi/51aF
2FLolke93M3jczxVX+hlT8G0xyw0jsd//7sf5OOdKCyWZ1pH8vyiWvtje50p
FDQ4pfjx/C0Ppm95NJXCF/gpxYTfj8bZKbBYwOfcze9r1/P63VcvSJ5B4WiA
k3bTFgaNtnGCMDcKS013dOrvYvCaWbvlPHcK5addF6XHM2gQNPqvT158PZVT
FuQwqBw821wPFLL2P9gwW8mg5NzsX0oWUKjb+PHFIxWDn33ulaX4UIg+Wbp9
710Gz3QFn9m4mML4Ny6T5jUz6Jvae3ihH4V3U6UK+3cM/uF6aJeNiMLYbL0d
LgYseshK2cZlFKZJ16g6BCy2TlgkLAug8Ku4peuiL4tJ+NwhbRWFwuyPLlXB
LD4lhv2+wRRu1uTrJmaxuFeZ3Wm3gYKVS+PDpDIW7UWC+sEwCoG7OzRJT1iM
zAxUlm+mMGw4Y5prLsLxwreZx7fy8045PWrj7w+b4+Kl2yhku7VNtQ8R4WgH
5UqnXRQq5iuizcpEePXnud5DoymAMOWK2UsRBm2pd3mxh0KuXXvzCsphYWk/
yYqn0FMakeXrySEXkN4TmcDjXZ6eUBLI4Ued4ws2idevvTLo/U4OFbnquimH
KTR5W9p4ZXG4cD53zTCVwhmDlVnaSg7ftLfltaZRuK3c/OHD7xymJ8uOVB2n
UJSREDGUiHHOtNGy7Ex+vx3FyzbNEGOL9mzozpMUNtT6TS4LEWNi1GxOkkNh
cufTOelyMU63uOcx/TSv/0XbjO4HYmxQBzsNP0shYdDAum+0BPes6zV5fZ7C
/NfFX0kDJGg39NCApoCCus7CTV0kwbp86y5FEYUSk3HOOSP9cduS0gZZMa/f
WtlW1/3++EWSNufZZfr/v/8HlUDBnA==
            "]], 
           Line[CompressedData["
1:eJw9VH0w1HkYN0X3+x4lrlDaWt2WQ7LpKG/nQS9c+P52l7QyqtWGJEok7tSW
Ti9WhQt7ZDrVxu2iGOOclyfiSprInKPcJXr10plVIk63d3/cM/PMM8/M8zyf
+TyfZx4LSYxQOktHR4fV+r/xk/YNiWVNDOj8ZwF4PXybvfg2A09vNUhzukVI
9Uc4Dr8yEH365OPeIBE6xkwIaSsDqYp3XgWvhLikc/apyPsMSH1cr62UC3H2
OsO6E+3a/mXjv9S7C3FQsVhT0MnAMfNZTX9MC7BjZoVldRcDo9b69naNAqyW
rAl52MOA8XKzggUZAixscb0w3MuAh6/vQckOAX5n7d0yp4+BnIwxKycHAUZn
iKa4Awx83NSaMzJPgAGaUL7LCwaqnxi0TQ6x6Lx1rzTwNQMuPnTu2D0WLWri
FTHDDDwpy5w+Xsois1T24PRfDJwza2+UZLH4Rpaue0XDgNvqC7lBSSzW+hTt
755gYPVU11SjH4tF6tIizRQDaZfVocNOLJ4xquk2+MjA9YuGQ3JLFmPjm+da
ziJQMhkXKDdhMain3dNDj4ClKvl+5xwWv3LrPbydIfA6oKdfMUqRd/mlKl6f
gFuIeU3HbxT19caenptH4DOrzB9s6yhqImZMSowIvOmdW5Z1jWJPG/G9vYDA
1KZsv+ELFJG/UPanKYFBTo9i+VGK17K5VROLCaxx7LPj7acon7AZMl5KYHFr
fmdfKMVDIeu4thYE/PoN3b8WUAxGz8DNPALyrpFB0UaKHjz/M7ssCXT6Oj/X
OFP84pS4IdmagO5DhZpjT9FwePfb720JdFfuMG2zpjhOY63K+QSig+P573kU
eyuSQ1vXEsh7nbsqj0uxyTQt65kjgV1uvgFqDsWS5Mw7M04Ehvy57+2WUDz/
pOBvMzcCiyx0dy3V5oe9iu3XAoH0G+KHCdr6UGVluJ8XgWVHipLWa+dt1Mf8
8E0EXnqq4sO0eKti7nXIfAg8c110b8KKonFn15x8XwIDl8NiP/ApTjr2u1RR
AlG3NvhFOVHsU4zEtgsJ0HGVJ/Wi2DIzcXUwkIDN7/u+/Mmfolqi+1hXTODb
FXcWntxOMbvFcP6yEALe0a6TA5EUk63NNzrtIHBE+ejz9iMUJRkrk0QSAgaZ
Kp7oLEVvzZqyaCmBbTp1o4cvUbTb6vYsLUK7nwdHdbdUUDSp8V70YxSB2Qmp
Zx/dpTjNCfCv3a/Vh5t7zrGfYuvzvdWjh7T6xH2MowYs3vBJGPk0kYB/TnBU
lDmLuWrZ8hXJBC4Gc7PybFhMMZIHuacQ6FPtrnvlyqI0PjddLCMwusWpIZKy
6NtTdCsulUBFxNFmuzAW7d3KxuVpBDwOkDo2kUUdvZadjXICTWN8MwMliwtN
bkuU57V8LbxKzRtYtLZs3J2eRWD9fIerzd0suq/HPQcuEthTcpOxe8tigE99
xNY8AjxZ2OYTRgKMDK7d65JPoMu5qvodX4ApUTX7uIUECvXWFjYJBaiUV8UO
XtHi95RnF18SYO2lyoMPlAQcXOaHn70rwPaym4cqSwjU0+LSiAkBPsfyhDy1
9n78agLf2QjxQ0dpYko5gWlPI3uOVIiGA6qksAoCM+fbHnGuCpH3tuQb7yoC
LyQ20hsjQnTSK06x/ZmArJkfIPYQob+J8phxLQGxh9p0uEiEqXd3Tm+pJ///
u38AV2g9LA==
            "]], 
           Line[CompressedData["
1:eJw9lH1Mk3cQxztKJc/NGUDHBKW+xFpFJgpBy0A4RUXwZb/naYWBL4ANaLEb
jKGgtr4wXxAqCDpgSpzyogiKBVEUEU9xRN3wpSJDZEABJyvqmIqZM4F1+2OX
XO6Py33ve8knN2ldvBBjIxKJgqz5b/W+nXk1tJVD0X+hIun1Q4dtH3O4gCoi
QrqV5GXKzv39CYey+yeFbTolLenJyr/bwWFu1MKmErmS1rw5cOS8mcOmlFdL
PToFSpQYCvJ7Ody51Fw1/bhA+5zSj+mfcdhmXGp7ZINABfK04+ssHLps7c92
nitQpWJvYdALDg3vhoQTIFBj8O5i9wEOF89zq4nr5ulJROpJh9ccRowX+7Zf
5Wlg487St4Mclu9J+ElXwJNEv73syV8cjmjIDunX8+SSqTtD7zns7pIYW6N5
CjSmGNM/AJw4vjNnziyevri+uSreFvDESydFoAtPWlNStcoOsPaFZop4BE+7
ehIv+gBgWos5bOVrRrlvEi5JPwKUFSza6trNqFwSXyu2B3zc6OYYaGJETl/W
9TkCzl9y5qmxgdEj+cb6po8BbYr6t6ouMrIoNFQ1FjDfZ3Klaxmj4eD1N/LG
AZ5d3KsdOsZozKqYmzopYJWvQWk5zGi6Vt0YPQlwbezVnJYMRv766FuLpwC+
TCmqvPwtI2Vm5J0ZcsDTN8bHZegYbfhhzc/2boDuGeq0hZsZ6Y2r7g66A57z
db7fkcAo53r4/TYPwIAA01OVltEpU5jpmifgSm2CX+EGRnU9K5uLvQFjL9VL
GmIYPXijbNmvAGyO65BVqxn9JhFav/IFVNz7dPo36xi9d2JtSn+r3qDabyia
kf20Fe2K+YAWzdmpKmt/is+yDteFgOEdRYuSrPM+ISFdNkGAf4y0y1hr1c8c
d23G1BDAjRdhONS6v/u5V3LwcsC48gqHAKu/ufWlN7QMsOycxNb5a0aGLNdR
B5WAKHMaeGa9zxyVE34+FLC+dvbDc3pGczztSlrCAY33Lh3dtIdRhlg38G41
oFRz4bOATEZdzQO+rlGA1zTtl0fnM/I+GbMP1YDJBRWh7wsZpSe3mdSxgM7m
0qLhCkYdSz6X7tMAqqJqjDPqGHm53NSUaQF3JKX4Ge4wSutXXGiKB/TWsgGP
NkbtdWdFfyYCDjlaTsv7Ge2NzMubuwVQ7t33q9rByu+skT0ROsCHYdKa1qk8
zbLZNXP7DsByUe0BsT9Pux8ObjmRCqjOjSy2C+PpcXHcjzf3AOaZPRNGJfI0
c3OnfV8aoN/yMRCcxVNqkGr1hwYrz7Mbx7yq4OmXsbdPzcwCdBwtC2IPeHK3
zHvN5wDalSSbL7+18nylyn/Td4DTPsne9v0EgVoM8vT8fMBU98i2pGUCua0t
eHTlKOCtdwuev9ULtMPDYVLnMSv/sRNah6oFahbt1doUAlbohg/WvBJomunv
GlkJYJN44qZ6hZL0RfHi4FLAQ0fWe8buV5IpqXeFthxwzeQtzl59SmpIkTmO
PgP//5d/ALBTAKc=
            "]], 
           Line[CompressedData["
1:eJw1UwtQlHUQP5Q5574/M5g85eCOO+MRyiMEDixyeT8U8f8dESHQIA8BkRPu
pBjQk3QAHejKI+EaECjAR1MGY+FcYGugCYoERpGEEpq8lOHCORQQ+2qmndnZ
+c0+Zve3u5K9CjZjDY/HC+T0Xztlpv0juJ8B3n8Sh4XK6cp5DrtJEyUR03K8
GZoyYjHIwN1tDZZFp+ToaH1nk+wXBh7mn52diJSjajJCkfgbAxnn5+fjBXLs
vdypP3yXi6/6fPnSIIuik6/zm8YYcLDpiVU3sqjc00p7xhlQHaILDSoWb2wR
1k8+YOB8m298eAyL9quaKWaSgZ0DYeKh11jMHzD18ZhhYPZW/IfXBCxebyxS
0ycMFEo8xZ2PKdoVzPWp5hnwURo60ocoKkLSrGsXGPD9IuuHEj3FHsuR1O+N
DDhat0r7mylufLTzq3vPGRDYjc24fEIxr+PqM5MXDDi/ZyzMVFP8scIv1IlH
IP7KT5IsBUWbxC81kWsJlGsqZK+kUszd7Di6n0+gVco4R8dRxJVqZ42AwOGJ
rb+vRlK0ui0oaDcjcOWlPEC0nWJOw5GuYXMCVHmuW+dH8YnDo+HuDQSudo9t
HfakeLAuZq7NioDrQJjI3Y3igt23/EZbAtPj/JLPnCgW6uzFHwkJrL+YXmYj
pfjc5risRERgMjP4TIOYYsnp2dgcCYGv8576e4oorlrKsxJeJeCj1Q92O1As
1eqPhrsQuH5z3/09nN90g1Tn40Yg1Xai38jll318ok3qTsCkMmy5mqsvMDf0
rvcisClQe1nmTLGyKmFi1ZvAd0GGmD+5/szNcOmxL4HTx+rXfOpF8dRJF4tR
fwJ1eMf1HRk3v0CzufcNAsW2Ag93bv7acmNIx1sEXorXfePA8SPkpyS1BBG4
79RY48VSPHP8mkobSiA63BCgSKYoWeteVRpBYEGdX/owm2JzaXWLIprj2/aA
Y/37FF14K13JMQTM9jMDZ8soXjiS9uuO3QSqk+tqrGooXiz2XucaT0Df5Vue
20nRe0kntn6XwNKNdufyQYqXPjDxN00iEByzJMyeoihbzNr9dwqBjtzlPj8T
FvWHfs4aTyUQlxMlEdqzGPhUVno7nUCLZKNjVACLWNCg69xHgDG1+OtFAosh
Bn77hRwC22ZWMo4Vc/epyOurPcDxF8z38GliMWpueKLsIIF7/VE1R/tYvJUb
uKxScvvZZRtmXGQxdrbZIq2QwJtQ4bTDTY5D2WZbaBGBHCryzNsrx7enlKHb
SwgoHiyONjXJcSRzNMldTaDJ5Jn1Oe4/84OMu4wc/v9//wE69qgc
            "]], 
           Line[CompressedData["
1:eJw1kw1Mk2cQx0tlY/F5pk4ZaWA167A0ITAsyXBLRS9TO0q2ked5wcgIiAYj
Li0NRUKWRVgsaMoWC0PxA5PiiMIgAzdGV4TCVUFGx4daBitCYA4VJSAIMvne
uyW75HL5J7/c/3K5Uxw28iNSiUQSJea/1eTnrtv/PQHJfxGP5jsT7rdrCCzU
nox29gn4apzw14ZaAu2ZxzWp5wW0dN9YWr5OYNJjmis8JCD9+B3/iXoCCnfV
4WG1gFa3JcxrJ3BpSa1O8BNws25mb0cjgdFST2LEnxzPdRxIbmgmsEE+H/Z7
C0eZFrMrWgncHUta7LVxLGtTnSm+KfIxTheaOW7dY72W107gw5ZR42efcyx3
zbcYfiXATDtuJwscgyFlIOk3Ao2Dxw6V7uI4+JZVo+khUBC8u0cdxrFoodUW
eJfAwZWKPlsQx4/6p9ctegg01fgG3aIcV39SpHv7CRy5mNNwco1hg5V3ObwE
yqQ7szpnGer15u0Xhgj8sVjFCp4wDNb9fDZnhECLc5VUjjIcVD58uf+BuA/J
PZfCy7BYGpAc9ZBA6qOjdU/vMYwZ0breHCdA9KfmXnYzXGvKUb54SkD7QdDR
fW6G9gtVlr5JAtIsl9HdwdCQ7Z2snyYw1lU7Zb7NcBtfz0tmCZgi51RGUd9/
V2M3zRPYLY+zF4r8t0QfyBcIpByk+f2dDHXjl3PVywSy8x2dgugnae9+sGmN
QM2zos2viPP8cmVVO+1D4dONI9qpAYYZuRE1vb4U8jy2Zv8Rhsqk1I11fhRu
Ncri8h4zHNpRnHVmPYW67/blRs0wLPG/OWB4ncJzS9r5vcsMY2eeaz7ZRCHd
mjDe8BpHn57g8rAtFL6UyiQXAzg6quN9aYDYLz5jbVXJ0Xi6IH1CRkH/o31l
KYpjSJq9yx1EwSfk2OlKHcdheLy9eisFVcKlaHkKx7Ny2TmLQuSvl5WfOM4x
djFmIX0bheEfnFuefSP6DXyRHKOiEBo6H26rFP3qq12qUAqJT1qz2to4ZhTd
V/qFU9hpsFWUj3FUGmjhowgKpX9HeszifQ7poqfaIyngictNd8IFLAnJ4Fff
o7Aya3NLDwgYu85mz3+fQqMzc8J+SkCf0d7ANA0FeeLXVxw3BHQ0S/L27KKQ
VJSpC3ghoPyNrzqaRf3/P/0D9smXnQ==
            "]], 
           Line[CompressedData["
1:eJxFUnss1XEc/YUkfcptMylNMTUpU6HFXH3IVAur7w/TA3kriSt5TjWPG3XN
rsU8cyukoXZXuGPuPubdSEw0hm6aPFoPj0rUuvVPZzs7O/+cnX0+xyQwioVo
cBxnoeZfrbiiaMoRAXL/4En5TtG3f6j9ibzzqa++8+RufP/TcCygc177du92
nrRW+llDPOB4nbKstICnpmGNhvwkQG1Bql5rNE8xz62N4lIAj/daVRi682Qu
Db7hdRPQMyjUcIslTxOReZM2aYD2/ZsdeQFPQ7pCKRMDHuRadEMXGfU8eu8Y
nQW4M+KG3Z1RRq0uko/ZEnWebOOm5HZGjSrrouocQImrYP2KnJH8+uix7lzA
oYRk81EZoyqjtKWpPMC22KnxBSmjMoXFQ61CwACnSYlZBqN8r4FTpiWAk0GN
PiyJUfZ84u8jZYCRpvpuYSJG6TkmNb4PAJ8tpVSevsQoaV/3meQKwHvtSh/N
EEai7uh1hVWAoBkuEwUwCg81rKuvBrQKkjTf9Wfkp0mBg08Az+7xVoapvZcs
TDAvB1zMKPCdvsDITain1KsD3H1ROm8QzOjoSH2EpQIwwYUTfQtnZB/vt/Vk
k/oevDRREsXogL52Z7hS/Q+9hGRVPCNzeW2suAXQ8bLGDJfKaIeHl2l5G2A8
p5O6nM3IYG61r6UTsCgkUTFWzAgyy1MmXgB+zTSzbatmpLnLbe+vXsA+Z4eM
rmZGP1sW3mzrB6zxqF7dMMDoi1+x+PAgoM8hh/H6aUYfVpxtvIcBS7q4d8tr
eBovmFVdHVH3V4iFAmOeXtvm5kjHADM6ZIHOQp56BuyET98CnqucaZvx56k1
SjXbMwk4svazaZyYp0bIKpidAiyvbTa6JudJ/ni/q84sYMzLXr9SFU/ptwaW
O+b+7/EPBYs2ww==
            "]], 
           Line[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAANwOmR+8pDUAAAAAAAABUwPCJ8IR3
Kw1A+sdsNAXqU8DnJpgylS4NQM4r9E+2wlPA3sM/4LIxDUCce1brDKBTwNVg
543QNA1A2aU6anaBU8DM/Y477jcNQPf0lQeAZlPAwpo26Qs7DUD1aF+wzk5T
wLk33pYpPg1AiM9+Xxk6U8Cw1IVER0ENQA1DDB4lKFPApnEt8mREDUAFZlQf
whhTwJ0O1Z+CRw1AvBqcockLU8CUq3xNoEoNQJd7t1ocAVPAufUWyIhNDUDY
CNcBIflSwN4/sUJxUA1A3ZxERv/yUsADiku9WVMNQP3pybqq7lLAKNTlN0JW
DUCLirY6GuxSwE0egLIqWQ1A1LQRqkfrUsByaBotE1wNQA1YZMsv7FLAl7K0
p/teDUBvrsIo0u5SwLz8TiLkYQ1AOfvUDjHzUsDhRumczGQNQOedmZlR+VLA
BpGDF7VnDUBalI7TOwFTwCvbHZKdag1Ao7P06PoKU8BQJbgMhm0NQGZpDHKd
FlPAdW9Sh25wDUB286HYNSRTwJq57AFXcw1A0i0o39ozU8C+A4d8P3YNQLya
OlKoRVPA400h9yd5DUADkgXxv1lTwAiYu3EQfA1AVhFWnkpwU8As4lXs+H4N
QFhP1/N5iVPAUSzwZuGBDUALfcRciqVTwHZ2iuHJhA1A7bWP78XEU8CbwCRc
socNQArFDVuI51PAGjNLn4iJDUAAAAAAAABUwA5q9iA=
            "]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGCQBGIQvVqq2fjjVV4HBjAIOdA0KcvL/Bqvw6Qvf3y1/wYf
WH6H5aj8TV6Hpb9KQzc+Cj5wRm2+PccdXgdhM4YpZaeDD3wssNz14R6vg4XY
EwWT7cEHxHZfNrn5kNfBONN634alwQesWfPWH3zC61B/J0po37TgAwn+HFqr
nvM6/MlYP9esK/hA68xFSya94nVQ5WUz/1MffGDVYxv56re8Dj7cvK++lQcf
OK97fWbyB16Ha+W58iJFwQe+lBeK+HwGuvdC/1/XvOADkoe4+02+AfmcGd+a
coIP2PEs45T9yevQtSa96iiQnxzm0ML6h9dhT3f9ae784AMdC279e/uP1+FN
it/b8OLgA2telVReY+RzaHWr3ri+MvjARRP+L/tY+ByO7P3/QKYp+ICZvcKO
p+x8Ds90l+qs7A0+MMvTsIaHm89Byjuy88Ls4AP/g50cjPn4HK5Mjc3ZtCb4
QEpcMEuUIJ9D0Lfw12UHgg+czEg50SDC56DzOb4i4HrwAb3i0p7l4nwOxWvW
Otd9DD7A8LOIz0CSDx7+AI5asvQ=
            "]], 
           
           Line[{{3.81058158486345, -80.}, {
            3.810791124320506, -79.97055633877497}, {
            3.8123299081282966`, -79.80222516933871}, {
            3.8138686919360874`, -79.67973258124746}, {
            3.815407475743878, -79.60158471623667}, {
            3.8169462595516688`, -79.56678185266651}, {
            3.8184850433594595`, -79.5747755726298}, {
            3.82002382716725, -79.62544531840481}, {
            3.821562610975041, -79.7190922869899}, {
            3.8231013947828316`, -79.85645013314662}, {
            3.824313335192483, -80.}}]}, "Charting`Private`Tag#3"], 
         Annotation[{
           Directive[
            Opacity[1.], 
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJwVj3k81AkfgL3jvkoNmSlW7LgjUeMIX7lWJaXUxrLLrmNRobRTKjnawpYj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            "]], 
           Line[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAomfwmfVt/T9mFh7Enn5FwB7JhfIh
HP4/xF3/txFnR8BoFca1UyL+P9HEgZ03eUfA+q1GPLcu/j+pO7SrrZ1HwB7f
R0l+R/4/+cWLB0TnR8BoQUpjDHn+P1RT724jfUjA/AVPlyjc/j+yLQJV/LNJ
wCOPWP9gov8/z5pg7q5QTMDINX5cKKj/P8PCSmEqZUzAbtyjue+t/z93RSOl
tHlMwLgp73N+uf8/NdCFyvWiTMBOxIXom9D/P9mPEbor9kzAevmy0db+/z9a
Wwa2b59NwOmxBlKmLQBAiVWlEqb9TsBBHGEkHIoAQKqu8YWr9VDA1K9qHD6N
AEBU1OEB+QJRwGZDdBRgkABA7oX87FAQUcCMaocEpJYAQMe4dDEgK1HA1rit
5CujAEAfKC9aPWFRwGpV+qQ7vABAbM8YdnnPUcCUjpMlW+4AQMuGGI40tFLA
4fHijeUxAUAAAAAAAABUwJ7dsAY=
            "]]}, "Charting`Private`Tag#4"], {}}}, {}}, <|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{0., 4.605170092005027}, {10., -80.}}, 
         "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0., 0},
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]], 
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[2]], 
           Directive[
            Opacity[1.], 
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[2]], 
           Directive[
            Opacity[1.], 
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Exp[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Log, Exp}, {Identity, Identity}}|>, 
         "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]], 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
    Axes -> {True, True}, AxesLabel -> {
      FormBox[
       TagBox["\[Omega]", HoldForm], TraditionalForm], None}, 
    AxesOrigin -> {0., 0}, DisplayFunction -> Identity, 
    Frame -> {{False, False}, {False, False}}, 
    FrameLabel -> {{None, None}, {None, None}}, 
    FrameTicks -> {{Automatic, Automatic}, {
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0], 
       Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> 
    FrontEndValueCache[{
      Charting`ScaledTickValues[{Log, Exp}][#, #2, {6, 6}]& , 
       Automatic}, {{{0., 
         Directive[]}, {1.6094379124341003`, 
         Directive[]}, {2.302585092994046, 
         Directive[]}, {3.912023005428146, 
         Directive[]}, {4.605170185988092, 
         Directive[]}, {-2.3025850929940455`, 
         Directive[]}, {-1.6094379124341003`, 
         Directive[]}, {-1.2039728043259361`, 
         Directive[]}, {-0.916290731874155, 
         Directive[]}, {-0.6931471805599453, 
         Directive[]}, {-0.5108256237659907, 
         Directive[]}, {-0.35667494393873245`, 
         Directive[]}, {-0.2231435513142097, 
         Directive[]}, {-0.10536051565782628`, 
         Directive[]}, {0.6931471805599453, 
         Directive[]}, {1.0986122886681098`, 
         Directive[]}, {1.3862943611198906`, 
         Directive[]}, {1.791759469228055, 
         Directive[]}, {1.9459101490553132`, 
         Directive[]}, {2.0794415416798357`, 
         Directive[]}, {2.1972245773362196`, 
         Directive[]}, {2.995732273553991, 
         Directive[]}, {3.4011973816621555`, 
         Directive[]}, {3.6888794541139363`, 
         Directive[]}, {4.0943445622221, 
         Directive[]}, {4.248495242049359, 
         Directive[]}, {4.382026634673881, 
         Directive[]}, {4.499809670330265, 
         Directive[]}, {5.298317366548036, 
         Directive[]}, {5.703782474656201, 
         Directive[]}, {5.991464547107982, 
         Directive[]}, {6.214608098422191, 
         Directive[]}, {6.907755278982137, 
         Directive[]}, {7.600902459542082, 
         Directive[]}}, Automatic}], GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, 
    Method -> {
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Exp[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Exp[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}}, 
    PlotRange -> {{0., 4.605170092005027}, {10., -80.}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}}, Ticks -> FrontEndValueCache[{
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0], Automatic}, {{{0., 
         FormBox["1", TraditionalForm], {0.01, 0.}}, {1.6094379124341003`, 
         FormBox["5", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
         FormBox["10", TraditionalForm], {0.01, 0.}}, {3.912023005428146, 
         FormBox["50", TraditionalForm], {0.01, 0.}}, {4.605170185988092, 
         FormBox["100", TraditionalForm], {0.01, 0.}}, {-2.3025850929940455`, 
         
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-1.6094379124341003`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-1.2039728043259361`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.916290731874155, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.6931471805599453, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.5108256237659907, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.35667494393873245`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.2231435513142097, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 
         0.}}, {-0.10536051565782628`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        0.6931471805599453, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        1.0986122886681098`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        1.3862943611198906`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        1.791759469228055, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        1.9459101490553132`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        2.0794415416798357`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        2.1972245773362196`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        2.995732273553991, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        3.4011973816621555`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        3.6888794541139363`, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        4.0943445622221, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        4.248495242049359, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        4.382026634673881, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        4.499809670330265, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        5.298317366548036, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        5.703782474656201, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        5.991464547107982, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        6.214608098422191, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        6.907755278982137, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
        7.600902459542082, 
         FormBox[
          TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, 
       Automatic}]], 
   FormBox[
    FormBox[
     TemplateBox[{
       StyleBox["\"pulse\"", Small, StripOnInput -> False], 
       StyleBox["\"triangle\"", Small, StripOnInput -> False], 
       StyleBox["\"raised cosine\"", Small, StripOnInput -> False], 
       StyleBox["\"Gaussian\"", Small, StripOnInput -> False]}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 20}, {20, 20}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 20}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.30000000000000004`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 20}, {20, 20}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 20}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.30000000000000004`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 20}, {20, 20}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 20}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.30000000000000004`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 20}, {20, 20}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 20}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.30000000000000004`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.893951850601911*^9, 3.893952078918468*^9, 
  3.897571941820659*^9},
 CellID->631726173,ExpressionUUID->"1fc70ac6-42cc-466e-ab17-d71087f0ba7f"]
}, Open  ]],

Cell["\<\
The spectrum of the square pulse, the \[OpenCurlyDoubleQuote]sharpest\
\[CloseCurlyDoubleQuote] of the signals, drops off the slowest as the \
frequency increases; it has the widest bandwidth.\
\>", "Text",
 CellChangeTimes->{
  3.675613869463106*^9, {3.718406762877966*^9, 3.718406768665354*^9}, {
   3.718406886585929*^9, 3.718406908211482*^9}, {3.801838794218257*^9, 
   3.801838822412757*^9}, {3.8018388831763887`*^9, 3.801838905088477*^9}, {
   3.801839337871955*^9, 3.801839355552712*^9}, {3.811503189457182*^9, 
   3.811503227780259*^9}, {3.811508899288645*^9, 3.811508901712286*^9}, {
   3.813247039473519*^9, 3.81324708579544*^9}, {3.834073005230842*^9, 
   3.834073005326976*^9}},
 CellID->464065731,ExpressionUUID->"554f67d0-4ceb-4733-a313-510f7e3df7fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourier Transform of Periodic Signals", "Subsection",
 CellChangeTimes->{{3.40287307465625*^9, 3.402873084734375*^9}, {
  3.465315841234375*^9, 3.465315845703125*^9}, {3.716072216104913*^9, 
  3.7160722199150963`*^9}, {3.803434148597896*^9, 3.8034341679732447`*^9}, {
  3.83399001469026*^9, 3.8339900215718594`*^9}},
 CellID->2039618660,ExpressionUUID->"1393ae8d-1b07-4d8b-af6e-256254ee0264"],

Cell["\<\
Periodic signals do not satisfy the existence condition of the Fourier \
integral:\
\>", "Text",
 CellChangeTimes->{{3.529057484296235*^9, 3.52905764076451*^9}, {
   3.5290577110738335`*^9, 3.5290577211358514`*^9}, {3.529057759637719*^9, 
   3.529057843862267*^9}, 3.5290578817547336`*^9, {3.529061512584711*^9, 
   3.5290615645328026`*^9}, {3.587339564463594*^9, 3.587339564806794*^9}, {
   3.587407941358757*^9, 3.587407946881157*^9}, {3.589583447742605*^9, 
   3.5895834690054426`*^9}, {3.654469742103041*^9, 3.654469754317684*^9}, {
   3.654557842663908*^9, 3.654557846922655*^9}, {3.8018425098911977`*^9, 
   3.801842522043691*^9}, 3.801842573185014*^9, {3.803428507552527*^9, 
   3.803428509227556*^9}, 3.810846135322272*^9, {3.813280113032203*^9, 
   3.813280119240202*^9}, 3.8254467721988187`*^9},
 CellID->1736845206,ExpressionUUID->"2c29987c-6753-473a-8534-0aa9808b6efd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}], "]"}], "2"], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.80184257739273*^9, 3.801842617086271*^9}, {
  3.813280101822204*^9, 3.8132801021761513`*^9}},
 CellID->412163571,ExpressionUUID->"e8c234e1-bb71-4417-a484-087ee322481d"],

Cell[BoxData[
 TemplateBox[{
  "Integrate", "idiv", 
   "\"Integral of \\!\\(\\*SuperscriptBox[RowBox[{\\\"Sin\\\", \\\"[\\\", \
RowBox[{\\\"2\\\", \\\" \\\", \\\"\[Pi]\\\", \\\" \\\", \\\"t\\\"}], \
\\\"]\\\"}], \\\"2\\\"]\\) does not converge on \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"\[Infinity]\\\"}], \\\",\\\", \
\\\"\[Infinity]\\\"}], \\\"}\\\"}]\\).\"", 2, 19, 1, 27218796162949084627, 
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.801842623360507*^9, 3.801843363025921*^9, 
  3.813280103259176*^9, 3.897571945520006*^9},
 CellID->46522221,ExpressionUUID->"cf077edb-3dd3-4afe-8f1a-fdb9c7123ce3"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", 
   RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"Abs", "[", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Pi]", " ", "t"}], "]"}], "]"}], "2"], 
   RowBox[{"\[DifferentialD]", "t"}]}]}]], "Output",
 CellChangeTimes->{3.801842623445281*^9, 3.801843363054847*^9, 
  3.813280103268179*^9, 3.897571945525172*^9},
 CellID->364958934,ExpressionUUID->"3b012881-39e8-414f-bd4b-1c458ebbdcda"]
}, Open  ]],

Cell[TextData[{
 "However, periodic signals do have Fourier transforms, but they must be \
obtained indirectly using the Fourier series and are formulated using the \
Dirac delta function. To derive the formula for the Fourier transform of a \
periodic signal, consider first the case of a signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "66c5076b-e398-4e94-8277-74de19cda194"],
 " with a Fourier transform given by the following formula"
}], "Text",
 CellChangeTimes->{{3.529057484296235*^9, 3.52905764076451*^9}, {
   3.5290577110738335`*^9, 3.5290577211358514`*^9}, {3.529057759637719*^9, 
   3.529057843862267*^9}, 3.5290578817547336`*^9, {3.529061512584711*^9, 
   3.5290615645328026`*^9}, {3.587339564463594*^9, 3.587339564806794*^9}, {
   3.587407941358757*^9, 3.587407946881157*^9}, {3.589583447742605*^9, 
   3.5895834690054426`*^9}, {3.654469742103041*^9, 3.654469775159017*^9}, {
   3.801845112825523*^9, 3.801845214981846*^9}, {3.811503835868735*^9, 
   3.811503850765425*^9}, {3.812846089619753*^9, 3.81284609706594*^9}, {
   3.833990104361595*^9, 3.8339901120988717`*^9}, {3.833990148419735*^9, 
   3.833990154615159*^9}, {3.891107368133236*^9, 3.891107403731181*^9}, 
   3.915815432586913*^9, 3.916220251559994*^9},
 CellID->1598376222,ExpressionUUID->"1048ac45-1bc1-4379-af16-1a4371f8ec7d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", "\[InvisibleSpace]", "\[Omega]"}], ")"}], "=", 
    RowBox[{"2", "\[Pi]", " ", 
     RowBox[{"\[Delta]", "(", 
      RowBox[{"\[Omega]", "-", 
       SubscriptBox["\[Omega]", "0"]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"1e9a1ac6-95dd-48e8-8b16-1919c73a6e0d"]
}], "Text",
 CellChangeTimes->{{3.654373640589531*^9, 3.654373651860531*^9}, {
  3.654373793353595*^9, 3.654373830403119*^9}, {3.654373874924949*^9, 
  3.654373911678078*^9}, {3.654373947167623*^9, 3.654374084399063*^9}, {
  3.6756097322021065`*^9, 3.675609917880106*^9}, {3.675609979198106*^9, 
  3.675610047551107*^9}, {3.675610146640106*^9, 3.675610163488106*^9}, {
  3.810845671337662*^9, 3.810845692079429*^9}, {3.834072971639165*^9, 
  3.83407297163926*^9}, {3.8340730890014477`*^9, 3.834073194379802*^9}},
 CellID->1036222831,ExpressionUUID->"78e484db-4891-4dd3-bded-02c5a9fd9437"],

Cell[TextData[{
 "Now use the inverse Fourier transform to determine the signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "2d969781-985c-4dad-93b2-05ee8114f355"],
 ":"
}], "Text",
 CellChangeTimes->{{3.529061627120113*^9, 3.529061649069351*^9}, {
   3.5916154977892666`*^9, 3.5916154979452767`*^9}, {3.810846182613514*^9, 
   3.81084618325948*^9}, {3.833990244992788*^9, 3.8339902453090005`*^9}, 
   3.834073219018997*^9, {3.891107454583259*^9, 3.891107471942488*^9}},
 CellID->1852227094,ExpressionUUID->"2daca6f7-6c59-4a04-a833-75a7c35d6c77"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseFourierTransform", "[", 
  RowBox[{
   RowBox[{"2", " ", "\[Pi]", " ", 
    RowBox[{"DiracDelta", "[", 
     RowBox[{"\[Omega]", "-", "\[Omega]0"}], "]"}]}], ",", "\[Omega]", ",", 
   "t", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.810846188926483*^9, 3.810846255619088*^9}, {
  3.810846348500398*^9, 3.810846349925361*^9}},
 CellID->457821946,ExpressionUUID->"30c31da4-9ef8-43ce-aa46-23e32034159a"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Omega]0"}]]], "Output",
 CellChangeTimes->{3.8108462565821247`*^9, 3.810846351993335*^9, 
  3.897571950401194*^9},
 CellID->41070951,ExpressionUUID->"f06f7b45-a480-431d-9bb0-bf101f937c6c"]
}, Open  ]],

Cell["\<\
This establishes the following relationship between a complex exponential (in \
time) and an impulse function (in frequency)\
\>", "Text",
 CellChangeTimes->{{3.529076406245673*^9, 3.529076406682474*^9}, {
   3.5291020506021614`*^9, 3.529102162251362*^9}, {3.6545578884337206`*^9, 
   3.654557891163686*^9}, 3.688335573197301*^9, {3.688335631798301*^9, 
   3.688335655533301*^9}, {3.811503877581*^9, 3.811503903782561*^9}, 
   3.916236650117882*^9},
 CellID->179539221,ExpressionUUID->"46d3b123-d29b-43e1-975d-243fd67583cf"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"j", " ", 
      SubscriptBox["\[Omega]", "0"], "t"}]], " ", 
    OverscriptBox["\[LongLeftRightArrow]", "\[ScriptCapitalF]"], " ", "2"}], 
   "\[Pi]", " ", 
   RowBox[{"\[Delta]", "(", 
    RowBox[{"\[Omega]", "-", 
     SubscriptBox["\[Omega]", "0"]}], ")"}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.811504485568046*^9, 3.811504496356764*^9}, {
   3.811504528221889*^9, 3.811504585940238*^9}, 3.9162203479331207`*^9},
 CellID->301163312,ExpressionUUID->"b65175e9-1e6b-43d9-ac7f-f619d81f4f5a"],

Cell[TextData[{
 "The rest is relatively straightforward. Recall that a periodic signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "d797944e-d22a-4cd0-a338-b8e0371e0631"],
 " has the following Fourier series representation"
}], "Text",
 CellChangeTimes->{{3.529076406245673*^9, 3.529076406682474*^9}, {
   3.5291020506021614`*^9, 3.529102162251362*^9}, {3.6545578884337206`*^9, 
   3.654557891163686*^9}, {3.6883357790963*^9, 3.688335781053301*^9}, {
   3.812846283708624*^9, 3.812846285909732*^9}, {3.812846514953225*^9, 
   3.812846546524667*^9}, {3.825446845929047*^9, 3.825446853229295*^9}, 
   3.833990261319195*^9, {3.891107512198636*^9, 3.891107591575596*^9}, {
   3.915815682621634*^9, 3.91581568449662*^9}, 3.9162202577997665`*^9, {
   3.916220290919119*^9, 3.9162203037303543`*^9}},
 CellID->32828805,ExpressionUUID->"bfdf2781-1e17-48b3-b7ae-5f0e69447ae8"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[ThinSpace]", 
       RowBox[{"k", "=", 
        RowBox[{"-", "\[Infinity]"}]}]}], 
      RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
     RowBox[{
      SubscriptBox["c", "k"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"j", " ", 
        SubscriptBox["\[Omega]", "0"], "k", " ", "t"}]]}]}]}], 
   TraditionalForm]],ExpressionUUID->"586e05fd-42d3-4ad3-a02f-98da0c331cfe"]
}], "Text",
 CellChangeTimes->{{3.854465137672836*^9, 3.854465138976389*^9}, {
  3.931269276428627*^9, 3.931269278760222*^9}},
 CellID->1997912003,ExpressionUUID->"12406f27-0862-4884-bf10-db9da7c9aaa6"],

Cell["\<\
Taking the Fourier transform on both sides and substituting the Fourier \
transform of the complex exponential gives the following result\
\>", "Text",
 CellChangeTimes->{{3.5291023690605617`*^9, 3.529102385424961*^9}, {
   3.529102521489161*^9, 3.5291026286299615`*^9}, {3.811504221456978*^9, 
   3.8115042533226285`*^9}, {3.833990293732664*^9, 3.833990299881171*^9}, {
   3.833990342855291*^9, 3.833990343257169*^9}, 3.834073543153343*^9, 
   3.9162202630216007`*^9},
 CellID->852729929,ExpressionUUID->"3e2ed506-0916-4f18-a41b-45f2aef57e1f"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
    RowBox[{"2", "\[Pi]", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[ThinSpace]", 
        RowBox[{"k", "=", 
         RowBox[{"-", "\[Infinity]"}]}]}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
      RowBox[{
       SubscriptBox["c", "k"], 
       RowBox[{"\[Delta]", "(", 
        RowBox[{"\[Omega]", "-", 
         RowBox[{"k", " ", 
          SubscriptBox["\[Omega]", "0"]}]}], ")"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"0f4accd3-69d0-43c7-87c6-266a49277e18"]
}], "Text",
 CellChangeTimes->{{3.8544651574526963`*^9, 3.854465158981517*^9}, {
  3.931269282043103*^9, 3.931269282772325*^9}},
 CellID->1673540272,ExpressionUUID->"a9f60814-a0c3-4ccd-9b6b-c8b5a7360b7f"],

Cell["\<\
This result states that the Fourier transform of a periodic signal is a \
superposition of impulses scaled by the coefficients of the Fourier series \
expansion of the signal. \
\>", "Text",
 CellChangeTimes->{{3.529102651421562*^9, 3.529102759638761*^9}, {
   3.529103973704362*^9, 3.5291039752019615`*^9}, {3.5291040110507617`*^9, 
   3.529104042484762*^9}, {3.529232335004163*^9, 3.5292323544912786`*^9}, {
   3.529232416099406*^9, 3.529232442791053*^9}, {3.529232486471129*^9, 
   3.529232501805957*^9}, {3.529232694669095*^9, 3.529232818446513*^9}, {
   3.5292329554303536`*^9, 3.529232956054355*^9}, 3.5873398421294837`*^9, {
   3.811504641343812*^9, 3.8115046486476016`*^9}, {3.8911076643077807`*^9, 
   3.891107696088051*^9}},
 CellID->1598026745,ExpressionUUID->"56b21fab-bb33-4321-850d-9d0a745e0b98"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsection",
 CellChangeTimes->{{3.6544705324736958`*^9, 3.654470537160695*^9}, {
  3.6844440021868157`*^9, 3.684444002717212*^9}, {3.686075431172246*^9, 
  3.686075431234646*^9}, {3.686259873300867*^9, 3.6862598733944674`*^9}, {
  3.687041360162407*^9, 3.687041360287205*^9}, {3.688299636688783*^9, 
  3.688299637148779*^9}, {3.801845526320036*^9, 3.801845526687056*^9}, {
  3.803434351387162*^9, 3.8034343514998507`*^9}},
 CellID->1605013833,ExpressionUUID->"f12e88b3-b6d6-4237-ab32-4656a8348219"],

Cell[" Obtain the Fourier transform of the square wave shown", "Text",
 CellChangeTimes->{{3.5291026514215617`*^9, 3.5291027596387615`*^9}, {
   3.529103973704362*^9, 3.5291039752019615`*^9}, {3.5291040110507617`*^9, 
   3.5291040424847617`*^9}, {3.5292323350041637`*^9, 
   3.5292323544912786`*^9}, {3.5292324160994062`*^9, 3.529232442791053*^9}, {
   3.5292324864711294`*^9, 3.529232501805957*^9}, {3.5292326946690955`*^9, 
   3.529232818446513*^9}, {3.5292329554303536`*^9, 3.5292329560543547`*^9}, {
   3.5873398421294813`*^9, 3.5873398719879336`*^9}, {3.587407953713957*^9, 
   3.587407955539157*^9}, {3.5916233636111517`*^9, 3.5916233639075537`*^9}, {
   3.592125561229852*^9, 3.5921255961528354`*^9}, {3.6544699831199512`*^9, 
   3.6544699863647094`*^9}, {3.6544700448015604`*^9, 3.654470046517538*^9}, {
   3.654814077994568*^9, 3.6548140793673506`*^9}, {3.8018468853818884`*^9, 
   3.801846895150775*^9}, {3.803434366439159*^9, 3.8034343742733192`*^9}, {
   3.811506893691835*^9, 3.8115069173668413`*^9}, {3.834073283012457*^9, 
   3.834073283292534*^9}, 3.918643983392849*^9},
 CellID->925401264,ExpressionUUID->"a780fba0-605c-4fa5-b11f-610ad1fb4aa7"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJxN2Hk0FdoeB/BjKjO5FEVFkS6FZCxDRclwkikRp6NIkTGZkpLK9cpQlCtJ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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxN2Hk0FdoeB/BjKjO5FEVFkS6FZCxDRclwkikRp6NIkTGZkpLK9cpQlCtJ
0STvhAaSOW7I7JjKEEWGDJlnb7237t3ft//Z67P22uv3W3v9fnuvtSUd3M0c
WSkUihgLhfLfebvO6oHl5eUCyv/GqI7Z9aoXyjTYtyb07Kn8JWImk2egiL5I
7FehFbyQv0AsUegurCYOBzjONWgJwU3cV2/rccKhdobjB9hg5XQBc6Ol+b9N
oXSzNmZSZ+Eoy3ghswlY+xnNy3IEHprbXG89ABsmvYymfYXZBksEz1bCmVrh
Hh4f4eNRh2q9i+Fclc+RAdnw+Usj/GEpcL/IWr7kC3Ccc6frE194//uUyude
8KPjCjfSneFjL/R48i3gGl13rlZ5+I1LCYdA+xyx+kY3pSfNcA5zjZ1WPVyo
5fLa5SNcISB0oiwD/vqKVnj5Gsy9MBcwoQAfv6E02hoySzxzKzCsQGeGOJm/
Qyyua4o4wVDJq+GPSeLNPIYVtaHwi08OUtXBcI5xTH2ZD9xKnd6RT4dXm+eN
P9OAI20P+lzsn8C6uENV4Hc4sS1A2r8TZtilNXo3wpU0AdXTRTDnycYp8z/h
qM3D1MMx8JqeFU+pkbCMk/qRg1dhfed7WdqecIgr3W/rQbgjwj4hZx+smWFb
aKQNj01acropw1RRc/nlbXCqpqlplCxMDzaMy5SAcx8eyN0nCouW6H1lCsHn
evewO/HBtZw6stMrYXm53cZhrHCYiYaH2OI46b/v7qoxqdOw7i3l7F1j8IbH
4i0lf8FLWRwzJvfg3PZmteN6cCBbqq/X0BjxcNFu6mYjmH6pZnPTs1/EsXk9
cQlnRolzOmV506SGiTcJ6u61SBwkPiNx0mrdngHizN/DznR/6yMWtTfpko+A
g6KFrH3VYauOD5Ncm2BFOZ/bCXxwQp1Jdw8rzOUno6Qw8wP3wfrlYL8huLuk
ubqoGz7kki7B0wLnrvrD1aIKjrXX5P6RBRvMJOjz3oTfJPrEWIbAUvrUb4m+
8Hz08iUlB5gh55BrpQYL07YoP+zqJe4szdioqgpfMJ/VU5eHRbt0T2tKwaYL
NRna/HDhjuG9B3p7iJMe/O5ofQd28E9+HjD1nbhHPnZHwdtvxKsuPlfdztKF
elQdkX883kZ8RW+o9p1fM3Gxwc9DO0/AFJPBaoYJfMGyvzJZCj7v1FN2s7KJ
2DmsvZC+ETaurErnKmMSh9dWKoRmwmXMT4ylBFi/vTxt3BPWHi591r4OVhTM
T8pwbyAWsWBEHV1Tj/dF5l85+myw6eyp70ojdYifKKnO/RFe6ovpzDkP33vv
yfXUAVaPoCrfpsJeypzXXWTg3qDA7eJNtThPU2trzmJ44yaVkIl/wzZlw42V
V+Hp+E/L2Z5wzNlnWx/bwdVCDkFBKrBLj/bT05IwZ/a6Oks+2FDk1+SVsRrS
P1dzUg8eq4Dn2Nf/4g2A3Q5Fx+VthQWT5Zh7n1aiv6dKBco2VxDv9Trmkviq
hPjxl56b/aH5xHaHxV9/OZFC/I47sLHYJ1nnH6t0s6y/bF1A/MDDvkQrq4R4
0+j7Wc3icuL8Uo1HDUGVxDb3sgxdNWqI+a0+0jqj4CLB5nNmfTCf78tlDu5a
nX/OJ8dxvKR7A3zKQi28QAUW3hd4KMEILlIqEPanw24b2T5b+sJli+EnBZLh
wOx4/5A5WPZphzZNsI6YGSvFvlsG3u6dGjF5GO7elpPs/Bw+mNxaRbWuJx69
ynAqPQvHOV9Z3nUF7tu2TWkrAw7LvhTDxt6AfKu22Ga/hA/M+PRJrmwk1jcR
Ypt800wcSWu+pJjVRvyRKsFnKtRFPCQpcrE+/huxeuBDz6IUOIS5zTGdAa++
vt84ohjW/um71nAAjnz7+W2RxndiJaOkkfQW+EKK/LcH3fBfi9lNET9hm/S6
PFdKD+KLsN2QlYUbOh1lk3xhn3Ny9MjVvciPeyTXShLOfpApul4eXqjQqE3b
A4dIGuhUuMIR1SclOD7Aiidl/Sur4LrZQebtFlhY2vuG1DAcH3h5XkfsB/ET
2cTWAHfYIJ+usjcA7jeXjua6CssHpxnExcPVwh4ptMewe6oyZUs6nNmYk/Wm
FLZwufhbUC08SdnrrvcFvnOH4xNPL6wuXy7TMAp/LroREj8PBx4x7aCv6CP9
KD70m+bWVXB+SHPs6Dq4QmHCW84Lbm4TNHMq+7/9L56Iq3EPEB/33/1jpfEg
8Qc5tfAPHMPEMly5fSkGo8QSuS76HGG/cH/Yqk3vUhkjpsyxPvfqhpciPa0O
KI8TL0h/ZRMPhec97tpcS4Pn3lMzRpmwPz21TbofnlmxgtN2EbYebTNzZp1A
vbW+uu+zEhb9EN4Xwgv7pdGVo1bBLbHqF++vhtWDBcpT18HTh/PsS6XhkNaX
7dpyMD/90bFsRVjG47rNi12wRcRhq+jDcHpFj4ldEHx6H7/WJBP+spO2Tjp0
ktjjiOAqqbYpYrGY79bsEjPEDNukp+N+s8RHtIINyvLmiNsmewWKi2EHBrX5
/UfYdcN6p5d1cAhL3pU7PTCjdC7/JN88MTv1vAqLHRy+omNhjg4LFOiXTDjB
axVFzPs8YAWh1x41obBN068X99PgrxFHve9mwI4HijSj38Ie2VHloYXwtXiF
Hy5MmNf8LsOxFY7mWfahdcAJF6rZzftgSRXVSuMh+MnQ/dv7x2D5Jxy2utNw
hv1ZKc0F2OHNqEQSywKpR2Hec2IrVsKlDtPCrrzw+XcBgvWr4BanyysTxWFN
4bCl01vgJbfYnyxacHH5o89/msFGwXlvy4Ng5s6WW7PP4N4HfEZHl+EZ7n1s
7ywXiaXdCsQHp2Czul2qEnFLxLqcW6P4jZeJ//5/If4PrCcnkA==
             "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.4, 
           1.4}}, "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.4, 1.4}},
          "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0},
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxN2Hk0FdoeB/BjKjO5FEVFkS6FZCxDRclwkikRp6NIkTGZkpLK9cpQlCtJ
0STvhAaSOW7I7JjKEEWGDJlnb7237t3ft//Z67P22uv3W3v9fnuvtSUd3M0c
WSkUihgLhfLfebvO6oHl5eUCyv/GqI7Z9aoXyjTYtyb07Kn8JWImk2egiL5I
7FehFbyQv0AsUegurCYOBzjONWgJwU3cV2/rccKhdobjB9hg5XQBc6Ol+b9N
oXSzNmZSZ+Eoy3ghswlY+xnNy3IEHprbXG89ABsmvYymfYXZBksEz1bCmVrh
Hh4f4eNRh2q9i+Fclc+RAdnw+Usj/GEpcL/IWr7kC3Ccc6frE194//uUyude
8KPjCjfSneFjL/R48i3gGl13rlZ5+I1LCYdA+xyx+kY3pSfNcA5zjZ1WPVyo
5fLa5SNcISB0oiwD/vqKVnj5Gsy9MBcwoQAfv6E02hoySzxzKzCsQGeGOJm/
Qyyua4o4wVDJq+GPSeLNPIYVtaHwi08OUtXBcI5xTH2ZD9xKnd6RT4dXm+eN
P9OAI20P+lzsn8C6uENV4Hc4sS1A2r8TZtilNXo3wpU0AdXTRTDnycYp8z/h
qM3D1MMx8JqeFU+pkbCMk/qRg1dhfed7WdqecIgr3W/rQbgjwj4hZx+smWFb
aKQNj01acropw1RRc/nlbXCqpqlplCxMDzaMy5SAcx8eyN0nCouW6H1lCsHn
evewO/HBtZw6stMrYXm53cZhrHCYiYaH2OI46b/v7qoxqdOw7i3l7F1j8IbH
4i0lf8FLWRwzJvfg3PZmteN6cCBbqq/X0BjxcNFu6mYjmH6pZnPTs1/EsXk9
cQlnRolzOmV506SGiTcJ6u61SBwkPiNx0mrdngHizN/DznR/6yMWtTfpko+A
g6KFrH3VYauOD5Ncm2BFOZ/bCXxwQp1Jdw8rzOUno6Qw8wP3wfrlYL8huLuk
ubqoGz7kki7B0wLnrvrD1aIKjrXX5P6RBRvMJOjz3oTfJPrEWIbAUvrUb4m+
8Hz08iUlB5gh55BrpQYL07YoP+zqJe4szdioqgpfMJ/VU5eHRbt0T2tKwaYL
NRna/HDhjuG9B3p7iJMe/O5ofQd28E9+HjD1nbhHPnZHwdtvxKsuPlfdztKF
elQdkX883kZ8RW+o9p1fM3Gxwc9DO0/AFJPBaoYJfMGyvzJZCj7v1FN2s7KJ
2DmsvZC+ETaurErnKmMSh9dWKoRmwmXMT4ylBFi/vTxt3BPWHi591r4OVhTM
T8pwbyAWsWBEHV1Tj/dF5l85+myw6eyp70ojdYifKKnO/RFe6ovpzDkP33vv
yfXUAVaPoCrfpsJeypzXXWTg3qDA7eJNtThPU2trzmJ44yaVkIl/wzZlw42V
V+Hp+E/L2Z5wzNlnWx/bwdVCDkFBKrBLj/bT05IwZ/a6Oks+2FDk1+SVsRrS
P1dzUg8eq4Dn2Nf/4g2A3Q5Fx+VthQWT5Zh7n1aiv6dKBco2VxDv9Trmkviq
hPjxl56b/aH5xHaHxV9/OZFC/I47sLHYJ1nnH6t0s6y/bF1A/MDDvkQrq4R4
0+j7Wc3icuL8Uo1HDUGVxDb3sgxdNWqI+a0+0jqj4CLB5nNmfTCf78tlDu5a
nX/OJ8dxvKR7A3zKQi28QAUW3hd4KMEILlIqEPanw24b2T5b+sJli+EnBZLh
wOx4/5A5WPZphzZNsI6YGSvFvlsG3u6dGjF5GO7elpPs/Bw+mNxaRbWuJx69
ynAqPQvHOV9Z3nUF7tu2TWkrAw7LvhTDxt6AfKu22Ga/hA/M+PRJrmwk1jcR
Ypt800wcSWu+pJjVRvyRKsFnKtRFPCQpcrE+/huxeuBDz6IUOIS5zTGdAa++
vt84ohjW/um71nAAjnz7+W2RxndiJaOkkfQW+EKK/LcH3fBfi9lNET9hm/S6
PFdKD+KLsN2QlYUbOh1lk3xhn3Ny9MjVvciPeyTXShLOfpApul4eXqjQqE3b
A4dIGuhUuMIR1SclOD7Aiidl/Sur4LrZQebtFlhY2vuG1DAcH3h5XkfsB/ET
2cTWAHfYIJ+usjcA7jeXjua6CssHpxnExcPVwh4ptMewe6oyZUs6nNmYk/Wm
FLZwufhbUC08SdnrrvcFvnOH4xNPL6wuXy7TMAp/LroREj8PBx4x7aCv6CP9
KD70m+bWVXB+SHPs6Dq4QmHCW84Lbm4TNHMq+7/9L56Iq3EPEB/33/1jpfEg
8Qc5tfAPHMPEMly5fSkGo8QSuS76HGG/cH/Yqk3vUhkjpsyxPvfqhpciPa0O
KI8TL0h/ZRMPhec97tpcS4Pn3lMzRpmwPz21TbofnlmxgtN2EbYebTNzZp1A
vbW+uu+zEhb9EN4Xwgv7pdGVo1bBLbHqF++vhtWDBcpT18HTh/PsS6XhkNaX
7dpyMD/90bFsRVjG47rNi12wRcRhq+jDcHpFj4ldEHx6H7/WJBP+spO2Tjp0
ktjjiOAqqbYpYrGY79bsEjPEDNukp+N+s8RHtIINyvLmiNsmewWKi2EHBrX5
/UfYdcN6p5d1cAhL3pU7PTCjdC7/JN88MTv1vAqLHRy+omNhjg4LFOiXTDjB
axVFzPs8YAWh1x41obBN068X99PgrxFHve9mwI4HijSj38Ie2VHloYXwtXiF
Hy5MmNf8LsOxFY7mWfahdcAJF6rZzftgSRXVSuMh+MnQ/dv7x2D5Jxy2utNw
hv1ZKc0F2OHNqEQSywKpR2Hec2IrVsKlDtPCrrzw+XcBgvWr4BanyysTxWFN
4bCl01vgJbfYnyxacHH5o89/msFGwXlvy4Ng5s6WW7PP4N4HfEZHl+EZ7n1s
7ywXiaXdCsQHp2Czul2qEnFLxLqcW6P4jZeJ//5/If4PrCcnkA==
          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {{-1.999999918367347, 1.999999918367347}, {-0.4, 1.4}}, 
       "Frame" -> {{False, False}, {False, False}}, "AxesOrigin" -> {0, 0}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["t", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.4, 1.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.893951876625472*^9, 3.893952064613555*^9},
 CellID->137943318,ExpressionUUID->"91903989-0088-44c3-a439-1d8991622fd7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.529102651421562*^9, 3.529102759638761*^9}, {
  3.529103973704362*^9, 3.5291039752019615`*^9}, {3.5291040110507617`*^9, 
  3.529104042484762*^9}, {3.5292323350041633`*^9, 3.5292323544912786`*^9}, {
  3.529232416099406*^9, 3.529232442791053*^9}, {3.529232486471129*^9, 
  3.529232501805957*^9}, {3.529232694669095*^9, 3.529232818446513*^9}, {
  3.5292329554303536`*^9, 3.529232956054355*^9}, {3.5873398421294823`*^9, 
  3.5873399210032196`*^9}, {3.5916155600682635`*^9, 3.591615560770296*^9}, {
  3.654470056220614*^9, 3.6544700578273945`*^9}},
 CellID->1142472474,ExpressionUUID->"95c4da53-64d8-41d2-942b-083130dfdd43"],

Cell[TextData[{
 "The given signal has a period of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "b8d0741a-a936-47ff-a19c-3e0ff0a8c5ca"],
 " and a fundamental frequency of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "0"], "=", 
    RowBox[{"2", "\[Pi]"}]}], TraditionalForm]],ExpressionUUID->
  "d320b66e-2217-4591-9159-a9ee928fdab2"],
 ". The Fourier series coefficients are:"
}], "Text",
 CellChangeTimes->{{3.811507125604726*^9, 3.811507136458759*^9}, {
  3.811510776649225*^9, 3.811510777207783*^9}, {3.852069533911415*^9, 
  3.852069570067709*^9}},
 CellID->883582691,ExpressionUUID->"8f128039-d3aa-42af-b703-e111ee6e7eb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourierCoefficient", "[", 
  RowBox[{
   RowBox[{"UnitBox", "[", "t", "]"}], ",", "t", ",", "k", ",", 
   RowBox[{"FourierParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "\[Pi]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8115071407384925`*^9, 3.8115072069733076`*^9}, {
  3.812846824280512*^9, 3.812846864516237*^9}},
 CellID->524868632,ExpressionUUID->"1758a866-d4fa-4804-8cfc-04e6732c747f"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        FractionBox["1", "2"], 
        RowBox[{"k", "\[Equal]", "0"}]},
       {
        FractionBox[
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "2"], "]"}], 
         RowBox[{"k", " ", "\[Pi]"}]], 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{{3.811507201632657*^9, 3.811507207632345*^9}, {
   3.8128468312457504`*^9, 3.81284686526917*^9}, 3.897571961944378*^9},
 CellID->14407281,ExpressionUUID->"121f27b4-443b-476d-a47f-0da069b8cb05"]
}, Open  ]],

Cell["Equivalently", "Text",
 CellChangeTimes->{{3.811507590532441*^9, 3.811507593213618*^9}, 
   3.834073287237174*^9, 3.916220358460703*^9},
 CellID->1751759795,ExpressionUUID->"6c56354b-9562-41d7-a866-c8cb1fa424d7"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "k"], "=", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"sinc", "(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "k"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"ba2fc0df-e22d-4d22-810f-611f4959666a"]
}], "Text",
 CellChangeTimes->{{3.811507603056094*^9, 3.811507632928299*^9}, {
  3.834073291701212*^9, 3.834073292517747*^9}},
 CellID->1973557842,ExpressionUUID->"e4c6434f-7f04-4654-9704-ad8e94bcd8fd"],

Cell["The transform follows immediately", "Text",
 CellChangeTimes->{{3.529102651421562*^9, 3.529102759638761*^9}, {
   3.529103973704362*^9, 3.5291039752019615`*^9}, {3.5291040110507617`*^9, 
   3.529104042484762*^9}, {3.529232335004163*^9, 3.5292323544912786`*^9}, {
   3.529232416099406*^9, 3.529232442791053*^9}, {3.529232486471129*^9, 
   3.529232501805957*^9}, {3.529232694669095*^9, 3.529232818446513*^9}, {
   3.5292329554303536`*^9, 3.529232956054355*^9}, {3.5873398421294837`*^9, 
   3.5873399210032196`*^9}, {3.591615560068263*^9, 3.591615560770296*^9}, {
   3.654470056220614*^9, 3.654470089588586*^9}, 3.811507772864424*^9, 
   3.916220361340355*^9},
 CellID->1701722579,ExpressionUUID->"aa981788-a6dd-4e31-9c34-4c6208409912"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
    RowBox[{"2", " ", "\[Pi]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[ThinSpace]", 
        RowBox[{"k", "=", 
         RowBox[{"-", "\[Infinity]"}]}]}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], " ", 
      RowBox[{
       SubscriptBox["c", "k"], "  ", 
       RowBox[{"\[Delta]", "(", 
        RowBox[{"\[Omega]", "-", 
         RowBox[{"k", " ", 
          SubscriptBox["\[Omega]", "0"]}]}], ")"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"fd97e98f-7336-416a-8945-7315f9d2cdbe"]
}], "Text",
 CellChangeTimes->{{3.587339720307867*^9, 3.5873397421011076`*^9}, {
   3.592049467318535*^9, 3.5920494673505383`*^9}, {3.592125609844573*^9, 
   3.592125612944193*^9}, {3.654470116404642*^9, 3.6544701169974346`*^9}, {
   3.656254261237704*^9, 3.6562543670826483`*^9}, 3.68626025962335*^9, {
   3.811507514741534*^9, 3.8115075233823376`*^9}, {3.83407329620594*^9, 
   3.834073304294213*^9}, {3.852069606465394*^9, 3.852069609982993*^9}, {
   3.891107748319194*^9, 3.89110775646257*^9}, {3.931269292155061*^9, 
   3.931269292765676*^9}},
 CellID->664174507,ExpressionUUID->"69a0e9ad-ddd0-4600-8372-d8513665b3f6"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{"\[Pi]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"\[ThinSpace]", 
        RowBox[{"k", "=", 
         RowBox[{"-", "\[Infinity]"}]}]}], 
       RowBox[{"\[ThinSpace]", "\[Infinity]"}]], 
      RowBox[{
       RowBox[{"sinc", "(", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "k"}], ")"}], "  ", 
       RowBox[{"\[Delta]", "(", 
        RowBox[{"\[Omega]", "-", 
         RowBox[{"k", " ", "2", "\[Pi]"}]}], ")"}], " "}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"be6b9c28-2361-4357-8aed-c548a625e008"]
}], "Text",
 CellChangeTimes->{{3.891107752650695*^9, 3.891107753763479*^9}, {
  3.931269299383193*^9, 3.931269299991251*^9}},
 CellID->427781454,ExpressionUUID->"26399ad3-ef3e-458a-bafe-839e96a08ef5"],

Cell[TextData[{
 "This shows the magnitude spectrum ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftBracketingBar]", 
    RowBox[{"X", "(", 
     RowBox[{"j", " ", "\[Omega]"}], ")"}], "\[RightBracketingBar]"}], 
   TraditionalForm]],ExpressionUUID->"1ea8710f-4057-479d-95fb-9c21cdce38bf"],
 " of the square wave:"
}], "Text",
 CellChangeTimes->{{3.8018456303300786`*^9, 3.801845665858159*^9}, {
  3.81084651304099*^9, 3.810846524029168*^9}},
 CellID->160942043,ExpressionUUID->"e0daeb47-53b8-4cbd-a996-0fe1f306dbb6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["5", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["1936", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[{
     RGBColor[0.368417, 0.506779, 0.709798], 
     Arrowheads[0.06], 
     Table[
      Arrow[{{($CellContext`k 2) Pi, 0}, {($CellContext`k 2) Pi, 
         Abs[Pi Sinc[Pi ($CellContext`k/2)]]}}], {$CellContext`k, -10, 10}]}, 
    PlotRange -> {{-40, 40}, {0, 4}}, Axes -> True, AspectRatio -> 1/2, 
    AxesLabel -> {$CellContext`\[Omega], None}],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.801845692556773*^9, 3.80184595828496*^9}, {
   3.801845994302746*^9, 3.801846176021149*^9}, {3.801846267326626*^9, 
   3.801846277427593*^9}, {3.801858869708535*^9, 3.801858898145211*^9}, {
   3.801858960379739*^9, 3.801858963071646*^9}, 3.810846475549927*^9, 
   3.8352696876190767`*^9, {3.8923009723019557`*^9, 3.892300984908998*^9}, {
   3.893951882503646*^9, 3.893951886281554*^9}, 3.8939519463755846`*^9, 
   3.893952051684477*^9},
 CellID->1271005128,ExpressionUUID->"7c21a338-7bd5-47c7-8a9e-031f09eee928"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.06], 
   ArrowBox[NCache[{{(-20) Pi, 0}, {(-20) Pi, 0}}, {{-62.83185307179586, 
       0}, {-62.83185307179586, 0}}]], 
   ArrowBox[NCache[{{(-18) Pi, 0}, {(-18) Pi, Rational[
       2, 9]}}, {{-56.548667764616276`, 0}, {-56.548667764616276`, 
      0.2222222222222222}}]], 
   ArrowBox[NCache[{{(-16) Pi, 0}, {(-16) Pi, 0}}, {{-50.26548245743669, 
       0}, {-50.26548245743669, 0}}]], 
   ArrowBox[NCache[{{(-14) Pi, 0}, {(-14) Pi, Rational[
       2, 7]}}, {{-43.982297150257104`, 0}, {-43.982297150257104`, 
      0.2857142857142857}}]], 
   ArrowBox[NCache[{{(-12) Pi, 0}, {(-12) Pi, 0}}, {{-37.69911184307752, 
       0}, {-37.69911184307752, 0}}]], 
   ArrowBox[NCache[{{(-10) Pi, 0}, {(-10) Pi, Rational[
       2, 5]}}, {{-31.41592653589793, 0}, {-31.41592653589793, 0.4}}]], 
   ArrowBox[NCache[{{(-8) Pi, 0}, {(-8) Pi, 0}}, {{-25.132741228718345`, 
       0}, {-25.132741228718345`, 0}}]], 
   ArrowBox[NCache[{{(-6) Pi, 0}, {(-6) Pi, Rational[
       2, 3]}}, {{-18.84955592153876, 0}, {-18.84955592153876, 
      0.6666666666666666}}]], 
   ArrowBox[NCache[{{(-4) Pi, 0}, {(-4) Pi, 0}}, {{-12.566370614359172`, 
       0}, {-12.566370614359172`, 0}}]], 
   ArrowBox[NCache[{{(-2) Pi, 0}, {(-2) Pi, 2}}, {{-6.283185307179586, 
       0}, {-6.283185307179586, 2}}]], 
   ArrowBox[NCache[{{0, 0}, {0, Pi}}, {{0, 0}, {0, 3.141592653589793}}]], 
   ArrowBox[NCache[{{2 Pi, 0}, {2 Pi, 2}}, {{6.283185307179586, 0}, {
      6.283185307179586, 2}}]], 
   ArrowBox[NCache[{{4 Pi, 0}, {4 Pi, 0}}, {{12.566370614359172`, 0}, {
      12.566370614359172`, 0}}]], 
   ArrowBox[NCache[{{6 Pi, 0}, {6 Pi, Rational[2, 3]}}, {{
      18.84955592153876, 0}, {18.84955592153876, 0.6666666666666666}}]], 
   ArrowBox[NCache[{{8 Pi, 0}, {8 Pi, 0}}, {{25.132741228718345`, 0}, {
      25.132741228718345`, 0}}]], 
   ArrowBox[NCache[{{10 Pi, 0}, {10 Pi, Rational[2, 5]}}, {{
      31.41592653589793, 0}, {31.41592653589793, 0.4}}]], 
   ArrowBox[NCache[{{12 Pi, 0}, {12 Pi, 0}}, {{37.69911184307752, 0}, {
      37.69911184307752, 0}}]], 
   ArrowBox[NCache[{{14 Pi, 0}, {14 Pi, Rational[2, 7]}}, {{
      43.982297150257104`, 0}, {43.982297150257104`, 0.2857142857142857}}]], 
   ArrowBox[NCache[{{16 Pi, 0}, {16 Pi, 0}}, {{50.26548245743669, 0}, {
      50.26548245743669, 0}}]], 
   ArrowBox[NCache[{{18 Pi, 0}, {18 Pi, Rational[2, 9]}}, {{
      56.548667764616276`, 0}, {56.548667764616276`, 0.2222222222222222}}]], 
   ArrowBox[NCache[{{20 Pi, 0}, {20 Pi, 0}}, {{62.83185307179586, 0}, {
      62.83185307179586, 0}}]]},
  AspectRatio->NCache[
    Rational[1, 2], 0.5],
  Axes->True,
  AxesLabel->{
    FormBox["\[Omega]", TraditionalForm], None},
  PlotRange->{{-40, 40}, {0, 4}}]], "Output",
 CellChangeTimes->{3.8939518998858767`*^9, 3.8939519476218505`*^9, 
  3.893952054138775*^9, 3.8975719662164392`*^9},
 CellID->157033055,ExpressionUUID->"e5b9922d-684a-4991-9a3f-f00812ddaa4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "SummarySection",
 CellID->763349587,ExpressionUUID->"f00d4fc9-1400-4720-8a14-37974ef96772"],

Cell["The Fourier transform was defined. ", "SummaryNote",
 CellChangeTimes->{{3.810846633017356*^9, 3.81084664316031*^9}},
 CellID->549201531,ExpressionUUID->"2a66f28b-3573-4d8e-a863-a0f554800898"],

Cell["Several forward and inverse transforms were shown", "SummaryNote",
 CellChangeTimes->{{3.810846760212362*^9, 3.8108467825083585`*^9}, {
   3.810846813346342*^9, 3.810846834250363*^9}, {3.8340028445945377`*^9, 
   3.834002847384712*^9}, {3.899845792771295*^9, 3.899845793150171*^9}, 
   3.916220378470644*^9},
 CellID->545416711,ExpressionUUID->"2a64b7fc-f8c3-46d5-a499-2d6032aa6c4a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1X8w1PkfB3A/vo7zK/1ATojiWOoqZUfOPbuS6xfhchZfpDs/sooM4aT8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        "]]},
      Annotation[#, "Charting`Private`Tag$22337#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{{3.654374342638152*^9, 3.6543743712013874`*^9}, {
    3.6543774519730883`*^9, 3.654377461083371*^9}, {3.684443897633803*^9, 
    3.6844439068846025`*^9}, 3.6861430294803605`*^9, 3.686143123187225*^9, 
    3.686143165322899*^9, 3.68614320434653*^9, 3.686143257818925*^9, 
    3.6861433773902607`*^9, {3.686143563517523*^9, 3.686143581069533*^9}, {
    3.774630574673765*^9, 3.774630588925894*^9}, {3.800709846299965*^9, 
    3.8007098626392803`*^9}, {3.833990888583919*^9, 3.833990912893713*^9}, {
    3.8339909450507536`*^9, 3.833990953821296*^9}, {3.834002106460252*^9, 
    3.834002114274732*^9}, {3.8340029032490745`*^9, 3.834002927335682*^9}, {
    3.83400295946646*^9, 3.834002971075172*^9}, 3.8340031900988607`*^9},
  ExpressionUUID->"aadf1a12-8191-482e-86c8-8863a01ea1fe"],
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340025442591133`*^9, 3.834002575684492*^9}},
  ExpressionUUID->"e132c068-6ffa-4834-a691-53b803af8f4c"],
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVjmk41GsfgK1j36YIqWgoFFJJJf2KIiWEdKJFnCgVspWtSDHkVMiWJEuF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        "]], LineBox[CompressedData["
1:eJwVlnc4FvoDxWXLXiG54kWiuiFk1PlK5DY1haKsK2kh0YuukiIVGWVlJF0N
RMb75kq8dvYeIXu/ZCby6/fHec5znudz/j3PkbO5csyelYWFJfm3/u/3S5Zq
T8vehJyatkXTKhPHNVrz/A3CYB+5Umv/i4nsNrPb96hR4Jnt4TRcYYK/YIzC
sIjHuObzyfqfTCD0jT/jxgt83uHzSnyJiWsOF0cYYcnwETpixrvIRKKO6sHi
9ymYOWip8mGOiUa+sdTi6re4fsH6uNAME5w9r4VLxtJg9tObd+MUEzHmmrq2
fu+RY6r+pG+cCU3D8It9IplITDDYajnCRPWWuRjbhA8wb36tfG+ACRaWrFXb
/Bzgu97jlU4mIkfE1PoP0uBU35lu0sqEeoObjV0HHQ+T4+L+amDCLnlHsd3i
fxi6ofPkchkTK4/D5vv9P+HuTkVqaCETlfpLoRmBBRDqVf55Je83r2RRrC5V
CJkJodKjaUxsl17b5dJTCKr3Zcrpf3/3BenzGa+K8Ms9SlsygYmIH1LKGlrF
MFXI6S4NYaL0S1ugxvEyhAz0x89fYcLRo73UUrUcs2VBxqIOTHArdLD7sVVA
eTHDrM+Sif3UTp/GzEo0fGNcTjBm4svmbpfrYjVY3x1kmy7JhHNTd1rseA34
LaPU7vAx4U+uztvY1EJj06KJMAsTm8avajzQrUN4SNZj28FJOBq6vOsYrcdX
hdTaX2mT2Bn5vZJ5qgFxxfLyFQmT4Ga6jLIVNeAnW+Qt89BJpES5btoS3Qjj
IomxsuuTGJ12S/A60IzvfD4pa3dOwjn+RrjM2zY4edJPymROQH9+IVNNsh3l
fudomQkT4DvoUW/k145ts8wXG4Mn8G7BQ/DymQ5k/JKPv+08gcnDNwPy+b7i
xC2bPn/KBHJ98vPTtHrg9om1596Dcehu/Zxh+rQPpc+tShL2j0GzsTkiv7wP
NlbuZ921x7CdOn5zy3IfTue4J+5RGINSuYQh9/l+uBj2VTBWRiFqf7nhk8oA
ljWqBHzTRzEeIz27LX8Q7K+Uj54RH0Ucn7sm/8AIOJe9PFV6hsHqLt5pJzWF
Hr7s/PRHg7A497o+d8cUygR5Yq5TB5GxH+V8plNYpyBocsBxEDayF7I/+E8h
xsk4cfOeQRSW5QWzz07huXyJdPb8AO5I2xklVU8jJsd8UMl2AOyfM1L77sxg
ZX297NBf/TjzZt9L7bgZsF0E78zOfnwI74x+QJ/By9ldHcLK/bBz4gzQmJ7B
nMOo4n3OfhSLWtjesZrFQz1DZTNGH/wd1khSdObQzB9QftOwD1x8pr42k/Pg
fG+hFn2kF6c3WRRo8SxAUT5NVs+gF6/32K2uVVgANfrGpnH1Xhz29PDONP+d
x1b2+a7rRcRgvCd78QLcIpY2und9g9Ln6WvJ0YvYq9Ks6XXtG4zcQ21GTZag
pmr76vaLHkSExCbk2y4h/9tCn+LTHgy/fdXzxGcJAdQhidbAHgT1fbTS+7CE
zYfsN1xw6UGjab9FkOxPqOmXh+nt6YGdqubxbfM/IWtceUChvBt3epoNXV6s
IFJ2UIb37y500Q5c8shbQacSR4Xm8S7ohhZE+DSt4O9x54fu6MKU0euRQK5f
4Pl3eEhHsgtWb7wfv7j4CyItWnWMiq/QdVfoaNRYRW6U5VS9xlf84NChSduw
kFQzgfvC4p1Idpmpen6ZhTyUb08sZ+vEie53vXJUFhJbrO0W9r0D6bnyfMph
LIRvcabpfG0HHC7yWe8oYSHTkWIdrUEdaKztZj+ksoZskKZ6yfP85qP9TX2+
ryEDatRuH4F2VIr6DwmysJJTRblsUr/aMPjgrk8CPyvZ53Qyt3iiDRu8/N4y
lFnJSneK/amqNtw/c5ub15qVMM6kdR192IZzMj4FTytZSdfIMUQJtUEo7vr2
90lspMX9cEgBpRWqEtdL92SwkazL8+M3xVth/NjNqvETG3FwGsjby9UKr1uu
QQvtbOSfdaLnOMdaMGx9bXiXMDtRixo1QWYLCjZeiq/wZicnUhiFbsYtuJJo
J9R/ioNEs04esbrRjEeekTGPbDnIjQxqW8bFZqSaVivrXOUgDRt8k0TONWPy
l7bBowAO4h0TVTRj0gxnS16XnXkcZE3A0we60s1wEstoCJLjJJqBvrlVn5vg
4L8aoTnOSRJouc9fr2uClVOUzD1fbvJk0XH0n87fu9PGUz39kJukDtPozg0N
ePaXp8+ZKG5CX+i1PVfRgDrl091qmdzEQyVtvXVuA/YOiSd09nMT6li3CC2s
AZvtQhTUTXhIcti5jS2HGzB79r7qV4G1RGJ/0op3WT0CjrrraMTwEhPxQLv3
NXV48kXF+W0KLxFSWVqfXlqHmH3dzxVzeEnwzmeZWZ/qkL7LhF2ynpcIuCZe
aEqrQ+vm9TXLXHyk/GPcqn1wHZRZ8+1KXPmIG7daBuNYHUoyOILND/CT59Pp
SQadtWAXCx+8tSRA7mafbU9hqYXIpI+ACJcgOZKsq686VwO5MketJFFBMq+W
lso7UoPdXvr+ZVsESdh/hduGamvg2d+nKGwtSLi+no/gSqjB5Ad1+8QiQfLn
i39ZB/fUYFxl+JqNsRDZXf/sY0dQNVoq7075CQqTgbYfjr3aVQjbHWt0cp0w
Gc5lZzRvqcKx9x+iFGWESWSxh16DXBWqI/r2lqgIEw1prrP9vFUoOW8QyWUs
THS0d1Eder4ge2HZINBLmAgX81f3Bn5BBMUt9PGIMNnMam9/Z6ASJ6k2WlFF
IkQqdsdgYVoFnHnH5KstxMhry4iUB6llkH1TEsE5Kk7i6H6uUz9LQM01PC4Y
LUEGLGt2+9kU42qyc7bWn1JkjwPbEwExBvhYtW22Dawn5vl5hxwbC2F06US4
SugGEsFpIfku/zMkaTJXjBT+IK/uzUXnNRfgicv9kO0tsoQrODunevgTjvkf
2RqbvZHEn3I1r3bKh4ql38kkbzmSFq76w0D8PzQP8iSGnpQnYarHRdsLP6La
ZsBARJZC/CwWxIIS6PjG/moxXJ5CfHUYrlkxdMwmO6ZJKVGIxoOukJ6ndEiN
jW2Q20oh//DqcOs/osPO9fvCn3oUsiPYvIiLSsfSndV3h8wo5EKgWNL0CTqU
XkqtD3hMIUXdlTnca+nQ2ddRyxdKIZtqL+k6ctBxcCTmXnAEhej437UuZ6Hj
2taNc09jKeTKppcPgxdoyMtSqk1+QyGCnGnn1QdoOFai4c8opZBPultViwpo
sHec0zeppBATBcUr+nk0eKzNmamsppDWZRGTnBwaYg/rnm9oohCbNr+s96k0
DDcT/d4+CsmKqfmbFkPDkgfrjP0QhXSb+erjGQ380oyUkVEKKb4WH1cSSoO6
9T6J6WkKWf5jgr89kAajNTzVbnMUomV4S8LBn4bTLyr8FhcpRHJo39sZ398/
yyhIz2uZQo5m3qy87U2D99Ch76urFBLVecBN1JOG/wHBtxIg
        "]]},
      Annotation[#, "Charting`Private`Tag$22383#1"]& ], {}}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["\[Omega]", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-9.999999591836735, 9.999999591836735}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{5, 
       FormBox["5", TraditionalForm]}}, {}}]],
  CellChangeTimes->{{3.654374342638152*^9, 3.6543743712013874`*^9}, {
    3.6543774519730883`*^9, 3.654377461083371*^9}, {3.684443897633803*^9, 
    3.6844439068846025`*^9}, 3.6861430294803605`*^9, 3.686143123187225*^9, 
    3.686143165322899*^9, 3.68614320434653*^9, 3.686143257818925*^9, 
    3.6861433773902607`*^9, {3.686143563517523*^9, 3.686143581069533*^9}, {
    3.774630574673765*^9, 3.774630588925894*^9}, {3.800709846299965*^9, 
    3.8007098626392803`*^9}, {3.833990888583919*^9, 3.833990912893713*^9}, {
    3.8339909450507536`*^9, 3.833990953821296*^9}, {3.834002106460252*^9, 
    3.834002114274732*^9}, {3.8340029032490745`*^9, 3.834002927335682*^9}, {
    3.83400295946646*^9, 3.834002971075172*^9}, 3.8340031900988607`*^9},
  ExpressionUUID->"2295e151-7485-4e6b-9254-b96e4263be69"]
}], "SummaryNote",
 CellChangeTimes->{{3.834003199661466*^9, 3.8340032736583366`*^9}, {
   3.834004021751137*^9, 3.834004029711529*^9}, 3.8939519072363586`*^9},
 CellID->1358456381,ExpressionUUID->"eae34e3d-e1a6-48de-b754-ef4f87470e9b"],

Cell[BoxData[
 RowBox[{"\t", 
  RowBox[{
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwUV3c81e8Xp+zslb2vvS7RkJ6nhJSVhK/ISCpKRiRkh2zXHlfGtecthOR5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         "]]},
       Annotation[#, "Charting`Private`Tag$22237#1"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{
      FormBox[
       TagBox["t", HoldForm], TraditionalForm], None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    ImageSize->80,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{-19.99999918367347, 19.99999918367347}, {-0.15, 0.45}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{{{10, 
        FormBox["10", TraditionalForm]}}, {}}], 
   GraphicsBox[InsetBox[
     StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
      StripOnInput->False,
      FontSize->18], {0, 0}],
    AspectRatio->Automatic,
    ImageSize->35], 
   GraphicsBox[{{{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJxF1WkwHAYUB/BdZ107U9eMpVtHSK1OkqauQV2REESIo0xIdxpCDENVJLaN
ZA0VIrrdisTSZSNk3VENIq66smabiDCMxDjqCGGtY1ndZdN2hvfezJv//D6+
+X94Jt8mnItSIBAIjP/2/7xYzxR9+KDaRdgfXRnZwnEX3XuqPDxlB20x+XRg
ZQ39XnO2bHwGnRhrE9rYg04zf9N1KQvNLjJjvSChS6ZuJQSoqYD1XwWetdRT
BvP9Az0E5kpgL0vzZDNTRbBDXXjF4FEFsDTnks5xSyJ4S/Lw7oXDBLzHlGXd
ES/vPLCj8o1Gq8hdcL6rnZ3bdSn4YnHo/PuSHfDgI4oakb0Npmg+/qKzSQxW
N14YXKraAE8UfySYfoCuNbDqH2Oj/XUS2/py0AUqUh43Fm0q1EoPo6IdW22s
ByrXwZp2oUe7uOjJRjq1uRCdXttpXJ6N5pee1mJcRgdlRSzYW6LjgjLv83hr
YK689UsqFz3KW3tZXYh23TuvXJ+D1q04nvQkDn3aP0bLLgqdJv2N1xKBXvRT
m3rmh26XTPl0H0NvcPXenbBEH/b1Se8zQYdv3/zEk4z+pbSpha+N7vdeCfTW
QMvEJiKBIprmXK9btCPa95qLgEX24Syhk+eeH6quRRvZXpE3f4fu+JEatcxY
BdN6pgQUlhDsRhCRNrKXwaZfyQP6GEvgypjGmWdN8+DYzYbw2+wZ8JE05TAV
s7dgndQRjYKiYfBYZBy1frYffJVOzRu4Wweu+tne9eGxWpcD511mjNLSn4O1
xL6ONQHD4OnkfuuUjLfg1adnuq/yZ8AVWVxaZPY82Hy7Wuda0RI4fSRqcZyx
DJ78/dN2xxgheOhjL9aDkFVwb2JitNpJEZhxq9Wo7CbauVTptVMb2qimskbt
DVrW7Jc1KkFvcfzpFxTXXA76Fc7883hIHT13qOydhzZ6ItqX0mKAHqnaCrIy
QQuEnNucz9Ct36/vZNih798oGA4IRgffm761zETneTZqEQvRfEkmS5+Ldgi1
KnZrQFMMUurvDaEX2RqjJ7TXwXSOrVnxr2hOeW67b8EGWOl8vFA5VQx+Sat8
dC5jG/xEixwhidsBW7BNFlV9pWBpSsZedeAueFlqSOLZy8Gl0VkjhmYE1wMz
3f7KNTAngkkJ1e49egrgDo+W9iayIngv/hvbEJISmKj6utBqD23rldTtTVAB
SydqFvU20B5xfOaZbfQd2ax9phRtTDbMFiuogj2/zrYc1kHnD0XFMm3QR/op
K+qp6GvBDvnu19F/zgU70RnoIMU7uUvZ6B9cZZ/z2Wh+61h8Zhta23tTr70L
HT5O6hD3okWSk6TIF2h9mz/q3CfRtN7BEPrf6MrAZXnDAtopyfSsiQj9E9FZ
ErqJfsUMK2FK0GTjK558GXr//4P/BRWuONQ=
         "]]},
       Annotation[#, "Charting`Private`Tag$22283#1"]& ]}, {}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{
      FormBox[
       TagBox["\[Omega]", HoldForm], TraditionalForm], None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{False, False}, {False, False}},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    ImageSize->80,
    Method->{
     "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotRange->{{-2.9999998775510206`, 2.9999998775510206`}, {-0.5, 1.5}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{{{1, 
        FormBox["1", TraditionalForm]}}, {}}]}]}]], "SummaryNote",
 CellChangeTimes->{{3.8340034916552672`*^9, 3.8340035027745647`*^9}, {
   3.834004036578807*^9, 3.8340040428388195`*^9}, 3.891039320139606*^9, 
   3.8923009950352902`*^9, 3.89273002720984*^9, {3.900100725801808*^9, 
   3.900100730419059*^9}},
 CellID->1677744210,ExpressionUUID->"13545fe7-6220-459e-91b5-16398ee7c1fd"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwU2nk4VO8XAHDfQmkhFC0qhDbZSqTlqGgRZd8JpQVtKi0kiaLFkhZJiJKQ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        "]]},
      Annotation[#, "Charting`Private`Tag$22182#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-2, 2}, {-0.9999968914310025, 0.9999975297451876}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.834003594261674*^9, {3.8340036392873173`*^9, 3.834003651006575*^9}},
  ExpressionUUID->"d70f0905-c114-4cb1-9c4d-a3d06b9eae98"],
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340034916552672`*^9, 3.8340035027745647`*^9}},
  ExpressionUUID->"a4d1896a-5494-4886-a31b-0c5eb732d94b"],
 Cell[BoxData[
  GraphicsBox[
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.15], 
    ArrowBox[{{-1, 0}, {-1, 2}}], ArrowBox[{{1, 0}, {1, 2}}]},
   Axes->True,
   AxesLabel->{
     FormBox["\[Omega]", TraditionalForm], None},
   ImageSize->80,
   PlotRange->{{-3, 3}, {-1, 3}},
   Ticks->{{{-1, 
       FormBox[
        RowBox[{"-", "1"}], TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}}, None}]],
  CellChangeTimes->{{3.834003800331958*^9, 3.834003910931409*^9}, 
    3.8340039509385047`*^9},ExpressionUUID->
  "0ee93655-41cd-4838-a1c0-310b9a3c2222"]
}], "SummaryNote",
 CellChangeTimes->{{3.834003961973633*^9, 3.83400397675373*^9}, {
  3.834004048697647*^9, 3.834004053945019*^9}, {3.8352697246677127`*^9, 
  3.8352697246677127`*^9}},
 CellID->1386652360,ExpressionUUID->"1bcd1c75-cdf8-4716-884a-a50d67a23749"],

Cell["The bandwidths of several pulse-shaped signals were compared", \
"SummaryNote",
 CellChangeTimes->{{3.8133544824703684`*^9, 3.813354521334998*^9}, {
   3.813354587427583*^9, 3.8133545911364*^9}, {3.825446893163287*^9, 
   3.825446897543475*^9}, {3.899845798003895*^9, 3.899845798461749*^9}, 
   3.9162203836157446`*^9},
 CellID->973677276,ExpressionUUID->"d5e7d031-3c49-4ea5-9aa0-466e59c9aaef"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF1mkwHAYUB/B1DZGuIHGlzl2syI6g6SqJcSQ0BBNbV2hcaWndpK7IbEUU
aSVRxSCk0rUStIQ4qo51hlCjFUFQZxxxLovsbhxtZ+S9N/Pmze/Tf+a9L0/D
N5T+pTCBQEj6r/+fembyi/v7+2zCQYXyySl8AfrJUwNt7hbaUMfed24JbSST
OPLnENp8Zr07pxxNT+4t/cgLHd2XGOzftAceGDi82OKzC1ZpDj1mpLwDrg5s
FzvyjwDsnWrAeZXAB/PS41LYZjwwU2pcKXtqG5xnaxDx4vYWOCHIJ+aEzSY4
TqQkOmJlA+wT36c5+HgdnNk4m50XwAH/MaHzwa+kVTBZ2tzS6cESuFI3JWB6
ZgE80VGhTqPNgWepmYbsmhmwLoO1ulCKDumrLpF9iOaFD5L8fkBL1iocJXqj
9S1yue6H0HHOP1dte0yDm4vKw9Qd0aI8NtXWGn03d7IwXx9dMKGReV4M/ezr
wsj0simwDKOYpieETqrR6ZJ+OwkWrD66zF1GT3sV3fh9GF1pwWy1fILWvk5y
0ipC51Y+nBXPQyeQCyR6k9F0sXwHVy/0M1PlSWNntEnU/XDli2jSfE7GFA2d
paak3U5FS7pl1xaR0Iw0BZvbimhuV9ZIoBTaX0g+yEEUXXNN953P5sSBOWYP
XuuoUibRSc4Ui+UetIuRZnIUE01R0uglxKFLKBK7dKNxMJW2RmVxx8BupquM
U7QR8K3zK3/VxQyB5ZzK0i4r9IMrtzuOdGl2g1mjs3feJDaBrzgqV41eLQTX
Sca9bI1kmr33x9NCqjfd2GAyp55v0vocbMN81evg1g+2spcV2aoeAgcMbrak
00bA97yG4vVrx8BSp/T9U2XHwXf3UuwXgifADEWn7s9y0CGGap+y29F+7ESx
yBG0p91imy4HXbpMseAIT5q9vxflqbt6DxHNjL2zz1JEq5k3j8eT0Qq9Wvk0
Y7T4PEfply/Qt34j82+EovevuQy7Xke/JTRkEdPQ88eTj8bWozsdVIiXZKfA
x/Sm5COU0d5ElnqGNlrQQz09bIKm2pz18L6KTjvnURxWhXb/JMfqR5dp8IqG
HKM/dwYc+c1Jn3vyc+ChMWm6X9cC5seenRe3WwK3nTT6vk1sFax9qGGh8AIH
rNIQaCWWsg4mCISLI6Y3cB+OjZ4dWpvg0dNeH2olboHDXKVlSGPbYKWM126i
KjxwmUfBI24MH+xq+u2FrkYBuMIzmGSy8w7MkzwnUue8C6b/fYamkr0Hljxz
uKUhH91SOHLxcyZaPybW534ZWkqtNlWpA/08yHBGbgNtLnEiTcpuH/PDecfL
HNHlo50se1e0arlffaovese5cE4yFl3LVDMVL0KHENc6i0rR2tFNdOsKdIbt
la++a0BHrOf+JPICresRoMocRk+1GxdbjqMvZQ833XyDlhB+bKOxhmYHRg80
b6KjXlp7eQvQB/8E+F+0FV3y
        "]]},
      Annotation[#, "Charting`Private`Tag$19960#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "bd22e260-7c84-4974-b9f0-c122b26a8748"],
 "\t",
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340025442591133`*^9, 3.834002575684492*^9}},
  ExpressionUUID->"bc58a9e1-34e7-4d36-af71-dc40a06f66b3"],
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJw1m3k41N/7/4W0kKKyJmbs28wYUbbuo03eqbShQlmThJSlVdmSNZFsKUvW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        "]]},
      Annotation[#, "Charting`Private`Tag$20144#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["\[Omega]", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-19.99999918367347, 19.99999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{10, 
       FormBox["10", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "ca442bd2-1aca-486c-9a2d-f61cad07dd90"]
}], "SummaryNote",
 CellChangeTimes->{{3.834002694469502*^9, 3.83400271961574*^9}, {
  3.834002797206118*^9, 3.834002802151798*^9}, {3.834003116428314*^9, 
  3.834003161628481*^9}, {3.8340032491321344`*^9, 3.8340032491321344`*^9}},
 CellID->768587592,ExpressionUUID->"847e4ad8-d1b9-410b-bb8c-4aba26d24da7"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxN1wk0VesXAPBrqFBJCpVklm5KSYbKf6vw6jUY4tEzNyAU7jOV0iUZShGS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        "]]},
      Annotation[#, "Charting`Private`Tag$20006#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{{3.834002596457526*^9, 3.8340026088583093`*^9}},
  ExpressionUUID->"1c6e4fb8-6b4c-461b-8df2-ece652194d74"],
 "\t",
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340025442591133`*^9, 3.834002575684492*^9}},
  ExpressionUUID->"7fca4dca-aa93-4147-aa4e-581aef4044b2"],
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwUV3c81e8XVxkZ2VvGveaVec0yzlOKFFEJTbJChZBEKCtJ9oiU7YoISeUr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        "]]},
      Annotation[#, "Charting`Private`Tag$20190#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["\[Omega]", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-19.99999918367347, 19.99999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{10, 
       FormBox["10", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "e9241fa7-ab9f-4468-8969-72925438b746"]
}], "SummaryNote",
 CellChangeTimes->{{3.8340026340006056`*^9, 3.8340026789058037`*^9}, {
  3.8340028070175076`*^9, 3.834002811443242*^9}, {3.8340031196157274`*^9, 
  3.834003163086946*^9}, {3.8340032506462975`*^9, 3.8340032506462975`*^9}},
 CellID->537522039,ExpressionUUID->"ef24f485-fb2b-4fd2-b8fd-d8c57e3da5d4"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxN2Xk4lF/YOPAJFZKklBJJshNRonKTQoslCaksFZUtVJYICdnKUNmyhmxl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        "]]},
      Annotation[#, "Charting`Private`Tag$20052#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "b15ce4b1-be3c-4e1d-871a-d083089cfc9f"],
 "\t",
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340025442591133`*^9, 3.834002575684492*^9}},
  ExpressionUUID->"23b94f48-601b-49db-b90d-0620236eb655"],
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwUV3c81d8bF0IlZO997T0y8xyRUcgKyc4mCSHzKkmSlJFVWYk0hOQruacI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        "]]},
      Annotation[#, "Charting`Private`Tag$20236#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["\[Omega]", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-19.99999918367347, 19.99999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{10, 
       FormBox["10", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "cac0014c-0d29-4ae3-a3ed-632b04c67143"]
}], "SummaryNote",
 CellChangeTimes->{{3.834002735011383*^9, 3.834002773604498*^9}, {
  3.834002817250707*^9, 3.834002821931308*^9}, {3.834003121702514*^9, 
  3.834003164480127*^9}, {3.834003252039439*^9, 3.834003252039439*^9}},
 CellID->1816690191,ExpressionUUID->"77ac27ed-c030-45a8-a69d-bf52ae25c88b"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJw12nc0V3/8B3AkRCGl1FdIVKTMlPlCMiNkb8qIQmWEskJGRkR2VvbeK29k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        "]]},
      Annotation[#, "Charting`Private`Tag$20098#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["t", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-1.999999918367347, 1.999999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{1, 
       FormBox["1", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "04389f17-1176-448a-a062-284b7ffa3c68"],
 "\t",
 Cell[BoxData[
  GraphicsBox[InsetBox[
    StyleBox["\<\"\\!\\(\\*OverscriptBox[\\(\[LongLeftRightArrow]\\), \\(\
\[ScriptCapitalF]\\)]\\)\"\>",
     StripOnInput->False,
     FontSize->18], {0, 0}],
   AspectRatio->Automatic,
   ImageSize->35]],
  CellChangeTimes->{{3.8340025442591133`*^9, 3.834002575684492*^9}},
  ExpressionUUID->"0da53c6a-f63c-4c1f-9d67-33538becbddb"],
 "\t",
 Cell[BoxData[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwUV3c8Vu8btkXI3uPl9dp7Ju85z5FKSiWJkpVVRrKSEknInoUku+xsofI+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        "]]},
      Annotation[#, "Charting`Private`Tag$20282#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox["\[Omega]", HoldForm], TraditionalForm], None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->80,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{-19.99999918367347, 19.99999918367347}, {-0.5, 1.5}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {0, 0}},
   Ticks->{{{10, 
       FormBox["10", TraditionalForm]}}, {}}]],
  CellChangeTimes->{
   3.8340011265774603`*^9, {3.834001156721785*^9, 3.834001238782977*^9}, 
    3.834001455909588*^9, 3.834001788169707*^9, 3.834001822426213*^9, 
    3.8340022466256795`*^9, {3.834002389006344*^9, 3.834002400180061*^9}, 
    3.834002471180276*^9},ExpressionUUID->
  "a53feb61-04a8-40ae-abe5-9b7343f4328b"]
}], "SummaryNote",
 CellChangeTimes->{{3.834002755264668*^9, 3.83400277553579*^9}, {
  3.834002826552258*^9, 3.8340028305313034`*^9}, {3.8340031237597337`*^9, 
  3.83400316585574*^9}, {3.83400325514662*^9, 3.83400325514662*^9}},
 CellID->189547091,ExpressionUUID->"2a61a960-a2cb-49ba-8abb-9312bda0d818"],

Cell["\<\
The Fourier transform of periodic signals was derived and was shown to be a \
sum of scaled and shifted Dirac delta functions.\
\>", "SummaryNote",
 CellChangeTimes->{{3.81084685042436*^9, 3.81084691168437*^9}, {
  3.81085346327881*^9, 3.81085354166087*^9}, {3.8911078107207546`*^9, 
  3.891107811119687*^9}},
 CellID->999709936,ExpressionUUID->"2400138c-bfba-47ed-b572-9ea349e6c153"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSection",
 CellID->212840224,ExpressionUUID->"12e30747-b056-4284-a444-777e0cfc7214"],

Cell[CellGroupData[{

Cell["Obtain the Fourier transform of the following signal.", "Exercise",
 CellChangeTimes->{3.9162203921574135`*^9, 3.9338608109745426`*^9},
 CellID->171279840,ExpressionUUID->"598d7da9-eea0-4c8c-bb43-6827a1828d8f"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   RowBox[{"\[Delta]", "(", "t", ")"}]}], 
  TraditionalForm]],ExpressionUUID->"5df9e200-65ef-48ec-9c88-a9cb1db1bc21"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.7183089413817053`*^9, 3.718308949329693*^9}, {3.748947264704677*^9, 
  3.7489473270860586`*^9}, {3.748947508564802*^9, 3.748947508564802*^9}, {
  3.852068529566748*^9, 3.852068544808993*^9}, {3.864219494090993*^9, 
  3.864219494091523*^9}, {3.930309703996748*^9, 3.9303097096845627`*^9}},
 CellID->14525259,ExpressionUUID->"a6f1e08b-3f22-4804-9045-9a5bc0f986ab"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtain the Fourier transform of the following signal.", "Exercise",
 CellChangeTimes->{3.9162203921574135`*^9, 3.933860812919731*^9},
 CellID->1645372513,ExpressionUUID->"0ce59e3f-8786-44ec-b54b-3b4480473288"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"\[LeftBracketingBar]", "t", "\[RightBracketingBar]"}]}]]}], 
  TraditionalForm]],ExpressionUUID->"985c3c90-704d-4da3-a60b-59b61dbc5a70"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.7183089413817053`*^9, 3.718308949329693*^9}, {3.748947264704677*^9, 
  3.7489473270860586`*^9}, {3.748947508564802*^9, 3.748947508564802*^9}, {
  3.852068529566748*^9, 3.852068544808993*^9}, {3.864219494090993*^9, 
  3.864219494091523*^9}},
 CellID->254810408,ExpressionUUID->"d50301f1-01f5-4343-8d9e-a1f8a39edece"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtain the Fourier transform of the following signal.", "Exercise",
 CellChangeTimes->{3.916220394537077*^9, 3.9338608153076935`*^9},
 CellID->628903572,ExpressionUUID->"69665ab1-8d31-49c4-812c-acefd23e3911"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{"t", "+", "1"}], ",", " "}], 
          RowBox[{
           RowBox[{"-", "1"}], "\[LessEqual]", "t", "<", "0"}]},
         {
          RowBox[{
           RowBox[{"1", "-", "t"}], ","}], 
          RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]},
         {
          RowBox[{"0", ","}], "else"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], 
  TraditionalForm]],ExpressionUUID->"0b998c4c-3867-40df-9102-1aafe143d24a"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.7183089413817053`*^9, 3.718308949329693*^9}, {3.748947560161535*^9, 
  3.748947564175668*^9}, {3.864219494225855*^9, 3.8642194942269983`*^9}},
 CellID->11156931,ExpressionUUID->"4fdbd496-c7fb-41ae-8ebf-d59d6c8fc4c0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtain the Fourier transform of the following signal.", "Exercise",
 CellChangeTimes->{
  3.916220396865551*^9, {3.933860817724783*^9, 3.933860820918247*^9}},
 CellID->67824070,ExpressionUUID->"5d10d889-bde8-4ce7-bd28-ec9ac3346f34"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"cos", "(", 
               RowBox[{"\[Pi]", " ", "t"}], ")"}]}], ")"}]}], ",", " "}], 
          RowBox[{
           RowBox[{"-", "1"}], "\[LessEqual]", "t", "\[LessEqual]", "1"}]},
         {
          RowBox[{"0", ","}], "else"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], 
  TraditionalForm]],ExpressionUUID->"05a8c6d3-c24c-42b6-9c5e-4c53185cea6f"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.7183089413817053`*^9, 3.718308949329693*^9}, {3.748947914195412*^9, 
  3.748947952165882*^9}, {3.8642194943666563`*^9, 3.864219494367806*^9}},
 CellID->131677954,ExpressionUUID->"bcc02adf-b1d9-452d-8075-1d089720a65a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtain the inverse Fourier transform.", "Exercise",
 CellChangeTimes->{{3.9158157581696315`*^9, 3.915815759875041*^9}, 
   3.91622039942184*^9, 3.9338608276448746`*^9, {3.9340202801252823`*^9, 
   3.9340202822581463`*^9}},
 CellID->1752811580,ExpressionUUID->"d1bf7759-241d-45ff-a5b4-94148199b256"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"X", "(", 
    RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{"-", "j"}], ",", " "}], 
          RowBox[{
           RowBox[{"-", "1"}], "\[LessEqual]", "\[Omega]", "\[LessEqual]", 
           "0"}]},
         {
          RowBox[{"j", ","}], 
          RowBox[{"0", "\[LessEqual]", "\[Omega]", "\[LessEqual]", "1"}]},
         {
          RowBox[{"0", ","}], "else"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], 
  TraditionalForm]],ExpressionUUID->"ec3367cd-e49e-418e-b7a4-0fedcf231d32"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.684443681825003*^9, 3.684443746254003*^9}, {3.718308967718085*^9, 
  3.718308984578082*^9}, {3.748948588682496*^9, 3.748948622865514*^9}, {
  3.8453062334605565`*^9, 3.84530623738171*^9}, {3.864219494511017*^9, 
  3.864219494512288*^9}},
 CellID->221542822,ExpressionUUID->"b5f578cd-c902-449f-9d27-130f9b0b9923"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obtain the inverse Fourier transform.", "Exercise",
 CellChangeTimes->{
  3.9162204019415913`*^9, 3.9162371998328023`*^9, {3.9303095181549625`*^9, 
   3.9303095379998093`*^9}, 3.933860829906313*^9, {3.934020285574911*^9, 
   3.934020287009104*^9}},
 CellID->323555514,ExpressionUUID->"ae64f440-75ed-4b22-8fb9-62d826d37577"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"X", "(", 
    RowBox[{"j", " ", "\[Omega]"}], ")"}], "=", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{"j", " ", "\[Omega]"}], ",", " "}], 
          RowBox[{
           RowBox[{"-", "1"}], "<", "\[Omega]", "\[LessEqual]", "1"}]},
         {
          RowBox[{"0", ","}], "else"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], 
  TraditionalForm]],ExpressionUUID->"d0fc86ec-d186-4302-9c46-765fc77cf43b"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6844435252896028`*^9, 3.684443602341003*^9}, {
  3.684443681825003*^9, 3.684443746254003*^9}, {3.686075968535858*^9, 
  3.686076018221946*^9}, {3.686078638479617*^9, 3.686078672344139*^9}, {
  3.686078817039756*^9, 3.686078854238825*^9}, {3.68609271837776*^9, 
  3.6860927544478846`*^9}, {3.686092900980151*^9, 3.686092903647756*^9}, {
  3.686093108651428*^9, 3.686093111388248*^9}, {3.748948608318488*^9, 
  3.748948609753392*^9}, {3.845306244069494*^9, 3.8453062444781*^9}, {
  3.864219494720831*^9, 3.864219494721904*^9}},
 CellID->448760640,ExpressionUUID->"b886570a-1bfb-48a1-883d-e7ced48f2643"]
}, Open  ]],

Cell[TextData[{
 "Obtain the Fourier transform of the periodic signal ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"cos", "(", 
       RowBox[{"2", "\[Pi]", " ", "t"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"cos", "(", 
       RowBox[{"8", " ", "\[Pi]", " ", "t"}], ")"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"27f67326-9122-4ffc-a378-c530efc9e887"],
 ". "
}], "Exercise",
 CellID->568929594,ExpressionUUID->"ad99057f-4364-4dfd-b07a-c30cc76da907"],

Cell[CellGroupData[{

Cell["\<\
Obtain the Fourier transform of the following full-wave rectified sine wave.\
\>", "Exercise",
 CellChangeTimes->{3.916220405108772*^9, 3.933860836078491*^9},
 CellID->1402489914,ExpressionUUID->"83034098-2b12-4243-b711-5774be0b8cc7"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "t", ")"}], "=", 
   RowBox[{"\[LeftBracketingBar]", 
    RowBox[{"sin", "(", 
     RowBox[{"\[Pi]", " ", "t"}], ")"}], "\[RightBracketingBar]"}]}], 
  TraditionalForm]],ExpressionUUID->"cf03c43e-c4d2-4582-a203-193801741519"]], \
"ExerciseNote",
 CellChangeTimes->{{3.893366250185943*^9, 3.8933662736866045`*^9}},
 CellID->129417543,ExpressionUUID->"917ca154-e1ce-41d2-8b38-10597ed15ecc"],

Cell["This shows the signal.", "ExerciseNote",
 CellChangeTimes->{{3.801849506800965*^9, 3.801849546636515*^9}, 
   3.864219494985241*^9, {3.893366337026975*^9, 3.893366369716365*^9}, 
   3.916220409084648*^9, 3.9338608389573097`*^9},
 CellID->134352946,ExpressionUUID->"7da4be98-6af2-4398-aa81-93ed5d9e599e"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[2], 
         Opacity[1.], LineBox[CompressedData["
1:eJwVm3c8Vf8bwO0dJSshURpCFA3qOS2jiG9WkSiahJARooyEjCiEEtkrGcno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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJwVm3c8Vf8bwO0dJSshURpCFA3qOS2jiG9WkSiahJARooyEjCiEEtkrGcno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             "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-1.9999998979591838`, 2.9999998979591838`}, {-0.5, 
           1.5}}, "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 180/GoldenRatio}, 
          "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {{-1.9999998979591838`, 2.9999998979591838`}, {-0.5, 
          1.5}}, "Frame" -> {{False, False}, {False, False}}, 
         "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 180/GoldenRatio}, 
         "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
         "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJwVm3c8Vf8bwO0dJSshURpCFA3qOS2jiG9WkSiahJARooyEjCiEEtkrGcno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          "]]}, "Charting`Private`Tag#1"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {{-1.9999998979591838`, 2.9999998979591838`}, {-0.5, 
        1.5}}, "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 180/GoldenRatio}, 
       "Axes" -> {True, True}, "AspectRatio" -> GoldenRatio^(-1), 
       "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["t", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->Small,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.9999998979591838`, 2.9999998979591838`}, {-0.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "ExerciseNote",
 CellChangeTimes->{{3.801849301131489*^9, 3.801849363253586*^9}, 
   3.801849405851756*^9, {3.801849571588134*^9, 3.801849583210077*^9}, {
   3.811511289494042*^9, 3.8115113157664604`*^9}, {3.8453072894483805`*^9, 
   3.845307319130492*^9}, 3.845307363179598*^9, 3.8642194951204767`*^9, {
   3.8931807142285995`*^9, 3.893180718501938*^9}, {3.893366394649709*^9, 
   3.893366431508611*^9}, {3.898783353647017*^9, 3.898783360864224*^9}},
 CellID->36529241,ExpressionUUID->"e328ff62-9b34-4959-b70c-4770c9eb0ed0"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["\[Copyright] 2024 Wolfram Media, Inc.", "SmallText",
 CellMargins->{{66, 66}, {20, 100}},
 CellGroupingRules->"SectionGrouping",
 FontSize->12,
 FontColor->RGBColor[
  0.7098039215686275, 0.7098039215686275, 0.7098039215686275],
 CellID->1958447119,ExpressionUUID->"899de554-a35f-4755-a746-397383569947"]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellInsertionPointCell->None,
WindowSize->Automatic,
WindowMargins->{Automatic, Automatic},
WindowFrame->"Normal",
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"15. Continuous\[Hyphen]Time Fourier Transform | Signals, \
Systems, and Signal Processing",
DockedCells->{
  Cell[
   TagBox[
    GridBox[{{
       PaneBox[
        TagBox[
         GridBox[{{
            StyleBox["Wolfram eTextbook Series", 12, 
             RGBColor[
             0.8823529411764706, 0.40784313725490196`, 0.1450980392156863], 
             FontFamily -> "Source Sans Pro"]}, {
            TemplateBox[{
              StyleBox["\"Signals, Systems, and Signal Processing\"", 20, 
               GrayLevel[1], FontWeight -> "SemiBold", FontFamily -> 
               "Source Sans Pro"], 
              "https://www.wolfram.com/wolfram-u/courses/image-signal-\
processing/signals-systems-and-signal-processing/"}, "HyperlinkURL"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}], "Grid"], 
        ImageSize -> Full, FrameMargins -> {{20, 20}, {5, 12}}], 
       PaneBox[
        PaneBox[
         TemplateBox[{"\[ThinSpace]", "\" \"", 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
               ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                 Method -> "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], 
             "\"14. Continuous\[Hyphen]Time Fourier Series\"", TooltipDelay -> 
             0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, "14. Continuous\[Hyphen]Time Fourier Series", 
             "Tooltip"]& ], 
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[5], Selectable -> False], 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-16_CT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                 Automatic, Method -> "Preemptive"], True -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-16_CT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                 GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                 "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], 
             "\"16. Continuous\[Hyphen]Time Fourier Transform Theorems\"", 
             TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, 
             "16. Continuous\[Hyphen]Time Fourier Transform Theorems", 
             "Tooltip"]& ]}, "RowWithSeparators"], Alignment -> Right], 
        Alignment -> Right, FrameMargins -> {{0, 6}, {0, 0}}, 
        ImageSize -> {100, 30}], 
       TagBox[
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0., 0.1607843137254902, 0.4], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Cover" :> NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00a_Cover.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Preface" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00b_Preface.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Signals and Systems\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "1. Introduction to Signals and Systems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2. Signal Classification" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-02_Signal-Classification.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3. Elementary Signals and Sequences" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-03_Elementary-Signals.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4. Elementary Operations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-04_Elementary-Operations.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5. System Properties" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-05_System-Properties.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "6. Continuous\[Hyphen]Time Systems as Differential Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "7. Differential Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-07_CT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "8. Continuous\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-08_CT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "9. Continuous\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-09_CT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10. Discrete\[Hyphen]Time Systems as Difference Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11. Difference Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-11_DT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12. Discrete\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-12_DT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13. Discrete\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-13_DT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14. Continuous\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15. Continuous\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-15_CT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16. Continuous\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-16_CT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "17. Continuous\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-17_CT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18. Discrete\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19. Discrete\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-19_DT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20. Discrete\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-20_DT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "21. Discrete\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-21_DT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Laplace Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "22. Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "23. Inverse Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-23_Inverse-Laplace-Transform.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "24. Laplace Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-24_Laplace-Transform-Theorems.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "25. Unilateral Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-25_Unilateral-Laplace-\
Transform.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"z\[Hyphen]Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "26. z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "27. Inverse z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-27_Inverse-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "28. z\[Hyphen]Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-28_Z-Transform-Theorems.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "29. Unilateral z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-29_Unilateral-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Sampling and Filter Design\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "30. Sampling" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "31. FIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-31_FIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "32. Butterworth Filter" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-32_Butterworth-Filter.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "33. IIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-33_IIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Sample Exam\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-34_Sample-Exam.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None], 
        MouseAppearanceTag["LinkHand"]]}}, AutoDelete -> False, 
     GridBoxItemSize -> {
      "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"], 
   Background -> RGBColor[0., 0.1607843137254902, 0.4], 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrameColor -> 
   RGBColor[0., 0.1607843137254902, 0.4], CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameMargins -> {{0, 20}, {5, 0}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, CellGroupingRules -> {"SectionGrouping", 0}, 
   CellContext -> CellGroup], 
  Cell[
   BoxData[
    GridBox[{{
       DynamicModuleBox[{$CellContext`open$$ = False}, 
        PaneSelectorBox[{True -> ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{93, 93, 93, 19}, {140, 140, 
                   140, 237}, {115, 115, 115, 181}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {115, 115, 115, 181}, {140,
                    140, 140, 237}, {93, 93, 93, 19}}, {{140, 140, 140, 
                   236}, {179, 179, 179, 255}, {179, 179, 179, 255}, {127, 
                   127, 127, 216}, {92, 92, 92, 11}, {92, 92, 92, 11}, {127, 
                   127, 127, 216}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {140, 140, 140, 236}}, {{102, 102, 102, 119}, {167, 
                   167, 167, 255}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {142, 142, 142, 240}, {141, 141, 141, 239}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {167, 167, 167, 
                   255}, {102, 102, 102, 119}}, {{0, 0, 0, 0}, {98, 98, 98, 
                   75}, {158, 158, 158, 251}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {179, 179, 179, 255}, {179, 179, 179, 255}, {
                   158, 158, 158, 251}, {98, 98, 98, 75}, {0, 0, 0, 0}}, {{0, 
                   0, 0, 0}, {0, 0, 0, 0}, {93, 93, 93, 38}, {144, 144, 144, 
                   241}, {179, 179, 179, 255}, {179, 179, 179, 255}, {144, 
                   144, 144, 241}, {93, 93, 93, 38}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {92, 92, 
                   92, 11}, {129, 129, 129, 222}, {129, 129, 129, 222}, {92, 
                   92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}}], {{0, 6.}, {10., 0}}, {0, 255}, ColorFunction -> 
                  RGBColor, ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {10., 6.}, PlotRange -> {{0, 10.}, {0, 6.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"], False -> 
          ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{0, 0, 0, 0}, {98, 98, 98, 
                   78}, {132, 132, 132, 225}, {97, 97, 97, 21}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{93, 93, 93, 49}, {168, 
                   168, 168, 255}, {179, 179, 179, 255}, {141, 141, 141, 
                   238}, {92, 92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{102,
                    102, 102, 15}, {149, 149, 149, 246}, {179, 179, 179, 
                   255}, {179, 179, 179, 255}, {133, 133, 133, 229}, {102, 
                   102, 102, 5}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {95, 95, 95, 
                   40}, {156, 156, 156, 250}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {129, 129, 129, 217}, {255, 255, 255, 1}}, {{0,
                    0, 0, 0}, {0, 0, 0, 0}, {95, 95, 95, 56}, {163, 163, 163, 
                   253}, {179, 179, 179, 255}, {179, 179, 179, 255}, {115, 
                   115, 115, 181}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {103, 103, 
                   103, 123}, {174, 174, 174, 255}, {179, 179, 179, 255}, {
                   176, 176, 176, 255}, {102, 102, 102, 119}}, {{0, 0, 0, 
                   0}, {100, 100, 100, 102}, {172, 172, 172, 255}, {179, 179, 
                   179, 255}, {179, 179, 179, 255}, {109, 109, 109, 154}, {0, 
                   0, 0, 0}}, {{91, 91, 91, 42}, {167, 167, 167, 255}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {114, 114, 114, 
                   176}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{97, 97, 97, 21}, {147,
                    147, 147, 245}, {179, 179, 179, 255}, {119, 119, 119, 
                   194}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0,
                    0}, {93, 93, 93, 19}, {103, 103, 103, 128}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}], {{
                   0, 10.}, {7., 0}}, {0, 255}, ColorFunction -> RGBColor, 
                  ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {7., 10.}, PlotRange -> {{0, 7.}, {0, 10.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"]}, 
         Dynamic[$CellGroupContext`open$$]], 
        Initialization :> ($CellGroupContext`open$$ = False), 
        DynamicModuleValues :> {}]}}, 
     GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
     GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}]], "Text", 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   CellFrameMargins -> {{28, 0}, {2, 2}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.], CellContext -> 
   CellGroup], 
  Cell[
   BoxData[
    TemplateBox[{
      TemplateBox[{
        StyleBox[
        "\"M. Jankowski (2024), \"", FontWeight -> "Bold", FontSize -> 11, 
         FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Signals, Systems, and Signal Processing: A Computational Approach, \
\"", Selectable -> True, Copyable -> True, FontSlant -> Italic, FontWeight -> 
         "Bold", FontSize -> 11, FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing.\"", 
         FontWeight -> "Bold", FontSize -> 11, FontFamily -> 
         "Source Sans Pro", FontColor -> 
         RGBColor[
          0.2784313725490196, 0.403921568627451, 0.5137254901960784]]}, 
       "RowDefault"], 
      "M. Jankowski (2024), \!\(\*StyleBox[\"Signals\",FontSlant->\"Italic\"]\
\)\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Systems\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \",FontSlant->\
\"Italic\"]\)\!\(\*StyleBox[\"and\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Signal\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Processing\",FontSlant->\"Italic\"\
]\)\!\(\*StyleBox[\":\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"A\",FontSlant->\"Italic\"]\)\!\(\*\
StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Computational\",FontSlant->\"\
Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Approach\",FontSlant->\"Italic\"]\
\), Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing."}, 
     "ClickToCopy2", BaseStyle -> {LineBreakWithin -> Automatic}]], "Text", 
   Selectable -> True, CellFrame -> {{0, 1}, {0, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {0, -1}}, 
   CellElementSpacings -> {"CellMinHeight" -> 2, "ClosedCellHeight" -> 1}, 
   Copyable -> True, CellOpen -> Dynamic[$CellGroupContext`open$$], 
   CellContext -> CellGroup, CellFrameMargins -> {{28, 0}, {5, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   LineSpacing -> {1, -3}, ShowStringCharacters -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.]]},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{504, 720}},
ShowCellBracket->Automatic,
ShowCellLabel->False,
CellLabelAutoDelete->True,
CellLabelTemplate-><|
 "In" -> "In[`1`]:=", "InExpired" -> "In[`1`]:=", "Out" -> "Out[`1`]=", 
  "OutExpired" -> "Out[`1`]="|>,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
AutoStyleOptions->{"HighlightComments"->True},
AutoMultiplicationSymbol->{},
Magnification->1,
FrontEndVersion->"14.0 for Mac OS X ARM (64-bit) (December 12, 2023)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["eBook Styles", "Section"], 
      Cell[
       StyleData["ContentsTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       MenuSortingValue -> 20000, FontFamily -> "Helvetica", FontSize -> 36, 
       FontWeight -> "Bold", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Leader"], TabFilling -> ".", MenuSortingValue -> 10000, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       18, FontWeight -> "Plain"], 
      Cell[
       StyleData["LeaderNoDots"], TabFilling -> " ", MenuSortingValue -> 
       10000, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["PageLink"], MenuSortingValue -> 10000, StyleMenuListing -> 
       None, ButtonStyleMenuListing -> Automatic, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[0.269993, 0.308507, 0.6], 
       ButtonBoxOptions -> {
        Active -> True, Appearance -> {Automatic, None}, 
         ButtonFunction :> (FrontEndExecute[{
            FrontEnd`NotebookLocate[#2]}]& )}], 
      Cell[
       StyleData["TOCPage"], CellSize -> {40, Inherited}, TextAlignment -> 
       Right, MenuSortingValue -> 20010, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["TOCTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 36, 
       CounterIncrements -> "TOCTitle", MenuSortingValue -> 20020, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Bold", FontColor -> 
       GrayLevel[0]], 
      Cell[
       StyleData["TOCSection"], CellMargins -> {{95, 95}, {1, 1}}, 
       CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 34, 
       CounterIncrements -> "TOCSection", MenuSortingValue -> 20030, 
       FontFamily -> "Source Sans Pro", FontSize -> 16], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 81}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"ItemGrouping", 70}, CellFrameLabelMargins -> 
          4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Baskerville", FontSize -> 
          18], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{81, 81}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["SectionSingleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
       CellDingbat -> Cell[
         TextData[
          CounterBox["Section"], 
          StyleBox[
          "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
           RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
           FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]], 
         "SectionNumber"], CellMargins -> {{100, 100}, {12, 64}}, Evaluatable -> 
       True, CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
       True, ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       26, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsubsection"], 
          CellMargins -> {{66, 66}, {2, 10}}, 
          StyleKeyMapping -> {
           "Backspace" -> 
            "Subsubsubsection", $CellContext`KeyEvent[
             "Tab", $CellContext`Modifiers -> {"Shift"}] -> 
            "Subsubsubsection"}, CellGroupingRules -> {"SectionGrouping", 70},
           PageBreakBelow -> False, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsubsubsection", 
          CounterAssignments -> {{"Item", 0}, {"Subitem", 0}, {
            "Subsubitem", 0}, {"ItemNumbered", 0}, {"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> None, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsubsubsection", "Printout"], 
          CellMargins -> {{66, 66}, {2, 10}}], 
         Cell[
          StyleData["Chapter", "Printout"], 
          CellMargins -> {{Inherited, Inherited}, {62, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
       CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
       Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
       PageBreakBelow -> False, ShowCellLabel -> False, 
       CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
       RGBColor[0.901961, 0.411765, 0.027451], 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, MenuSortingValue -> 10015, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       GridBoxOptions -> {GridBoxAlignment -> {}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{108, 108}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10025, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{110, 110}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummarySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], MenuSortingValue -> 9000, 
          FontFamily -> "Source Sans Pro", FontSize -> 18, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["SummarySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 9010, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryNote", "Printout"], 
          CellMargins -> {{68, 68}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryList"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 9020, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryList", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Open]], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[5]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Appearance -> "PopupMenu",
                Method -> "Queued", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {"PageSize" -> {504, 720}}, 
       AutoStyleOptions -> {"UndefinedSymbolStyle" -> None}, Magnification -> 
       0.6], 
      Cell[
       StyleData[All, "Invisibles"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, Appearance -> 
               "PopupMenu", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Method -> "Queued", 
               FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], 
       PrintingOptions -> {"PageHeaderMargins" -> {28, 28}}, StyleMenuListing -> 
       None, FontFamily -> "Source Sans Pro", FontSize -> 8, FontWeight -> 
       "Regular", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> WindowWidth, 
       PrintingOptions -> {
        "FirstPageHeader" -> True, "InnerOuterMargins" -> {30, 30}, 
         "PaperOrientation" -> "Portrait", "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, 64}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, 64}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{64, 64}, {12, 64}}, 
          CellGroupingRules -> {"SectionGrouping", 30}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{62, 62}, {52, 182}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, 112}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, 112}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionBar"], FontFamily -> "Source Sans Pro", 
          FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionBar", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], CellMargins -> {{64, 64}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, 64}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumbered"], CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Subsection"]}], "SubsectionNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{98, 98}, {Inherited, 32}}, CounterIncrements -> 
          "Subsection", FontFamily -> "Source Sans Pro Semibold", FontSize -> 
          18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsectionNumbered", "Printout"], 
          CellMargins -> {{102, 102}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumber"], FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          GrayLevel[0.25]], 
         Cell[
          StyleData["SubsectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionFirst"], CellMargins -> {{64, 64}, {2, 72}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, 64}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsubsectionTopMargin"], 
          CellMargins -> {{64, 64}, {2, 14}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsubsectionTopMargin", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.45]], 
         Cell[
          StyleData["Subsubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, 64}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, 64}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsection"], 
          CellMargins -> {{64, 64}, {2, 10}}, FontFamily -> "Source Sans Pro",
           FontSize -> 16, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsectionSM"], 
          CellFrame -> {{0, 0}, {0.75, 0}}, 
          CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Regular", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {6, 15}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakBelow -> False, ShowCellLabel -> False, 
          CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, 64}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsectionSM"], 
          CellMargins -> {{64, 64}, {4, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ExerciseSubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> False, CellMargins -> {{106, 106}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 62}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{108, 108}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellGroupingRules -> {"SectionGrouping", 62.}, PageBreakBelow -> 
          False, LineSpacing -> {1., 1., 2.}, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}, LineSpacing -> {0.8, 1., 2.}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {2, 12}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, CounterIncrements -> "Question", 
          MenuSortingValue -> 10030, MenuCommandKey :> "3", FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, 65}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> WindowWidth, 
          CellMargins -> {{66, 66}, {4, 1}}, ReturnCreatesNewCell -> True, 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`DefaultReturnCreatedCellStyle -> 
          "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 66}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSubsection"], CellMargins -> {{64, 64}, {2, 10}},
           FontFamily -> "Source Sans Pro", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["TechNoteSubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, 93}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, 93}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteNoDingbat"], PageWidth :> WindowWidth, 
          CellMargins -> {{82, 82}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"\[FilledSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 4, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 1, FontSize -> 
          14], 
         Cell[
          StyleData["TechNoteInput", "Printout"], 
          CellMargins -> {{99, 99}, {3, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TechNoteOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 14], 
         Cell[
          StyleData["TechNoteOutput", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10050, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], CellMargins -> {{64, 64}, {4, 8}},
           PageBreakBelow -> False, FontFamily -> "Source Sans Pro Light", 
          FontSize -> 14, FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{1, 1}, {1, 1}}, CellMargins -> {{52, 52}, {-1, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{16, 8}, {6, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "Bold", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[1], Background -> 
          RGBColor[0.901961, 0.411765, 0.027451]], 
         Cell[
          StyleData["TakeawaysSection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysHeader"], CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "SemiBold", 
          FontSlant -> "Regular", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysHeader", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysTable"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 0}}, CellMargins -> {{52, 52}, {12, -1}}, 
          ReturnCreatesNewCell -> True, 
          CellFrameMargins -> {{18, 12}, {20, 12}}, CellFrameLabelMargins -> 
          6, LineSpacing -> {1.25, 1., 2.}, SpanMaxSize -> 1, FontFamily -> 
          "Source Sans Pro Light", FontColor -> GrayLevel[0.25], Background -> 
          RGBColor[1., 0.9490196078431372, 0.8509803921568627], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"TakeawaysDingbat", Inherited}, 
              "Rows" -> {{SpanFromLeft, Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.75}}}}], 
         Cell[
          StyleData["TakeawaysTable", "Printout"], 
          CellMargins -> {{51.5, 51.5}, {12, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysText", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TakeawaysDingbat", StyleDefinitions -> StyleData["Text"]], 
          FontFamily -> "Source Sans Pro", FontSize -> 10, FontWeight -> 
          "SemiBold", FontColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TakeawaysDingbat", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeText", StyleDefinitions -> StyleData["Text"]], 
          CellMargins -> {{66, 66}, {3, 15}}, LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 1540, 
          MenuCommandKey :> $CellContext`MenuKey[
           "7", $CellContext`Modifiers -> {"Shift"}], FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeText", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 66}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], CellMargins -> {{99, 99}, {2, 12}}, 
          StripStyleOnPaste -> True, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 99}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, 100}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.135 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, 18}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontFamily -> Automatic, FontSize -> 
            18, FontWeight -> GrayLevel[0], 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{81, 81}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontSize -> 17, FontFamily -> 
            "Automatic", FontWeight -> "Black", 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{80, 80}, {Inherited, Inherited}}, 
          CellDingbatMargin -> 2, 
          CellGroupingRules -> {
           "GroupTogetherNestedGrouping", 1.073741821*^9}, 
          CellChangeTimes -> {{3.8855684925344043`*^9, 
           3.885568495926271*^9}, {3.885643888233819*^9, 
           3.885643900721007*^9}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 81}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, 80}, {Inherited, 0.5 Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 85}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, 90}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Note"], CellFrame -> {{0, 0}, {0, 1}}, 
          CellMargins -> {{66, 66}, {8, 6}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameMargins -> {{14, 14}, {12, 12}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          LineSpacing -> {1.2, 1., 2.}, MenuSortingValue -> 1600, FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontColor -> GrayLevel[0.2], 
          Background -> RGBColor[1., 0.9647058823529412, 0.9411764705882353]], 
         Cell[
          StyleData["Note", "Printout"], CellMargins -> {{66, 66}, {10, 8}}, 
          FontSize -> 14]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EchoTiming"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["EchoTiming", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 100}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 125}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 80}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110586`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 66}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TextFirst"], CellMargins -> {{66, 66}, {4, 72}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 66}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 66}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SmallText"], CellMargins -> {{66, 66}, {6, 6}}, 
          LineSpacing -> {1, 3}, TabSpacings -> {2.5}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "SmallText", 
          MenuSortingValue -> 1750, StyleMenuListing -> None, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["SmallText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}, Hyphenation -> True]}, Closed]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 99}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 99}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 99}, {15, 10}}]}, Closed]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       StyleData[
       "CellLabelExpired", StyleDefinitions -> StyleData["CellLabel"]], 
       CellLabelMargins -> 6, FontSlant -> Italic, FontTracking -> 0.4, 
       FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["SummaryPanel"], GeneratedCell -> True, CellAutoOverwrite -> 
       True, CellChangeTimes -> {3.84753348107472*^9}, FontFamily :> 
       CurrentValue["PanelFontFamily"], FontSize :> 0.8 Inherited, FontWeight -> 
       "Plain", FontSlant -> "Plain", FontColor :> 
       CurrentValue[{"SystemColors", "DialogText"}], 
       TemplateBoxOptions -> {
        DisplayFunction -> (
          ButtonBox[#, Active -> False, Alignment -> Left, 
           Appearance -> {"Default" -> Image[CompressedData["
1:eJzNlk0KgkAUgKVatGzRAWohXqFty7ZFB1AyaWOgQXQozyIPZmCgxYBLQUQ6
gL2R/ElcBKWvgU+cQd/3ZhxnZmmdt8eRpmn+FC9b87r2PPO2m2Fl7/onx7UP
G/diO7a3ssbYOEcWyATJvyw/CFGECcNQRwIkQ3J4Eb4BrXqjDT55togdYFxd
OUs5ABj4fipllMdxnCdJ0gsqdoQOzC3FPIyGP1DtfXnbSCkLZ/ntGEDWZ7+7
xgGAPSo/Y4O5SxiDau5yAj/nrPZzTuDnlV9wMbhfCFH4Fep+cP9d1P2n9hOO
/z/MP+r/j3r9oV5/qfcf6v2X4vyB+XQenMo1sS/a5QlC6exw
               "], "Byte", ColorSpace -> "RGB", Interleaving -> True]}, 
           FrameMargins -> 7, BaseStyle -> {Deployed -> False}, 
           DefaultBaseStyle -> {"Pane", Background -> None}, BaselinePosition -> 
           Baseline]& ), Tooltip -> None}, 
       GraphicsBoxOptions -> {
        Axes -> False, 
         DefaultBaseStyle -> {"GraphicsNoFontOrMenu", CacheGraphics -> False},
          ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}, 
       Graphics3DBoxOptions -> {
        Axes -> False, DefaultBaseStyle -> {"Graphics3DNoFontOrMenu"}, 
         ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}], 
      Cell[
       StyleData["IconizedDefaultName"], FontSize -> 12, 
       PrivateFontOptions -> {"OperatorSubstitution" -> False}, FontColor -> 
       GrayLevel[0.15]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, 66}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, 100}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{106, 106}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{106, 106}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{106, 106}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{106, 106}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 66}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 66}, {8, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Tentative"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[
          0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
         "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
       StyleMenuListing -> None, Background -> 
       RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["PrintOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.89, 0.867, 0.99], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.89, 0.867, 0.99]], 
         Cell[
          StyleData["PrintOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Closed]], 
      Cell[
       StyleData["SolvedExampleNote", StyleDefinitions -> StyleData["Text"]], 
       CellMargins -> {{66, 66}, {8, 0}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleInput", StyleDefinitions -> StyleData["Input"]], 
       CellMargins -> {{66, 66}, {0, -10}}, 
       GeneratedCellStyles -> {"Output" -> "SolvedExampleOutput"}, Background -> 
       RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleOutput", StyleDefinitions -> StyleData["Output"]], 
       CellMargins -> {{66, 66}, {8, -9}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData["SolvedExample"], CellMargins -> {{66, 66}, {0, 16}}, 
       CounterIncrements -> "SolvedExample", FontFamily -> "Source Sans Pro", 
       FontSize -> 16.5, FontWeight -> "SemiBold", FontColor -> 
       RGBColor[0., 0.0078, 0.13], Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0, 2}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["StandardForm", "Printout"], LineSpacing -> {1.25, 0, 2}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["OutputForm"], LineSpacing -> {0.6, 1}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["OutputForm", "Printout"], LineSpacing -> {0.6, 1}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputForm"], FontFamily -> "Source Sans Code"], 
         Cell[
          StyleData["InputForm", "Printout"], FontFamily -> 
          "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FormattedFunction"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]]], 
         Cell[
          StyleData["FormattedFunction", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup["ref/" <> #]]& ), ButtonSource -> 
            ButtonContents, Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FunctionLink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["FunctionLink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "FunctionHyperlink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["FunctionHyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ResourceFunctionlink", StyleDefinitions -> StyleData["Hyperlink"]],
           MenuSortingValue -> None, FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourceFunctionlink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Closed]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineMath"], SpanMaxSize -> 0, FontColor -> GrayLevel[0], 
       CellID -> 644119144], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.94 Inherited], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["DialogElementName"], 
       CellChangeTimes -> {3.642251807158844*^9, 3.8358753610849867`*^9, 
        3.835875471581566*^9}, FontFamily -> "Source Sans Pro SemiBold", 
       FontSize -> 0.95 Inherited, FontWeight -> "Regular"], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          1.05 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          1.1 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontSize -> 0.85 Inherited, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    PaneBox[
                    StyleBox[#4, "EntityTypeLabel"], BaselinePosition -> 
                    Baseline, ContentPadding -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               Directive[
                 RGBColor[1., 0.504768, 0.], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Helvetica", FontSize -> 0.85 Inherited, FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> Directive[
                 RGBColor[0.94227, 0.703639, 0.033387], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "14.0 for Mac OS X ARM (64-bit) (December 12, 2023)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"85565063-591d-40c9-a4c8-904c223b45d4"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[680, 24, 356, 5, 111, "SectionDoubleDigit",ExpressionUUID->"f88b082e-fffc-49c3-89d0-275fdcb40a49",
 CounterAssignments->{{"Section", 14}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
 CellID->1640225589],
Cell[1039, 31, 1148, 18, 113, "Text",ExpressionUUID->"e8681450-7299-4e6b-a571-1b2f0c7f4673",
 CellID->23897784],
Cell[CellGroupData[{
Cell[2212, 53, 4302, 79, 32, "Input",ExpressionUUID->"6382d507-c1af-4ccd-88ee-ce378fbde8dc",
 CellID->70613699],
Cell[6517, 134, 3693, 68, 226, "Output",ExpressionUUID->"effca984-4267-42b2-9b31-0f54c64757dc",
 CellID->484819639]
}, Open  ]],
Cell[10225, 205, 566, 9, 63, "Text",ExpressionUUID->"cdfb9f20-dc0e-4dc3-aea2-ddeb15bc0e7c",
 CellID->36609945]
}, Open  ]],
Cell[CellGroupData[{
Cell[10828, 219, 360, 5, 57, "Subsection",ExpressionUUID->"a6b5f963-1857-4a1b-b8a0-a5567e19b523",
 CellID->1393465949],
Cell[11191, 226, 382, 7, 63, "Text",ExpressionUUID->"978b3d7f-f23e-4b0e-ad92-49953975dc36",
 CellID->1673034308],
Cell[11576, 235, 939, 26, 42, "Text",ExpressionUUID->"0196fe6f-4e80-49f2-9ca7-4ee0426399bb",
 CellID->1684224385],
Cell[12518, 263, 1104, 29, 43, "Text",ExpressionUUID->"f9f547f8-8c15-443b-a698-68b4d2ebda41",
 CellID->777287588],
Cell[13625, 294, 1252, 32, 65, "Text",ExpressionUUID->"1522aa19-fd5d-4d8f-965f-e95cd7985e45",
 CellID->729466815],
Cell[14880, 328, 516, 9, 63, "Text",ExpressionUUID->"2b099a0a-1a45-47c7-82ae-b8f99c43ee74",
 CellID->164618982],
Cell[15399, 339, 892, 21, 42, "Text",ExpressionUUID->"e57c218d-a748-4be4-a79b-998cd3e88028",
 CellID->792293138],
Cell[16294, 362, 349, 6, 63, "Text",ExpressionUUID->"d3567b31-7971-43ee-a20d-d6e631b4e1cf",
 CellID->1672158966],
Cell[16646, 370, 655, 13, 70, "Item",ExpressionUUID->"c75ff204-53da-4424-b179-0caf6bd966f6",
 CellID->2004736920],
Cell[17304, 385, 473, 11, 70, "Item",ExpressionUUID->"825716d7-3a24-41f4-ac29-33a951f85f3a",
 CellID->1742476657],
Cell[17780, 398, 720, 18, 70, "Text",ExpressionUUID->"1bc607fe-3f2d-4a86-a1ba-66ca6fafd03f",
 CellID->570680060]
}, Open  ]],
Cell[CellGroupData[{
Cell[18537, 421, 496, 7, 70, "Subsection",ExpressionUUID->"a8019496-d54b-46c8-a257-47f0afa7dc2a",
 CellID->757800918],
Cell[19036, 430, 388, 5, 70, "Text",ExpressionUUID->"4003087e-7b83-478d-b6cf-32d75573f2fc",
 CellID->1782002116],
Cell[19427, 437, 585, 19, 70, "Text",ExpressionUUID->"c8f3f566-0068-4b7b-93e2-22e164a91e96",
 CellID->1302622550],
Cell[CellGroupData[{
Cell[20037, 460, 219, 3, 70, "Subsubsection",ExpressionUUID->"b8eeb237-52da-4674-a00c-ca08d0dbfa1e",
 CellID->1728900332],
Cell[20259, 465, 702, 12, 70, "Text",ExpressionUUID->"ed4c5be3-0a79-4703-aaf2-49902c89b77c",
 CellID->26652367],
Cell[CellGroupData[{
Cell[20986, 481, 420, 10, 70, "Input",ExpressionUUID->"5fdedbf4-4070-4494-a85e-8d7a3d302842",
 CellID->1269733593],
Cell[21409, 493, 220, 3, 70, "Output",ExpressionUUID->"89bd3386-70ac-444f-b7ad-9f9037a16b63",
 CellID->213638193]
}, Open  ]],
Cell[21644, 499, 812, 17, 70, "Text",ExpressionUUID->"7a186b38-1a01-4228-b8bf-c96767ba2fd5",
 CellID->867497312],
Cell[CellGroupData[{
Cell[22481, 520, 514, 11, 70, "Input",ExpressionUUID->"c9b53bbc-b329-42da-9ef5-42a466c83ed0",
 CellID->760843301],
Cell[22998, 533, 302, 6, 70, "Output",ExpressionUUID->"5a746253-50a9-496f-9cd4-adbeb7180c65",
 CellID->111348218]
}, Open  ]],
Cell[23315, 542, 440, 8, 70, "Text",ExpressionUUID->"3d0fa574-1347-4ebd-8d36-49e163dd5e01",
 CellID->1375725669],
Cell[CellGroupData[{
Cell[23780, 554, 2124, 42, 70, "Input",ExpressionUUID->"98705f04-bbf3-432a-8088-55fa1781b4cb",
 CellID->2012375281],
Cell[25907, 598, 90121, 1558, 70, "Output",ExpressionUUID->"e6b4d4ee-f68f-421d-8478-505afb3c373e",
 CellID->275226895]
}, Open  ]],
Cell[CellGroupData[{
Cell[116065, 2161, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"6c4d38f7-a5d6-4c6b-a044-c64d0b9473a9",
 CellID->1271391164],
Cell[116229, 2165, 224, 3, 70, "Text",ExpressionUUID->"1f1b3da1-3653-42bf-a4a7-0a2b5a6be890",
 CellID->809005698],
Cell[116456, 2170, 1108, 26, 70, "Text",ExpressionUUID->"8b872573-ff52-4656-afa5-866d520875cd",
 CellID->1239797129],
Cell[117567, 2198, 579, 10, 70, "Text",ExpressionUUID->"eb966562-44fd-4af4-9c97-6679067155c0",
 CellID->236520262],
Cell[118149, 2210, 712, 20, 70, "Text",ExpressionUUID->"8cb1909b-2c34-4dc7-b829-250bccefa450",
 CellID->203812837],
Cell[118864, 2232, 202, 3, 70, "Text",ExpressionUUID->"fe5a294f-cd1e-4c88-87ca-fad6c2765c50",
 CellID->245934494],
Cell[119069, 2237, 716, 21, 70, "Text",ExpressionUUID->"a7bea3bc-208d-48b8-8e91-84bf3a04f664",
 CellID->1662503830],
Cell[119788, 2260, 694, 21, 70, "Text",ExpressionUUID->"b1dca42b-16c7-4f40-9473-ba0421498028",
 CellID->792139693],
Cell[120485, 2283, 486, 13, 70, "Text",ExpressionUUID->"d5bcc448-4ce0-4d89-9431-5726b44daa47",
 CellID->1240692498],
Cell[120974, 2298, 367, 10, 70, "Text",ExpressionUUID->"2fbd1124-ae8c-4094-b1b7-3d2919b90fc0",
 CellID->252601516]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[121402, 2315, 376, 5, 70, "Subsection",ExpressionUUID->"144ea7da-ba9e-4b15-9ccb-9ba8a084f869",
 CellID->2045992940],
Cell[121781, 2322, 596, 16, 70, "Text",ExpressionUUID->"f01f4a6f-55ff-4972-8062-cce6c2e34ee7",
 CellID->1495186816],
Cell[CellGroupData[{
Cell[122402, 2342, 217, 3, 70, "Subsubsection",ExpressionUUID->"7249553a-fd1a-4678-8c43-cc93bb2cc2ab",
 CellID->1898662965],
Cell[122622, 2347, 664, 11, 70, "Text",ExpressionUUID->"244384de-2927-4659-bef9-d2479431e5ef",
 CellID->1368941982],
Cell[CellGroupData[{
Cell[123311, 2362, 503, 13, 70, "Input",ExpressionUUID->"89ed1c8b-2e3e-4b4b-88ba-63043d16818c",
 CellID->1815581163],
Cell[123817, 2377, 169, 2, 70, "Output",ExpressionUUID->"5467f455-a91c-4824-b769-5b76ff2fdb51",
 CellID->412909794]
}, Open  ]],
Cell[124001, 2382, 624, 13, 70, "Text",ExpressionUUID->"d2556e03-9d81-4998-a144-4833e718709d",
 CellID->877466318],
Cell[CellGroupData[{
Cell[124650, 2399, 644, 14, 70, "Input",ExpressionUUID->"a548dcf2-7c4b-4561-8827-0060acee239c",
 CellID->806202677],
Cell[125297, 2415, 280, 6, 70, "Output",ExpressionUUID->"b4a19b33-1320-4330-8805-7a0e9cfdbe29",
 CellID->150360892]
}, Open  ]],
Cell[CellGroupData[{
Cell[125614, 2426, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"08fec22e-a981-4010-a689-1f411e1d105f",
 CellID->1374063416],
Cell[125778, 2430, 225, 3, 70, "Text",ExpressionUUID->"0e7b31be-7b68-4670-b953-f3ab8b7dfcb1",
 CellID->1992176521],
Cell[126006, 2435, 1093, 26, 70, "Text",ExpressionUUID->"4e2f007b-232e-4544-9453-0557a061001d",
 CellID->1093248070],
Cell[127102, 2463, 686, 11, 70, "Text",ExpressionUUID->"f45535a6-af6f-4f49-8e33-11623b016cf1",
 CellID->350228758],
Cell[127791, 2476, 1329, 36, 70, "Text",ExpressionUUID->"ae7177ce-69b7-4d67-9844-b7895f6907cc",
 CellID->42059279],
Cell[129123, 2514, 203, 3, 70, "Text",ExpressionUUID->"5bce320e-143c-4216-8062-96dec214db11",
 CellID->368182290],
Cell[129329, 2519, 864, 23, 70, "Text",ExpressionUUID->"b332339d-719d-480a-8b6e-0c9574f935eb",
 CellID->1139361023],
Cell[130196, 2544, 948, 27, 70, "Text",ExpressionUUID->"8f3599e4-14c1-4e6b-96f3-22b8c9e1f976",
 CellID->129033262],
Cell[131147, 2573, 613, 17, 70, "Text",ExpressionUUID->"133a022c-65e6-4f1f-97c6-e675ef94030e",
 CellID->1851034611],
Cell[131763, 2592, 589, 17, 70, "Text",ExpressionUUID->"5273de49-48db-45f7-ac1e-36ee9392ab7d",
 CellID->1890596635],
Cell[132355, 2611, 213, 3, 70, "Text",ExpressionUUID->"96f36cf9-72ee-4c6f-8a87-fbcf5b40b758",
 CellID->1089603433],
Cell[132571, 2616, 440, 12, 70, "Text",ExpressionUUID->"22d99522-3075-4ac1-a228-00adc2d9104e",
 CellID->1371840462]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133072, 2635, 295, 4, 70, "Subsection",ExpressionUUID->"7fc2aeed-a337-4f74-963e-67f48501b14c",
 CellID->1138210642],
Cell[133370, 2641, 877, 13, 70, "Text",ExpressionUUID->"08bbe328-4a25-4966-8d70-59aa6d699b9a",
 CellID->121932618],
Cell[134250, 2656, 324, 6, 70, "Text",ExpressionUUID->"464797cf-1a29-43f3-887e-d0a9a0a75db1",
 CellID->622111488],
Cell[134577, 2664, 438, 10, 70, "Input",ExpressionUUID->"eda370ed-d3ae-46b3-b5f9-58f2647303b8",
 CellID->1877385220],
Cell[135018, 2676, 244, 3, 70, "Text",ExpressionUUID->"9b2ed0a7-4bdc-4e04-bab2-79c489e7ec35",
 CellID->236167169],
Cell[CellGroupData[{
Cell[135287, 2683, 2263, 50, 70, "Input",ExpressionUUID->"d8f62c48-e1cf-44b3-a4dd-af8efc5b9e1d",
 CellID->711829727],
Cell[137553, 2735, 53248, 956, 70, "Output",ExpressionUUID->"acf0c569-d4e6-4670-a67b-aac5fd466707",
 CellID->32834574]
}, Open  ]],
Cell[190816, 3694, 199, 2, 70, "Text",ExpressionUUID->"72cffcdf-a0de-49b3-ab57-323c030b9e18",
 CellID->90824252],
Cell[CellGroupData[{
Cell[191040, 3700, 2299, 51, 70, "Input",ExpressionUUID->"93d5f946-18dc-42dc-92ea-957b7ca9261f",
 CellID->1769813994],
Cell[193342, 3753, 65562, 1155, 70, "Output",ExpressionUUID->"4335a298-58cb-484e-aa05-f93d519a7767",
 CellID->282322313]
}, Open  ]],
Cell[258919, 4911, 298, 6, 70, "Text",ExpressionUUID->"beee90b6-6d30-491c-a9cd-5c21e2aca80a",
 CellID->467802561],
Cell[259220, 4919, 726, 19, 70, "Text",ExpressionUUID->"26fd2d75-ac9f-4d9c-a7ba-97d1c5bda6f1",
 CellID->420011060],
Cell[259949, 4940, 677, 18, 70, "Text",ExpressionUUID->"d1b2a212-f0bf-438f-b096-b85a5b60e3c8",
 CellID->347137731],
Cell[260629, 4960, 698, 20, 70, "Text",ExpressionUUID->"c2b73dba-5229-4f4d-844d-2cf9bd145d54",
 CellID->1778259665],
Cell[261330, 4982, 725, 20, 70, "Text",ExpressionUUID->"bbebb34c-913c-42ff-96cd-7d045b79566a",
 CellID->680274356],
Cell[262058, 5004, 806, 12, 70, "Text",ExpressionUUID->"bdbcef35-d623-46ae-82ef-10d3516b5663",
 CellID->168164664],
Cell[CellGroupData[{
Cell[262889, 5020, 2358, 52, 70, "Input",ExpressionUUID->"931126c1-01c8-4602-97e7-ba9806e4eddb",
 CellID->255028396],
Cell[265250, 5074, 29044, 561, 70, "Output",ExpressionUUID->"31d65842-d783-4521-b94a-9467c8b0a134",
 CellID->60733066]
}, Open  ]],
Cell[294309, 5638, 1134, 17, 70, "Text",ExpressionUUID->"e1b8aba8-f0cb-40d0-b1a6-235531642b48",
 CellID->2032375807],
Cell[CellGroupData[{
Cell[295468, 5659, 1863, 39, 70, "Input",ExpressionUUID->"05a0b3af-02c7-4619-83b3-5c4610f139cc",
 CellID->265299067],
Cell[297334, 5700, 14966, 288, 70, "Output",ExpressionUUID->"d10b37a1-da6b-4369-82d3-c3d4f2380b38",
 CellID->2722495]
}, Open  ]],
Cell[312315, 5991, 986, 15, 70, "Text",ExpressionUUID->"dceb54f0-e20b-4837-8dbf-ad2547586177",
 CellID->705367897],
Cell[CellGroupData[{
Cell[313326, 6010, 1643, 36, 70, "Input",ExpressionUUID->"c3b3c35b-e940-411a-949a-29663eb8f69f",
 CellID->1008513439],
Cell[314972, 6048, 34096, 663, 70, "Output",ExpressionUUID->"fb4daee0-52d2-49b2-892f-3f5bab905265",
 CellID->611949984]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[349117, 6717, 216, 3, 70, "Subsection",ExpressionUUID->"24411bc8-16d7-4ea7-8947-5849f5f3e606",
 CellID->2144427149],
Cell[349336, 6722, 443, 6, 70, "Text",ExpressionUUID->"32b4e633-282a-4b66-aac1-4e6aacd28877",
 CellID->169045642],
Cell[349782, 6730, 977, 25, 70, "Text",ExpressionUUID->"8c1b2a74-692e-45ce-8afb-f3e358858021",
 CellID->29240113],
Cell[350762, 6757, 1036, 21, 70, "Text",ExpressionUUID->"53f62305-95f9-48da-92d7-20973ae9aac0",
 CellID->1812307675],
Cell[351801, 6780, 654, 17, 70, "Text",ExpressionUUID->"3d691632-78c7-4d64-ab8d-e9a038463f9d",
 CellID->1694528324],
Cell[352458, 6799, 497, 8, 70, "Text",ExpressionUUID->"5cb28aec-45de-4694-b360-3e7f2f9f27a4",
 CellID->9414954],
Cell[CellGroupData[{
Cell[352980, 6811, 555, 13, 70, "Input",ExpressionUUID->"e20439b3-1964-4eb4-a956-adb7b663ca5c",
 CellID->1470825647],
Cell[353538, 6826, 287, 6, 70, "Output",ExpressionUUID->"03f61161-b70b-401f-b6ec-3e76eda465ac",
 CellID->348709352]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[353874, 6838, 590, 8, 70, "Subsection",ExpressionUUID->"4d88813f-5322-4104-83bf-a6d82eaa8a0f",
 CellID->482388512],
Cell[354467, 6848, 484, 9, 70, "Text",ExpressionUUID->"8db3cafd-e90f-4290-94e6-cf208e525aaa",
 CellID->752953759],
Cell[CellGroupData[{
Cell[354976, 6861, 1578, 34, 70, "Input",ExpressionUUID->"b77402f7-eb94-4dba-a6be-e4e7284936b1",
 CellID->1920179389],
Cell[356557, 6897, 10289, 212, 70, "Output",ExpressionUUID->"067db3fe-0eb6-4f66-80b4-0616af93f65f",
 CellID->356116241]
}, Open  ]],
Cell[CellGroupData[{
Cell[366883, 7114, 217, 3, 70, "Subsubsection",ExpressionUUID->"51a6edea-1713-4060-865a-07d027daf112",
 CellID->70743807],
Cell[367103, 7119, 451, 10, 70, "Text",ExpressionUUID->"e48ab696-de13-44aa-8271-91b0e5f9c533",
 CellID->1432707458],
Cell[CellGroupData[{
Cell[367579, 7133, 505, 11, 70, "Input",ExpressionUUID->"e7589caa-e24e-42b2-8f95-8f1d40c07786",
 CellID->1927596442],
Cell[368087, 7146, 250, 5, 70, "Output",ExpressionUUID->"cc91817f-b7df-44e9-b5e3-2e3aecbe56f9",
 CellID->10904196]
}, Open  ]],
Cell[368352, 7154, 483, 8, 70, "Text",ExpressionUUID->"f5f49501-4efd-4d8b-b67f-c0d1926f6247",
 CellID->175102052],
Cell[CellGroupData[{
Cell[368860, 7166, 2499, 48, 70, "Input",ExpressionUUID->"686a7e5f-1b6c-49d7-b15d-bc40d066e086",
 CellID->887591574],
Cell[371362, 7216, 98530, 1702, 70, "Output",ExpressionUUID->"4c341185-4443-498c-893b-80a68b272f5e",
 CellID->430536912]
}, Open  ]],
Cell[CellGroupData[{
Cell[469929, 8923, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"f79dc070-7448-4d17-bc38-77ba455fe45e",
 CellID->1330172156],
Cell[470093, 8927, 526, 7, 70, "Text",ExpressionUUID->"3927b042-4db1-4a48-9569-1d39d8c10a2d",
 CellID->898660622],
Cell[470622, 8936, 1209, 29, 70, "Text",ExpressionUUID->"ddcea1e3-0d24-4de8-94f7-83729ba1aa2c",
 CellID->536584603],
Cell[471834, 8967, 239, 3, 70, "Text",ExpressionUUID->"a80f55cf-c086-40a5-beaa-90606d0ae418",
 CellID->1093588868],
Cell[472076, 8972, 1044, 25, 70, "Text",ExpressionUUID->"d35b3964-1cb3-4796-9d10-7e9a9744c0c1",
 CellID->1783053450],
Cell[473123, 8999, 206, 3, 70, "Text",ExpressionUUID->"cc574ed3-ba45-473e-b584-8645b0e83492",
 CellID->1792523912],
Cell[473332, 9004, 1009, 24, 70, "Text",ExpressionUUID->"cb8a2dbe-ec02-4d2a-8949-b0deae67a208",
 CellID->2048788868],
Cell[474344, 9030, 1093, 26, 70, "Text",ExpressionUUID->"9599ac4b-eaa9-4435-bbbd-7fe6034a8f48",
 CellID->1241708478],
Cell[475440, 9058, 226, 3, 70, "Text",ExpressionUUID->"a997e539-e850-439b-88b0-619ce215feee",
 CellID->148308200],
Cell[475669, 9063, 918, 22, 70, "Text",ExpressionUUID->"1dd3d32b-2063-4f34-81b5-fdd290743079",
 CellID->1534886880],
Cell[476590, 9087, 807, 18, 70, "Text",ExpressionUUID->"1b67e289-18e0-450d-a2b0-bb641cd415ad",
 CellID->1270224396]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[477458, 9112, 222, 3, 70, "Subsection",ExpressionUUID->"39cd1a1c-86b7-4e23-83ac-e5c6e0c76eaa",
 CellID->526488745],
Cell[477683, 9117, 757, 12, 70, "Text",ExpressionUUID->"415979ec-1ffb-47a7-8bbe-17372adabca2",
 CellID->1063711575],
Cell[478443, 9131, 98940, 1778, 70, "Output",ExpressionUUID->"a8d7777b-d42a-4d05-8e73-667dd6f891ce",
 CellID->122065701],
Cell[577386, 10911, 597, 8, 70, "Text",ExpressionUUID->"492c71f4-e187-4a3d-a89a-3cbc4966ef65",
 CellID->2146563397],
Cell[CellGroupData[{
Cell[578008, 10923, 2018, 42, 70, "Input",ExpressionUUID->"b7e5e9fa-572c-40c9-bce7-1eff5564fa76",
 CellID->1713227426],
Cell[580029, 10967, 2351, 64, 70, "Output",ExpressionUUID->"057232ad-2858-49f3-a2fa-ee602eb4bcb4",
 CellID->32592075]
}, Open  ]],
Cell[582395, 11034, 427, 7, 70, "Text",ExpressionUUID->"cc1a4979-8fae-42aa-aeb1-a9bb4ff611a9",
 CellID->752609806],
Cell[CellGroupData[{
Cell[582847, 11045, 3236, 60, 70, "Input",ExpressionUUID->"10272b42-099a-4329-ae37-f2cf261cbf71",
 CellID->434328612],
Cell[586086, 11107, 329654, 5786, 70, "Output",ExpressionUUID->"1fc70ac6-42cc-466e-ab17-d71087f0ba7f",
 CellID->631726173]
}, Open  ]],
Cell[915755, 16896, 775, 13, 70, "Text",ExpressionUUID->"554f67d0-4ceb-4733-a313-510f7e3df7fa",
 CellID->464065731]
}, Open  ]],
Cell[CellGroupData[{
Cell[916567, 16914, 398, 5, 70, "Subsection",ExpressionUUID->"1393ae8d-1b07-4d8b-af6e-256254ee0264",
 CellID->2039618660],
Cell[916968, 16921, 891, 14, 70, "Text",ExpressionUUID->"2c29987c-6753-473a-8534-0aa9808b6efd",
 CellID->1736845206],
Cell[CellGroupData[{
Cell[917884, 16939, 505, 13, 70, "Input",ExpressionUUID->"e8c234e1-bb71-4417-a484-087ee322481d",
 CellID->412163571],
Cell[918392, 16954, 655, 12, 70, "Message",ExpressionUUID->"cf077edb-3dd3-4afe-8f1a-fdb9c7123ce3",
 CellID->46522221],
Cell[919050, 16968, 495, 12, 70, "Output",ExpressionUUID->"3b012881-39e8-414f-bd4b-1c458ebbdcda",
 CellID->364958934]
}, Open  ]],
Cell[919560, 16983, 1364, 22, 70, "Text",ExpressionUUID->"1048ac45-1bc1-4379-af16-1a4371f8ec7d",
 CellID->1598376222],
Cell[920927, 17007, 961, 20, 70, "Text",ExpressionUUID->"78e484db-4891-4dd3-bded-02c5a9fd9437",
 CellID->1036222831],
Cell[921891, 17029, 601, 12, 70, "Text",ExpressionUUID->"2daca6f7-6c59-4a04-a833-75a7c35d6c77",
 CellID->1852227094],
Cell[CellGroupData[{
Cell[922517, 17045, 557, 13, 70, "Input",ExpressionUUID->"30c31da4-9ef8-43ce-aa46-23e32034159a",
 CellID->457821946],
Cell[923077, 17060, 283, 5, 70, "Output",ExpressionUUID->"f06f7b45-a480-431d-9bb0-bf101f937c6c",
 CellID->41070951]
}, Open  ]],
Cell[923375, 17068, 534, 9, 70, "Text",ExpressionUUID->"46d3b123-d29b-43e1-975d-243fd67583cf",
 CellID->179539221],
Cell[923912, 17079, 617, 15, 70, "DisplayFormula",ExpressionUUID->"b65175e9-1e6b-43d9-ac7f-f619d81f4f5a",
 CellID->301163312],
Cell[924532, 17096, 922, 16, 70, "Text",ExpressionUUID->"bfdf2781-1e17-48b3-b7ae-5f0e69447ae8",
 CellID->32828805],
Cell[925457, 17114, 753, 21, 70, "Text",ExpressionUUID->"12406f27-0862-4884-bf10-db9da7c9aaa6",
 CellID->1997912003],
Cell[926213, 17137, 554, 9, 70, "Text",ExpressionUUID->"3e2ed506-0916-4f18-a41b-45f2aef57e1f",
 CellID->852729929],
Cell[926770, 17148, 847, 24, 70, "Text",ExpressionUUID->"a9f60814-a0c3-4ccd-9b6b-c8b5a7360b7f",
 CellID->1673540272],
Cell[927620, 17174, 820, 13, 70, "Text",ExpressionUUID->"56b21fab-bb33-4321-850d-9d0a745e0b98",
 CellID->1598026745]
}, Open  ]],
Cell[CellGroupData[{
Cell[928477, 17192, 518, 7, 70, "Subsection",ExpressionUUID->"f12e88b3-b6d6-4237-ab32-4656a8348219",
 CellID->1605013833],
Cell[928998, 17201, 1161, 15, 70, "Text",ExpressionUUID->"a780fba0-605c-4fa5-b11f-610ad1fb4aa7",
 CellID->925401264],
Cell[930162, 17218, 14663, 281, 70, "Output",ExpressionUUID->"91903989-0088-44c3-a439-1d8991622fd7",
 CellID->137943318],
Cell[CellGroupData[{
Cell[944850, 17503, 716, 10, 70, "Subsubsection",ExpressionUUID->"95c4da53-64d8-41d2-942b-083130dfdd43",
 CellID->1142472474],
Cell[945569, 17515, 702, 18, 70, "Text",ExpressionUUID->"8f128039-d3aa-42af-b703-e111ee6e7eb0",
 CellID->883582691],
Cell[CellGroupData[{
Cell[946296, 17537, 444, 9, 70, "Input",ExpressionUUID->"1758a866-d4fa-4804-8cfc-04e6732c747f",
 CellID->524868632],
Cell[946743, 17548, 1603, 46, 70, "Output",ExpressionUUID->"121f27b4-443b-476d-a47f-0da069b8cb05",
 CellID->14407281]
}, Open  ]],
Cell[948361, 17597, 218, 3, 70, "Text",ExpressionUUID->"6c56354b-9562-41d7-a866-c8cb1fa424d7",
 CellID->1751759795],
Cell[948582, 17602, 510, 15, 70, "Text",ExpressionUUID->"e4c6434f-7f04-4654-9704-ad8e94bcd8fd",
 CellID->1973557842],
Cell[949095, 17619, 739, 10, 70, "Text",ExpressionUUID->"aa981788-a6dd-4e31-9c34-4c6208409912",
 CellID->1701722579],
Cell[949837, 17631, 1287, 30, 70, "Text",ExpressionUUID->"69a0e9ad-ddd0-4600-8372-d8513665b3f6",
 CellID->664174507],
Cell[951127, 17663, 825, 23, 70, "Text",ExpressionUUID->"26399ad3-ef3e-458a-bafe-839e96a08ef5",
 CellID->427781454],
Cell[951955, 17688, 516, 12, 70, "Text",ExpressionUUID->"e0daeb47-53b8-4cbd-a996-0fe1f306dbb6",
 CellID->160942043],
Cell[CellGroupData[{
Cell[952496, 17704, 1799, 38, 70, "Input",ExpressionUUID->"7c21a338-7bd5-47c7-8a9e-031f09eee928",
 CellID->1271005128],
Cell[954298, 17744, 2966, 55, 70, "Output",ExpressionUUID->"e5b9922d-684a-4991-9a3f-f00812ddaa4d",
 CellID->157033055]
}, Open  ]],
Cell[CellGroupData[{
Cell[957301, 17804, 108, 1, 70, "SummarySection",ExpressionUUID->"f00d4fc9-1400-4720-8a14-37974ef96772",
 CellID->763349587],
Cell[957412, 17807, 198, 2, 70, "SummaryNote",ExpressionUUID->"2a66f28b-3573-4d8e-a863-a0f554800898",
 CellID->549201531],
Cell[957613, 17811, 389, 5, 70, "SummaryNote",ExpressionUUID->"2a64b7fc-f8c3-46d5-a499-2d6032aa6c4a",
 CellID->545416711],
Cell[958005, 17818, 15136, 288, 70, "SummaryNote",ExpressionUUID->"eae34e3d-e1a6-48de-b754-ef4f87470e9b",
 CellID->1358456381],
Cell[973144, 18108, 32521, 574, 70, "SummaryNote",ExpressionUUID->"13545fe7-6220-459e-91b5-16398ee7c1fd",
 CellID->1677744210],
Cell[1005668, 18684, 25223, 447, 70, "SummaryNote",ExpressionUUID->"1bcd1c75-cdf8-4716-884a-a50d67a23749",
 CellID->1386652360],
Cell[1030894, 19133, 400, 6, 70, "SummaryNote",ExpressionUUID->"d5e7d031-3c49-4ea5-9aa0-466e59c9aaef",
 CellID->973677276],
Cell[1031297, 19141, 25967, 473, 70, "SummaryNote",ExpressionUUID->"847e4ad8-d1b9-410b-bb8c-4aba26d24da7",
 CellID->768587592],
Cell[1057267, 19616, 34528, 612, 70, "SummaryNote",ExpressionUUID->"ef24f485-fb2b-4fd2-b8fd-d8c57e3da5d4",
 CellID->537522039],
Cell[1091798, 20230, 39788, 700, 70, "SummaryNote",ExpressionUUID->"77ac27ed-c030-45a8-a69d-bf52ae25c88b",
 CellID->1816690191],
Cell[1131589, 20932, 44972, 785, 70, "SummaryNote",ExpressionUUID->"2a61a960-a2cb-49ba-8abb-9312bda0d818",
 CellID->189547091],
Cell[1176564, 21719, 394, 7, 70, "SummaryNote",ExpressionUUID->"2400138c-bfba-47ed-b572-9ea349e6c153",
 CellID->999709936]
}, Open  ]],
Cell[CellGroupData[{
Cell[1176995, 21731, 111, 1, 70, "ExerciseSection",ExpressionUUID->"12e30747-b056-4284-a444-777e0cfc7214",
 CellID->212840224],
Cell[CellGroupData[{
Cell[1177131, 21736, 216, 2, 70, "Exercise",ExpressionUUID->"598d7da9-eea0-4c8c-bb43-6827a1828d8f",
 CellID->171279840],
Cell[1177350, 21740, 662, 12, 70, "ExerciseNote",ExpressionUUID->"a6f1e08b-3f22-4804-9045-9a5bc0f986ab",
 CellID->14525259]
}, Open  ]],
Cell[CellGroupData[{
Cell[1178049, 21757, 215, 2, 70, "Exercise",ExpressionUUID->"0ce59e3f-8786-44ec-b54b-3b4480473288",
 CellID->1645372513],
Cell[1178267, 21761, 703, 14, 70, "ExerciseNote",ExpressionUUID->"d50301f1-01f5-4343-8d9e-a1f8a39edece",
 CellID->254810408]
}, Open  ]],
Cell[CellGroupData[{
Cell[1179007, 21780, 214, 2, 70, "Exercise",ExpressionUUID->"69665ab1-8d31-49c4-812c-acefd23e3911",
 CellID->628903572],
Cell[1179224, 21784, 2243, 59, 70, "ExerciseNote",ExpressionUUID->"4fdbd496-c7fb-41ae-8ebf-d59d6c8fc4c0",
 CellID->11156931]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181504, 21848, 238, 3, 70, "Exercise",ExpressionUUID->"5d10d889-bde8-4ce7-bd28-ec9ac3346f34",
 CellID->67824070],
Cell[1181745, 21853, 2288, 60, 70, "ExerciseNote",ExpressionUUID->"bcc02adf-b1d9-452d-8075-1d089720a65a",
 CellID->131677954]
}, Open  ]],
Cell[CellGroupData[{
Cell[1184070, 21918, 304, 4, 29, "Exercise",ExpressionUUID->"d1bf7759-241d-45ff-a5b4-94148199b256",
 CellID->1752811580],
Cell[1184377, 21924, 2371, 62, 62, "ExerciseNote",ExpressionUUID->"b5f578cd-c902-449f-9d27-130f9b0b9923",
 CellID->221542822]
}, Open  ]],
Cell[CellGroupData[{
Cell[1186785, 21991, 329, 5, 29, "Exercise",ExpressionUUID->"ae64f440-75ed-4b22-8fb9-62d826d37577",
 CellID->323555514],
Cell[1187117, 21998, 2480, 61, 43, "ExerciseNote",ExpressionUUID->"b886570a-1bfb-48a1-883d-e7ced48f2643",
 CellID->448760640]
}, Open  ]],
Cell[1189612, 22062, 610, 18, 51, "Exercise",ExpressionUUID->"ad99057f-4364-4dfd-b07a-c30cc76da907",
 CellID->568929594],
Cell[CellGroupData[{
Cell[1190247, 22084, 244, 4, 25, "Exercise",ExpressionUUID->"83034098-2b12-4243-b711-5774be0b8cc7",
 CellID->1402489914],
Cell[1190494, 22090, 458, 10, 29, "ExerciseNote",ExpressionUUID->"917ca154-e1ce-41d2-8b38-10597ed15ecc",
 CellID->129417543],
Cell[1190955, 22102, 309, 4, 29, "ExerciseNote",ExpressionUUID->"7da4be98-6af2-4398-aa81-93ed5d9e599e",
 CellID->134352946],
Cell[1191267, 22108, 66141, 1126, 126, "ExerciseNote",ExpressionUUID->"e328ff62-9b34-4959-b70c-4770c9eb0ed0",
 CellID->36529241]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[1257459, 23240, 310, 6, 135, "SmallText",ExpressionUUID->"899de554-a35f-4755-a746-397383569947",
 CellGroupingRules->"SectionGrouping",
 CellID->1958447119]
}
]
*)

(* NotebookSignature bRWAHU5KA#ppbleQ75U0MuwF *)
