(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    485778,      10533]
NotebookOptionsPosition[    318594,       7118]
NotebookOutlinePosition[    462721,      10068]
CellTagsIndexPosition[    462678,      10065]
WindowTitle->27. Inverse z\:2010Transform | Signals, Systems, and Signal \
Processing
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Inverse z-Transform", "SectionDoubleDigit",
 CellChangeTimes->{{3.892664010635433*^9, 3.892664011051731*^9}, {
  3.9169129043491144`*^9, 3.916912905712324*^9}, {3.91691314163554*^9, 
  3.916913141814379*^9}, {3.9194304583380013`*^9, 3.919430459156599*^9}},
 CounterAssignments->{{"Section", 26}, {"Subsection", 0}, {
   "Subsubsection", 0}, {"Exercise", 0}},
 CellID->636714798,ExpressionUUID->"c30f2170-4564-4536-b02a-06c3e87e0df9"],

Cell["\<\
Formally, the inverse z-transform is defined as the following contour integral\
\>", "Text",
 CellChangeTimes->{
  3.666448363942761*^9, 3.838471527753508*^9, {3.916913146170587*^9, 
   3.9169131463713512`*^9}, 3.916915499614622*^9, {3.9194304705892296`*^9, 
   3.919430470761442*^9}},
 CellID->354596985,ExpressionUUID->"9db5dd6c-71da-4311-a427-32889a9c22b0"],

Cell[BoxData[
 FormBox[
  RowBox[{"\t", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]", " ", "j"}]], " ", 
     RowBox[{"\[ClockwiseContourIntegral]", " ", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], TraditionalForm]], "Text",\

 CellChangeTimes->{
  3.541237013432409*^9, 3.666448366736126*^9, {3.838471533581286*^9, 
   3.8384715346373034`*^9}, {3.838819189574549*^9, 3.8388191952312794`*^9}},
 CellID->444406470,ExpressionUUID->"112a4cc4-023b-4151-8db1-0c70f10b41e0"],

Cell["\<\
In the case of discrete-time linear shift-invariant (LSI) systems, inversion \
by contour integration is unnecessary because such systems invariably lead to \
rational z-transforms, such as the one shown here, for which there are \
relatively simple methods for accomplishing the inversion\
\>", "Text",
 CellChangeTimes->{
  3.4044787625*^9, {3.489488407609375*^9, 3.489488412265625*^9}, {
   3.5317640160886707`*^9, 3.5317641184211693`*^9}, {3.541237072291312*^9, 
   3.5412371114785805`*^9}, {3.836684957635682*^9, 3.836684968655233*^9}, 
   3.838471549480776*^9, 3.852983691464811*^9, {3.889052215672388*^9, 
   3.8890522223853426`*^9}, {3.91691315323094*^9, 3.916913153384794*^9}, {
   3.916914364308405*^9, 3.916914365753221*^9}, {3.916914398297425*^9, 
   3.91691440442544*^9}, 3.916915512844206*^9, {3.919430481039913*^9, 
   3.9194304812249813`*^9}},
 CellID->191417024,ExpressionUUID->"051a8669-370c-442d-8c60-ea7b6251b78f"],

Cell[BoxData[
 FormBox[
  RowBox[{"\t", 
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["b", "M"], 
       SuperscriptBox["z", 
        RowBox[{"-", "M"}]]}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["a", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], "+", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["a", "N"], 
       SuperscriptBox["z", 
        RowBox[{"-", "N"}]]}]}]]}]}], TraditionalForm]], "Text",
 CellChangeTimes->{{3.41314958625*^9, 3.41314958634375*^9}, {
   3.413149650796875*^9, 3.413149783796875*^9}, {3.413152044046875*^9, 
   3.4131521205*^9}, {3.4131539860625*^9, 3.413154017203125*^9}, {
   3.531178905495652*^9, 3.5311789479901266`*^9}, {3.655396232716739*^9, 
   3.65539623890986*^9}, {3.835732680326991*^9, 3.835732721524023*^9}, 
   3.835732880639071*^9, {3.846705660072981*^9, 3.846705721424822*^9}, {
   3.846706724167384*^9, 3.846706724951359*^9}, {3.88905214508476*^9, 
   3.889052154636197*^9}},
 CellID->215419162,ExpressionUUID->"33c2c4d2-40e5-4ce0-843f-8ecd099f266c"],

Cell["\<\
The common method for inverting such a z-transform is to use partial fraction \
decomposition. The goal of partial fraction decomposition is to express a \
rational z-transform in terms of superposition of simple terms, with inverse \
transforms readily available in tables of z-transform pairs and therefore by \
inspection. \
\>", "Text",
 CellChangeTimes->{{3.541237115238187*^9, 3.541237123818202*^9}, {
  3.805408662037386*^9, 3.805408666192301*^9}, {3.825543690246624*^9, 
  3.825543727882069*^9}, {3.889052287888633*^9, 3.889052356916293*^9}, {
  3.916913157501597*^9, 3.916913173860473*^9}, {3.916915567251219*^9, 
  3.91691556956113*^9}, {3.919430486772833*^9, 3.9194305046336136`*^9}, {
  3.919434547012169*^9, 3.9194345491213436`*^9}},
 CellID->2039910539,ExpressionUUID->"aaea5527-8f36-4a45-bb45-540c279662e2"],

Cell["\<\
Each term of the expansion corresponds to one of the roots of the denominator \
polynomial. In what follows, the cases of distinct and repeated roots are \
presented.\
\>", "Text",
 CellChangeTimes->{{3.782432660126254*^9, 3.782432757895665*^9}, {
  3.8357919176418514`*^9, 3.83579193999407*^9}, {3.836911375783584*^9, 
  3.836911383502501*^9}, {3.88905238905539*^9, 3.889052459180904*^9}, {
  3.889052533434726*^9, 3.8890525351632276`*^9}},
 CellID->200004618,ExpressionUUID->"76b94b4c-6bab-4b30-8519-d18e00208de6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Distinct Roots", "Subsection",
 CellChangeTimes->{{3.604349362919951*^9, 3.604349382483351*^9}, 
   3.66673864216765*^9, {3.835912763474248*^9, 3.8359127742715864`*^9}, {
   3.838471567566089*^9, 3.838471569135034*^9}, {3.8384726355496473`*^9, 
   3.838472636811815*^9}, {3.8467059371126313`*^9, 3.846705938243671*^9}},
 CellID->665707171,ExpressionUUID->"9d8a3ec6-5f26-44ba-a343-6dc439f36237"],

Cell[TextData[{
 "In the case of ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],ExpressionUUID->
  "c4396889-39cf-4ab9-b190-33e7d371695e"],
 " distinct poles ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "k"], TraditionalForm]],ExpressionUUID->
  "15c6141a-0b9c-40e8-99eb-90398c942440"],
 ", the transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "4adfdf4e-63ec-466f-9402-64af31d1c92b"],
 " may be expanded into a linear combination of first-order terms, as \
follows"
}], "Text",
 CellChangeTimes->{{3.591808007027527*^9, 3.591808007043127*^9}, 
   3.591808521904436*^9, 3.591808870087612*^9, {3.5919203728526*^9, 
   3.591920422346237*^9}, {3.591920467804717*^9, 3.591920483233144*^9}, {
   3.59192069193797*^9, 3.591920695697578*^9}, {3.591958898868783*^9, 
   3.591958934406266*^9}, {3.655505227092273*^9, 3.65550528275236*^9}, {
   3.688481510269168*^9, 3.688481513014733*^9}, {3.7070768081336*^9, 
   3.707076809446447*^9}, {3.83691141069502*^9, 3.836911415670719*^9}, {
   3.84670690482004*^9, 3.846706905268908*^9}, 3.8529837105930767`*^9, 
   3.9169162916699924`*^9},
 CellID->150622127,ExpressionUUID->"2fe21045-852c-4402-9eec-72f8f12691d9"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        SubscriptBox["A", "1"], 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["p", "1"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}]], "+", 
       FractionBox[
        SubscriptBox["A", "2"], 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["p", "2"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}]], "+"}], "..."}], "+", 
     FractionBox[
      SubscriptBox["A", "N"], 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["p", "N"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}]]}]}], TraditionalForm]],ExpressionUUID->
  "a101e4a3-f24f-421a-a5f3-dd29942ee602"]
}], "Text",
 CellChangeTimes->{{3.846707057772581*^9, 3.846707134479459*^9}, {
  3.8468508878120675`*^9, 3.8468508878120675`*^9}},
 CellID->1770352323,ExpressionUUID->"9fe6ee81-3fb6-4d3b-bda0-fbdd192404b7"],

Cell[TextData[{
 "The constants ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "i"], TraditionalForm]],ExpressionUUID->
  "b83b6b0a-0b6f-4050-9413-dbb53495671c"],
 ", called the residues, are given by"
}], "Text",
 CellChangeTimes->{{3.666563709261354*^9, 3.66656375637275*^9}, {
   3.846756770663705*^9, 3.846756777051893*^9}, 3.852983719321043*^9, 
   3.9169162975931797`*^9},
 CellID->925563476,ExpressionUUID->"4d2bf175-ded6-48c8-b71d-bd9607dd95af"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{
     RowBox[{
      SubscriptBox["A", "i"], "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          SubscriptBox["p", "i"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}], ")"}], " ", 
       RowBox[{"X", "(", "z", ")"}]}]}], " ", "\[RightBracketingBar]"}], 
    RowBox[{"z", "=", 
     SubscriptBox["p", "i"]}]], TraditionalForm]],ExpressionUUID->
  "e83498c1-0f0a-49f6-a933-9ad089f01ca6"]
}], "Text",
 CellChangeTimes->{{3.666563948843082*^9, 3.666564008949112*^9}, {
  3.7009154357893715`*^9, 3.700915436850158*^9}, {3.836685039990307*^9, 
  3.8366850414509325`*^9}},
 CellID->1721285911,ExpressionUUID->"bb27de69-d651-4814-8fb8-76003e05e9d3"],

Cell[TextData[{
 "Then, assuming the region of convergence (ROC) is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], ">", 
    RowBox[{"\[LeftBracketingBar]", 
     SubscriptBox["p", "i"], "\[RightBracketingBar]"}]}], TraditionalForm]],
  ExpressionUUID->"07e9ad8e-842f-49be-a4ba-e9a5db8c3ccb"],
 ", each term of the partial fraction expansion has an inverse transform of \
the form"
}], "Text",
 CellChangeTimes->{{3.666564057105694*^9, 3.6665640599448576`*^9}, {
  3.666564098086369*^9, 3.666564189906854*^9}, {3.666564224619935*^9, 
  3.666564296137624*^9}, {3.6665643333792667`*^9, 3.666564343431076*^9}, {
  3.8366850621564083`*^9, 3.836685083647943*^9}, {3.838471619774927*^9, 
  3.838471622342374*^9}, {3.8467072486039886`*^9, 3.8467072806563916`*^9}, {
  3.916915113734667*^9, 3.916915120680523*^9}, {3.9169163075484905`*^9, 
  3.916916307702284*^9}},
 CellID->900097440,ExpressionUUID->"d72f747c-4bb5-4483-b796-0e41a959f033"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{
      SubscriptBox["A", "i"], "(", 
      SubscriptBox["p", "i"], ")"}], "n"], " ", 
    RowBox[{"u", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "bdb449e0-6018-41d8-b4a7-6b45f90ac77a"],
 " "
}], "Text",
 CellChangeTimes->{{3.666564057105694*^9, 3.6665640599448576`*^9}, {
  3.666564098086369*^9, 3.666564189906854*^9}, {3.666564224619935*^9, 
  3.666564296137624*^9}, {3.6665643333792667`*^9, 3.666564343431076*^9}, {
  3.8366850621564083`*^9, 3.836685083647943*^9}, {3.838471619774927*^9, 
  3.838471622342374*^9}, {3.8467072486039886`*^9, 3.846707293821274*^9}},
 CellID->1062864612,ExpressionUUID->"f1b8a451-ca1a-4200-915f-530f44f58620"],

Cell[TextData[{
 "Therefore, the resulting sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "c94940df-9172-44b4-a984-a763be141965"],
 " is"
}], "Text",
 CellChangeTimes->{{3.666564057105694*^9, 3.6665640599448576`*^9}, {
   3.666564098086369*^9, 3.666564189906854*^9}, {3.666564224619935*^9, 
   3.666564296137624*^9}, {3.6665643333792667`*^9, 3.666564343431076*^9}, {
   3.8366850621564083`*^9, 3.836685083647943*^9}, {3.838471619774927*^9, 
   3.838471622342374*^9}, {3.8467072486039886`*^9, 3.846707295131531*^9}, 
   3.9169163109666*^9},
 CellID->796558138,ExpressionUUID->"dbf500fa-5828-47e7-acf8-8e42581ad2fd"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SubscriptBox["A", "1"], "(", 
          SubscriptBox["p", "1"], ")"}], "n"], " ", 
        RowBox[{"u", "[", "n", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SubscriptBox["A", "2"], "(", 
          SubscriptBox["p", "2"], ")"}], "n"], " ", 
        RowBox[{"u", "[", "n", "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SubscriptBox["A", "N"], "(", 
        SubscriptBox["p", "N"], ")"}], "n"], 
      RowBox[{"u", "[", "n", "]"}], " "}]}]}], TraditionalForm]],
  ExpressionUUID->"d87f3599-53b9-463f-80b1-ed10b823ebbb"]
}], "Text",
 CellChangeTimes->{{3.666564349206184*^9, 3.6665644021498766`*^9}, {
  3.838471628367397*^9, 3.838471634990994*^9}, {3.846756800535364*^9, 
  3.846756835538395*^9}},
 CellID->339569968,ExpressionUUID->"c1baafcd-0520-4b5b-90a3-7a12ef251e2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1", "Subsection",
 CellChangeTimes->{{3.604349362919951*^9, 3.604349382483351*^9}, {
   3.666564700601266*^9, 3.666564702067929*^9}, 3.666566551578443*^9, {
   3.668362244517332*^9, 3.668362244578331*^9}, {3.731754212250413*^9, 
   3.731754212702799*^9}, {3.7317866001972938`*^9, 3.731786604838085*^9}, {
   3.731786711672717*^9, 3.731786711954542*^9}, {3.792606662063455*^9, 
   3.7926066622299786`*^9}, {3.792716642031926*^9, 3.7927166422124834`*^9}, {
   3.793011897840987*^9, 3.7930118979190974`*^9}, {3.825543874523613*^9, 
   3.825543874573361*^9}, {3.835912925292824*^9, 3.835912925358189*^9}, {
   3.836685089815799*^9, 3.8366850899357963`*^9}},
 CellID->1288402097,ExpressionUUID->"d5a6b6c9-5245-4739-9187-26fbaa6c968c"],

Cell["\<\
Determine the inverse z-transform of the following proper rational function \
using partial fraction expansion\
\>", "Text",
 CellChangeTimes->{{3.666547473111367*^9, 3.666547499078367*^9}, {
   3.666564720399255*^9, 3.666564749962771*^9}, {3.6665648293240404`*^9, 
   3.666564855689392*^9}, {3.666564955596916*^9, 3.666564962632878*^9}, 
   3.66664652071467*^9, 3.838471642259556*^9, {3.846707946641475*^9, 
   3.8467079481523333`*^9}, {3.9169131814445453`*^9, 3.9169131815748396`*^9}, 
   3.916916319312839*^9, {3.9194305140334797`*^9, 3.9194305142341805`*^9}},
 CellID->1096431578,ExpressionUUID->"ff0b7dae-ce35-4546-88b8-cf46273c156a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]]}], TraditionalForm]],
  ExpressionUUID->"cabfd5d7-dc10-4929-8a24-3ef1485cffb8"],
 ",\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], ">", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "51cad9fb-90cb-411a-aa12-1c6f23f0eed8"]
}], "Text",
 CellChangeTimes->{{3.846707325242838*^9, 3.846707367378333*^9}, {
  3.846707414767723*^9, 3.8467074269016447`*^9}, {3.8467075145566864`*^9, 
  3.846707613929324*^9}, {3.846707676743353*^9, 3.8467076781590304`*^9}, {
  3.846707915050256*^9, 3.846707916052804*^9}, {3.9201085910172405`*^9, 
  3.920108591748247*^9}},
 CellID->168356539,ExpressionUUID->"91989cf1-7a92-4437-b8b2-156de64b8b10"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.82550664119885*^9, 3.825506642761591*^9}},
 CellID->1332387874,ExpressionUUID->"819c6144-7109-47ba-a137-485218759341"],

Cell[TextData[{
 "The ",
 ButtonBox["InverseBilateralZTransform",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InverseBilateralZTransform"],
 " returns: "
}], "Text",
 CellChangeTimes->{{3.8255066534697547`*^9, 3.8255067726559796`*^9}, {
  3.835913078068743*^9, 3.8359130886304655`*^9}, {3.838471687894616*^9, 
  3.8384716878968277`*^9}, {3.923569430750948*^9, 3.923569430750948*^9}},
 CellID->1631011049,ExpressionUUID->"371b2382-32ed-4486-84cb-d2373d506f4f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "z_", "]"}], ":=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"InverseBilateralZTransform", "[", 
   RowBox[{
    RowBox[{"ConditionalExpression", "[", 
     RowBox[{
      RowBox[{"X", "[", "z", "]"}], ",", 
      RowBox[{
       RowBox[{"Abs", "[", "z", "]"}], ">", 
       FractionBox["1", "2"]}]}], "]"}], ",", "z", ",", "n"}], "]"}], "//", 
  "Expand"}]}], "Input",
 CellChangeTimes->{{3.825506777606272*^9, 3.825506811745391*^9}, {
   3.84668741638983*^9, 3.8466874323927927`*^9}, {3.846707458784946*^9, 
   3.846707481935521*^9}, 3.8467079727866116`*^9, {3.897573418361211*^9, 
   3.8975734505565805`*^9}},
 CellID->1921430235,ExpressionUUID->"88a83666-53a9-4379-953b-d362da10d262"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{
         FractionBox["1", "3"], " ", 
         SuperscriptBox["2", 
          RowBox[{"-", "n"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "n"], " ", 
            SuperscriptBox["2", 
             RowBox[{"1", "+", "n"}]]}]}], ")"}]}], 
        RowBox[{"n", "\[GreaterEqual]", "0"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{{3.825506801282776*^9, 3.825506812254601*^9}, {
   3.846687419540601*^9, 3.8466874329168963`*^9}, 3.84670748259688*^9, 
   3.846707974148744*^9, 3.8975733790246267`*^9, {3.8975734514124255`*^9, 
   3.897573470994645*^9}},
 CellID->693098080,ExpressionUUID->"3995ed7b-6e3d-4641-a059-8c538820eb4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1766359706,ExpressionUUID->"c963c3a9-487e-43ea-86a6-94acb71dc8ff"],

Cell[TextData[{
 "Express the z-transform in positive powers of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "90dc1ccb-91c5-415b-bd7c-dfd66ab0df10"]
}], "Text",
 CellChangeTimes->{{3.6665650564849834`*^9, 3.666565236478937*^9}, {
   3.6665679265136147`*^9, 3.666567947432948*^9}, {3.825507267497025*^9, 
   3.825507273344549*^9}, 3.838471693955916*^9, {3.916913185630228*^9, 
   3.916913185793394*^9}, 3.91691634913524*^9, {3.9194305252863007`*^9, 
   3.9194305255029373`*^9}},
 CellID->393642614,ExpressionUUID->"39ffef6d-975e-4327-8b34-9426d85a3e85"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox[
     SuperscriptBox["z", "2"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}], ")"}]}]]}], TraditionalForm]],ExpressionUUID->
  "c4b24a0f-9d80-4080-8b63-ecf114004d59"]
}], "Text",
 CellChangeTimes->{{3.6665652441541862`*^9, 3.666565276695995*^9}, {
  3.666567950958502*^9, 3.6665679731882167`*^9}, {3.666632435137162*^9, 
  3.666632442782064*^9}, {3.838471698336361*^9, 3.838471699119708*^9}, {
  3.846707999963468*^9, 3.846707999963468*^9}},
 CellID->1701780738,ExpressionUUID->"c2211b1d-d8e7-474f-a603-a0fb95e9a80f"],

Cell[TextData[{
 "The advantage of working with positive powers of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "cc26567f-d6aa-47bb-86e8-f0517fbd390e"],
 " stems from the fact that the method is now similar to partial fraction \
decomposition of rational Laplace transforms."
}], "Text",
 CellChangeTimes->{{3.836685263434203*^9, 3.836685276064682*^9}, {
  3.8366853124033933`*^9, 3.836685342905362*^9}, {3.83668538449058*^9, 
  3.836685486968463*^9}, {3.838471704623439*^9, 3.838471705391499*^9}},
 CellID->1641652820,ExpressionUUID->"305c53c3-55d8-4748-bfcf-4de993ecf9c9"],

Cell[TextData[{
 "However, note that the expression in terms of positive powers of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "7dbe774d-8383-4d43-814d-255e57845ca8"],
 " is formally improper. The workaround is to reduce the order of the \
numerator polynomial by dividing by ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "0a0c2451-be49-40e9-8666-dd979f02794a"],
 " and performing the expansion on the reduced rational, as shown here"
}], "Text",
 CellChangeTimes->{{3.6665680245115585`*^9, 3.666568084835985*^9}, {
   3.792624769205451*^9, 3.792624778055795*^9}, {3.792624816069347*^9, 
   3.792624891397441*^9}, {3.8359129754852667`*^9, 3.835912984883619*^9}, {
   3.836685184379547*^9, 3.8366852004325633`*^9}, {3.836685510134037*^9, 
   3.8366855359881697`*^9}, {3.836856869597263*^9, 3.8368568861558557`*^9}, 
   3.852983753617095*^9, 3.916916371962925*^9},
 CellID->389049084,ExpressionUUID->"5911d312-1657-4e63-af7d-df87a44aa245"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"X", 
      RowBox[{"(", "z", ")"}], " "}], "z"], "=", 
    RowBox[{
     FractionBox["z", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", 
       RowBox[{
        FractionBox["1", "2"], "z"}], "-", 
       FractionBox["1", "2"]}]], "=", 
     FractionBox["z", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}]}]]}]}], TraditionalForm]],
  ExpressionUUID->"538d7d9f-f0a4-46a5-9f9b-8332f577d473"]
}], "Text",
 CellChangeTimes->{{3.6665652441541862`*^9, 3.666565276695995*^9}, {
  3.666567950958502*^9, 3.6665679731882167`*^9}, {3.6665680970662284`*^9, 
  3.6665681013405733`*^9}, {3.66663245710368*^9, 3.66663245710368*^9}, {
  3.666632577350343*^9, 3.6666325942449265`*^9}, {3.666632646907652*^9, 
  3.6666326495908175`*^9}, {3.8384717220641947`*^9, 3.838471728968039*^9}},
 CellID->1807733320,ExpressionUUID->"04c45060-6731-46e5-aa44-c1ff09b91d6d"],

Cell["Partial fraction decomposition yields", "Text",
 CellChangeTimes->{{3.40586054278125*^9, 3.405860543140625*^9}, {
   3.604349635266751*^9, 3.6043496363743505`*^9}, {3.604350727143951*^9, 
   3.604350853769151*^9}, {3.666547402691367*^9, 3.666547402764367*^9}, {
   3.6665474395953674`*^9, 3.666547443602368*^9}, 3.6665475237883673`*^9, {
   3.6665649863304915`*^9, 3.666564988374196*^9}, {3.666568111620842*^9, 
   3.666568129295415*^9}, {3.792624907547786*^9, 3.792624910967302*^9}, 
   3.9169163747968802`*^9},
 CellID->2122755131,ExpressionUUID->"f5815ca9-af2e-4474-b2e4-a76f66838705"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"X", "(", "z", ")"}], "z"], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", "1"], 
      FractionBox["1", 
       RowBox[{"z", "+", "1"}]]}], "+", 
     RowBox[{
      SubscriptBox["A", "2"], 
      FractionBox["1", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "764352f8-d9f9-4086-b940-940b558f6ae6"]
}], "Text",
 CellChangeTimes->{{3.40586054278125*^9, 3.405860543140625*^9}, {
   3.604349635266751*^9, 3.6043496363743505`*^9}, {3.604350727143951*^9, 
   3.604350853769151*^9}, {3.666547402691367*^9, 3.666547402764367*^9}, {
   3.6665474395953674`*^9, 3.666547443602368*^9}, 3.6665475237883673`*^9, {
   3.66656499467692*^9, 3.6665650148795166`*^9}, {3.666565288162069*^9, 
   3.666565334946577*^9}, {3.666565611721692*^9, 3.6665656132816725`*^9}, {
   3.666568140854867*^9, 3.6665681577338505`*^9}, {3.666632547783722*^9, 
   3.66663256355812*^9}, {3.666632660590677*^9, 3.666632663805235*^9}, {
   3.836685218618827*^9, 3.836685218618827*^9}},
 CellID->999659106,ExpressionUUID->"6b88a424-f12b-456a-861c-c22421d44f1a"],

Cell[TextData[{
 "The values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "1"], TraditionalForm]],ExpressionUUID->
  "1f8c2b6a-0030-4df7-983b-fcd4ec28606d"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "2"], TraditionalForm]],ExpressionUUID->
  "a3cc0dff-f006-4a5d-acf5-9311c96b5abb"],
 " are:"
}], "Text",
 CellChangeTimes->{{3.666565359313777*^9, 3.666565365943777*^9}, {
  3.835913011581812*^9, 3.835913055720733*^9}, {3.916916378375204*^9, 
  3.916916383586897*^9}},
 CellID->1506024061,ExpressionUUID->"5812422c-6aff-4ce8-a79d-6fc34aea11f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", "+", "1"}], ")"}], 
    FractionBox[
     RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.666547720894367*^9, 3.666547721306367*^9}, 
   3.66656610640695*^9, {3.762779237036234*^9, 3.762779251848234*^9}, {
   3.792625228582302*^9, 3.792625241885476*^9}, {3.825509568459569*^9, 
   3.8255095924842176`*^9}, {3.825509759144204*^9, 3.8255097631688967`*^9}},
 CellID->1504129685,ExpressionUUID->"06d12b41-286b-49ff-af8f-3ec5a4c8c4a2"],

Cell[BoxData[
 FractionBox["2", "3"]], "Output",
 CellChangeTimes->{
  3.762779252601234*^9, {3.8255095934201565`*^9, 3.825509606964845*^9}, 
   3.825509766400742*^9, 3.897573385918962*^9, {3.897573457702024*^9, 
   3.897573477837194*^9}},
 CellID->762490,ExpressionUUID->"1d9ddd30-8cc1-4334-9098-dbc5ce82b8ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", "-", 
      FractionBox["1", "2"]}], ")"}], 
    FractionBox[
     RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
   RowBox[{"z", "\[Rule]", 
    FractionBox["1", "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.666547720894367*^9, 3.666547721306367*^9}, 
   3.66656610640695*^9, {3.762779237036234*^9, 3.762779294725234*^9}, {
   3.825509611996728*^9, 3.825509635684987*^9}, {3.825509770070077*^9, 
   3.825509782674641*^9}},
 CellID->1877606958,ExpressionUUID->"bf79587b-1b32-44b5-b8b1-5b65dcab1d2e"],

Cell[BoxData[
 FractionBox["1", "3"]], "Output",
 CellChangeTimes->{
  3.762779296088234*^9, 3.8255096369713883`*^9, 3.825509783650811*^9, {
   3.8975734591935344`*^9, 3.8975734792370653`*^9}},
 CellID->169268107,ExpressionUUID->"4577a6d5-39cd-4767-8f6c-f2a24b4c9580"]
}, Open  ]],

Cell["This gives", "Text",
 CellChangeTimes->{{3.6665654952833767`*^9, 3.666565497389377*^9}, 
   3.838471739151655*^9, 3.916916388674225*^9},
 CellID->1815434088,ExpressionUUID->"3811ecfb-ab36-429d-947c-e8bfeeb312fb"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox["z", 
        RowBox[{"z", "+", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "3"], 
       FractionBox["z", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}]]}]}], " ", "=", 
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox["1", 
        RowBox[{"1", "+", 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]]}], "+", 
      RowBox[{
       FractionBox["1", "3"], 
       FractionBox["1", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}]]}]}]}]}], TraditionalForm]],ExpressionUUID->
  "4df81042-1086-4bb2-a7f0-d0aad04f4c16"]
}], "Text",
 CellChangeTimes->{{3.40586054278125*^9, 3.405860543140625*^9}, {
   3.604349635266751*^9, 3.6043496363743505`*^9}, {3.604350727143951*^9, 
   3.604350853769151*^9}, {3.666547402691367*^9, 3.666547402764367*^9}, {
   3.6665474395953674`*^9, 3.666547443602368*^9}, 3.6665475237883673`*^9, {
   3.66656499467692*^9, 3.6665650148795166`*^9}, {3.666565288162069*^9, 
   3.666565334946577*^9}, {3.666565511772578*^9, 3.666565522692577*^9}, {
   3.666565607306949*^9, 3.6665656076657443`*^9}, {3.666568223721004*^9, 
   3.666568256277787*^9}, {3.6666327530652943`*^9, 3.666632764642346*^9}, {
   3.666633624395953*^9, 3.666633624395953*^9}, {3.6666336934456673`*^9, 
   3.666633728055028*^9}, {3.666633783659316*^9, 3.666633792410804*^9}, {
   3.666635636973945*^9, 3.66663566154363*^9}, {3.838471751184419*^9, 
   3.8384717511844687`*^9}},
 CellID->553060440,ExpressionUUID->"9a524d1b-c1a8-43ea-a7e6-d6745ff7da9d"],

Cell[TextData[{
 "The term-by-term inversion of the partial fraction decomposition of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "7dfc6d41-7454-4064-bef3-befb5d868d05"],
 " gives"
}], "Text",
 CellChangeTimes->{{3.8255074382571735`*^9, 3.825507467163443*^9}, {
   3.8255076011556735`*^9, 3.8255076347648*^9}, {3.8255143801595445`*^9, 
   3.8255144660416985`*^9}, {3.8368570151250377`*^9, 3.836857025378402*^9}, 
   3.916916392851433*^9},
 CellID->977590864,ExpressionUUID->"d75e1fdc-2194-4226-b08c-443ca869c274"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["2", "3"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      RowBox[{"u", "[", "n", "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "3"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"], 
      RowBox[{"u", "[", "n", "]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "7ac3b89e-f767-48cd-8505-f97474623cd1"]
}], "Text",
 CellChangeTimes->{{3.825507471908594*^9, 3.825507523735427*^9}, {
  3.836857035546065*^9, 3.836857043177571*^9}, {3.838471758520549*^9, 
  3.838471759336625*^9}},
 CellID->2119751698,ExpressionUUID->"0d60dbea-f913-4685-8c9f-58225eb14067"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Repeated Roots", "Subsection",
 CellChangeTimes->{{3.604349362919951*^9, 3.604349382483351*^9}, 
   3.66673864216765*^9, {3.666741073646077*^9, 3.6667410750500593`*^9}, {
   3.835913744585325*^9, 3.835913755925232*^9}, {3.838471867233362*^9, 
   3.838471868875366*^9}, {3.838472645469183*^9, 3.838472646309412*^9}, 
   3.846756881682587*^9},
 CellID->2060568203,ExpressionUUID->"1f211018-cdd3-4c47-badf-86a9f28d8f7d"],

Cell[TextData[{
 "The partial fraction expansion of a z-transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "124ebc16-cfdd-4da0-bfb7-0492ee5fda57"],
 " with a multiple-order pole of order ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "e94fef3e-d4cf-466b-8262-50c5f7c52600"],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", "p"}], TraditionalForm]],ExpressionUUID->
  "568bc39f-2c5d-41c9-993b-1d72116c66ca"],
 " takes the following form"
}], "Text",
 CellChangeTimes->{{3.846949461792585*^9, 3.846949497441526*^9}, 
   3.846949550324804*^9, {3.846949590913153*^9, 3.8469496173072987`*^9}, {
   3.9169131898481236`*^9, 3.916913189979713*^9}, 3.916916800970276*^9, {
   3.919430533414219*^9, 3.9194305336682167`*^9}, {3.9201086404916153`*^9, 
   3.9201086408436165`*^9}},
 CellID->1648496299,ExpressionUUID->"b74af5b6-03be-4c40-b0a1-073f3ff09e8d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        SubscriptBox["A", "1"], 
        RowBox[{"1", "-", 
         RowBox[{"p", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}]], "+", 
       FractionBox[
        SubscriptBox["A", "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"p", " ", 
            SuperscriptBox["z", 
             RowBox[{"-", "1"}]]}]}], ")"}], "2"]], "+"}], "..."}], "+", 
     FractionBox[
      SubscriptBox["A", "k"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"p", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}], ")"}], "k"]]}]}], TraditionalForm]],
  ExpressionUUID->"5f54ffc3-3b6c-4f19-a8eb-1c4dca13c9bc"]
}], "Text",
 CellChangeTimes->{{3.6984511024393616`*^9, 3.698451110713376*^9}, {
  3.698451164554101*^9, 3.6984512835053625`*^9}, {3.698451325408639*^9, 
  3.698451368570523*^9}, {3.698452056849073*^9, 3.6984520592428775`*^9}, {
  3.698492520343476*^9, 3.6984926285562663`*^9}, {3.6984931561653976`*^9, 
  3.698493161859407*^9}, {3.698494675649917*^9, 3.6984946896295414`*^9}, {
  3.698494917336542*^9, 3.698494930035964*^9}, {3.835909706246628*^9, 
  3.8359097350264964`*^9}, {3.836857301592267*^9, 3.836857311685297*^9}, {
  3.8467569965404387`*^9, 3.8467570559317083`*^9}, {3.846759554299771*^9, 
  3.84675959808013*^9}, {3.846759634446436*^9, 3.846759679974149*^9}, {
  3.846761835087215*^9, 3.846761866622479*^9}, {3.8467664837523975`*^9, 
  3.846766492098236*^9}, {3.846851962055396*^9, 3.846851985867176*^9}, {
  3.846949645300201*^9, 3.846949653594125*^9}, {3.8470216428979664`*^9, 
  3.8470216428979664`*^9}},
 CellID->1590767346,ExpressionUUID->"1de2648e-852d-4736-adc3-89f0dc721a3d"],

Cell[TextData[{
 "The constants ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "i"], TraditionalForm]],ExpressionUUID->
  "12173579-61fc-4781-9cee-bfbef592de98"],
 " are given by"
}], "Text",
 CellChangeTimes->{{3.666563709261354*^9, 3.66656375637275*^9}, {
   3.846756770663705*^9, 3.846756777051893*^9}, {3.847147377851924*^9, 
   3.8471473794743814`*^9}, 3.847148322875324*^9, 3.9169168035473957`*^9},
 CellID->2002862719,ExpressionUUID->"c741ca00-8824-4270-ab30-b7f50b23c55e"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{
     RowBox[{
      SubscriptBox["A", "i"], "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "-", "i"}], ")"}], "!"}]], 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "p"}], ")"}], 
         RowBox[{"k", "-", "i"}]]], 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[DifferentialD]", 
          RowBox[{"k", "-", "i"}]], 
         RowBox[{"\[DifferentialD]", 
          SuperscriptBox[
           RowBox[{"(", 
            SuperscriptBox["z", 
             RowBox[{"-", "1"}]], ")"}], 
           RowBox[{"\[ThinSpace]", 
            RowBox[{"k", "-", "i"}]}]]}]], 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"p", " ", 
              SuperscriptBox["z", 
               RowBox[{"-", "1"}]]}]}], ")"}], "k"], " ", 
          RowBox[{"X", "(", "z", ")"}]}], "}"}]}]}]}], " ", 
     "\[RightBracketingBar]"}], 
    RowBox[{"z", "=", "p"}]], TraditionalForm]],ExpressionUUID->
  "40547476-4620-46d0-aea0-d03c47fd83fc"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "2", ",", "...", ",", "k"}], 
   TraditionalForm]],ExpressionUUID->"e3139a49-e285-40fa-b491-e3747caee828"]
}], "Text",
 CellChangeTimes->{{3.666563948843082*^9, 3.666564008949112*^9}, {
  3.7009154357893715`*^9, 3.700915436850158*^9}, {3.836685039990307*^9, 
  3.8366850414509325`*^9}, {3.847147414093952*^9, 3.847147583794795*^9}, {
  3.847147696276137*^9, 3.847147718245055*^9}, {3.9312730746203613`*^9, 
  3.93127307462046*^9}},
 CellID->307551508,ExpressionUUID->"8e5eb310-d3d8-4c71-966b-426edd29a6dd"],

Cell[TextData[{
 "Then, assuming the ROC is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], ">", 
    RowBox[{"\[LeftBracketingBar]", "p", "\[RightBracketingBar]"}]}], 
   TraditionalForm]],ExpressionUUID->"0dd46326-461c-488d-9555-ac68933c98a9"],
 ", each term of the partial fraction expansion has an inverse transform of \
the form"
}], "Text",
 CellChangeTimes->{{3.666564057105694*^9, 3.6665640599448576`*^9}, {
  3.666564098086369*^9, 3.666564189906854*^9}, {3.666564224619935*^9, 
  3.666564296137624*^9}, {3.6665643333792667`*^9, 3.666564343431076*^9}, {
  3.8366850621564083`*^9, 3.836685083647943*^9}, {3.838471619774927*^9, 
  3.838471622342374*^9}, {3.8467072486039886`*^9, 3.8467072806563916`*^9}, {
  3.847147661386769*^9, 3.847147662189657*^9}, {3.9169168079275417`*^9, 
  3.916916812279823*^9}},
 CellID->25056627,ExpressionUUID->"8a47d9a2-4206-4574-bdeb-a4f4656c470a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"p", "\[ThinSpace]"}], "n"], " ", 
    RowBox[{
     RowBox[{"u", "[", "n", "]"}], " ", 
     OverscriptBox["\[LongLeftRightArrow]", "\[DoubleStruckCapitalZ]"], " ", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"p", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}]]}]}], TraditionalForm]],ExpressionUUID->
  "79a084a5-4da7-4bdf-9f7b-40df6e3a4fd4"]
}], "Text",
 CellChangeTimes->{{3.8467684976146083`*^9, 3.8467686099918327`*^9}, {
  3.8471478717890058`*^9, 3.847147871856186*^9}, {3.8505089522098165`*^9, 
  3.8505089522849774`*^9}, {3.931273096316648*^9, 3.9312730963167152`*^9}},
 CellID->219935177,ExpressionUUID->"5b0e61d8-e3f1-4705-8a09-0db505e3d342"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], " ", 
    SuperscriptBox["p", 
     RowBox[{"\[ThinSpace]", "n"}]], " ", 
    RowBox[{
     RowBox[{"u", "[", "n", "]"}], " ", 
     OverscriptBox["\[LongLeftRightArrow]", "\[DoubleStruckCapitalZ]"], " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"p", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}], ")"}], "2"]]}]}], TraditionalForm]],
  ExpressionUUID->"34438e00-0dd7-4984-8af8-cd7cc9b9e7d5"]
}], "Text",
 CellChangeTimes->{{3.8467684976146083`*^9, 3.846768630487595*^9}, {
  3.8467687382696643`*^9, 3.8467687568221846`*^9}, {3.8471479200385704`*^9, 
  3.847147932720456*^9}, {3.847148067732215*^9, 3.8471480678136225`*^9}, {
  3.8505089566518984`*^9, 3.850508956757951*^9}, {3.9312730925594482`*^9, 
  3.931273092559503*^9}},
 CellID->631163352,ExpressionUUID->"ba2457ce-895c-4304-94dd-ab4a89027798"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"n", "+", "2"}], ")"}], " ", 
    SuperscriptBox["p", 
     RowBox[{"\[ThinSpace]", "n"}]], " ", 
    RowBox[{
     RowBox[{"u", "[", "n", "]"}], " ", 
     OverscriptBox["\[LongLeftRightArrow]", "\[DoubleStruckCapitalZ]"], " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"p", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}], ")"}], "3"]]}]}], TraditionalForm]],
  ExpressionUUID->"87e445e4-58ec-4219-9d4c-9422490bb471"]
}], "Text",
 CellChangeTimes->{{3.8467684976146083`*^9, 3.846768630487595*^9}, {
  3.8467687382696643`*^9, 3.8467687568221846`*^9}, {3.8471479200385704`*^9, 
  3.847147932720456*^9}, {3.84714797309837*^9, 3.847147987911398*^9}, {
  3.8471480712964096`*^9, 3.8471480713548765`*^9}, {3.8505089607769957`*^9, 
  3.850508960847353*^9}, {3.931273084907276*^9, 3.931273084907353*^9}},
 CellID->1540724531,ExpressionUUID->"33a4a342-a553-40b3-89e9-bdbe5eda500e"],

Cell["In general", "Text",
 CellChangeTimes->{{3.846769219038713*^9, 3.846769221326846*^9}, 
   3.852982914445026*^9, 3.916916830501522*^9},
 CellID->599376991,ExpressionUUID->"5cb5986e-5fd7-4229-ab83-1c41a500f288"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "-", "1"}], ")"}], "!"}]], 
      RowBox[{"(", 
       RowBox[{"n", "+", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"n", "+", "2"}], ")"}]}], "..."}], 
    RowBox[{"(", 
     RowBox[{"n", "+", "k", "-", "1"}], ")"}], 
    SuperscriptBox["p", 
     RowBox[{"\[ThinSpace]", "n"}]], " ", 
    RowBox[{
     RowBox[{"u", "[", "n", "]"}], " ", 
     OverscriptBox["\[LongLeftRightArrow]", "\[DoubleStruckCapitalZ]"], " ", 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"p", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}], ")"}], 
       RowBox[{"\[ThinSpace]", "k"}]]]}]}], TraditionalForm]],ExpressionUUID->
  "d7976676-0c23-4f17-885d-e372fdd3ca23"]
}], "Text",
 CellChangeTimes->{{3.8467684976146083`*^9, 3.8467686099918327`*^9}, {
  3.8467687657309675`*^9, 3.846768781212628*^9}, {3.846769070102723*^9, 
  3.846769073447969*^9}, {3.846769133394736*^9, 3.8467691624305*^9}, {
  3.846769503771829*^9, 3.846769534668624*^9}, {3.8467703124530234`*^9, 
  3.84677041502879*^9}, {3.846770810959872*^9, 3.8467708127214804`*^9}, {
  3.8467711006632166`*^9, 3.846771101002223*^9}, {3.846771173894894*^9, 
  3.846771174031899*^9}, {3.846771223803984*^9, 3.846771230023136*^9}, {
  3.847148060677963*^9, 3.847148076777579*^9}, {3.847148119554582*^9, 
  3.847148123960387*^9}, {3.85050896509816*^9, 3.850508965160206*^9}, {
  3.9312731016035213`*^9, 3.931273106150587*^9}},
 CellID->2030783307,ExpressionUUID->"098bb777-2773-474d-92f4-b24bfc85f1b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection",
 CellChangeTimes->{{3.604349362919951*^9, 3.604349382483351*^9}, 
   3.66673864216765*^9, {3.666741073646077*^9, 3.6667410750500593`*^9}, {
   3.835913744585325*^9, 3.835913755925232*^9}, {3.838471867233362*^9, 
   3.838471868875366*^9}, {3.838472645469183*^9, 3.838472646309412*^9}, 
   3.846756881682587*^9, {3.846760199776272*^9, 3.8467602015801196`*^9}},
 CellID->1417438978,ExpressionUUID->"cf105f74-730f-4cbd-aa26-9898e9b7115c"],

Cell["\<\
Determine the inverse z-transform of the following function using partial \
fraction expansion\
\>", "Text",
 CellChangeTimes->{{3.666547473111367*^9, 3.666547499078367*^9}, {
   3.666564720399255*^9, 3.666564749962771*^9}, {3.6665648293240404`*^9, 
   3.666564855689392*^9}, {3.666564955596916*^9, 3.666564962632878*^9}, 
   3.66664652071467*^9, 3.838471642259556*^9, {3.846707946641475*^9, 
   3.8467079481523333`*^9}, {3.847144639523294*^9, 3.847144642177546*^9}, {
   3.9169131941650343`*^9, 3.916913194327862*^9}, 3.916916836412836*^9, {
   3.919430547913639*^9, 3.91943054814534*^9}},
 CellID->860807075,ExpressionUUID->"58a23179-d1d6-4522-a470-36aeda9c5816"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox[
     RowBox[{"1", "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}], "3"]]}], TraditionalForm]],
  ExpressionUUID->"1e83eed6-cec7-4150-ad72-69f47720093e"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], ">", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "8884e7a5-6df9-4d17-bd7f-d2baafd922ea"]
}], "Text",
 CellChangeTimes->{{3.846700983113594*^9, 3.846701062100625*^9}, {
  3.846760273952235*^9, 3.846760312092614*^9}, {3.8471496033962507`*^9, 
  3.8471496145279465`*^9}, {3.920108652893795*^9, 3.9201086548946133`*^9}},
 CellID->2134663333,ExpressionUUID->"6ba124a7-d250-4af5-8402-9754bdfe0397"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.846760335247684*^9, 3.8467603366943617`*^9}},
 CellID->1424830949,ExpressionUUID->"11ec7a4c-bd5c-4e20-9cfd-9be2807cc7e8"],

Cell[TextData[{
 "Directly from the ",
 ButtonBox["InverseBilateralZTransform",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InverseBilateralZTransform"],
 ", you get:"
}], "Text",
 CellChangeTimes->{{3.846701189091983*^9, 3.8467011937270346`*^9}, {
   3.8467603564846783`*^9, 3.846760372544221*^9}, 3.8529837854664497`*^9, {
   3.902783331696408*^9, 3.9027833316984997`*^9}, {3.923569453246584*^9, 
   3.9235694532566185`*^9}},
 CellID->543612146,ExpressionUUID->"e4354fea-9db0-4f4e-9ba1-7ee28d3b2f8d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "z_", "]"}], ":=", 
   FractionBox[
    RowBox[{"1", "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}], "3"]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   RowBox[{"X", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], "Input",
 CellChangeTimes->{{3.846701216969787*^9, 3.8467012216118917`*^9}, {
   3.846757114477939*^9, 3.8467571165594373`*^9}, 3.846774807895036*^9, {
   3.847029652426059*^9, 3.847029669085934*^9}, {3.847144670324262*^9, 
   3.847144680497718*^9}, {3.8471447334626894`*^9, 3.847144749400622*^9}, {
   3.847144864481671*^9, 3.847144877048763*^9}, {3.847149630105261*^9, 
   3.847149631937621*^9}},
 CellID->1093903484,ExpressionUUID->"c75fd8a1-0245-481d-b0bb-b615d5634fac"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{
    RowBox[{"-", "1"}], "-", "n"}]], " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "n"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", 
    RowBox[{"3", " ", "n"}]}], ")"}], " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{3.8471448781805286`*^9, 3.847149640540838*^9, 
  3.8471506059252462`*^9, 3.897573490551989*^9},
 CellID->49333281,ExpressionUUID->"cfc661f9-0cd2-47ae-bf6d-5ff1ebb57378"]
}, Open  ]],

Cell["This shows the first few samples of the sequence:", "Text",
 CellChangeTimes->{{3.8471510170624313`*^9, 3.8471510281309366`*^9}},
 CellID->628353621,ExpressionUUID->"96561a82-139c-4102-8ffc-c4ad494801fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "n"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"3", " ", "n"}]}], ")"}], " ", 
    RowBox[{"UnitStep", "[", "n", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847151031090965*^9, 3.847151046637724*^9}},
 CellID->1562215848,ExpressionUUID->"c0979578-2abd-4527-8bc8-62c74571a28e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   FractionBox["5", "2"], ",", "3", ",", 
   FractionBox["11", "4"], ",", 
   FractionBox["35", "16"], ",", 
   FractionBox["51", "32"]}], "}"}]], "Output",
 CellChangeTimes->{3.8471510472661743`*^9, 3.897573494294635*^9},
 CellID->57978281,ExpressionUUID->"c84e6f20-d301-410d-b7ae-493ff8164fb5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1026689114,ExpressionUUID->"08221c8f-befa-471a-ad10-3cb43e730450"],

Cell[TextData[{
 "Using positive powers of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "1d07bbfe-55c9-4293-bb4b-4a71c46cd633"],
 " and the reduced transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "/", "z"}], TraditionalForm]],
  ExpressionUUID->"32c33767-2833-4684-af0d-4144c6637787"],
 ", you get the following partial fraction expansion"
}], "Text",
 CellChangeTimes->{{3.846759488464293*^9, 3.846759489447106*^9}, {
   3.846759715755367*^9, 3.8467597280296383`*^9}, {3.846853313165631*^9, 
   3.8468533139989133`*^9}, {3.846936768125446*^9, 3.846936775862648*^9}, {
   3.847150409181822*^9, 3.8471504115566797`*^9}, {3.847150450375799*^9, 
   3.847150457165739*^9}, {3.847227821787585*^9, 3.847227832756347*^9}, {
   3.847227887708975*^9, 3.847227906492487*^9}, {3.84722795540638*^9, 
   3.8472279729376206`*^9}, 3.852982940132752*^9, 3.916916865118372*^9},
 CellID->532835353,ExpressionUUID->"ae593c71-9b26-414a-9389-da44346432c8"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"X", "(", "z", ")"}], "z"], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"z", "(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], "3"]], "=", 
     RowBox[{
      FractionBox[
       SubscriptBox["A", "1"], 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}]], "+", 
      FractionBox[
       SubscriptBox["A", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", "2"]}], ")"}], "2"]], "+", 
      FractionBox[
       SubscriptBox["A", "3"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", "2"]}], ")"}], "3"]]}]}]}], TraditionalForm]],
  ExpressionUUID->"a76b321f-5c5b-4a35-8eaf-6a9e267e57bc"]
}], "Text",
 CellChangeTimes->{{3.698451642651052*^9, 3.69845167957232*^9}, {
  3.698451716832191*^9, 3.698451808938373*^9}, {3.69845187493952*^9, 
  3.698451914177395*^9}, {3.6984520710603013`*^9, 3.698452075759909*^9}, {
  3.698452140226241*^9, 3.698452140226241*^9}, {3.698489497691008*^9, 
  3.698489497691008*^9}, {3.698492722810033*^9, 3.698492779256933*^9}, {
  3.6984929582258477`*^9, 3.698492969817668*^9}, {3.6984931663678145`*^9, 
  3.6984931846706467`*^9}, {3.698493230507528*^9, 3.6984932351875367`*^9}, {
  3.69849453516267*^9, 3.6984945462738895`*^9}, {3.698494768865081*^9, 
  3.6984947775386972`*^9}, {3.838471907250441*^9, 3.838471907250498*^9}, {
  3.8467587553973656`*^9, 3.84675876920072*^9}, {3.846758912995193*^9, 
  3.846758942532246*^9}, {3.8471505642735415`*^9, 3.84715056784599*^9}},
 CellID->356969881,ExpressionUUID->"7e79243b-0c1b-44a3-bfd1-161522632509"],

Cell[TextData[{
 "The general formula for the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "i"], TraditionalForm]],ExpressionUUID->
  "696426a6-56f8-4c41-8b61-a8d8fbbf1c32"],
 " of a ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "8c2ecd5d-38a0-4c54-9fef-66e90e57068e"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", "th"], TraditionalForm]],ExpressionUUID->
  "d84af111-e404-4be5-b686-04607ebbd6a0"],
 "-order pole is now the same as in the case of the Laplace transform"
}], "Text",
 CellChangeTimes->{{3.698494202273284*^9, 3.6984942044592876`*^9}, {
   3.825512481721885*^9, 3.825512484774054*^9}, {3.825512527254743*^9, 
   3.8255125422036066`*^9}, {3.825512587401912*^9, 3.825512636253815*^9}, {
   3.838471916250093*^9, 3.838471937602215*^9}, {3.838905731627234*^9, 
   3.838905731987268*^9}, {3.84702108702126*^9, 3.847021103117873*^9}, {
   3.847150395472346*^9, 3.847150395563705*^9}, {3.8471504849013786`*^9, 
   3.847150495097673*^9}, 3.9169279797021084`*^9},
 CellID->1670963896,ExpressionUUID->"7dad32a3-b896-4883-81b6-0a52fcb4917a"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{
     RowBox[{
      SubscriptBox["A", "i"], "=", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k", "-", "i"}], ")"}], "!"}]], 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[DifferentialD]", 
          RowBox[{" ", 
           RowBox[{"k", "-", "i"}]}]], 
         RowBox[{"\[DifferentialD]", 
          SuperscriptBox["z", 
           RowBox[{" ", 
            RowBox[{"k", "-", "i"}]}]]}]], 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "p"}], ")"}], "k"], 
          FractionBox[
           RowBox[{"X", "(", "z", ")"}], "z"]}], "}"}]}]}]}], 
     "\[RightBracketingBar]"}], 
    RowBox[{"z", "=", "p"}]], TraditionalForm]],ExpressionUUID->
  "f1d2691a-143a-4674-aec3-f3c2da2a65e1"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "...", ",", "k"}], TraditionalForm]],
  ExpressionUUID->"11fc90af-f8c1-43c8-9a6f-559f0f72f88c"]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxNzltIk2EAxvFvE5JmCumUlUubS5y6Bc4JCTX4LiQa2jZPU/GQiyWU2MAU
rZQhmDhLZBsiEgm5xAOKoBfiFL2IPIDKQjTaki2K4dzESiFlmO/z3uTFw+/q
gb9I/zTfwGUYRkIGG+bzkp5o99jUVwEJtHkyZruIR1WZ1DRdouI1UbQlopal
pLa8IZY8yjBBxUex2XLOsqIYH2wy6HYh58XG7/P6Y1cF97v32PeDWiGsC7Ze
hxMVH6jpOzy+mrihaL4CNbzFzxri0P7DTdi+nOaC00tSKtdr8sLknQ6qWyrf
hY5vg8dQHjKf0j8/xGiJleOXL8BuhfMifNDpioePa24K4fr+r9uQ3ZLdgaWy
WBVMkAqolufqaqg5nK+FYr3DCAXZPfXwR25RE6xy1rTA6fprbbB8TNkOh+Wy
BXhvkbcC9ZK4NahMSqb2OAs2aY8yfBuuFl/yQS7f6Ifmyp+HUOX2U+Oix4+h
/cbMCZz0hZ9aTQH2z3LkPxjjNXJ6iRHvPFQPZ8aU3fvfdXN6q3AkwLYdyajC
FNco1JQnTsIc5cEUDN36S7X3i3Uq4txXOTXYMHz3LZEZ+ES9KvE8cxG/OxyN
sER9EDmbGWS/LLyMgnx7nzUsK8gWWkZt8Ax3vEAO
  "],
 CellID->1246548253,ExpressionUUID->"cb18ed1e-c634-407f-9249-fccc9d0139bb"],

Cell[TextData[{
 "The following returns the value of the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "3"], TraditionalForm]],ExpressionUUID->
  "a5255ca1-ec31-43ea-af13-8c3385b90d94"],
 " coefficient:"
}], "Text",
 CellChangeTimes->{{3.6984874643787227`*^9, 3.698487487076762*^9}, {
  3.698489648211073*^9, 3.698489650722678*^9}, {3.6984931902242565`*^9, 
  3.69849319250186*^9}, {3.69849548982955*^9, 3.69849548989195*^9}, {
  3.825544138499294*^9, 3.825544141631914*^9}, {3.8467587817073216`*^9, 
  3.8467587817666683`*^9}},
 CellID->2033511686,ExpressionUUID->"42fa42f9-4cec-48c9-9af3-5c731fbad54a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", 
       FractionBox["1", "2"]}], ")"}], "3"], 
    FractionBox[
     RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
   RowBox[{"z", "\[Rule]", 
    FractionBox["1", "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.666547720894367*^9, 3.666547721306367*^9}, 
   3.66656610640695*^9, {3.762779237036234*^9, 3.762779251848234*^9}, {
   3.792625228582302*^9, 3.792625241885476*^9}, {3.825509568459569*^9, 
   3.8255095924842176`*^9}, {3.825509759144204*^9, 3.8255097631688967`*^9}, {
   3.82550999399463*^9, 3.825510004884871*^9}, {3.82551220492388*^9, 
   3.8255122053339233`*^9}},
 CellID->28664597,ExpressionUUID->"81fecd77-06a4-410f-8115-05cc38499936"],

Cell[BoxData[
 FractionBox["3", "4"]], "Output",
 CellChangeTimes->{
  3.762779252601234*^9, {3.8255095934201565`*^9, 3.825509606964845*^9}, 
   3.825509766400742*^9, 3.825510005654416*^9, 3.825512264692835*^9, 
   3.825513262324723*^9, 3.825513514915141*^9, 3.825514141844394*^9, 
   3.847150610387154*^9, 3.8975735009596395`*^9},
 CellID->752241404,ExpressionUUID->"d2bf30f2-9eb3-4820-965e-8598bb64e3c1"]
}, Open  ]],

Cell[TextData[{
 "This gives the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "2"], TraditionalForm]],ExpressionUUID->
  "56605ca5-0f22-4e7c-a1e7-4caa5f1d2671"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "1"], TraditionalForm]],ExpressionUUID->
  "72ab8e37-39dd-4ff9-963c-ca6975c531fa"],
 " coefficients:"
}], "Text",
 CellChangeTimes->{{3.698495499064766*^9, 3.698495532605825*^9}, {
  3.698590973830808*^9, 3.698590974595194*^9}, {3.82551273952452*^9, 
  3.82551274704207*^9}, {3.846758786012106*^9, 3.8467587889830017`*^9}, {
  3.847228016165676*^9, 3.847228041095343*^9}},
 CellID->729544851,ExpressionUUID->"3fe3585c-cd6a-46c6-98c8-3ae308690e91"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], "3"], 
      FractionBox[
       RowBox[{"X", "[", "z", "]"}], "z"]}], ",", "z"}], "]"}], ",", 
   RowBox[{"z", "\[Rule]", 
    FractionBox["1", "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.666547720894367*^9, 3.666547721306367*^9}, 
   3.66656610640695*^9, {3.762779237036234*^9, 3.762779251848234*^9}, {
   3.792625228582302*^9, 3.792625241885476*^9}, {3.825509568459569*^9, 
   3.8255095924842176`*^9}, {3.825509759144204*^9, 3.8255097631688967`*^9}, {
   3.82550999399463*^9, 3.825510004884871*^9}, {3.82551220492388*^9, 
   3.8255122053339233`*^9}, {3.8255122839859858`*^9, 3.825512292493986*^9}},
 CellID->1476170034,ExpressionUUID->"8381db7f-9814-4653-b393-becd70d3ac68"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.825512296506028*^9, 3.825513265289039*^9, 
  3.825513516823225*^9, 3.825514144038892*^9, 3.84715061277979*^9, 
  3.897573503026684*^9},
 CellID->609443523,ExpressionUUID->"d331a016-60ce-4430-9c96-4344c7327c08"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "!"}]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", "2"]}], ")"}], "3"], 
       FractionBox[
        RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"z", "\[Rule]", 
    FractionBox["1", "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.666547720894367*^9, 3.666547721306367*^9}, 
   3.66656610640695*^9, {3.762779237036234*^9, 3.762779251848234*^9}, {
   3.792625228582302*^9, 3.792625241885476*^9}, {3.825509568459569*^9, 
   3.8255095924842176`*^9}, {3.825509759144204*^9, 3.8255097631688967`*^9}, {
   3.82550999399463*^9, 3.825510004884871*^9}, {3.82551220492388*^9, 
   3.8255122053339233`*^9}, {3.8255122839859858`*^9, 
   3.8255123113877535`*^9}, {3.825514120149838*^9, 3.825514123594441*^9}},
 CellID->111187647,ExpressionUUID->"f9d68682-a464-4498-807b-29c71c53d836"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.825512312667527*^9, 3.825513108464434*^9, 3.825513266513*^9, 
   3.825513518222866*^9, {3.8255141289857874`*^9, 3.825514146335804*^9}, 
   3.84715061414126*^9, 3.89757350530464*^9},
 CellID->179365035,ExpressionUUID->"f3cdff1f-afc1-4ee1-a868-cad361ef94e6"]
}, Open  ]],

Cell["Therefore", "Text",
 CellChangeTimes->{{3.762792193555653*^9, 3.76279219588756*^9}, 
   3.838471959323455*^9, {3.8471506292139125`*^9, 3.847150630393386*^9}, 
   3.9169168900759945`*^9},
 CellID->420010239,ExpressionUUID->"f98b4ff3-ffa0-4f66-8211-320dc6436915"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     FractionBox["z", 
      RowBox[{"z", "-", 
       FractionBox["1", "2"]}]], "+", 
     RowBox[{"2", 
      FractionBox["z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", "2"]}], ")"}], "2"]]}], "+", 
     RowBox[{
      FractionBox["3", "4"], 
      FractionBox["z", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", "2"]}], ")"}], "3"]]}]}]}], TraditionalForm]],
  ExpressionUUID->"46544fde-4717-4431-99eb-feb01d809665"]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQnXU1ZLpN32vHooBPs0G038JZC0C0GrvcGhDdIxC3
BURbrHXdCaL/vn14BkTrBVacBdFxtu1Xkem9MmbC/kj0qdeRywJAtEXGWhCt
anX8MIgO07I6CqKVj56+C6I/lIo+ANGrbC88BdE+DGnPQPR0k6cdgUB6y2GP
LhC9b530MhDNYGu4HERveP2APwhI/zliIgqiZ+m3Xv3C8cYxvuPCNRDtpi3x
aWoDgo5mK746DYlmiFj12HfmG8dKKF1xeeE2mZVvHBPXbtsOone1z22/DaTV
Wc06QDQAH9Kc0A==
  "],
 CellID->333339184,ExpressionUUID->"37a099d2-6d0c-46a2-b9e9-043dffd6db27"],

Cell["\<\
Each of the terms in the decomposition may be inverted by table lookup or \
evaluated as shown here\
\>", "Text",
 CellChangeTimes->{{3.4051805174375*^9, 3.405180519109375*^9}, {
   3.604350917667751*^9, 3.604350985246951*^9}, {3.604351099407751*^9, 
   3.604351111762951*^9}, 3.666481701099156*^9, {3.666566662087426*^9, 
   3.666566680947584*^9}, {3.666567137023337*^9, 3.6665671378501267`*^9}, {
   3.825513714583801*^9, 3.825513715998133*^9}, {3.825544223082829*^9, 
   3.8255442480836897`*^9}, 3.838471969658684*^9, 3.916916926578165*^9},
 CellID->1794314112,ExpressionUUID->"23444c38-cb1f-4a33-a6eb-9ceada16eae2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   FractionBox["z", 
    RowBox[{"z", "-", 
     FractionBox["1", "2"]}]], ",", "z", ",", "n"}], "]"}]], "Input",
 CellChangeTimes->{{3.846849394838688*^9, 3.846849422360182*^9}},
 CellID->2071909210,ExpressionUUID->"e5ffa992-ad13-4e99-9fc3-5eb9e03eaa6c"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"-", "n"}]], " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{3.846849423321847*^9, 3.8470253875693445`*^9, 
  3.847150669922162*^9, 3.889052637730697*^9, 3.8975735099355083`*^9},
 CellID->12047558,ExpressionUUID->"c727b46b-1fe7-4079-b6e9-1dcb48d5f977"]
}, Open  ]],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    RowBox[{
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], "2"]], " ", 
     OverscriptBox["\[LongRightArrow]", 
      SuperscriptBox["\[DoubleStruckCapitalZ]", 
       RowBox[{"-", "1"}]]], "4"}], 
    SuperscriptBox[
     RowBox[{"n", "(", 
      FractionBox["1", "2"], ")"}], "n"], " ", 
    RowBox[{"u", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "f4c9c6a4-4040-4b3e-9274-f17b344dca73"]
}], "Text",
 CellChangeTimes->{{3.8467737280939407`*^9, 3.846773923225944*^9}, {
  3.847029745291394*^9, 3.847029759718901*^9}, {3.847150865239339*^9, 
  3.847150871162678*^9}, {3.847150966668123*^9, 3.847150966699734*^9}},
 CellID->1130756365,ExpressionUUID->"4d1beae1-819d-4b99-b18a-b0d688a0a45e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   RowBox[{"2", 
    FractionBox["z", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}], ")"}], "2"]]}], ",", "z", ",", "n"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.846849394838688*^9, 3.846849457601859*^9}, 
   3.846849504395305*^9, {3.846849574919927*^9, 3.846849576413015*^9}, 
   3.847150876481644*^9},
 CellID->1539434252,ExpressionUUID->"a621ba43-f34d-4ea1-bef3-a2ed6137fa5e"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"2", "-", "n"}]], " ", "n", " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{3.846849458275215*^9, 3.84684950495946*^9, 
  3.8468495772209225`*^9, 3.847025303336614*^9, 3.8471506790146065`*^9, 
  3.8471508777240405`*^9, 3.8890526491197968`*^9, 3.897573511731478*^9},
 CellID->310702850,ExpressionUUID->"76b5bf9a-3b61-4368-b91b-b9336892b0dd"]
}, Open  ]],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["3", "4"], 
    RowBox[{
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], "3"]], " ", 
     OverscriptBox["\[LongRightArrow]", 
      SuperscriptBox["\[DoubleStruckCapitalZ]", 
       RowBox[{"-", "1"}]]], 
     FractionBox["3", "4"]}], "2", 
    RowBox[{"n", "(", 
     RowBox[{"n", "-", "1"}], ")"}], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "2"], ")"}], "n"], " ", 
    RowBox[{"u", "[", "n", "]"}]}], TraditionalForm]],ExpressionUUID->
  "239939c6-b724-4765-bffa-1c05d13f8309"]
}], "Text",
 CellChangeTimes->{{3.8467737280939407`*^9, 3.846773923225944*^9}, {
  3.847029745291394*^9, 3.847029759718901*^9}, {3.847150865239339*^9, 
  3.847150871162678*^9}, {3.847150966668123*^9, 3.847150966699734*^9}, {
  3.85050886571729*^9, 3.8505088756891313`*^9}, {3.8505099103884273`*^9, 
  3.850509949570365*^9}},
 CellID->388494308,ExpressionUUID->"74fc9b1e-1f54-4828-b3bd-9118d05fd52c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   RowBox[{
    FractionBox["3", "4"], 
    FractionBox["z", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}], ")"}], "3"]]}], ",", "z", ",", "n"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.666566684707136*^9, 3.666566712677577*^9}, {
   3.666635387579943*^9, 3.666635390746702*^9}, 3.792704730655638*^9, 
   3.7927048050224986`*^9, {3.825512856334484*^9, 3.825512874970864*^9}, {
   3.8467011277203712`*^9, 3.846701129249188*^9}, {3.846774148055305*^9, 
   3.8467741883477736`*^9}, {3.846774241377045*^9, 3.846774241708366*^9}, {
   3.846774316533682*^9, 3.846774335078279*^9}, {3.8470253394957037`*^9, 
   3.8470253412092605`*^9}, {3.847055761689493*^9, 3.847055762540483*^9}, 
   3.847150698409825*^9, {3.8471509055939445`*^9, 3.847150906337711*^9}, 
   3.850509931529309*^9, {3.8505099834862967`*^9, 3.850509984362221*^9}},
 CellID->1073547676,ExpressionUUID->"c3d37353-6519-482f-a063-cd43d55ba9e2"],

Cell[BoxData[
 RowBox[{"3", " ", 
  SuperscriptBox["2", 
   RowBox[{
    RowBox[{"-", "1"}], "-", "n"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", "n", " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{
  3.666566713317169*^9, 3.666635404037731*^9, 3.7927047320234256`*^9, 
   3.792704810319874*^9, 3.825512876431101*^9, 3.825513565468503*^9, 
   3.825514158555084*^9, 3.8467011305052524`*^9, {3.846774168568311*^9, 
   3.846774184443506*^9}, 3.846774242270595*^9, {3.8467743172189384`*^9, 
   3.846774338263615*^9}, 3.847025341828638*^9, 3.847025419278427*^9, 
   3.847055763336966*^9, 3.847150699120769*^9, 3.847150906889606*^9, 
   3.8505099323412223`*^9, 3.850509985337012*^9, 3.889052652839662*^9, 
   3.897573513418847*^9},
 CellID->88816281,ExpressionUUID->"bed00ed1-5f3a-4eee-9130-3cf51f148cc8"]
}, Open  ]],

Cell["The resulting time-domain sequence is", "Text",
 CellChangeTimes->{{3.825604911236762*^9, 3.8256049241509953`*^9}, 
   3.916916933643793*^9},
 CellID->2105672085,ExpressionUUID->"5cbac0bd-9361-41fd-a945-7d66db415579"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{"1", "+", 
       RowBox[{"4", " ", "n"}], "+", 
       RowBox[{
        FractionBox["3", "2"], 
        RowBox[{"(", 
         RowBox[{"n", "-", "1"}], ")"}], "n"}]}], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", "2"], ")"}], "n"], " ", 
     RowBox[{"u", "[", "n", "]"}]}]}], TraditionalForm]],ExpressionUUID->
  "3e2d090b-b891-4b47-bf43-bdba3bcf887d"]
}], "Text",
 CellChangeTimes->{{3.8256049266662197`*^9, 3.825604934622961*^9}, {
  3.825605751530768*^9, 3.825605766241457*^9}, {3.838471975324059*^9, 
  3.838471975324121*^9}, {3.847055797144514*^9, 3.847055861198438*^9}, {
  3.8470558962175817`*^9, 3.8470558962175817`*^9}, {3.8471507211838903`*^9, 
  3.847150748372208*^9}, {3.8471509326134586`*^9, 3.847150939639179*^9}},
 CellID->1647713682,ExpressionUUID->"f543dce7-fd66-4d0a-acd5-2b5482b2f09a"],

Cell["This shows the first few samples of the sequence:", "Text",
 CellChangeTimes->{{3.847151064958884*^9, 3.847151075342726*^9}},
 CellID->1322225309,ExpressionUUID->"9f848ec1-5559-4e17-a48e-38027d751bc0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{"1", "+", 
      RowBox[{"4", " ", "n"}], "+", 
      RowBox[{
       FractionBox["3", "2"], 
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], "n"}]}], ")"}], 
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], 
    RowBox[{"UnitStep", "[", "n", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847145036311513*^9, 3.847145063920426*^9}, {
  3.84715081871996*^9, 3.847150824010728*^9}},
 CellID->479989207,ExpressionUUID->"46db8739-402a-40ea-9eb2-5274d9a29f3c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   FractionBox["5", "2"], ",", "3", ",", 
   FractionBox["11", "4"], ",", 
   FractionBox["35", "16"], ",", 
   FractionBox["51", "32"]}], "}"}]], "Output",
 CellChangeTimes->{{3.8471450480153036`*^9, 3.847145065037765*^9}, 
   3.847150827205075*^9, 3.8975735162448883`*^9},
 CellID->23473236,ExpressionUUID->"81e47b4e-3938-46ed-af13-ae66b8051bb1"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3", "Subsection",
 CellChangeTimes->{{3.666569648232342*^9, 3.666569649527125*^9}, {
  3.6667409645410757`*^9, 3.666740981607257*^9}, {3.666741104096886*^9, 
  3.6667411166703253`*^9}, {3.6683622514472322`*^9, 3.668362251955221*^9}, {
  3.698445438694575*^9, 3.6984454387881746`*^9}, {3.731754236564852*^9, 
  3.73175423664285*^9}, {3.792606774880343*^9, 3.792606775180569*^9}, {
  3.827608861725193*^9, 3.827608861854647*^9}, {3.8359138278143067`*^9, 
  3.835913829717927*^9}, {3.836686431642595*^9, 3.8366864317277813`*^9}},
 CellID->1230023917,ExpressionUUID->"c2a0a24b-30e5-4990-99b2-565713c51f35"],

Cell["Given the following z-transform:", "Text",
 CellChangeTimes->{{3.666569658606209*^9, 3.666569672146835*^9}, {
  3.761351292408727*^9, 3.761351331545803*^9}, {3.838471985024127*^9, 
  3.83847199067502*^9}, {3.846708122735067*^9, 3.846708125097565*^9}, {
  3.847235712110872*^9, 3.8472357122732224`*^9}, {3.916913440659223*^9, 
  3.916913440869911*^9}, {3.919430563660761*^9, 3.9194305639078255`*^9}},
 CellID->1334386997,ExpressionUUID->"5e3f00f0-2543-4022-823d-c8be3ca3edd8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"G", "[", "z_", "]"}], ":=", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "\[VeryThinSpace]", "+", "z"}], ")"}], "3"], 
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"15", "z"}], "-", 
     RowBox[{"25", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"21", 
      SuperscriptBox["z", "3"]}]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.761351249120602*^9, 3.761351284161543*^9}, 
   3.761351344834113*^9, 3.847235708033424*^9},
 CellID->870532958,ExpressionUUID->"810a5412-75f6-4730-8a24-01544546869c"],

Cell["A. Obtain and plot the poles and zeros.", "Text",
 CellChangeTimes->{{3.666569681647113*^9, 3.666569738570783*^9}, {
  3.9169177937999077`*^9, 3.9169177954918785`*^9}, {3.93263805281784*^9, 
  3.9326380533647137`*^9}},
 CellID->241338095,ExpressionUUID->"39465e18-f79c-40ca-82ff-5243673858a7"],

Cell[TextData[{
 "B. Plot the magnitude of the z-transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "e4ee6a37-f121-4e1a-97ff-c61bf7377f95"],
 "."
}], "Text",
 CellChangeTimes->{{3.66656974289193*^9, 3.666569784683792*^9}, {
   3.666569876675813*^9, 3.6665698771438065`*^9}, 3.838471997639594*^9, {
   3.9169134449404774`*^9, 3.9169134451260376`*^9}, {3.916917798190068*^9, 
   3.9169178000002327`*^9}, {3.919430570243238*^9, 3.9194305704430904`*^9}, {
   3.9326380550420923`*^9, 3.9326380553845987`*^9}},
 CellID->1720237129,ExpressionUUID->"b4a9eeb3-4ad3-4ac9-96c1-da1ab6ed739f"],

Cell[TextData[{
 "C. Obtain the causal sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "38cc8bd2-5457-4f5a-aae9-4d8903f83d51"],
 " with z-transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "c304e229-39ef-4305-83df-2d6a3e942552"],
 ". "
}], "Text",
 CellChangeTimes->{{3.6665698826973376`*^9, 3.6665699372810354`*^9}, {
  3.838472007675728*^9, 3.8384720110069313`*^9}, {3.847235897765067*^9, 
  3.8472358978386407`*^9}, {3.916913448255209*^9, 3.916913448386923*^9}, {
  3.916917801993679*^9, 3.916917804894703*^9}, {3.9194305738052177`*^9, 
  3.9194305740208073`*^9}, {3.932638056881369*^9, 3.9326380573847857`*^9}},
 CellID->453087542,ExpressionUUID->"c7060c02-561c-4efb-8e41-490f76ded275"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.666570031581827*^9, 3.666570033422603*^9}},
 CellID->65306132,ExpressionUUID->"1b5f2f64-3845-4e75-a2ba-0c29b189a3de"],

Cell["A. This shows the poles and zeros:", "Text",
 CellChangeTimes->{{3.6669081704634333`*^9, 3.666908181445692*^9}, {
  3.916917807738333*^9, 3.916917809099655*^9}, {3.91943412691382*^9, 
  3.919434129787853*^9}, {3.9326380615055037`*^9, 3.932638061836873*^9}},
 CellID->236016907,ExpressionUUID->"0376b7bd-911d-4813-aefd-a5d27bb192a4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"zeros", "=", 
   RowBox[{
    RowBox[{"SolveValues", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Numerator", "[", 
        RowBox[{"G", "[", "z", "]"}], "]"}], "==", "0"}], ",", "z"}], "]"}], "//",
     "Flatten"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"poles", "=", 
   RowBox[{
    RowBox[{"SolveValues", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Denominator", "[", 
        RowBox[{"G", "[", "z", "]"}], "]"}], "==", "0"}], ",", "z"}], "]"}], "//",
     "Flatten"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ComplexListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"poles", ",", "zeros"}], "}"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["6", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["1400", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[
    PlotRange -> {{-2, 2}, {-2, 2}}, PlotStyle -> PointSize[Large], AxesLabel -> {
       Style["Re", Small], 
       Style["Im", Small]}, AspectRatio -> Automatic, PlotLegends -> {
       Style["poles", Small, Italic], 
       Style["zeros", Small, Italic]}, Epilog -> {Red, 
       Circle[{0, 0}, 1]}],
    SelectWithContents->True,
    Selectable->False]}], "]"}]}], "Input",
 CellChangeTimes->{{3.666525234361369*^9, 3.6665253813363686`*^9}, {
   3.666525457187369*^9, 3.666525536482369*^9}, {3.666526229556369*^9, 
   3.666526235274369*^9}, {3.666526475676369*^9, 3.666526542030369*^9}, {
   3.666570207485172*^9, 3.666570212461508*^9}, {3.666570250993014*^9, 
   3.666570251117812*^9}, {3.6665703068090982`*^9, 3.666570337384706*^9}, {
   3.666570448221285*^9, 3.666570465927058*^9}, 3.6665705000594206`*^9, {
   3.666570549463988*^9, 3.666570570632916*^9}, {3.666570768843974*^9, 
   3.666570817468551*^9}, {3.6669079397891903`*^9, 3.66690795701137*^9}, {
   3.666908827324211*^9, 3.666908876260784*^9}, {3.6670598018282366`*^9, 
   3.667059825992327*^9}, {3.761351358762556*^9, 3.761351361810104*^9}, {
   3.825606189515967*^9, 3.825606193248023*^9}, 3.8359138470055847`*^9, {
   3.8359145713167562`*^9, 3.8359145783216286`*^9}, {3.8368574020263877`*^9, 
   3.83685750401894*^9}, 3.854468157093226*^9, {3.854468201445278*^9, 
   3.854468214015659*^9}, {3.854468298938679*^9, 3.854468327522295*^9}, 
   3.8924958545553265`*^9, {3.894485335793994*^9, 3.894485418846078*^9}, {
   3.8946658689402122`*^9, 3.894665885228183*^9}, 3.9296518892268925`*^9},
 CellID->333859940,ExpressionUUID->"df0bc4e8-d9ec-4056-acbe-d7d66edc20a7"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {}}, {}, {{}, 
      InterpretationBox[{
        TagBox[{
          TagBox[{
            RGBColor[0.368417, 0.506779, 0.709798], 
            PointSize[Large], 
            AbsoluteThickness[2], 
            
            PointBox[{{0.3333333333333333, 0.}, {
             0.42857142857142855`, -0.4948716593053935}, {
             0.42857142857142855`, 0.4948716593053935}}]}, 
           Annotation[#, "Charting`Private`Tag#1"]& ], 
          TagBox[{
            RGBColor[0.880722, 0.611041, 0.142051], 
            PointSize[Large], 
            AbsoluteThickness[2], 
            PointBox[{{-1., 0.}, {-1., 0.}, {-1., 0.}}]}, 
           Annotation[#, "Charting`Private`Tag#2"]& ]}, {
         "WolframDynamicHighlight", <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
        StyleBox[
         DynamicBox[
          (Charting`HighlightActionBox["DynamicHighlight", {}, 
           Slot["HighlightElements"], 
           Slot["LayoutOptions"], 
           Slot["Meta"], 
           Charting`HighlightActionFunction["DynamicHighlight", {{
              Annotation[{
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                
                Point[{{0.3333333333333333, 0.}, {
                 0.42857142857142855`, -0.4948716593053935}, {
                 0.42857142857142855`, 0.4948716593053935}}]}, 
               "Charting`Private`Tag#1"], 
              Annotation[{
                Directive[
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                Point[{{-1., 0.}, {-1., 0.}, {-1., 0.}}]}, 
               "Charting`Private`Tag#2"]}}, <|
            "HighlightElements" -> <|
              "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
             "LayoutOptions" -> <|
              "PanelPlotLayout" -> <||>, 
               "PlotRange" -> {{-2., 2.}, {-2., 2.}}, 
               "Frame" -> {{False, False}, {False, False}}, 
               "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 432}, 
               "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
               Automatic, "DefaultStyle" -> {
                 Directive[
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[2], 
                  PointSize[Large]], 
                 Directive[
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[2], 
                  PointSize[Large]]}, 
               "HighlightLabelingFunctions" -> <|
                "CoordinatesToolOptions" -> (Identity[
                    Part[#, 1]] + I Identity[
                    Part[#, 2]]& ), 
                 "ScalingFunctions" -> {{Identity, Identity}, {
                   Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
               False|>, 
             "Meta" -> <|
              "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
               "Function" -> ComplexListPlot, "GroupHighlight" -> 
               False|>|>]]& )[<|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
            "LayoutOptions" -> <|
             "PanelPlotLayout" -> <||>, "PlotRange" -> {{-2., 2.}, {-2., 2.}},
               "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 432}, 
              "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
              Automatic, "DefaultStyle" -> {
                Directive[
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Large]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> (Identity[
                   Part[#, 1]] + I Identity[
                    Part[#, 2]]& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> ComplexListPlot, "GroupHighlight" -> False|>|>], 
          ImageSizeCache -> {{
           4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}}], Selectable -> 
         False]}, 
       Annotation[{{
          Annotation[{
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2], 
             PointSize[Large]], 
            
            Point[{{0.3333333333333333, 0.}, {
             0.42857142857142855`, -0.4948716593053935}, {
             0.42857142857142855`, 0.4948716593053935}}]}, 
           "Charting`Private`Tag#1"], 
          Annotation[{
            Directive[
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2], 
             PointSize[Large]], 
            Point[{{-1., 0.}, {-1., 0.}, {-1., 0.}}]}, 
           "Charting`Private`Tag#2"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, "PlotRange" -> {{-2., 2.}, {-2., 2.}}, 
           "Frame" -> {{False, False}, {False, False}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 432}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           Automatic, "DefaultStyle" -> {
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[2], 
              PointSize[Large]], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Large]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> (Identity[
                Part[#, 1]] + I Identity[
                 Part[#, 2]]& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ComplexListPlot, "GroupHighlight" -> False|>|>, 
        "DynamicHighlight"]], {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}, 
    AspectRatio -> Automatic, Axes -> True, AxesLabel -> {
      FormBox[
       StyleBox["\"Re\"", Small, StripOnInput -> False], TraditionalForm], 
      FormBox[
       StyleBox["\"Im\"", Small, StripOnInput -> False], TraditionalForm]}, 
    AxesOrigin -> {0, 0}, DisplayFunction -> Identity, Epilog -> {
      RGBColor[1, 0, 0], 
      CircleBox[{0, 0}, 1]}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, 
    Method -> {
     "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.528488, 0.470624, 0.701351], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.772079, 0.431554, 0.102387], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.363898, 0.618501, 0.782349], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[1, 0.75, 0], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.647624, 0.37816, 0.614037], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.571589, 0.586483, 0.], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.915, 0.3325, 0.2125], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
         AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
      "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05],
       "MessagesHead" -> ComplexListPlot, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> (Identity[
           Part[#, 1]] + I Identity[
            Part[#, 2]]& ), "CopiedValueFunction" -> (Identity[
           Part[#, 1]] + I Identity[
            Part[#, 2]]& )}}, PlotRange -> {{-2., 2.}, {-2., 2.}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
    Ticks -> {Automatic, Automatic}], 
   FormBox[
    FormBox[
     TemplateBox[{
       StyleBox["\"poles\"", Small, Italic, StripOnInput -> False], 
       StyleBox["\"zeros\"", Small, Italic, StripOnInput -> False]}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.89448535343629*^9, 3.8944853590044947`*^9}, {
   3.894485399817499*^9, 3.894485420986613*^9}, 3.89757352459302*^9, 
   3.929651979789156*^9},
 CellID->494451371,ExpressionUUID->"81e5247c-6a86-44c7-8952-5a29e271c3f6"]
}, Open  ]],

Cell["\<\
B. This shows the magnitude (in decibels) of the z-transform evaluated on the \
complex plane:\
\>", "Text",
 CellChangeTimes->{{3.541237239882406*^9, 3.541237260396442*^9}, {
   3.5412373307525654`*^9, 3.541237333123769*^9}, {3.5412373665702286`*^9, 
   3.541237397442683*^9}, {3.6669081862660303`*^9, 3.666908189635587*^9}, {
   3.666909577175398*^9, 3.666909580794552*^9}, {3.8255443198154325`*^9, 
   3.825544320185693*^9}, 3.83847202479979*^9, {3.916913453957676*^9, 
   3.916913454142372*^9}, {3.916917811758362*^9, 3.9169178132522964`*^9}, {
   3.919430581814333*^9, 3.9194305820157013`*^9}, {3.93263806452595*^9, 
   3.932638064924266*^9}},
 CellID->1956725616,ExpressionUUID->"4526b4da-8db3-4110-958a-3d043f5f3fa6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  InterpretationBox[
   DynamicModuleBox[{Typeset`open = False}, 
    TemplateBox[{"Expression", "SequenceIcon", 
      GridBox[{{
         RowBox[{
           TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["Sequence", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["5", "IconizedItem"]}]}, {
         RowBox[{
           TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
           TagBox["800", "IconizedItem"]}]}}, 
       GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
       "Column", 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
      Dynamic[Typeset`open]},
     "IconizedObject"]],
   Sequence[20 Log10[
      Abs[
       $CellContext`G[$CellContext`\[Sigma] + 
        I $CellContext`\[Omega]]]], {$CellContext`\[Sigma], -1, 
     1}, {$CellContext`\[Omega], -1, 1}, Mesh -> False, 
    PlotRange -> {-60, 20}],
   SelectWithContents->True,
   Selectable->False], "]"}]], "Input",
 CellChangeTimes->{{3.401450998875*^9, 3.401451003171875*^9}, 
   3.404478802484375*^9, {3.6669082084801455`*^9, 3.666908217122435*^9}, {
   3.666908250552807*^9, 3.666908273141317*^9}, {3.6669083076012745`*^9, 
   3.666908312359214*^9}, {3.666908893857359*^9, 3.666908909831554*^9}, {
   3.6669093307453575`*^9, 3.6669093675608854`*^9}, {3.666909484434587*^9, 
   3.6669095223733006`*^9}, {3.667059844571689*^9, 3.667059844649688*^9}, {
   3.761351389968994*^9, 3.761351416274618*^9}, {3.8359138808069425`*^9, 
   3.835913906573411*^9}, {3.847235750740546*^9, 3.847235795022058*^9}, {
   3.892495862017181*^9, 3.892495869288204*^9}, {3.8944854252253027`*^9, 
   3.894485443639145*^9}, {3.894665902045239*^9, 3.89466593041311*^9}},
 CellID->122857954,ExpressionUUID->"10112f30-ea00-49f9-9756-14c478b47f49"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJyVWwtYzdnXzr2RqEhJcbpISrnFkLSO3FLKbYQhcglDl79bZow7YTAujcuU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    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[
         TagBox[{Polygon3DBox[CompressedData["
1:eJxNm3f8FtWxh3f3xQpiwRY6qAgiRUUFNLkWbFgoYoEYFQRsUZqCoiJYExTE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            "]], Polygon3DBox[CompressedData["
1:eJwtkskuRFEURd97pwz1FIJQqEb0orTRjEpqIuITfACDmjIQv1AJMfMDBiLx
AYZGEmMSopcgUQMpEmvnvMHO3ae59+7TpDa3N7aiIAhGQQJcYfyGQVAFFfiI
BUGZs6IceBIksKeIt8FnwSexa+w5eAuoiTynFb4OzomdgWd8zdh/oecod8z8
7SK+cb2F/wJ+jO8S3otvB/4DUvB+cEf8HgyYa5CWPdAO7wR5+D7oMs9R7hpI
wwfBIW8dgCF4LViEL4E6+A1/ZkAahHoblIjtYufNNUprEXsCnjF/u0pOFj5v
3osC8QXzO7q7gm8a3qB64CV8jeZ3dFeacvC3yHu1iv0S/6G/pGHSXJO0ZcEt
6MFeDr1H6tU3vo/Qa1Atqkm16c961WquLamhwx85T4jlOAvmPVQv1cMO+LB5
bjneBdWgWjTzGfMaVItm2mSuKRvP8J0z0o5wnmI/xX/kYo3Sqhlr1tLwFXmO
crUz2h3NXLPXzPvMd1K7ORu/rR6pV0f4XuEPkXPtsHZZO6BdUI+64f+Dp1Fj

            "]]},
          Annotation[#, "Charting`Private`Tag$5660#1"]& ]],
        Lighting->{{"Ambient", 
           RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
          "Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{0, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 0, 2}]}}]}, 
      {GrayLevel[1], EdgeForm[None], 
       StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNlb1OW0EQhX3XkjFuAFekTJsKQosNBAlT4CZtSJMyjpI2BGToQp4gFaYD
/ADY2GC3JFIkjBLIf5GfJ8BSTLqco/1QXIxm7u7O7JkzM3tvP3p2/2lIpVKv
JWlJK0mltiSrstvaaElykn1JAfuNZF37Z9KXkoeyr6WvpV9JXkjqinFLa8vS
G9Jt6YJkMsT1K53p43MlvaS9Pr4DtGPVtF5K4nmvb0vWJPfksyh5IntCuscZ
x57k3l3pGnsfpO9Ivw8RT15yV99j0uPYjjdPzIUQ77Dd59s5F5O47jXndE5e
vsM4ZqWL0nOSis5sJvGuB6nI66jsmSTyXJVMJzHOOL72s79xTSXRb0Vyou9j
yaEkw74xL8OpOSlhm4eLEGMPyDsdYhzzXIOrnRDzcS4vk8jvTf28to5cD9W0
I3ksuxfi2W/S36mj63kGT6ch4hlQL+f6XGtl7BY9toU9DQfmwnl1ZXckRyHe
O0Fe5/BlDAV4MB+OnSa+eaxzJs3eFHVboHZvwd+jP5bgJA1fZfrKcWa5cwPO
S3BoTvL0k3vgQHovRF4ds0Zf/wFXNh3jG8tNLXbAM6AG2/TM1BA/5sYzVk7i
GePO0qvupXlmwbX0+igz6dntwmEHOzP07fhN6Qa4F+n5Ith3wP+ZOfgtPYKv
43Tg2T3oGCf0p30P8C8wC66TsZfJ8WuI9jvm1ZyuMe9LcHtKL32BsyqcOL8s
uf8i10uwbXJmn5wq9PkeeY2A3XU0D+bXcYxzn/PT3HVTM+sfvBNjzOkh82jf
PfKtwJG5+kQdtqhdk/g55rtHXw2YW+c7D3+OeUJdcsQ4ol55cjR+x2uSW4u6
zvD+7HJHl70MeFucydOzfl/M7Sb2HDWrgCdLPh34XaU/R+Cwxl0+v0tutg/o
gwr/kUL4/24V4dBrbXJsgS9H3s2h9Ta+h/R8kbekypy04dLz/jPE+fV7/5He
cI/4v1Bnxv+GWOMLuGsQs8Edto/pZ2P4B+FB1m8=
           "]], 
          Polygon3DBox[{{762, 520, 93, 727}, {754, 248, 123, 712}, {759, 305, 
           77, 758}, {728, 108, 520, 762}, {760, 93, 305, 761}, {723, 298, 76,
            710}, {730, 123, 577, 771}, {771, 577, 108, 729}, {732, 137, 248, 
           733}, {737, 77, 298, 738}, {716, 333, 137, 713}, {810, 136, 333, 
           731}}]}],
        Lighting->{{"Ambient", 
           GrayLevel[0.8]}}]}, 
      {GrayLevel[1], EdgeForm[None], 
       StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtUUuSAVEQfLowgSUOYMEpJmj0xPiLmb2NA3CG7kM5gV6yEGFl4wJmDkAg
MyoX2VmvXlZW1evWevu7iUIIHcCAT3wyJKrgPTgHGkAz8nMd+AfOhRCO4B/o
2ohPiL+AFBji/GGuoXYkzdjcK1X9Q34V5Gvm9SX1bcpnrNoJuAdcEMfSNFR/
BVbId829c9XSl/d3ns01Cfgl/ydnVv4bPFBM7VR9Z+Z3zLPPQT05+5/24K6J
NPSLNWcfPAd2iBfgonbkrrnek3Omejt6ZYqZz/VW3HOieThX2fz+Frkv/Zfm
/4AavvcbTRsxaQ==
           "]], 
          Polygon3DBox[{{844, 293, 438, 845}, {749, 323, 533, 767}, {833, 475,
            349, 834}, {847, 438, 293, 849}, {763, 531, 532, 765}, {778, 642, 
           323, 774}, {773, 581, 642, 828}, {830, 349, 475, 831}, {718, 469, 
           581, 772}, {765, 532, 469, 750}, {766, 533, 531, 717}}]}],
        Lighting->{{"Ambient", 
           GrayLevel[0.8]}}]}, {}, {}}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0bkuRGEABeDL2M3cuWbsy4yxi6VBxxPoJqFQ6iRjKacWIRKJIKHR8gT0
hEpp35dn8AK+SRRfzjl/bu6Sm1tcza+UBUGwRjmlHpFlnBnisSBIEJIkooEU
aRppopkWWmmjnQ466SJDlm5y9NBLH/0MMMgQw4xw46WOvMMp51xzxz0PPPLE
My+88sY7H3yy6x77Piwvv+w9eWDPyW97WZ/Xf/RRWbBv9SvOOOGQbedb8tg1
m/qlLNo7csO+kEv2ur4gZ5lmjAxp51OuSeq/eoqw9HxnkT4pE3ZBhvaEjNv1
1FFLDdVUUUkFsf9/9wftvykW
       "]], 
      Line3DBox[{710, 76, 91, 317, 465, 106, 445, 328, 121, 136, 810, 731, 
       716, 713, 720, 732, 733, 755, 754, 712, 719, 711, 730, 771, 729, 740, 
       728, 762, 727, 739, 726, 760, 761, 725, 759, 758, 776, 737, 738, 724, 
       723, 710}], 
      Line3DBox[{828, 773, 779, 772, 718, 751, 775, 750, 765, 763, 777, 764, 
       717, 766, 767, 749, 774, 778, 828}], 
      Line3DBox[{816, 815, 814, 813, 812, 768, 829, 827, 826, 825, 824, 823, 
       822, 821, 820, 819, 818, 817, 816}], 
      Line3DBox[{838, 742, 753, 715, 752, 748, 735, 769, 734, 756, 838}], 
      Line3DBox[{848, 743, 770, 757, 721, 741, 746, 745, 747, 744, 848}], 
      Line3DBox[{845, 844, 843, 842, 841, 840, 722, 849, 847, 846, 845}], 
      Line3DBox[{833, 832, 831, 830, 736, 839, 837, 836, 835, 834, 833}]}},
    VertexNormals->CompressedData["
1:eJzduwdMlduz948FARUFBVERBLGLXUTqKAqIooIUFQVEkCaIVGnSpQhIR1Ap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     "]], {}},
  Axes->True,
  AxesLabel->{None, None, None},
  AxesOrigin->{Automatic, Automatic, Automatic},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGrids->None,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "RotationControl" -> 
    "Globe"},
  PlotRange->{{-0.9999998571428571, 0.9999998571428571}, {-0.9999998571428571,
    0.9999998571428571}, {-60., 20.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.894485435466999*^9, 3.894485445217983*^9}, 
   3.897573525198865*^9, 3.929651984219549*^9},
 CellID->53632302,ExpressionUUID->"fd214362-c5da-46a6-9f2a-ed9d9e308887"]
}, Open  ]],

Cell[TextData[{
 "C. The result may be obtained directly from the ",
 ButtonBox["InverseBilateralZTransform",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InverseBilateralZTransform"],
 ":"
}], "Text",
 CellChangeTimes->{{3.6669090596208334`*^9, 3.666909061149615*^9}, 
   3.761351704546798*^9, {3.825544391428726*^9, 3.825544391848467*^9}, {
   3.846708325179914*^9, 3.846708326903315*^9}, {3.8472359108470182`*^9, 
   3.847235910916477*^9}, {3.9027833714246593`*^9, 3.902783371425667*^9}, {
   3.9169178154795837`*^9, 3.9169178169546337`*^9}, {3.923569480064398*^9, 
   3.923569480065399*^9}, {3.932638067508316*^9, 3.932638068083014*^9}},
 CellID->1141848111,ExpressionUUID->"eaf32f88-81b3-4cf9-81ac-4ea83a740b36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "n_", "]"}], "=", 
  RowBox[{"InverseBilateralZTransform", "[", 
   RowBox[{
    RowBox[{"G", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4058606179375*^9, 3.40586062275*^9}, {
   3.603534826530225*^9, 3.603534827419424*^9}, {3.6043551213961506`*^9, 
   3.6043551236425505`*^9}, {3.6669087107001066`*^9, 
   3.6669087126812816`*^9}, {3.6669087439120812`*^9, 
   3.6669087453628626`*^9}, {3.6669090008095875`*^9, 3.666909010387865*^9}, 
   3.761351628601633*^9, {3.846701276911162*^9, 3.846701278496717*^9}, {
   3.8472358120135283`*^9, 3.847235814410926*^9}},
 CellID->1127331985,ExpressionUUID->"b78f795e-499e-47ed-b1e8-dfe215c1922d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "21"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["3", 
      RowBox[{"-", "n"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "14"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["3", 
         RowBox[{
          FractionBox["1", "2"], "+", "n"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "7"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}]}], ")"}], "n"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["3", "7"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}]}], ")"}], "n"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["3", 
         RowBox[{
          FractionBox["1", "2"], "+", "n"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "7"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}]}], ")"}], "n"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["3", "7"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SqrtBox["3"]}]}], ")"}]}], ")"}], "n"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"-", "n"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"UnitStep", "[", 
     RowBox[{"-", "n"}], "]"}]}], ")"}], " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{
  3.401451366859375*^9, 3.40447883584375*^9, 3.405860624203125*^9, 
   3.48948858453125*^9, 3.531763771310321*^9, 3.535157041138197*^9, {
   3.604355117121751*^9, 3.6043551246097503`*^9}, 3.6665701052440825`*^9, {
   3.666908725441918*^9, 3.6669087528663692`*^9}, 3.66690901155785*^9, 
   3.667059890045106*^9, 3.698591431486238*^9, 3.761351477834139*^9, 
   3.761351629390494*^9, {3.846701279365444*^9, 3.8467012893455195`*^9}, {
   3.847235807552091*^9, 3.847235815393659*^9}, 3.894485462190731*^9, 
   3.8975735282208786`*^9, 3.92965198885293*^9},
 CellID->542977811,ExpressionUUID->"43d4d586-2a2a-4370-a92c-d47ab27a8dbc"]
}, Open  ]],

Cell["This shows the sequence:", "Text",
 CellChangeTimes->{{3.4058605995*^9, 3.4058606044375*^9}, {3.405860638375*^9, 
  3.405860645234375*^9}, {3.604355300343751*^9, 3.604355311185751*^9}, {
  3.836857542027344*^9, 3.836857542397115*^9}},
 CellID->1967938061,ExpressionUUID->"7c04350f-9e3b-4aba-8dcb-d952b6d23222"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"g", "[", "n", "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["5", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["464", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`n, -5, 20}, Filling -> Axis, PlotRange -> 0.5, 
     PlotStyle -> PointSize[Medium], AxesLabel -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.40447885115625*^9, 3.404478863125*^9}, {
   3.40586067234375*^9, 3.405860685015625*^9}, {3.489488608640625*^9, 
   3.489488620796875*^9}, {3.5317646866540346`*^9, 3.531764717171503*^9}, {
   3.603534963701024*^9, 3.603534999113025*^9}, {3.604355162034151*^9, 
   3.604355209255351*^9}, {3.666570137566868*^9, 3.666570148939122*^9}, {
   3.7613515006018476`*^9, 3.761351532472752*^9}, {3.761351645468967*^9, 
   3.761351647816447*^9}, {3.792606810824448*^9, 3.792606822801283*^9}, 
   3.825544407785597*^9, {3.83685758143391*^9, 3.83685762737528*^9}, {
   3.8467012954609056`*^9, 3.8467013015352325`*^9}, {3.8472358226541176`*^9, 
   3.847235867259611*^9}, {3.892495880066886*^9, 3.892495885971515*^9}, {
   3.894485451100008*^9, 3.894485483268451*^9}},
 CellID->1739343780,ExpressionUUID->"7fd97636-bd67-41b8-9cad-110da5d49561"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
     AbsoluteThickness[2], 
     TagBox[{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWImKIYAkQMMKACdL0CAz0GAz0CA/2E/fr6Ew/0JOf8/
qa3eD+Ojyss4aCrpZ7fYr9oP46PKKzjMcLx8r8h+6n4YH1Vey0HEOvTMvRdx
+2F8VHkdB1umjffOBKfuh/FR5fUc/rt9S+j0D98P46PKGzh8dEvorNWT3g/j
o8qbOHx1kZLIamfdD+PDZAAonjKa
         "],
         VertexColors->None]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgBWImKIYBibZEIFphz4AVfLBPZJO129t10h7GR1PgsHsi
h1Ga9jWYuAOqNIeD6Jr24PMHrtjD+KjyAg5XHpVP+ZB81B7GR5UXceg7ut02
yGyiPYyPKq/kIH7z+FrN44X2MD6qvIpDKd9N24/vO+1hfFR5NYcYHvEItdIm
exgfVV7DQXGjlcSJu0n2MD6qvKFDmm+ny1pBR3sYH1XeyMFO8F6/u5iDPYyP
Km/sUDplSTb7U017GB8mAwCyEzkC
         "],
         VertexColors->None]}},
      Annotation[#, "Charting`Private`Tag$5854#1"]& ]}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[2], {}, PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEiBxhQgAAanwONz4DG/7AfTZ5Boi0RiFbYQ+Xt
E9lk7fZ2nYTyGRx2T+QwStO+BuVzOIiuaQ8+f+AKlC/gcOVR+ZQPyUehfBGH
vqPbbYPMJkL5Eg73J+T8/6S2GmqvjIOmkn52i/0qKF/BYYbj5XtF9lOhfCUH
8ZvH12oeL4TqV3Eo5btp+/F9J5Sv5hDDIx6hVtoE5Ws4KG60kjhxNwnK13IQ
sQ49c+9FHNQ8HQdbpo33zgSnQvl6Dv/dviV0+odD+QYOH90SOmv1pKF8Q4c0
306XtYKOUPOMHOwE7/W7izlA+cYOpVOWZLM/1YTyTRy+ukhJZLWz7gcAdqJc
jA==
       "]], {}},
     Annotation[#, "Charting`Private`Tag$5854#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox["n", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{-5, 20}, {-0.5, 0.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.894485471068386*^9, 3.894485484694051*^9}, 
   3.8975735289608665`*^9, 3.929651989469969*^9},
 CellID->753861776,ExpressionUUID->"a5242f64-3f13-4a86-9256-e84d218aa5eb"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ROC and the Inverse z-Transform", "Subsection",
 CellChangeTimes->{{3.835743018218447*^9, 3.835743019417491*^9}, {
  3.8357895205478067`*^9, 3.835789553503967*^9}, {3.846709029673673*^9, 
  3.846709029755415*^9}, {3.85298299643841*^9, 3.852983000218136*^9}, {
  3.9169134586304607`*^9, 3.9169134587620316`*^9}, {3.919430590003193*^9, 
  3.9194305902420044`*^9}},
 CellID->1603507496,ExpressionUUID->"1be40f24-64da-4f13-a2e9-4b0498cb4d77"],

Cell[TextData[{
 "The examples given thus far all assumed system causality and therefore an \
ROC that spans the exterior of a circle marked by the largest pole. While \
this may indeed be the most common case encountered in practice, it is \
important and interesting to consider alternative ROC specifications for a \
given z-transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "b36f9508-1e25-48af-9b44-2837129b9212"],
 " and the resulting sequences ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "[", "n", "]"}], TraditionalForm]],ExpressionUUID->
  "b85500ba-5341-4ae9-a237-72ef61218fda"],
 ". "
}], "Text",
 CellChangeTimes->{{3.835789115708738*^9, 3.835789183026046*^9}, {
   3.835789285701228*^9, 3.8357892928291807`*^9}, {3.8357893268408723`*^9, 
   3.8357893272120514`*^9}, {3.835789401043058*^9, 3.835789415260663*^9}, {
   3.8357894476302257`*^9, 3.83578948389071*^9}, {3.836911659034879*^9, 
   3.836911659315329*^9}, 3.838211909254182*^9, {3.847183097208243*^9, 
   3.847183105104272*^9}, {3.847183162949545*^9, 3.847183171924902*^9}, {
   3.8505102843790507`*^9, 3.850510285066571*^9}, {3.889052850347835*^9, 
   3.8890528699652767`*^9}, {3.9169134642854424`*^9, 3.916913464540834*^9}, {
   3.9194305961947384`*^9, 3.9194305994375*^9}},
 CellID->1378199069,ExpressionUUID->"fc2148e8-5a75-4396-9068-4e1d577a7ed3"],

Cell["This defines an example z-transform with two poles:", "Text",
 CellChangeTimes->{{3.835790174915765*^9, 3.835790209812875*^9}, {
  3.8472281726737237`*^9, 3.847228172818491*^9}, {3.8535864589583654`*^9, 
  3.853586464596328*^9}, {3.916913468704782*^9, 3.916913468890213*^9}, {
  3.919430608683073*^9, 3.9194306088899536`*^9}},
 CellID->633136141,ExpressionUUID->"0c8e062d-fbf2-4291-b9b0-37241bcb38c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "z_", "]"}], ":=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["4", "5"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.8147941597058473`*^9, 3.814794199446866*^9}, {
  3.847183217334572*^9, 3.847183217426193*^9}, {3.847183295214455*^9, 
  3.847183327109624*^9}, {3.84722857326285*^9, 3.8472285748434873`*^9}, {
  3.847229807868778*^9, 3.847229808110345*^9}},
 CellID->337650902,ExpressionUUID->"eae5db34-f3b6-45e3-9d6c-4b2078ad6022"],

Cell[TextData[{
 "The two poles are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "1"], "=", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "3f126249-0639-4ded-9b01-5d3fce311c4a"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "2"], "=", 
    FractionBox["4", "5"]}], TraditionalForm]],ExpressionUUID->
  "ed032b9e-5c43-4022-a57b-46a7db808199"],
 ", resulting in three possible ROCs, as shown here"
}], "Text",
 CellChangeTimes->{{3.835790258544539*^9, 3.8357903308078585`*^9}, {
  3.8369116758917913`*^9, 3.836911679548058*^9}, {3.847183338560975*^9, 
  3.8471833461423936`*^9}, {3.847228578541179*^9, 3.8472285805158663`*^9}, {
  3.847229799685727*^9, 3.8472298161685305`*^9}, {3.916917909483177*^9, 
  3.9169179096305523`*^9}},
 CellID->1246914540,ExpressionUUID->"0e5efc7f-8483-4fde-9d0a-9967cdba679e"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyFlk1IlFEUhsdZREZSaFEZkWGRi8p+HMifuplEBEJT0KbAoj+yjdHPQtdl
G8WCQcKFErUclMJFwdBFmEU6UROGJoqDNgYVhYQZQozZd+a5whk+CuLy3nPu
+77n3HPnc9vFptNXgoFAIL30/996qDDaMBp+a/euqdreUDdmK1a//pIO9Ttc
KNiAd0m+w6zw6BU+MHxg+MBlwmf8fGlevcIPhh8Mv1+d2qfm1Sv8YPj9+qbr
1j41r17h9+ubrlP7yuHx4nFb6e1P2p0e/uDWgPfvWYx4seQb8FbJM+SzD+8+
wTk68BL30yEORgddvWpdraN56Re69AvMSt7/zhHX86P3dV+oi/sEP1nVUV/W
995GC/LuP46NuH3OufnK4v61twaKh8Zthbc/6PKpm3ww+aWS7/rLnKDbJT6c
X/qNXzB+n8o5dy/ouXvK8pOn+d08Z+uIis8cHjD51EG+7iv14FP3ET36oudO
95E6iFMHOnoudd/0O8Q3PoijS5w60YcXffrq+pf1w6rrLPV4Xrn7gwcdPSfw
oKPvXc8f7xDMO4AHffpAvWD3e5nlxd+bvh/94e7hnO9EJjHTGOtMOR3w13Ud
xwt2TLh5mJd9907BnCNff/fiouv0uSdW4uhMC4+7L3Dl7Ycvw5mkPdFyZ0/d
pnG3sr9/tmZi0cRtzd3Po+kzS7+LFxoLIxvitu7auaHF85N2c2a2INIz4tbg
jfJUOtRlQ/k90dBcyrY0ediAV8p5w/kS4TfwFwmPgY96qfNbcsGUvfvo7pVz
+IQXnxUSN8Tx4edzt2BDHD58o4fvaokb4vimjk/i170PfOALHXThgffw5XuP
Wm8ufy+4T+YiLPGc7yd94r7Jh4985oQ+45Pz5KHDfHEf1Icuc4VPfHOed+D3
TtDDp55b+IjjU/8dgC/qwzd5xPGlv6v6HYK5V9ZyeSeGd1Mra867Io84mDy9
Dz44X3Lq59nl7zRzwXyPPai6HruaMskVwY3N7S/sge9FPeFMyv3dwVwx3+ub
E9ODiaU5m4o8D0Wijp/fO+aS+UaXPHjR4Zz2eUSwxdeU+HS/w9Vy3taLD7tF
fFl8geGHLyp8Bj720WUfXXTQhddPl/4Qhx8f8OOD/oM5B4/Oo6/0mXvkXvFN
vv5d0j4Xa5MDoblhm3/s6J/evDHbffLSr96ZCZvfXtzW2pJweKHNw4a833LO
nc+TfcNKHJ5O4THwgOFzPpSu48nmuXM+vOTjg3342EfvL0XHGds=
        "], {{
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[0.3], EdgeForm[None], 
           GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwNw4dWUgEAAFB57L333ns4UEEQIghEkBAQkEjBAYJp2lSz0vYy27tsl3u0
LJtmVjZsfEffkPecK0x31qaBgoKCf2vBayvMIhMAx8LgCABcaZU1R0J4BJKG
J7TGowo0MYMhkTFYChZHxeEtMAwOjrBa0Cm7is9kscgUNoWacNPSLk2ZjheR
Im0kRggBzpGZhWKgSAI2m2AAAl6u58OwGL+BXyxDI/C4KB4ZlxMyRDSGTMJS
yDgqBU+jKmkEu42eY5DILCaFzXKzqZsSaieTB8dhfXzW5qQ2KAQCIhggBjeF
JS0xqcvJNSqIJUpCqZq23qHxaNnVXh1fz2PyeUkfW1gIKIrR8hJCykhUltL0
ZTxDOb8haIKZ4CIzrMEMMleAGgMWtAUjs6IbrVBrJdRTpXV6uevs9DY70b5O
ZXPQ0w6GYz29Pe9sy9o2uLjtLoZrg4bmpnrcHLeHXeXhOGwMc4NJ5+XF6+Vs
H8vvE/j8/Bq/wF9j2BiAWgKwwEZRbRBkCgLBWmE4BEaEkJIwuDkMEReBvdXc
SJ00FkXiowRpDNkaQ0XjhPo4KhRBuhMcdYKW2MTxJQXaJDu5WRBsANVFIF4n
L9AIfXlPvXBG//qs4c0e4ath3bt94lyecX0SFW6CRJohsRYUOUfK55gPhjR3
TqqGH+t+vdJ1fy+9/cU48ql49bXhaVeJM890pDX5doa10eJqd7rSDGNKFW4O
zb9Uv+0o/NBZtHJC9ey58mC/6EKfcOmQ7NIEZPmo4tYR+dwT+ckV1dZe6LlV
Q6w1am+zxVtR2TaiLUvKZInZDOn0uHZLD+jqoBSTQS8OSI4tKz6PFPe9EQ7e
kO5flExcgXR+LDr+TDl5E7VrhvtnQd/xvtCeIo4/0vYegO59J+45Dxq4LDm8
JPs5Vt5/UfRjtGx6J+fQNdm328axv+VH5uSjv8tmdwtmdnAfzgpedJd2fS0Z
uq+5O83ZPkU/Na+e2kb/D5MFyKE=
              "]], 
             PolygonBox[{{148, 222, 82, 1}, {155, 214, 62, 38}, {136, 200, 51,
               40}, {127, 194, 50, 35}, {165, 216, 67, 44}, {180, 181, 52, 
              39}, {157, 228, 101, 37}, {131, 221, 80, 5}, {196, 128, 36, 
              50}, {153, 223, 86, 4}, {152, 227, 99, 36}, {202, 138, 41, 
              52}, {124, 191, 49, 33}, {183, 184, 54, 41}, {205, 141, 43, 
              54}, {193, 126, 35, 49}, {118, 218, 73, 28}, {117, 217, 70, 
              29}, {169, 219, 75, 46}, {164, 225, 92, 43}, {201, 137, 40, 
              53}, {198, 134, 38, 51}, {158, 224, 90, 10}, {224, 159, 39, 
              90}, {227, 151, 4, 99}, {223, 154, 37, 86}, {139, 204, 53, 
              42}, {225, 163, 28, 92}, {222, 149, 33, 82}, {145, 206, 55, 
              47}, {146, 207, 56, 48}, {226, 167, 32, 94}, {221, 132, 34, 
              80}, {220, 147, 48, 78}, {115, 215, 65, 23}, {219, 119, 29, 
              75}, {150, 213, 59, 34}, {212, 211, 47, 56}, {120, 220, 78, 
              32}, {210, 209, 46, 55}, {217, 166, 44, 70}, {215, 162, 42, 
              65}, {218, 143, 45, 73}, {216, 116, 23, 67}, {168, 226, 94, 
              45}, {214, 112, 5, 62}, {213, 109, 1, 59}, {228, 156, 10, 
              101}}]}]}, {}, {}, {}, {}}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          LineBox[{198, 134, 197, 133, 155, 214, 112, 122, 131, 221, 132, 125,
            150, 213, 109, 121, 148, 222, 149, 123, 190, 124, 191, 110, 193, 
           126, 192, 127, 194, 111, 196, 128, 195, 129, 152, 227, 151, 173, 
           153, 223, 154, 130, 157, 228, 156, 174, 158, 224, 159, 135, 179, 
           180, 181, 113, 202, 138, 182, 183, 184, 114, 205, 141, 185, 186, 
           164, 225, 163, 176, 118, 218, 143, 172, 168, 226, 167, 178, 120, 
           220, 147, 208, 189, 146, 207, 171, 212, 211, 188, 145, 206, 170, 
           210, 209, 187, 144, 169, 219, 119, 177, 117, 217, 166, 142, 165, 
           216, 116, 175, 115, 215, 162, 140, 203, 139, 204, 161, 201, 137, 
           199, 136, 200, 160, 198}]}}], {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         StyleBox["\"Re\"", Small, StripOnInput -> False], TraditionalForm], 
        FormBox[
         StyleBox["\"Im\"", Small, StripOnInput -> False], TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Epilog->{{
         RGBColor[1, 0, 0], 
         CircleBox[{0, 0}]}, {
         GrayLevel[0], 
         PointSize[Medium], 
         PointBox[
          NCache[{{
             Rational[1, 2], 0}, {
             Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 19.5048828125}, {0.5, 45.22767578125004}},
      ImageSize->Small,
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
        "AxesInFront" -> True},
      PlotLabel->FormBox[
        StyleBox[
         RowBox[{
           TemplateBox[{"z"}, "Abs"], "<", 
           FractionBox["1", "2"]}], Small, StripOnInput -> False], 
        TraditionalForm],
      PlotRange->NCache[{{
          Rational[-3, 2], 
          Rational[3, 2]}, {
          Rational[-3, 2], 
          Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{{{1, 
          FormBox["1", TraditionalForm]}}, {}}], {96.75, -94.5}, 
     ImageScaled[{0.5, 0.5}], {180, 180.}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1mWlsVVUQx0vBaJAGBUQoAiIEGiW4BFxwOQ2NIGV7+MEI6BNUTBFUDILi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        "], {{
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[0.3], EdgeForm[None], 
           GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXv819Mdx8/7Qzc/3dO9dNFNoaSoJZdCKStNN1FkRqTc5jojd1KkMFak
lpTNrSyXzZ0tG2NjG3ObZnOPXGJr2fu516tH/fHqfb7ncz7ncz7v1+t9+fzq
OHXmmBlVKaVF/rNd2l8k+if2SvRJRKJOYmJioMeritbW43cuqJ2Yn+MfJ8Yn
+iZq5dz2iXk5Xp+onWiQ+CzxaaJfYmGiZaJt4reJ2xKtEwMS9RNNEvslBvve
Vrnf5rSbEpckjk0MSjySuNHrH0vcnGiW+E6iJtEw8VTiyUTzxAGJndgvsX+i
UaJp4veJJT5Pi3xW88SKHF+ROCkxpMghG9PskhiRODTRAX/k/OdpD05sSHRK
dE0MTezs9cMTnRM9E9ckZiQOKfITPq2bOCjRPtGRM+V8k8Qyzpu2WWJ5jkcl
uiV2S5yWGO09z0yMSeyROCKxZwJuZya+6/PMM4dhnvuYm/nmE17hEw53MJ97
248DzUNtc7jePF2amGJfzkpMsu832fc15qmpfb2vOW5cxOc+nh9sDtnzJnMK
T1cnTrRvnjRvzC8u0ky7xIHmDT0tNY/4vW7oWex7S5E2WpjLjvb1MPPU2Xzu
4ns/N5ddzFNX87rR/mb9K+bg8MRc+xp+lpkfeGpi3nbH7yHnjyzSF9z1LuJ2
hbk7rEgruyZ+lPieearM6XbmoI+5HFfE1/bmrK99fmFign3976KYrm3b32Ou
97PPb0gcbT5a5nn+a+4XFcVqGz9voO99LvED+7DGnPP8i4ritoH3G2R+dwiN
ic2zrQM0cJTvRSvnJCaXrTE/2Gf7Q2JaUXydbD7g4vtF8YwmjrMO0MAxRXpE
c61DfLP+ysQJ2/A91Hw38vqGfg5a26IPxu38rkM819VngN+vzT+amJOYbv6+
SnxZFHsdirSFrs5LnOLfVxXlkQ7me7j3eblIB7t67UifE27H29/nFml3S04Z
7fXnJ07371OL9IgW0Rb5AR2iHXSFHN8syheV32eU3++CIm2hK3Q3tkh7f0/c
XbZqa4I5uq+oTtQxn+QB9IBejjSf8E/eRgMXF3GPz9Hc0eYBPqcWxTicTPEa
tIA2iOVHzTH8PlHEPbyTh6eZO7RwfFFegMMTzSOcn2Au/lWUX7jnLJ+T8/6m
SFutzDn5H/3MLtJfJ3M1vWzNG6eYI3QxYxtfzrQ/8fcP7fNPzNOW3HHaNhzC
HTnhWvMHd68V5fctHJ5hHj9OfORnTPQ7DPS5zvXZiMVz7D+0dp7Pe5rPMNo8
zDJv5AbyDhqBf+o6unu7SBPb208XmVPimFwzwFxdbL7g8xJzDleXmk94uNxc
oIXLivSAX6+x/4i1K+x7NH6leSMm5tj308wd3L5bFEsdzNVsc4T/5pqHNUV1
Dk1eX1QL4YJehd/o/y5fY36B16P5O4pyejfzc505+rnXsYZeaIH9c6/3p6bX
C9Uh6tlPimob2q4J5URq0lRfY/7WopxLvt3R19H2T4tqWAvvyT7kz/qhdQu9
J2uaei+e2dxrFvletP+zIv03DNVRdH570bid5xuE6mvjtI1ia01dYj+zjuvt
vWapz8zeS72W9+NMnOfP9iG6pbfBp939m/qItu/0mHl6sJVFOe2PvsY8vRDj
HonXzRl8vVpUQ+Flpces+ZN/Mx5rzuBrdVHfRd9DTr2nqN7BHbmMPHa/f9f1
Pausk5esCfRA/iMf9vP11V7/S4/r2T7geTS1xvMPeYwmJ/k3Yzh/zLzD4SPm
8VcekwMn+zdjtPCw9QD/j1oDrP217+U5D/q5j3v/ZrZP+Fnv+Foz30O/hY7Q
AmP680bWWltff8rz6xJP+76nPc8Y3T1bpD3mnvH6xUV5Fu2hI74B0NJaj1mD
jn5XpCvmnvOaGeYA/6NHevcOiec95mzksDeK8i5zL3jN8V7HGnL2i0X19f0i
naExtETORZN/LdIuOl3mMTn5wyJt9fDcXzx/hu9hPbqjlqPhv3lf9LnCY/an
JqBjNEzuoR6jsSrUZ9dKvFWUf8kt9ELULfLfZeasmXleZ5/j43/Yh+RmajY6
JV/+sygH44937ZMFfgb7o+v37Afi7AO/43v2UXfPfeh5ag81iD6H837mM5N3
P/Z13oUelG8GembqH/Wnn++pb3CdmoL+yR28V5tQD0cvTnzxvYR/6MPpvXp6
Df06df+LonEXX2ddL89xjR7yG1/r5XPTp1GjN3jcxfarbfbhHmp1K/fGO/q8
vBf98H885t25zvdPjee4Rt/d0PP0OXt7XY3nNnse3taau118fur4t16zoy2/
9/H++JfnIiK+MXrZT7Xsq0+9Zr39QJ+Er0b6Hp4zz/eQo6Z5Db5Ck7X8LU8f
wPchOhlkjpp6ro7n0VId/01go/fvZX9usJ/n+x5yHfmN+kgeG+AxeYycVi+2
Xq/nec5BTiY/k+tqXCO/QWOhPH5IvvTiUKyflPbZUM8xjfNW0v4J7FcpvxyZ
dmmoNk5NW79Szvoyx8NDOn0w7UOheN0vr88K1ZPL0g4L8Ts651eFegTqGN9+
xMsyj8kJ5E/q5Zb6Tm0mNy7075YeN/IacgXfiuSNJZ4nd5EbG7su8/1IXezh
5zT1c3vmeXpVim3imvll3rOZ1y/3mFw0NNdeH6otY9FOpbryIe8d/pbJuY9C
sdAmx6eH8mbzHO9UKT/tnLZ9pVjnvnt9b9ucOyOUN8enHVOpP70GX1bqYacT
95W0dyb3Ver79gn5F9/2y/FhleoA9aW+a9Kpob9l0efukbZ3pXz3cc6fH+qd
V4aewf6T8vqKUL+8Pu1BoW+dq9OOCMXXgblmTqjn/TrtoaHY7ZLzF4Ty+snw
VqkH7Za2e6XaMyDtfaE+dH7aKZV65BtzPL5SX0wNpb62sm3o8e55fVkoVx9O
XFeq35PTXhvqF95M+1boW4e9F4T2PyjHN4X668E5bhv6xns77W6Oi2E5v0eo
1/4sbTvruU7OTw59hw3JcddQjw9X40J8nZ32pVAf/H7aD0K5pG+u2atSrYCf
u0IcwcnMEC8jcrxnqK/vl+P+lerJ8LR3hPr3c0I6Q2MHp+0Z+sZDC/1Dejg3
badKdfeYtA+Eau/EHC8Kfb8dmuM+oW+Lu9O+4FxEPNFfUpfJwfy9g7xKvWae
+Oia914Y6h+O5XqlujqRPFep3k5Ie0uof19cxB29DDmWmkS+o4YSm8TZpLTP
hOr2aJ+DM9xm7sn55PZWPg/fP9S+jsRU2kGhPH9F2se9pm6e4WafgRiaHYqj
/YnB0DccWrshpLdRaTeH+tEN3r+T/cBzN3mujZ87Lu+9LvSNuHfa50M1cW5I
i+hwdYgD/M8ZL/U5jwhpCP10D+UXckunUFwRU8eFdIyGG+Xc8aH61yOkYzQM
n/UqcVpD3IR6zNtDOkbD6Je8jIYvCb0/7452GlTSz8KQnhh/Sz4J9enEBDXj
/3EBb6F8vjYU28Q1772X331KKE6Ikc6V3p93X8N+oW/1HpVqBvWC+LjHMbIu
7Tuh761HeW7ou5oaRv6nFhCvnzpm7wzlKXJUn0r1jFqGlgdYzy+mPSv0N4NH
0j4c+hvbG2lfD31TvpJ2cOjvfLVzn6NCvf5raV8NfV8ODeVBciD6usoa+yLt
56H/H/gETkPfXTNC8Uws8/yBlc7wVY43hr6LyKMvh3IptfTyUD29P5QfyY2t
0rau1ItvIr5D317LQzFM/JJ3rwzl3kGVcjr5/NZQzKON3qE8Qg4hJohP4mJJ
qMZT3y8K5UR8C1f7VuLrAPau1MvOC+kezf8PeMlwQQ==
              "]], PolygonBox[CompressedData["
1:eJwtlnfUz2UYxp/7mzppaypFZKXMhEh6VeqcUhmReON9rSZC2WVkZpSIoxIp
ySwliVLJVlYIKUKInJSGVPpc5/LH5/yu+/cdz/Pc81s8v2PDDllKaS4UgFMx
ciOlz9CLIbBLYhdEfwjH0XfBu+h34Av0i9AS/axAN+KZ43oXJHSD8LPzoTa6
BDyAfgpGoRvCAnRz6I/+BPqgd8JV6H/C+zs9eS8n4IPkPV3I+y+Gteh6sIhr
HeAOdA8og14I3dCFoA66LDyI7g6n8Gwz7I/RC+Eb7U17QE+AKei98Aa6PRRF
L4an0U2gPM//gT0bvQtGo++HRclrfI3eBGPRNeBudFOog+4LxdHHYA66KdyE
LgW5yc9oLd2ja1pzCfpqyEMPgM/RI8O+6wd/o/+C6snvzDL7QGf/CDaj7wvr
cXAF17ti19deoTd6PnRFb4Px6NO451P0D/Av9j0wD/0+/BeOkWKj/1qhz+D+
JcoN7Rn7MMxAfwuFudYJ+070UP2H3g6voidCBfRumKy9QS35g2e2oyvJp1oL
Ox+doz1h74JJyc+0RZ/L9RXolcmxUIwVW8VkS9gHOvt4uA19RD5BV5EP0fVg
ZvJ/W8M5oVx4GR5Cn8/71qC/TM6NPTAlOUdahGtItSOfDcVujH0CfRZci70j
fNYiUFq1Bs+oNqCq6ov7j6JLwXLsSvAIejCsQU+Dx9Aj4Gb0dfA4uqf2iD4z
s+93w2rs61UT6OGqWcVPOatcVE5of+G1VSOvoc/L7Ls9MBO7CPYG9AE4G12O
/y5BL4Mb0A3475jOBn9i/641k2tCuZCHvTQ5JxTr/PCzinltrt8IDZNzbhbX
LsfeiD4on2KvDOfK3uS1t4VjoT2sQL8ers0h8j/Pzg7vJfgdEa451Zp6zpvo
ytwzSLGEi9BVYF9yDymQ2YfynXqCYqMaV20rRquwK2L/iB4GS8M1otoYqBzl
WoXM79Y9F2Q+g/b+lXIgs4/lW/lkQbhGVBtPyoeZe+BO9PdQFrs0NELvSM61
9rA6OefuDdekalE9sX64R6s3q2cOQufw/JHkmNTEXgej0OVhI/qazGuN0Zmx
y2Req7fOrH6TeW/awwbsctjfoUfrjMo/7P3oqVAycw9R79gK89A9VUPoLlCd
6wfDuXcIqmWOuWL9E+xT7mTW01QPmXNQuac1NFsGYldNnjHKve7KweQcVG5X
D9eOcjwXe3C49gqfrK3p4VmhGlNtDgv3ZtXo/nBPVC+cnjybNMM0uzSjZmA/
AeuTa6o413pgb0FvhsuwD2gd9LrkXvFwOPbqGTWwc8Jn/xkKZe4J6gWK6aRw
j1FvaQu91F8z+041UiJzDBU7rbk2/E69a2RyL7g089rqCUXRteAwelNyb1PM
FWv1OM3y4dAseab/ij4Ks5J9PA7dPJzbeTA2PPM161tBk/BM1SzVTHsuPOM1
2/XO9eEert79vNYI71l77QTvobuFr3VWziv3w2evCxPCPVu9Wj3/7fCM12xX
D+wY7oHqfZopOmtd7F7JZ9Ys1czUrNRM1bfNK9A6+RunIPe3DM+SNnBLOMeV
25pZt+vZ8KzXN8kYdCPon/zNc2W4ZlQr1XTG8Ezuh24B7dCToR16lWKCfgse
la+Sa0M5pNxRjdREzw37RjW6LDwTNQvVs+aEe1yczDHNvjawPHkGVgvPCM0G
zfQu4ZxWLqundg7XmGpLPV25rBpW7Sqn1SuKhb/d1DM0S3UG7V0z9RC6WOZc
Us3pW+mlcC7om0m+eSF8dvmocngGafbozFPDPtDZNdO094lh3+sM5/Du1uHY
K0Z9wj1FvUTfAFXCPV+9Xt94FcMzUrNRPlZv6ovdOLlHqberZ6tXq8f/Fo6Z
YqUcHxLuEeoN+mb6hd9bw98CeodyqUY4N5VT/wM4MG69
              "]]}]}, {}, {}, {}, {}}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJwl08lvjVEYwOHPTRQbCzWUoFq0KNeYlLZaNU8J1UqIFsHC0Gg3NdSsKP4B
KtpYsLEwVk1BRUhIXHPtjCtTUVrDynNi8eT3vue7Sc8dmraqYtHGTlEUJciI
RdEuy3C9olfZSSvTeMoIz3ZrvvbXb0znKzP4zgAKPN+jM3lGln0ke803mUUN
U5wN1Fuk8Ye//GYuBynzmlpt5hAl9sM6j+e8CPdhKHfC/cNdvOaILuMuR0ly
VqqdtUyPh/uZs7S7rtZXvOYNo8I9nZ/QtfQwr9NkPan32UCKvVL7aEV4T4yn
r70fH8wfOUup/YwmmESRfYsO0s+aGj4Pcplqn8hC80XdzBNyw3t1tkOH6Ha9
TBOT7Xl8MW9jsLlRV+olrQ6fs3mrpmuOPmYTOfYL4V56Xh+Fv28u1Gz9pFWc
Y4E9Wx8ygfn201pOT3NvejGOB85G6xjinLKP1fV6jzjvecdb1tDAUq+p1266
Qrvocu2qdbpEj+lLWlhMzFmmXuda+K2E366zDL0dvlNzh/6inTkcoNB5quax
j2L7fp1NGz/5Eb4nbpDp+bDY//+Zf++FXxc=
           "]], LineBox[CompressedData["
1:eJwl0ckuZGEYgOFTWBmCNRaGhYjE2HYiEQuzVqJMiSlpVohh4xrM48ZCkHS3
4A6sRELCBRh3pntA6+ePxZP3+86pc1L1V/7oVHwyFkXRPH2GlKQo2tE0HdZU
HdF03dUs/aWZOqZ7NJrL9IJymuy/dYI/NNsr9IoftNmPdJoXquzVHJtzdEZf
w2fNNZyYc3VW38gzz2l7uK/X/GXAfqinhB/VYq/US/bptx/oM0+Mk+1aqT7y
wD2jZLheonfcchOeZ5se97b0nA2G7JvaxRoJ+6qescygfUXj4aDNnRrTIv3i
J5908I9CPsI58U4ri3R7ZkFrKaDevhTOIXyn8H57QusopsG+rr0kJ33/v/8B
Xtg39g==
           "]]}}], {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         StyleBox["\"Re\"", Small, StripOnInput -> False], TraditionalForm], 
        FormBox[
         StyleBox["\"Im\"", Small, StripOnInput -> False], TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Epilog->{{
         RGBColor[1, 0, 0], 
         CircleBox[{0, 0}]}, {
         GrayLevel[0], 
         PointSize[Medium], 
         PointBox[
          NCache[{{
             Rational[1, 2], 0}, {
             Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 19.5048828125}, {0.5, 45.22767578125004}},
      ImageSize->Small,
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
        "AxesInFront" -> True},
      PlotLabel->FormBox[
        StyleBox[
         RowBox[{
           FractionBox["1", "2"], "<", 
           TemplateBox[{"z"}, "Abs"], "<", 
           FractionBox["4", "5"]}], Small, StripOnInput -> False], 
        TraditionalForm],
      PlotRange->NCache[{{
          Rational[-3, 2], 
          Rational[3, 2]}, {
          Rational[-3, 2], 
          Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{{{1, 
          FormBox["1", TraditionalForm]}}, {}}], {290.25, -94.5}, 
     ImageScaled[{0.5, 0.5}], {180, 180.}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyF2H+s11Udx3F0bS0W6FjLQWuWWt0Va1rcDVvts0Y0Vo7IxYatMWVaDtpo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        "], {{
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[0.3], EdgeForm[None], 
           GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx9/7jrHvhrFUZElTlrKlLEnIWvaKERVJaCGhSLYR2ZKxZ2wj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              "]], PolygonBox[CompressedData["
1:eJwtlPlPz3Ecx7/vl5zD5r5mFnMz59xnZYlqSuSIVHKklJCiSFHO5AhT5GzM
GD/YjB/9C/wJjh+MNsfGDI/nXp8fHvs8Xt/P8X2/368jPr80c6/FYrECiIPe
BBXQEGKxRpiK34eHeAp0wcfDRrwGPsM94g6uDbyfg2+GYuIS+Ah39A3F3B+D
34a7xImQj+dBKV4GX+EB8WOubTy/FH8Ob4izYCb+FF7qOe6/59pO3M51E3EW
PgwyidfDB9hNfJjrZu6fxIfDWuKLMA0/ZL7XVu434iPM/2s7xOElcAyvhUFy
aMJf83wKPlF7Jt4B+/EesBLfAl3xMqjD62G2zkp7wFOhGz4FcvATkIb3hzQ8
V2vEm83PagPMwS/DNfw6LMYfwbPge07EE2A5ng2/4JPOBgphl/mZ6ayquHZq
nea56uC3VLynea63wjJ9C9Ypl9xfgp+CSzpb4iR8hflek4P/dxO0BF/DOPM1
6L9VMxnE8yBfa4GF+A2Bv+V7a/DveAHsDH4WV833qjP5GX1D7yqH34K/o2fz
YACeDtvwdDA82fzskmCocm+e2wyYbJ5D5U45UO330R6D98Ak8xwqd8rxfPOa
Va1qD0XmPaFeqFZO8D/RXsq1B+J/wc+6Ev6qTsxzkwB1+HHzWlIP5Grt5rlf
DXvUS+bfLuaZbPOaUa0UwW/Vhbk3cr8XftA8d6tggnkN10Y1UIqr4dWrquly
fJ95b6pGp+NP4EXwGq407zn1ms6kyrxH1Zung/fCYLgQvCdq8KNwFn/FM9X4
QDgX/Ld6rR0O4O+4X2tRzoJ/YxR+xrx3VXPn9a753q8Qx+vb5q4aO4L3M+8l
5Vz/Nde8FvSfI/FCqAheszHznCgXmglD8ALzXDWr581nhGaD1qhZ1td8r5pp
C8zfaY5qVL3cGfWOerrVvMZUW63Ba3uRRR58Vo02z71m1i3zHlNvtQVf601z
15o1KzXDNLs0MzVLx5rXsmaqZm93897TDNbsnGGee81QzYYf0VlrRmiWf4lq
RTNds3SWea1ppir3momahaqBFp21eS41czSLNQPU+5rJ/wG+mLUj
              "]]}]}, {}, {}, {}, {}}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJwt0DlOQgEUBdCPDKIiCGqipR0mqODAoEwbMFGWQLDFRnrosYVWW2ixxx53
IHvAHXBILE5yq3dz31n7tdUNBUHwyBabfMw5NZ55oceAd8Z8MuWLb35Y8kfU
kVMuuOSKPAWuueGWO4qUKFPhngeq1KjToEmOEyKs9PyyYM6MCR+MGNLnjQ5P
VMlyxCEZ0hyQIsk+CfbYZYc428Q224gQ/v/XGso+GMI=
           "]], LineBox[CompressedData["
1:eJwl09VWlVEUgNGfI4rdYgd2d2CCAahggCgGFoqFgmBhKyYmFmIHio36Ir6F
BdiKHXMML+b49ll77f/uRGXkpGSHBUHwjKhQEBzlOMeI57XLLF3LGmrQgwd0
57v7V9x07kk468ghm9NMpcpOqUYwiTjemG3Q2sxjPgN5xAC2UJ/NNCCfwZQz
hEYsYjFL+OB707QpxQznDOc4ywzOs5Nd7KA5I7jDJ+9n6me9q6NoyTJK+GV+
QVMYzUXGcIlWzOKrnUPaloO0I4anjOMw7cnkCleJZTwdKKQjR/jmW6namrHc
44vZby4772M/yzlAG+5T7T5Zo3nMSDJYSgF7+WjnJy2cdxPJHpoxnWFspwnb
aMxQynjv3UJNZwEN2co789s6iHpspC6b6E8SdejHLd7aT9RK/cFc5zRq0ZeH
9GEKvXhCb2qynjxyqfB2sr7UG9qNEAl05RRFzCGMLlznhf3VGrCSv36v0ud6
TTtzktn8MVuhnZjIBE6E/v9n/gF4NFsz
           "]]}}], {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
         StyleBox["\"Re\"", Small, StripOnInput -> False], TraditionalForm], 
        FormBox[
         StyleBox["\"Im\"", Small, StripOnInput -> False], TraditionalForm]},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Epilog->{{
         RGBColor[1, 0, 0], 
         CircleBox[{0, 0}]}, {
         GrayLevel[0], 
         PointSize[Medium], 
         PointBox[
          NCache[{{
             Rational[1, 2], 0}, {
             Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0.5, 19.5048828125}, {0.5, 45.22767578125004}},
      ImageSize->Small,
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
        "AxesInFront" -> True},
      PlotLabel->FormBox[
        StyleBox[
         RowBox[{
           TemplateBox[{"z"}, "Abs"], ">", 
           FractionBox["4", "5"]}], Small, StripOnInput -> False], 
        TraditionalForm],
      PlotRange->NCache[{{
          Rational[-3, 2], 
          Rational[3, 2]}, {
          Rational[-3, 2], 
          Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{{{1, 
          FormBox["1", TraditionalForm]}}, {}}], {483.75, -94.5}, 
     ImageScaled[{0.5, 0.5}], {180, 180.}]}, {}},
  ImageSize->{
    UpTo[540], 
    UpTo[180]},
  PlotRange->{{0, 580.5}, {-189., 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.846767872693953*^9, 3.8472283929555244`*^9, 3.847228423090192*^9, {
   3.847228453884222*^9, 3.84722852018682*^9}, 3.8472286156176023`*^9},
 CellID->1747246354,ExpressionUUID->"7c9cf3d2-aa7a-4856-b84e-11083c697c80"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 4", "Subsection",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
  3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
  3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
  3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
  3.591922479275842*^9}, {3.655396306074999*^9, 3.655396310598941*^9}, {
  3.6555054648020253`*^9, 3.655505465270019*^9}, {3.688420122502099*^9, 
  3.6884201234600987`*^9}, {3.782091268773879*^9, 3.782091268905491*^9}, {
  3.782121413968338*^9, 3.78212141405696*^9}, {3.8472309242051463`*^9, 
  3.8472309242915554`*^9}, {3.847230960476324*^9, 3.847230960571143*^9}},
 CellID->1278082600,ExpressionUUID->"9707bf36-9f12-4c76-b1c4-c6385c70bdf4"],

Cell["\<\
Obtain the inverse z-transform given the following specification\
\>", "Text",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
   3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
   3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
   3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
   3.591922479275842*^9}, 3.655396306074999*^9, {3.814794187905379*^9, 
   3.81479418936787*^9}, 3.836912362767934*^9, {3.8505106024751644`*^9, 
   3.8505106099479055`*^9}, 3.852983024135757*^9, {3.916913473223137*^9, 
   3.916913473445879*^9}, 3.916918078426016*^9, {3.919430615790077*^9, 
   3.919430615984197*^9}, 3.9194350104519997`*^9},
 CellID->1602820906,ExpressionUUID->"a096f032-6ea6-40b1-bca1-8854d82b35ae"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["4", "5"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]]}], TraditionalForm]],
  ExpressionUUID->"f31ea0e0-f76c-480c-9e6e-f8630916ec56"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], ">", 
    FractionBox["4", "5"]}], TraditionalForm]],ExpressionUUID->
  "fcc67fa1-96d9-45b7-86ba-ffea09a103c1"]
}], "Text",
 CellChangeTimes->{{3.5917409389363613`*^9, 3.5917410053612776`*^9}, 
   3.782085558076461*^9, {3.814794176773161*^9, 3.814794184315883*^9}, {
   3.835791336938426*^9, 3.835791366362398*^9}, {3.847228664702566*^9, 
   3.847228712638552*^9}, {3.847229158968726*^9, 3.8472291741306667`*^9}, {
   3.8472293973818207`*^9, 3.847229401109679*^9}, {3.847229718647982*^9, 
   3.847229718940446*^9}, {3.847229857662145*^9, 3.847229861287423*^9}, {
   3.8504987128359003`*^9, 3.850498712941703*^9}, 3.852983028950531*^9, {
   3.920108880467997*^9, 3.920108881500637*^9}},
 CellID->576099174,ExpressionUUID->"45d3a362-fe3b-4fa6-b537-7492a99a0cc8"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.591720240155363*^9, 3.591720243875363*^9}, {
  3.591741025313713*^9, 3.591741092643431*^9}, {3.591741122969884*^9, 
  3.59174112612212*^9}, {3.655396319180831*^9, 3.6553963221779943`*^9}},
 CellID->1642536742,ExpressionUUID->"69a4fee3-f6d5-477b-b38f-f5b3acab130a"],

Cell["Using the same approach as in Example 1 gives:", "Text",
 CellChangeTimes->{{3.835729289033542*^9, 3.835729303834452*^9}},
 CellID->212740609,ExpressionUUID->"01baf677-b221-46f6-a33a-3020ab8ff538"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "n_", "]"}], "=", 
  RowBox[{
   RowBox[{"InverseBilateralZTransform", "[", 
    RowBox[{
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", 
       RowBox[{
        RowBox[{"Abs", "[", "z", "]"}], ">", 
        FractionBox["4", "5"]}]}], "]"}], ",", "z", ",", "n"}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.782434893637779*^9, 3.782434919877004*^9}, {
  3.835728953280023*^9, 3.835728960091308*^9}, {3.835728993259104*^9, 
  3.835729042197328*^9}, {3.835729322916952*^9, 3.835729325303783*^9}, {
  3.8472291817333007`*^9, 3.847229249006349*^9}, {3.8472294566894836`*^9, 
  3.8472294599444666`*^9}, {3.8472296748727875`*^9, 3.8472296898063498`*^9}, {
  3.8472298638909435`*^9, 3.847229868854487*^9}, {3.8472339216134424`*^9, 
  3.847233921899381*^9}},
 CellID->2118626855,ExpressionUUID->"f4630743-75fc-4782-a494-38e290d4a80b"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{
         FractionBox["1", "3"], " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "n"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"3", "+", 
             RowBox[{"3", " ", "n"}]}]], "-", 
           SuperscriptBox["5", 
            RowBox[{"1", "+", "n"}]]}], ")"}]}], 
        RowBox[{"n", "\[GreaterEqual]", "0"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{
  3.835729328504025*^9, {3.84722923915488*^9, 3.847229250588333*^9}, {
   3.847229453036516*^9, 3.847229460476754*^9}, {3.847229679080551*^9, 
   3.847229691772477*^9}, 3.8472298693018274`*^9, 3.8472338927338705`*^9, 
   3.847233924908288*^9, {3.894485503358763*^9, 3.894485514800317*^9}, 
   3.894485644662953*^9, 3.897573538768453*^9, 3.9296519988021603`*^9},
 CellID->344981843,ExpressionUUID->"01e5092e-c842-4442-a11a-f6e476bd4192"]
}, Open  ]],

Cell["This shows the resulting sequence:", "Text",
 CellChangeTimes->{{3.7824349941166453`*^9, 3.782435002290396*^9}, {
  3.847229531988667*^9, 3.8472295371557045`*^9}},
 CellID->335201078,ExpressionUUID->"8c670ee0-a54d-48f1-b32c-2fe1114760b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["472", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`n, -5, 15}, PlotRange -> {-1, 2}, PlotStyle -> 
     PointSize[Medium], AxesLabel -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.7824349863745604`*^9, 3.782435055693524*^9}, {
   3.8147942376486597`*^9, 3.814794284802774*^9}, {3.847228839862235*^9, 
   3.847228947311513*^9}, 3.847229088291212*^9, {3.8472292940302873`*^9, 
   3.847229303974963*^9}, {3.847229336379531*^9, 3.8472293437266026`*^9}, {
   3.847229478902161*^9, 3.847229481398406*^9}, {3.847229702477152*^9, 
   3.8472297038354053`*^9}, {3.84722988487033*^9, 3.847229886799213*^9}, 
   3.8472338904620805`*^9, {3.8924959061972923`*^9, 3.89249591493827*^9}, {
   3.8944855179411917`*^9, 3.8944855379956837`*^9}, {3.8944856321649537`*^9, 
   3.8944856584346533`*^9}},
 CellID->874911865,ExpressionUUID->"cf036e49-07ae-4a61-b706-5e603236fc0e"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
     AbsoluteThickness[2], 
     TagBox[{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], 
        LineBox[{{{-5., 0.}, {-5., 0}}, {{-4., 0.}, {-4., 0}}, {{-3., 
           0.}, {-3., 0}}, {{-2., 0.}, {-2., 0}}, {{-1., 0.}, {-1., 0}}},
         VertexColors->None]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], 
        LineBox[{{{0., 1.}, {0., 0}}, {{1., 1.3}, {1., 0}}, {{2., 1.29}, {
           2., 0}}, {{3., 1.157}, {3., 0}}, {{4., 0.9881}, {4., 0}}, {{5., 
           0.82173}, {5., 0}}, {{6., 0.673009}, {6., 0}}, {{7., 0.5462197}, {
           7., 0}}, {{8., 0.44088201}, {8., 0}}, {{9., 0.354658733}, {
           9., 0}}, {{10., 0.2847035489}, {10., 0}}, {{11., 0.22825112037}, {
           11., 0}}, {{12., 0.182845036921}, {12., 0}}, {{13., 
           0.1463980998493}, {13., 0}}, {{14., 0.11717951503569}, {
           14., 0}}, {{15., 0.093774129606677}, {15., 0}}},
         VertexColors->None]}},
      Annotation[#, "Charting`Private`Tag$5915#1"]& ]}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[2], {}, PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEiBxhQgAAanwONz4DG/7CfASv4YA+jz54BgS9Q
PoPDkgJbruuLYXwOh4De6XlCzZ+gfAGHZ+tUnzTPew/lizi87m7ZNsf7FZQv
4bDHZq62V+dTKF/GweBU7Z6FVQ+hfAUHX4Fpupnmd6B8JYfC4ntduzZdg/JV
HNQ1n1pPtbgE5as5FN1eqBNqfhbK13A4+Oh5WHn6cShfy4HRv81VZ+8hKF/H
4fyTaxxV//dC+XoORbL3L09h3GEPANpFTNU=
       "]], {}},
     Annotation[#, "Charting`Private`Tag$5915#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox["n", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Small,
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{-5., 15.}, {-1., 2.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.782435050240145*^9, 3.782435056367252*^9}, {
   3.814794261590398*^9, 3.8147942869408865`*^9}, 3.835729192082477*^9, {
   3.8472288743991747`*^9, 3.8472289477436376`*^9}, {3.8472290815119996`*^9, 
   3.847229089109644*^9}, {3.847229268275045*^9, 3.847229304477708*^9}, {
   3.847229337036609*^9, 3.84722934424139*^9}, {3.8472294635393887`*^9, 
   3.8472294818152914`*^9}, {3.847229681180337*^9, 3.847229704343757*^9}, {
   3.84722987126116*^9, 3.847229887252857*^9}, 3.847233894454195*^9, {
   3.894485531115703*^9, 3.894485540210623*^9}, {3.894485641146585*^9, 
   3.8944856600011263`*^9}, 3.897573540892354*^9, 3.9296520019250755`*^9},
 CellID->131238335,ExpressionUUID->"c596a80f-bc5e-437f-85ba-a3a447878549"]
}, Open  ]],

Cell["\<\
The result is a bounded and causal (or right-sided) sequence.\
\>", "Text",
 CellChangeTimes->{{3.8357914823600235`*^9, 3.835791487042556*^9}, {
  3.835791520561558*^9, 3.8357915708360195`*^9}, {3.846108632756357*^9, 
  3.846108633251234*^9}, {3.847229429810448*^9, 3.847229446063701*^9}, {
  3.88905293139497*^9, 3.889052933958144*^9}, {3.916918094797588*^9, 
  3.916918097712492*^9}},
 CellID->823184046,ExpressionUUID->"4122ad64-40a0-4cc0-bcf4-2bd6655c34d9"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Step-by-step",
 FontSlant->"Italic"]], "Subsubsubsubsection",
 CellID->1164607148,ExpressionUUID->"eb382cd2-014b-4475-8e54-6e8b63cdfdec"],

Cell[TextData[{
 "Partial fraction expansion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "ab62b794-e4d8-42f8-9441-81b5d98d78a9"]
}], "Text",
 CellChangeTimes->{{3.591720240155363*^9, 3.591720243875363*^9}, {
   3.591741025313713*^9, 3.591741092643431*^9}, {3.591741122969884*^9, 
   3.59174112612212*^9}, {3.655396319180831*^9, 3.6553963221779943`*^9}, {
   3.6566846858649426`*^9, 3.656684686161339*^9}, {3.814794372277813*^9, 
   3.8147943782523127`*^9}, {3.847230294159915*^9, 3.8472302963894415`*^9}, 
   3.916918102431919*^9},
 CellID->1386377678,ExpressionUUID->"d523a256-0598-4a44-8ef7-5ab412f4b5c1"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"X", "(", "z", ")"}], "z"], "=", 
    RowBox[{
     FractionBox["z", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["1", "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox["4", "5"]}], ")"}]}]], "=", 
     RowBox[{
      FractionBox["A", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}]], "+", 
      FractionBox["B", 
       RowBox[{"z", "-", 
        FractionBox["4", "5"]}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "e2dc9496-7086-4e03-8e02-79e2d7b0ba38"]
}], "Text",
 CellChangeTimes->{
  3.4044787625*^9, {3.413207774140625*^9, 3.413207776375*^9}, {
   3.591553656596655*^9, 3.5915536702622786`*^9}, {3.591554325863833*^9, 
   3.59155432926464*^9}, {3.591720732435363*^9, 3.591720780705144*^9}, {
   3.591740757679643*^9, 3.5917407581788435`*^9}, {3.591741142143349*^9, 
   3.5917411754208364`*^9}, {3.591741381182702*^9, 3.591741422600775*^9}, {
   3.658535707895876*^9, 3.658535707895876*^9}, {3.847230305167622*^9, 
   3.847230354695143*^9}, {3.852983044416109*^9, 3.852983044416171*^9}},
 CellID->652064196,ExpressionUUID->"da20f5ca-b2fb-4d72-aec9-3433595b615b"],

Cell[TextData[{
 "The values of ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]],ExpressionUUID->
  "2d01a103-112a-4cf2-812a-02bce06a2434"],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],ExpressionUUID->
  "638b02a1-836c-4759-8e97-236a7706ee20"],
 " can be quickly obtained using the method of residues:"
}], "Text",
 CellChangeTimes->{{3.658535451086469*^9, 3.658535514869469*^9}},
 CellID->633891531,ExpressionUUID->"d7dbefd9-4306-4173-8ecd-5d6f3646ed67"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", "-", 
      FractionBox["1", "2"]}], ")"}], 
    FractionBox[
     RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
   RowBox[{"z", "->", 
    FractionBox["1", "2"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7826879052367887`*^9, 3.782687925522904*^9}, {
  3.8357430425400906`*^9, 3.8357430907842407`*^9}, {3.8472303748540688`*^9, 
  3.847230394036857*^9}},
 CellID->148588750,ExpressionUUID->"b550414c-1809-4a0e-b575-01187e368cd3"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["5", "3"]}]], "Output",
 CellChangeTimes->{
  3.7826879262796807`*^9, {3.835743076000636*^9, 3.8357430912236786`*^9}, 
   3.847230394948756*^9, 3.8975735448830194`*^9, 3.929652005796097*^9},
 CellID->247839065,ExpressionUUID->"3a224037-c4e6-457b-b1c5-1dcab2f89286"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", "-", 
      FractionBox["4", "5"]}], ")"}], 
    FractionBox[
     RowBox[{"X", "[", "z", "]"}], "z"]}], ",", 
   RowBox[{"z", "->", 
    FractionBox["4", "5"]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7826879052367887`*^9, 3.782687931316459*^9}, {
  3.835743109318616*^9, 3.835743131561098*^9}, {3.847230400090673*^9, 
  3.8472304161151357`*^9}},
 CellID->1955123436,ExpressionUUID->"a79ba079-23b1-4bf6-8a4f-a2842c3b5bec"],

Cell[BoxData[
 FractionBox["8", "3"]], "Output",
 CellChangeTimes->{3.782687931863185*^9, 3.8357431327717867`*^9, 
  3.8472304168082*^9, 3.897573546200537*^9, 3.9296520072286644`*^9},
 CellID->29780168,ExpressionUUID->"070be13c-4845-403d-a6c6-c868015a3a67"]
}, Open  ]],

Cell["This gives the partial expansion as", "Text",
 CellChangeTimes->{{3.658535715134183*^9, 3.658535728206816*^9}, 
   3.916918109945965*^9},
 CellID->1112306105,ExpressionUUID->"f3866127-cb6d-4236-8409-c066a77f192c"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["5", "3"]}], " ", 
      FractionBox["z", 
       RowBox[{"z", "-", 
        FractionBox["1", "2"]}]]}], "+", 
     RowBox[{
      FractionBox["8", "3"], " ", 
      FractionBox["z", 
       RowBox[{"z", "-", 
        FractionBox["4", "5"]}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "0ef326fe-acc8-4e8e-b99c-ad33c491b3e4"]
}], "Text",
 CellChangeTimes->{{3.658535733198751*^9, 3.658535753603289*^9}, {
  3.836911717108116*^9, 3.836911717853304*^9}, {3.847230424391568*^9, 
  3.847230465987689*^9}},
 CellID->683559600,ExpressionUUID->"3325963e-8c28-4303-8434-777e70f50b3d"],

Cell["\<\
Each of the terms in the decomposition may be inverted by table lookup or \
evaluated as shown here:\
\>", "Text",
 CellChangeTimes->{{3.4051805174375*^9, 3.405180519109375*^9}, {
   3.604350917667751*^9, 3.604350985246951*^9}, {3.604351099407751*^9, 
   3.604351111762951*^9}, 3.666481701099156*^9, {3.666566662087426*^9, 
   3.666566680947584*^9}, {3.666567137023337*^9, 3.666567137850127*^9}, {
   3.825513714583801*^9, 3.825513715998133*^9}, {3.825544223082829*^9, 
   3.8255442480836897`*^9}, 3.838471969658684*^9},
 CellID->1696169397,ExpressionUUID->"47f7ea6c-ed60-4584-a46f-e18d16c0c258"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["5", "3"]}], " ", 
    FractionBox["z", 
     RowBox[{"z", "-", 
      FractionBox["1", "2"]}]]}], ",", "z", ",", "n"}], "]"}]], "Input",
 CellChangeTimes->{{3.8472306170881796`*^9, 3.847230651454867*^9}},
 CellID->1821125101,ExpressionUUID->"f2312893-4dd9-4d76-8d25-2f4a129dcb17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["5", "3"]}], " ", 
  SuperscriptBox["2", 
   RowBox[{"-", "n"}]], " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{3.847230652171616*^9, 3.897573549203816*^9, 
  3.9296520102366047`*^9},
 CellID->61088352,ExpressionUUID->"2e2eddf9-2a98-4c44-aad6-f178efe4686a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseBilateralZTransform", "[", 
  RowBox[{
   RowBox[{
    FractionBox["8", "3"], " ", 
    FractionBox["z", 
     RowBox[{"z", "-", 
      FractionBox["4", "5"]}]]}], ",", "z", ",", "n"}], "]"}]], "Input",
 CellChangeTimes->{{3.8472306170881796`*^9, 3.847230651454867*^9}, {
  3.847230744834196*^9, 3.847230754105839*^9}},
 CellID->1712635463,ExpressionUUID->"9458d775-cbe7-44f2-a55f-029059cdefd5"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  SuperscriptBox["2", 
   RowBox[{"3", "+", 
    RowBox[{"2", " ", "n"}]}]], " ", 
  SuperscriptBox["5", 
   RowBox[{"-", "n"}]], " ", 
  RowBox[{"UnitStep", "[", "n", "]"}]}]], "Output",
 CellChangeTimes->{3.847230755509495*^9, 3.897573552214009*^9, 
  3.929652011677683*^9},
 CellID->133765948,ExpressionUUID->"7bc1e392-00b6-4b8b-949c-f5fc6db455af"]
}, Open  ]],

Cell["\<\
The result is the following sequence given the z-transform and ROC\
\>", "Text",
 CellChangeTimes->{{3.59174267975433*^9, 3.591742712217987*^9}, {
   3.591742801169344*^9, 3.5917428254273863`*^9}, {3.65550554790216*^9, 
   3.655505576480994*^9}, {3.836911788700611*^9, 3.836911805597775*^9}, {
   3.847230776864975*^9, 3.8472307847387857`*^9}, 3.852983058555006*^9, {
   3.916913477178335*^9, 3.916913477325823*^9}, 3.916918119399994*^9, {
   3.919430624211349*^9, 3.919430624363548*^9}, 3.919435077352602*^9},
 CellID->1540905900,ExpressionUUID->"f8c1824c-723c-4ebd-abef-ce6207a1ca46"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["5", "3"]}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "2"], ")"}], "n"]}], "+", 
       RowBox[{
        FractionBox["8", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["4", "5"], ")"}], "n"]}]}], ")"}], 
     RowBox[{"u", "[", "n", "]"}]}]}], TraditionalForm]],ExpressionUUID->
  "21bf2582-d6e5-4105-ae6a-16d061f2dced"]
}], "Text",
 CellChangeTimes->{{3.591742830902996*^9, 3.591742869887464*^9}, {
  3.782085482613924*^9, 3.782085525212817*^9}, {3.847230804949493*^9, 
  3.847230886929096*^9}},
 CellID->1500162127,ExpressionUUID->"5cf4c8dd-e28d-4249-b806-aa1047d08b7a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 5", "Subsection",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
  3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
  3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
  3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
  3.591922479275842*^9}, {3.655396306074999*^9, 3.655396310598941*^9}, {
  3.6555054648020253`*^9, 3.655505465270019*^9}, {3.78209124315571*^9, 
  3.782091243295292*^9}, {3.782121402850355*^9, 3.782121402915711*^9}, {
  3.847230928525195*^9, 3.847230928611808*^9}, {3.847230964845201*^9, 
  3.847230964935234*^9}},
 CellID->1766852709,ExpressionUUID->"08bb878c-8d2e-4722-b35c-e988c2e0cde8"],

Cell["\<\
Obtain the inverse z-transform given the following transform specification\
\>", "Text",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
   3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
   3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
   3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
   3.591922479275842*^9}, 3.655396306074999*^9, {3.814794187905379*^9, 
   3.81479418936787*^9}, 3.836912362767934*^9, {3.850510134364409*^9, 
   3.8505101426708975`*^9}, 3.852983066135917*^9, {3.916913481627716*^9, 
   3.916913481759201*^9}, 3.916918124397903*^9, {3.919430630666254*^9, 
   3.919430630983862*^9}, 3.9194350553694053`*^9},
 CellID->89609447,ExpressionUUID->"ce429f73-0578-4109-943e-28e03288e2de"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["4", "5"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]]}], TraditionalForm]],
  ExpressionUUID->"811ebab3-571a-41e7-99bc-c2645cfe2e66"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "7ef92ead-4e47-4d28-be72-68c3f51b575c"]
}], "Text",
 CellChangeTimes->{{3.5917409389363613`*^9, 3.5917410053612776`*^9}, 
   3.782085558076461*^9, {3.814794176773161*^9, 3.814794184315883*^9}, {
   3.835791336938426*^9, 3.835791366362398*^9}, {3.847228664702566*^9, 
   3.847228712638552*^9}, {3.847229772212085*^9, 3.847229772466467*^9}, {
   3.8472299228822*^9, 3.8472299258370275`*^9}, {3.850498702046976*^9, 
   3.8504987021163254`*^9}, 3.852983070239089*^9, {3.920108908874491*^9, 
   3.9201089105506*^9}},
 CellID->679939182,ExpressionUUID->"d10154a0-0da7-401c-8684-0f42c5cfa44e"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.591720240155363*^9, 3.591720243875363*^9}, {
  3.591741025313713*^9, 3.591741092643431*^9}, {3.591741122969884*^9, 
  3.59174112612212*^9}, {3.655396319180831*^9, 3.6553963221779943`*^9}},
 CellID->977346187,ExpressionUUID->"90fed691-a2e0-49ce-bc6c-2c093efe5247"],

Cell["\<\
Substituting the given z-transform and the ROC into the inverse z-transform \
function gives:\
\>", "Text",
 CellChangeTimes->{{3.8147938759181747`*^9, 3.81479388462332*^9}, {
   3.814793999035944*^9, 3.8147941443492393`*^9}, {3.8357290667392187`*^9, 
   3.835729174662204*^9}, {3.836911694796036*^9, 3.8369116957864437`*^9}, 
   3.836912375023815*^9, {3.847228730790848*^9, 3.847228731133346*^9}, {
   3.850510158561613*^9, 3.850510159630344*^9}, {3.852983073699245*^9, 
   3.8529830770191307`*^9}, {3.916913485159698*^9, 3.9169134880727673`*^9}, {
   3.919430637692375*^9, 3.919430641247164*^9}},
 CellID->154949006,ExpressionUUID->"4e3a5161-9f36-4abf-9f3e-628db0fd84d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "n_", "]"}], "=", 
  RowBox[{"InverseBilateralZTransform", "[", 
   RowBox[{
    RowBox[{"ConditionalExpression", "[", 
     RowBox[{
      RowBox[{"X", "[", "z", "]"}], ",", 
      RowBox[{
       RowBox[{"Abs", "[", "z", "]"}], "<", 
       FractionBox["1", "2"]}]}], "]"}], ",", "z", ",", "n"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8147941597058473`*^9, 3.814794199446866*^9}, {
   3.847183217334572*^9, 3.847183217426193*^9}, {3.847183295214455*^9, 
   3.847183327109624*^9}, {3.84722857326285*^9, 3.8472285748434873`*^9}, {
   3.847229072736074*^9, 3.847229077797704*^9}, 3.847229515198353*^9, {
   3.847229751189744*^9, 3.847229757138922*^9}, {3.8472298198648887`*^9, 
   3.847229823172908*^9}, {3.847233934310165*^9, 3.847233934565841*^9}},
 CellID->1477763678,ExpressionUUID->"27bd9419-a17d-4275-9a13-a2c0499d0e0f"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{
         FractionBox["1", "3"], " ", 
         SuperscriptBox["10", 
          RowBox[{"-", "n"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["5", 
            RowBox[{"1", "+", "n"}]], "-", 
           SuperscriptBox["8", 
            RowBox[{"1", "+", "n"}]]}], ")"}]}], 
        RowBox[{"n", "<", "0"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{{3.782434913170009*^9, 3.782434920345622*^9}, 
   3.835728964111146*^9, {3.835729018324855*^9, 3.835729043520588*^9}, {
   3.84722881488968*^9, 3.8472288328118744`*^9}, 3.847229079847491*^9, {
   3.847229508936757*^9, 3.8472295177712803`*^9}, 3.8472297578785*^9, 
   3.847229823696124*^9, 3.847233865289118*^9, 3.847233936195428*^9, 
   3.8944855485322094`*^9, 3.894485684473367*^9, 3.897573557226728*^9, 
   3.9296520167739506`*^9},
 CellID->302594512,ExpressionUUID->"a2aaff78-456e-46a9-8612-2c50d2c6b62c"]
}, Open  ]],

Cell["This shows the resulting sequence:", "Text",
 CellChangeTimes->{{3.7824349941166453`*^9, 3.782435002290396*^9}, {
  3.847229531988667*^9, 3.8472295371557045`*^9}},
 CellID->1125758591,ExpressionUUID->"4c51a92a-a3cd-4fe7-a808-83cf696fb68b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["472", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`n, -10, 10}, PlotRange -> {-5, 15}, PlotStyle -> 
     PointSize[Medium], AxesLabel -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.7824349863745604`*^9, 3.782435055693524*^9}, {
   3.8147942376486597`*^9, 3.814794284802774*^9}, {3.847228839862235*^9, 
   3.847228947311513*^9}, 3.847229088291212*^9, {3.847229502582423*^9, 
   3.847229504749613*^9}, 3.84723385196551*^9, {3.892495922555709*^9, 
   3.892495928638664*^9}, {3.894485575242465*^9, 3.894485587973794*^9}, {
   3.8944856783708124`*^9, 3.8944857063873844`*^9}},
 CellID->1293708867,ExpressionUUID->"124984d0-1cae-43e6-bd6e-aae8503ee1b6"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
     AbsoluteThickness[2], 
     TagBox[{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], 
        LineBox[{{{-1., 0.}, {-1., 0}}, {{0., 0.}, {0., 0}}, {{1., 0.}, {
           1., 0}}, {{2., 0.}, {2., 0}}, {{3., 0.}, {3., 0}}, {{4., 0.}, {
           4., 0}}, {{5., 0.}, {5., 0}}, {{6., 0.}, {6., 0}}, {{7., 0.}, {
           7., 0}}, {{8., 0.}, {8., 0}}, {{9., 0.}, {9., 0}}, {{10., 0.}, {
           10., 0}}},
         VertexColors->None]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], 
        LineBox[{{{-10., 1681.831398010254}, {-10., 0}}, {{-9., 
           833.4651184082031}, {-9., 0}}, {{-8., 
           410.7720947265625}, {-8., 0}}, {{-7., 
           200.61767578125}, {-7., 0}}, {{-6., 
           96.494140625}, {-6., 0}}, {{-5., 45.1953125}, {-5., 0}}, {{-4., 
           20.15625}, {-4., 0}}, {{-3., 8.125}, {-3., 0}}, {{-2., 
           2.5}, {-2., 0}}},
         VertexColors->None]}},
      Annotation[#, "Charting`Private`Tag$6012#1"]& ]}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[2], {}, PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEqB4BEVLD7LAcIXwnEn7CDuwvKVwDxG6LWVEL5
MiA+wxHhTChfAsxfIB8B5YuA+Qwz3aB8AQhfwwTK54DwHRSgfAYIn4EFyv+w
nwEv+GCPJuCAyuVA4wug8UXQ+BJofBk0vgIaXwmNrwLnAwCmdhrN
       "]], {}},
     Annotation[#, "Charting`Private`Tag$6012#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox["n", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{-10., 10.}, {-5., 15.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.894485592221037*^9, {3.894485681134618*^9, 3.894485708870939*^9}, 
   3.897573559137368*^9, 3.929652018618025*^9},
 CellID->165017189,ExpressionUUID->"185b7904-d5d4-48f2-acd2-ba3c2fa34048"]
}, Open  ]],

Cell["\<\
The resulting signal is unbounded and anti-causal (or left sided).\
\>", "Text",
 CellChangeTimes->{{3.835791278117122*^9, 3.835791284793466*^9}, {
  3.835791440887553*^9, 3.835791453207143*^9}, {3.835792374057883*^9, 
  3.835792374387625*^9}, {3.847229123811655*^9, 3.8472291297079477`*^9}, {
  3.889052988527374*^9, 3.889052994644776*^9}, {3.91691815916178*^9, 
  3.9169181619051*^9}, {3.919435116006143*^9, 3.919435116242826*^9}},
 CellID->93001794,ExpressionUUID->"bb2d9a82-8f14-496e-b112-5d65d1625a0e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 6", "Subsection",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
  3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
  3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
  3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
  3.591922479275842*^9}, {3.655396306074999*^9, 3.655396310598941*^9}, {
  3.6555054648020253`*^9, 3.655505465270019*^9}, {3.688419950743099*^9, 
  3.688419950831099*^9}, {3.78209126444328*^9, 3.782091264583894*^9}, {
  3.782121408406484*^9, 3.782121408517951*^9}, {3.8472309311339903`*^9, 
  3.8472309312250705`*^9}, {3.847230968733571*^9, 3.847230968845914*^9}},
 CellID->1860540389,ExpressionUUID->"0ef46fbf-10d0-40e6-a1a7-ba75f9494285"],

Cell["\<\
Obtain the inverse z-transform given the following specification\
\>", "Text",
 CellChangeTimes->{{3.591720227715363*^9, 3.591720235305363*^9}, {
   3.591720902375889*^9, 3.5917209125368032`*^9}, {3.5917403276844573`*^9, 
   3.591740361661317*^9}, {3.591740820937754*^9, 3.5917408765206513`*^9}, {
   3.5917409171431227`*^9, 3.591740934225153*^9}, {3.591922479182243*^9, 
   3.591922479275842*^9}, 3.655396306074999*^9, {3.814794187905379*^9, 
   3.81479418936787*^9}, 3.836912362767934*^9, {3.850510168991393*^9, 
   3.850510173720108*^9}, 3.852983085635564*^9, {3.916913491918989*^9, 
   3.9169134923275623`*^9}, 3.916918165806394*^9, {3.919430648223074*^9, 
   3.9194306484917088`*^9}, 3.919435093492309*^9},
 CellID->592933956,ExpressionUUID->"7bf98989-e588-4697-977f-dd6aa0cb098d"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["4", "5"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]]}], TraditionalForm]],
  ExpressionUUID->"9b3efd1e-f7ff-4f93-9498-0908c70f8029"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2"], "<", 
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<", 
    FractionBox["4", "5"]}], TraditionalForm]],ExpressionUUID->
  "48f50119-2739-4331-9428-b3be42e882c2"]
}], "Text",
 CellChangeTimes->{{3.5917409389363613`*^9, 3.5917410053612776`*^9}, 
   3.782085558076461*^9, {3.814794176773161*^9, 3.814794184315883*^9}, {
   3.835791336938426*^9, 3.835791366362398*^9}, {3.847228664702566*^9, 
   3.847228712638552*^9}, {3.847229158968726*^9, 3.8472291741306667`*^9}, {
   3.8472298393613434`*^9, 3.8472298395818777`*^9}, {3.850498694224977*^9, 
   3.85049869431382*^9}, 3.85298308930322*^9, {3.920108919780288*^9, 
   3.920108921462347*^9}},
 CellID->1116876412,ExpressionUUID->"e3bb3a7d-3132-4486-a39d-5544fd84abd7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution",
 FontSlant->"Italic"]], "Subsubsection",
 CellChangeTimes->{{3.591720240155363*^9, 3.591720243875363*^9}, {
  3.591741025313713*^9, 3.591741092643431*^9}, {3.591741122969884*^9, 
  3.59174112612212*^9}, {3.655396319180831*^9, 3.6553963221779943`*^9}},
 CellID->187298057,ExpressionUUID->"623f2859-3d05-4d83-8fdf-d84cd1e1f69b"],

Cell["Using the same approach as in Example 1 gives:", "Text",
 CellChangeTimes->{{3.835729289033542*^9, 3.835729303834452*^9}},
 CellID->1854901144,ExpressionUUID->"078ef227-839b-4b75-b06e-2c12fd68c314"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "[", "n_", "]"}], "=", 
  RowBox[{
   RowBox[{"InverseBilateralZTransform", "[", 
    RowBox[{
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", 
       RowBox[{
        FractionBox["1", "2"], "<", 
        RowBox[{"Abs", "[", "z", "]"}], "<", 
        FractionBox["4", "5"]}]}], "]"}], ",", "z", ",", "n"}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.782434893637779*^9, 3.782434919877004*^9}, {
  3.835728953280023*^9, 3.835728960091308*^9}, {3.835728993259104*^9, 
  3.835729042197328*^9}, {3.835729322916952*^9, 3.835729325303783*^9}, {
  3.8472291817333007`*^9, 3.847229249006349*^9}, {3.8472297245002775`*^9, 
  3.847229724753606*^9}, {3.847229843509928*^9, 3.847229846351841*^9}, {
  3.847233941530785*^9, 3.8472339417538443`*^9}},
 CellID->303423709,ExpressionUUID->"dee11a45-0381-47da-8e90-211199698003"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SuperscriptBox["2", 
            RowBox[{"-", "n"}]]}], "3"]}], 
        RowBox[{"n", "\[GreaterEqual]", "0"}]},
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "3"]}], " ", 
         SuperscriptBox["2", 
          RowBox[{"3", "+", 
           RowBox[{"2", " ", "n"}]}]], " ", 
         SuperscriptBox["5", 
          RowBox[{"-", "n"}]]}], 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{
  3.835729328504025*^9, {3.84722923915488*^9, 3.847229250588333*^9}, 
   3.8472294953404374`*^9, 3.847229726177677*^9, 3.847229846983358*^9, 
   3.847233875077999*^9, 3.847233942630516*^9, 3.894485715664534*^9, 
   3.897573563175109*^9, 3.929652022836132*^9},
 CellID->58453344,ExpressionUUID->"f81dc383-b148-4640-a998-fa5c883d1798"]
}, Open  ]],

Cell["This shows the resulting sequence:", "Text",
 CellChangeTimes->{{3.7824349941166453`*^9, 3.782435002290396*^9}, {
  3.847229531988667*^9, 3.8472295371557045`*^9}},
 CellID->1516099185,ExpressionUUID->"a0d2d068-012f-41a9-a567-afefa33c4032"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["4", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            
            TagBox["472", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[{$CellContext`n, -10, 10}, PlotRange -> {-10, 5}, PlotStyle -> 
     PointSize[Medium], AxesLabel -> Automatic],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.7824349863745604`*^9, 3.782435055693524*^9}, {
   3.8147942376486597`*^9, 3.814794284802774*^9}, {3.847228839862235*^9, 
   3.847228947311513*^9}, 3.847229088291212*^9, {3.8472292940302873`*^9, 
   3.847229303974963*^9}, {3.847229336379531*^9, 3.8472293437266026`*^9}, {
   3.8472294893675485`*^9, 3.8472294919891033`*^9}, 3.847233842594615*^9, {
   3.892495933621012*^9, 3.892495940888678*^9}, {3.894485721722279*^9, 
   3.894485727171294*^9}, {3.8944857630519314`*^9, 3.894485811183056*^9}},
 CellID->1185530640,ExpressionUUID->"a438d879-a7d2-4735-a09e-597efeee4c3a"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
     AbsoluteThickness[2], 
     TagBox[{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], 
        LineBox[{{{-10., -24.83526865641276}, {-10., 
            0}}, {{-9., -19.868214925130207`}, {-9., 
            0}}, {{-8., -15.894571940104166`}, {-8., 
            0}}, {{-7., -12.715657552083334`}, {-7., 
            0}}, {{-6., -10.172526041666666`}, {-6., 
            0}}, {{-5., -8.138020833333334}, {-5., 
            0}}, {{-4., -6.510416666666667}, {-4., 
            0}}, {{-3., -5.208333333333333}, {-3., 
            0}}, {{-2., -4.166666666666667}, {-2., 
            0}}, {{-1., -3.3333333333333335`}, {-1., 0}}, {{
           0., -1.6666666666666667`}, {0., 0}}, {{1., -0.8333333333333334}, {
           1., 0}}, {{2., -0.4166666666666667}, {2., 0}}, {{
           3., -0.20833333333333334`}, {3., 0}}, {{
           4., -0.10416666666666667`}, {4., 0}}, {{
           5., -0.052083333333333336`}, {5., 0}}, {{
           6., -0.026041666666666668`}, {6., 0}}, {{
           7., -0.013020833333333334`}, {7., 0}}, {{
           8., -0.006510416666666667}, {8., 0}}, {{
           9., -0.0032552083333333335`}, {9., 0}}, {{
           10., -0.0016276041666666667`}, {10., 0}}},
         VertexColors->None]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
        AbsoluteThickness[2], Opacity[0.2], LineBox[{},
         VertexColors->None]}},
      Annotation[#, "Charting`Private`Tag$6085#1"]& ]}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[2], {}, PointBox[CompressedData["
1:eJw1yqEKwlAUgOGDIIylhSsMWZjjFi0Gi01B8AGEgRgFy4J2H8FH8BGub2DZ
zcuuGHwAk9nktvN74HD4+M9of9oceiIyaLa9OtbfnJs86rlXZz5vZvWa4bRz
v5ripP13xXGM467nW4tN1906xZE6HOJA/2uDRbuL8KdUh/8u6m9JX6jfWJbq
Jw5whSN8xwY7HOMrTvAFp/iMM1xgi3flD0fPcrg=
       "]], {}},
     Annotation[#, "Charting`Private`Tag$6085#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox["n", HoldForm], TraditionalForm], None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{-10., 10.}, {-10., 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8944858048450637`*^9, 3.8944858126623116`*^9}, 
   3.897573564730231*^9, 3.9296520250695305`*^9},
 CellID->279381984,ExpressionUUID->"278ac8ed-0623-4038-a07b-e3f2a3f83028"]
}, Open  ]],

Cell["The resulting sequence is two sided and also unbounded.", "Text",
 CellChangeTimes->{{3.835791414497083*^9, 3.835791429683509*^9}, {
  3.847229368974447*^9, 3.847229377990334*^9}, {3.889053019306679*^9, 
  3.889053024403802*^9}, {3.919435161604553*^9, 3.91943516176922*^9}},
 CellID->860189614,ExpressionUUID->"69ee7358-8a2d-4db7-90aa-b1c0fadb50bf"],

Cell[CellGroupData[{

Cell["Summary", "SummarySection",
 CellID->346930894,ExpressionUUID->"29503115-38d8-486d-9479-836531c6eb8f"],

Cell["\<\
The z-transform inversion by method of partial fraction expansion was \
presented.\
\>", "SummaryNote",
 CellChangeTimes->{{3.8155017862995462`*^9, 3.8155017888688045`*^9}, {
  3.815501826096397*^9, 3.815501854084262*^9}, {3.836858292585725*^9, 
  3.83685829318143*^9}, {3.838472360177432*^9, 3.838472363314762*^9}, {
  3.8467089874335737`*^9, 3.846708987922225*^9}, {3.9169134965424385`*^9, 
  3.916913496743362*^9}, {3.919430656296854*^9, 3.919430656533964*^9}},
 CellID->449433853,ExpressionUUID->"0afd0ee6-0d2c-42f3-a535-03c2e28558fa"],

Cell["\<\
Several examples were shown with details describing the evaluation of \
residues for both distinct and repeated roots.\
\>", "SummaryNote",
 CellChangeTimes->{{3.815501758922827*^9, 3.8155017733710184`*^9}, {
  3.8155019122599225`*^9, 3.815502006222185*^9}},
 CellID->934780872,ExpressionUUID->"939ace3e-0ef5-4bc7-9bef-f795f15ac90f"],

Cell["Examples of inversions for different ROCs were shown", "SummaryNote",
 CellChangeTimes->{{3.815501758922827*^9, 3.8155017733710184`*^9}, {
   3.8155019122599225`*^9, 3.815502006222185*^9}, {3.83824758161032*^9, 
   3.838247642574911*^9}, 3.916918181155699*^9},
 CellID->2019237899,ExpressionUUID->"953980cf-4369-4d07-a399-3728f2b797e5"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyFlk1IlFEUhsdZREZSaFEZkWGRi8p+HMifuplEBEJT0KbAoj+yjdHPQtdl
G8WCQcKFErUclMJFwdBFmEU6UROGJoqDNgYVhYQZQozZd+a5whk+CuLy3nPu
+77n3HPnc9vFptNXgoFAIL30/996qDDaMBp+a/euqdreUDdmK1a//pIO9Ttc
KNiAd0m+w6zw6BU+MHxg+MBlwmf8fGlevcIPhh8Mv1+d2qfm1Sv8YPj9+qbr
1j41r17h9+ubrlP7yuHx4nFb6e1P2p0e/uDWgPfvWYx4seQb8FbJM+SzD+8+
wTk68BL30yEORgddvWpdraN56Re69AvMSt7/zhHX86P3dV+oi/sEP1nVUV/W
995GC/LuP46NuH3OufnK4v61twaKh8Zthbc/6PKpm3ww+aWS7/rLnKDbJT6c
X/qNXzB+n8o5dy/ouXvK8pOn+d08Z+uIis8cHjD51EG+7iv14FP3ET36oudO
95E6iFMHOnoudd/0O8Q3PoijS5w60YcXffrq+pf1w6rrLPV4Xrn7gwcdPSfw
oKPvXc8f7xDMO4AHffpAvWD3e5nlxd+bvh/94e7hnO9EJjHTGOtMOR3w13Ud
xwt2TLh5mJd9907BnCNff/fiouv0uSdW4uhMC4+7L3Dl7Ycvw5mkPdFyZ0/d
pnG3sr9/tmZi0cRtzd3Po+kzS7+LFxoLIxvitu7auaHF85N2c2a2INIz4tbg
jfJUOtRlQ/k90dBcyrY0ediAV8p5w/kS4TfwFwmPgY96qfNbcsGUvfvo7pVz
+IQXnxUSN8Tx4edzt2BDHD58o4fvaokb4vimjk/i170PfOALHXThgffw5XuP
Wm8ufy+4T+YiLPGc7yd94r7Jh4985oQ+45Pz5KHDfHEf1Icuc4VPfHOed+D3
TtDDp55b+IjjU/8dgC/qwzd5xPGlv6v6HYK5V9ZyeSeGd1Mra867Io84mDy9
Dz44X3Lq59nl7zRzwXyPPai6HruaMskVwY3N7S/sge9FPeFMyv3dwVwx3+ub
E9ODiaU5m4o8D0Wijp/fO+aS+UaXPHjR4Zz2eUSwxdeU+HS/w9Vy3taLD7tF
fFl8geGHLyp8Bj720WUfXXTQhddPl/4Qhx8f8OOD/oM5B4/Oo6/0mXvkXvFN
vv5d0j4Xa5MDoblhm3/s6J/evDHbffLSr96ZCZvfXtzW2pJweKHNw4a833LO
nc+TfcNKHJ5O4THwgOFzPpSu48nmuXM+vOTjg3342EfvL0XHGds=
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[0.3], EdgeForm[None], 
            GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwNw4dWUgEAAFB57L333ns4UEEQIghEkBAQkEjBAYJp2lSz0vYy27tsl3u0
LJtmVjZsfEffkPecK0x31qaBgoKCf2vBayvMIhMAx8LgCABcaZU1R0J4BJKG
J7TGowo0MYMhkTFYChZHxeEtMAwOjrBa0Cm7is9kscgUNoWacNPSLk2ZjheR
Im0kRggBzpGZhWKgSAI2m2AAAl6u58OwGL+BXyxDI/C4KB4ZlxMyRDSGTMJS
yDgqBU+jKmkEu42eY5DILCaFzXKzqZsSaieTB8dhfXzW5qQ2KAQCIhggBjeF
JS0xqcvJNSqIJUpCqZq23qHxaNnVXh1fz2PyeUkfW1gIKIrR8hJCykhUltL0
ZTxDOb8haIKZ4CIzrMEMMleAGgMWtAUjs6IbrVBrJdRTpXV6uevs9DY70b5O
ZXPQ0w6GYz29Pe9sy9o2uLjtLoZrg4bmpnrcHLeHXeXhOGwMc4NJ5+XF6+Vs
H8vvE/j8/Bq/wF9j2BiAWgKwwEZRbRBkCgLBWmE4BEaEkJIwuDkMEReBvdXc
SJ00FkXiowRpDNkaQ0XjhPo4KhRBuhMcdYKW2MTxJQXaJDu5WRBsANVFIF4n
L9AIfXlPvXBG//qs4c0e4ath3bt94lyecX0SFW6CRJohsRYUOUfK55gPhjR3
TqqGH+t+vdJ1fy+9/cU48ql49bXhaVeJM890pDX5doa10eJqd7rSDGNKFW4O
zb9Uv+0o/NBZtHJC9ey58mC/6EKfcOmQ7NIEZPmo4tYR+dwT+ckV1dZe6LlV
Q6w1am+zxVtR2TaiLUvKZInZDOn0uHZLD+jqoBSTQS8OSI4tKz6PFPe9EQ7e
kO5flExcgXR+LDr+TDl5E7VrhvtnQd/xvtCeIo4/0vYegO59J+45Dxq4LDm8
JPs5Vt5/UfRjtGx6J+fQNdm328axv+VH5uSjv8tmdwtmdnAfzgpedJd2fS0Z
uq+5O83ZPkU/Na+e2kb/D5MFyKE=
               "]], 
              PolygonBox[{{148, 222, 82, 1}, {155, 214, 62, 38}, {136, 200, 
               51, 40}, {127, 194, 50, 35}, {165, 216, 67, 44}, {180, 181, 52,
                39}, {157, 228, 101, 37}, {131, 221, 80, 5}, {196, 128, 36, 
               50}, {153, 223, 86, 4}, {152, 227, 99, 36}, {202, 138, 41, 
               52}, {124, 191, 49, 33}, {183, 184, 54, 41}, {205, 141, 43, 
               54}, {193, 126, 35, 49}, {118, 218, 73, 28}, {117, 217, 70, 
               29}, {169, 219, 75, 46}, {164, 225, 92, 43}, {201, 137, 40, 
               53}, {198, 134, 38, 51}, {158, 224, 90, 10}, {224, 159, 39, 
               90}, {227, 151, 4, 99}, {223, 154, 37, 86}, {139, 204, 53, 
               42}, {225, 163, 28, 92}, {222, 149, 33, 82}, {145, 206, 55, 
               47}, {146, 207, 56, 48}, {226, 167, 32, 94}, {221, 132, 34, 
               80}, {220, 147, 48, 78}, {115, 215, 65, 23}, {219, 119, 29, 
               75}, {150, 213, 59, 34}, {212, 211, 47, 56}, {120, 220, 78, 
               32}, {210, 209, 46, 55}, {217, 166, 44, 70}, {215, 162, 42, 
               65}, {218, 143, 45, 73}, {216, 116, 23, 67}, {168, 226, 94, 
               45}, {214, 112, 5, 62}, {213, 109, 1, 59}, {228, 156, 10, 
               101}}]}]}, {}, {}, {}, {}}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           LineBox[{198, 134, 197, 133, 155, 214, 112, 122, 131, 221, 132, 
            125, 150, 213, 109, 121, 148, 222, 149, 123, 190, 124, 191, 110, 
            193, 126, 192, 127, 194, 111, 196, 128, 195, 129, 152, 227, 151, 
            173, 153, 223, 154, 130, 157, 228, 156, 174, 158, 224, 159, 135, 
            179, 180, 181, 113, 202, 138, 182, 183, 184, 114, 205, 141, 185, 
            186, 164, 225, 163, 176, 118, 218, 143, 172, 168, 226, 167, 178, 
            120, 220, 147, 208, 189, 146, 207, 171, 212, 211, 188, 145, 206, 
            170, 210, 209, 187, 144, 169, 219, 119, 177, 117, 217, 166, 142, 
            165, 216, 116, 175, 115, 215, 162, 140, 203, 139, 204, 161, 201, 
            137, 199, 136, 200, 160, 198}]}}], {}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{
         FormBox[
          StyleBox["\"Re\"", Tiny, StripOnInput -> False], TraditionalForm], 
         FormBox[
          StyleBox["\"Im\"", Tiny, StripOnInput -> False], TraditionalForm]},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Epilog->{{
          RGBColor[1, 0, 0], 
          CircleBox[{0, 0}]}, {
          GrayLevel[0], 
          PointSize[Medium], 
          PointBox[
           NCache[{{
              Rational[1, 2], 0}, {
              Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       ImageSize->80,
       Method->{
        "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True},
       PlotRange->NCache[{{
           Rational[-3, 2], 
           Rational[3, 2]}, {
           Rational[-3, 2], 
           Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}},
       Ticks->{{{1, 
           FormBox["1", TraditionalForm]}}, {}}], " ", " ", 
      OverscriptBox["\[LongRightArrow]", 
       SuperscriptBox["\[DoubleStruckCapitalZ]", 
        RowBox[{"-", "1"}]]], " ", " ", 
      GraphicsBox[{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[{
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], 
             LineBox[{{{-5., -6.103515625}, {-5., 
                 0}}, {{-4., -4.8828125}, {-4., 0}}, {{-3., -3.90625}, {-3., 
                 0}}, {{-2., -3.125}, {-2., 0}}, {{-1., -2.5}, {-1., 0}}, {{
                0., 0.}, {0., 0}}, {{1., 0.}, {1., 0}}, {{2., 0.}, {
                2., 0}}, {{3., 0.}, {3., 0}}, {{4., 0.}, {4., 0}}, {{5., 
                0.}, {5., 0}}},
              VertexColors->None]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], LineBox[{},
              VertexColors->None]}},
           Annotation[#, "Charting`Private`Tag$16146#1"]& ]}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
           AbsoluteThickness[1.6], {}, 
           PointBox[{{-5., -6.103515625}, {-4., -4.8828125}, {-3., -3.90625}, \
{-2., -3.125}, {-1., -2.5}, {0., 0.}, {1., 0.}, {2., 0.}, {3., 0.}, {4., 
            0.}, {5., 0.}}], {}},
          Annotation[#, "Charting`Private`Tag$16146#1"]& ]}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{
         FormBox[
          TagBox["n", HoldForm], TraditionalForm], None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImageSize->80,
       Method->{
        "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
         "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05]},
       PlotRange->{{-5., 5.}, {-5., 5.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 0}},
       Ticks->{None, None}]},
     {
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1mWlsVVUQx0vBaJAGBUQoAiIEGiW4BFxwOQ2NIGV7+MEI6BNUTBFUDILi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         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[0.3], EdgeForm[None], 
            GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXv819Mdx8/7Qzc/3dO9dNFNoaSoJZdCKStNN1FkRqTc5jojd1KkMFak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               "]], PolygonBox[CompressedData["
1:eJwtlnfUz2UYxp/7mzppaypFZKXMhEh6VeqcUhmReON9rSZC2WVkZpSIoxIp
ySwliVLJVlYIKUKInJSGVPpc5/LH5/yu+/cdz/Pc81s8v2PDDllKaS4UgFMx
ciOlz9CLIbBLYhdEfwjH0XfBu+h34Av0i9AS/axAN+KZ43oXJHSD8LPzoTa6
BDyAfgpGoRvCAnRz6I/+BPqgd8JV6H/C+zs9eS8n4IPkPV3I+y+Gteh6sIhr
HeAOdA8og14I3dCFoA66LDyI7g6n8Gwz7I/RC+Eb7U17QE+AKei98Aa6PRRF
L4an0U2gPM//gT0bvQtGo++HRclrfI3eBGPRNeBudFOog+4LxdHHYA66KdyE
LgW5yc9oLd2ja1pzCfpqyEMPgM/RI8O+6wd/o/+C6snvzDL7QGf/CDaj7wvr
cXAF17ti19deoTd6PnRFb4Px6NO451P0D/Av9j0wD/0+/BeOkWKj/1qhz+D+
JcoN7Rn7MMxAfwuFudYJ+070UP2H3g6voidCBfRumKy9QS35g2e2oyvJp1oL
Ox+doz1h74JJyc+0RZ/L9RXolcmxUIwVW8VkS9gHOvt4uA19RD5BV5EP0fVg
ZvJ/W8M5oVx4GR5Cn8/71qC/TM6NPTAlOUdahGtItSOfDcVujH0CfRZci70j
fNYiUFq1Bs+oNqCq6ov7j6JLwXLsSvAIejCsQU+Dx9Aj4Gb0dfA4uqf2iD4z
s+93w2rs61UT6OGqWcVPOatcVE5of+G1VSOvoc/L7Ls9MBO7CPYG9AE4G12O
/y5BL4Mb0A3475jOBn9i/641k2tCuZCHvTQ5JxTr/PCzinltrt8IDZNzbhbX
LsfeiD4on2KvDOfK3uS1t4VjoT2sQL8ers0h8j/Pzg7vJfgdEa451Zp6zpvo
ytwzSLGEi9BVYF9yDymQ2YfynXqCYqMaV20rRquwK2L/iB4GS8M1otoYqBzl
WoXM79Y9F2Q+g/b+lXIgs4/lW/lkQbhGVBtPyoeZe+BO9PdQFrs0NELvSM61
9rA6OefuDdekalE9sX64R6s3q2cOQufw/JHkmNTEXgej0OVhI/qazGuN0Zmx
y2Req7fOrH6TeW/awwbsctjfoUfrjMo/7P3oqVAycw9R79gK89A9VUPoLlCd
6wfDuXcIqmWOuWL9E+xT7mTW01QPmXNQuac1NFsGYldNnjHKve7KweQcVG5X
D9eOcjwXe3C49gqfrK3p4VmhGlNtDgv3ZtXo/nBPVC+cnjybNMM0uzSjZmA/
AeuTa6o413pgb0FvhsuwD2gd9LrkXvFwOPbqGTWwc8Jn/xkKZe4J6gWK6aRw
j1FvaQu91F8z+041UiJzDBU7rbk2/E69a2RyL7g089rqCUXRteAwelNyb1PM
FWv1OM3y4dAseab/ij4Ks5J9PA7dPJzbeTA2PPM161tBk/BM1SzVTHsuPOM1
2/XO9eEert79vNYI71l77QTvobuFr3VWziv3w2evCxPCPVu9Wj3/7fCM12xX
D+wY7oHqfZopOmtd7F7JZ9Ys1czUrNRM1bfNK9A6+RunIPe3DM+SNnBLOMeV
25pZt+vZ8KzXN8kYdCPon/zNc2W4ZlQr1XTG8Ezuh24B7dCToR16lWKCfgse
la+Sa0M5pNxRjdREzw37RjW6LDwTNQvVs+aEe1yczDHNvjawPHkGVgvPCM0G
zfQu4ZxWLqundg7XmGpLPV25rBpW7Sqn1SuKhb/d1DM0S3UG7V0z9RC6WOZc
Us3pW+mlcC7om0m+eSF8dvmocngGafbozFPDPtDZNdO094lh3+sM5/Du1uHY
K0Z9wj1FvUTfAFXCPV+9Xt94FcMzUrNRPlZv6ovdOLlHqberZ6tXq8f/Fo6Z
YqUcHxLuEeoN+mb6hd9bw98CeodyqUY4N5VT/wM4MG69
               "]]}]}, {}, {}, {}, {}}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           LineBox[CompressedData["
1:eJwl08lvjVEYwOHPTRQbCzWUoFq0KNeYlLZaNU8J1UqIFsHC0Gg3NdSsKP4B
KtpYsLEwVk1BRUhIXHPtjCtTUVrDynNi8eT3vue7Sc8dmraqYtHGTlEUJciI
RdEuy3C9olfZSSvTeMoIz3ZrvvbXb0znKzP4zgAKPN+jM3lGln0ke803mUUN
U5wN1Fuk8Ye//GYuBynzmlpt5hAl9sM6j+e8CPdhKHfC/cNdvOaILuMuR0ly
VqqdtUyPh/uZs7S7rtZXvOYNo8I9nZ/QtfQwr9NkPan32UCKvVL7aEV4T4yn
r70fH8wfOUup/YwmmESRfYsO0s+aGj4Pcplqn8hC80XdzBNyw3t1tkOH6Ha9
TBOT7Xl8MW9jsLlRV+olrQ6fs3mrpmuOPmYTOfYL4V56Xh+Fv28u1Gz9pFWc
Y4E9Wx8ygfn201pOT3NvejGOB85G6xjinLKP1fV6jzjvecdb1tDAUq+p1266
Qrvocu2qdbpEj+lLWlhMzFmmXuda+K2E366zDL0dvlNzh/6inTkcoNB5quax
j2L7fp1NGz/5Eb4nbpDp+bDY//+Zf++FXxc=
            "]], LineBox[CompressedData["
1:eJwl0ckuZGEYgOFTWBmCNRaGhYjE2HYiEQuzVqJMiSlpVohh4xrM48ZCkHS3
4A6sRELCBRh3pntA6+ePxZP3+86pc1L1V/7oVHwyFkXRPH2GlKQo2tE0HdZU
HdF03dUs/aWZOqZ7NJrL9IJymuy/dYI/NNsr9IoftNmPdJoXquzVHJtzdEZf
w2fNNZyYc3VW38gzz2l7uK/X/GXAfqinhB/VYq/US/bptx/oM0+Mk+1aqT7y
wD2jZLheonfcchOeZ5se97b0nA2G7JvaxRoJ+6qescygfUXj4aDNnRrTIv3i
J5908I9CPsI58U4ri3R7ZkFrKaDevhTOIXyn8H57QusopsG+rr0kJ33/v/8B
Xtg39g==
            "]]}}], {}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{
         FormBox[
          StyleBox["\"Re\"", Tiny, StripOnInput -> False], TraditionalForm], 
         FormBox[
          StyleBox["\"Im\"", Tiny, StripOnInput -> False], TraditionalForm]},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Epilog->{{
          RGBColor[1, 0, 0], 
          CircleBox[{0, 0}]}, {
          GrayLevel[0], 
          PointSize[Medium], 
          PointBox[
           NCache[{{
              Rational[1, 2], 0}, {
              Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       ImageSize->80,
       Method->{
        "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True},
       PlotRange->NCache[{{
           Rational[-3, 2], 
           Rational[3, 2]}, {
           Rational[-3, 2], 
           Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}},
       Ticks->{{{1, 
           FormBox["1", TraditionalForm]}}, {}}], " ", " ", 
      OverscriptBox["\[LongRightArrow]", 
       SuperscriptBox["\[DoubleStruckCapitalZ]", 
        RowBox[{"-", "1"}]]], " ", " ", 
      GraphicsBox[{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[{
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], 
             LineBox[{{{-5., -3.0517578125}, {-5., 
                 0}}, {{-4., -2.44140625}, {-4., 0}}, {{-3., -1.953125}, {-3.,
                  0}}, {{-2., -1.5625}, {-2., 0}}, {{-1., -1.25}, {-1., 0}}},
              VertexColors->None]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], 
             LineBox[{{{0., 1.}, {0., 0}}, {{1., 0.8}, {1., 0}}, {{2., 
                0.64}, {2., 0}}, {{3., 0.512}, {3., 0}}, {{4., 0.4096}, {
                4., 0}}, {{5., 0.32768}, {5., 0}}},
              VertexColors->None]}},
           Annotation[#, "Charting`Private`Tag$16169#1"]& ]}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
           AbsoluteThickness[1.6], {}, 
           PointBox[{{-5., -3.0517578125}, {-4., -2.44140625}, {-3., \
-1.953125}, {-2., -1.5625}, {-1., -1.25}, {0., 1.}, {1., 0.8}, {2., 0.64}, {
            3., 0.512}, {4., 0.4096}, {5., 0.32768}}], {}},
          Annotation[#, "Charting`Private`Tag$16169#1"]& ]}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{
         FormBox[
          TagBox["n", HoldForm], TraditionalForm], None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImageSize->80,
       Method->{
        "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
         "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05]},
       PlotRange->{{-5., 5.}, {-2., 2.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 0}},
       Ticks->{None, None}]},
     {
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyF2H+s11Udx3F0bS0W6FjLQWuWWt0Va1rcDVvts0Y0Vo7IxYatMWVaDtpo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         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[0.3], EdgeForm[None], 
            GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4l1MWx9/7jrHvhrFUZElTlrKlLEnIWvaKERVJaCGhSLYR2ZKxZ2wj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               "]], PolygonBox[CompressedData["
1:eJwtlPlPz3Ecx7/vl5zD5r5mFnMz59xnZYlqSuSIVHKklJCiSFHO5AhT5GzM
GD/YjB/9C/wJjh+MNsfGDI/nXp8fHvs8Xt/P8X2/368jPr80c6/FYrECiIPe
BBXQEGKxRpiK34eHeAp0wcfDRrwGPsM94g6uDbyfg2+GYuIS+Ah39A3F3B+D
34a7xImQj+dBKV4GX+EB8WOubTy/FH8Ob4izYCb+FF7qOe6/59pO3M51E3EW
PgwyidfDB9hNfJjrZu6fxIfDWuKLMA0/ZL7XVu434iPM/2s7xOElcAyvhUFy
aMJf83wKPlF7Jt4B+/EesBLfAl3xMqjD62G2zkp7wFOhGz4FcvATkIb3hzQ8
V2vEm83PagPMwS/DNfw6LMYfwbPge07EE2A5ng2/4JPOBgphl/mZ6ayquHZq
nea56uC3VLynea63wjJ9C9Ypl9xfgp+CSzpb4iR8hflek4P/dxO0BF/DOPM1
6L9VMxnE8yBfa4GF+A2Bv+V7a/DveAHsDH4WV833qjP5GX1D7yqH34K/o2fz
YACeDtvwdDA82fzskmCocm+e2wyYbJ5D5U45UO330R6D98Ak8xwqd8rxfPOa
Va1qD0XmPaFeqFZO8D/RXsq1B+J/wc+6Ev6qTsxzkwB1+HHzWlIP5Grt5rlf
DXvUS+bfLuaZbPOaUa0UwW/Vhbk3cr8XftA8d6tggnkN10Y1UIqr4dWrquly
fJ95b6pGp+NP4EXwGq407zn1ms6kyrxH1Zung/fCYLgQvCdq8KNwFn/FM9X4
QDgX/Ld6rR0O4O+4X2tRzoJ/YxR+xrx3VXPn9a753q8Qx+vb5q4aO4L3M+8l
5Vz/Nde8FvSfI/FCqAheszHznCgXmglD8ALzXDWr581nhGaD1qhZ1td8r5pp
C8zfaY5qVL3cGfWOerrVvMZUW63Ba3uRRR58Vo02z71m1i3zHlNvtQVf601z
15o1KzXDNLs0MzVLx5rXsmaqZm93897TDNbsnGGee81QzYYf0VlrRmiWf4lq
RTNds3SWea1ppir3momahaqBFp21eS41czSLNQPU+5rJ/wG+mLUj
               "]]}]}, {}, {}, {}, {}}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           LineBox[CompressedData["
1:eJwt0DlOQgEUBdCPDKIiCGqipR0mqODAoEwbMFGWQLDFRnrosYVWW2ixxx53
IHvAHXBILE5yq3dz31n7tdUNBUHwyBabfMw5NZ55oceAd8Z8MuWLb35Y8kfU
kVMuuOSKPAWuueGWO4qUKFPhngeq1KjToEmOEyKs9PyyYM6MCR+MGNLnjQ5P
VMlyxCEZ0hyQIsk+CfbYZYc428Q224gQ/v/XGso+GMI=
            "]], LineBox[CompressedData["
1:eJwl09VWlVEUgNGfI4rdYgd2d2CCAahggCgGFoqFgmBhKyYmFmIHio36Ir6F
BdiKHXMML+b49ll77f/uRGXkpGSHBUHwjKhQEBzlOMeI57XLLF3LGmrQgwd0
57v7V9x07kk468ghm9NMpcpOqUYwiTjemG3Q2sxjPgN5xAC2UJ/NNCCfwZQz
hEYsYjFL+OB707QpxQznDOc4ywzOs5Nd7KA5I7jDJ+9n6me9q6NoyTJK+GV+
QVMYzUXGcIlWzOKrnUPaloO0I4anjOMw7cnkCleJZTwdKKQjR/jmW6namrHc
44vZby4772M/yzlAG+5T7T5Zo3nMSDJYSgF7+WjnJy2cdxPJHpoxnWFspwnb
aMxQynjv3UJNZwEN2co789s6iHpspC6b6E8SdejHLd7aT9RK/cFc5zRq0ZeH
9GEKvXhCb2qynjxyqfB2sr7UG9qNEAl05RRFzCGMLlznhf3VGrCSv36v0ud6
TTtzktn8MVuhnZjIBE6E/v9n/gF4NFsz
            "]]}}], {}},
       AspectRatio->1,
       Axes->{True, True},
       AxesLabel->{
         FormBox[
          StyleBox["\"Re\"", Tiny, StripOnInput -> False], TraditionalForm], 
         FormBox[
          StyleBox["\"Im\"", Tiny, StripOnInput -> False], TraditionalForm]},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Epilog->{{
          RGBColor[1, 0, 0], 
          CircleBox[{0, 0}]}, {
          GrayLevel[0], 
          PointSize[Medium], 
          PointBox[
           NCache[{{
              Rational[1, 2], 0}, {
              Rational[4, 5], 0}}, {{0.5, 0}, {0.8, 0}}]]}},
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       ImageSize->80,
       Method->{
        "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True},
       PlotRange->NCache[{{
           Rational[-3, 2], 
           Rational[3, 2]}, {
           Rational[-3, 2], 
           Rational[3, 2]}}, {{-1.5, 1.5}, {-1.5, 1.5}}],
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}},
       Ticks->{{{1, 
           FormBox["1", TraditionalForm]}}, {}}], " ", " ", 
      OverscriptBox["\[LongRightArrow]", 
       SuperscriptBox["\[DoubleStruckCapitalZ]", 
        RowBox[{"-", "1"}]]], " ", " ", 
      GraphicsBox[{{
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
          AbsoluteThickness[1.6], 
          TagBox[{
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], 
             LineBox[{{{-5., 0.}, {-5., 0}}, {{-4., 0.}, {-4., 0}}, {{-3., 
                0.}, {-3., 0}}, {{-2., 0.}, {-2., 0}}, {{-1., 0.}, {-1., 0}}},
              
              VertexColors->None]}, 
            {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
             AbsoluteThickness[1.6], Opacity[0.2], 
             LineBox[{{{0., 2.}, {0., 0}}, {{1., 1.6}, {1., 0}}, {{2., 
                1.28}, {2., 0}}, {{3., 1.024}, {3., 0}}, {{4., 0.8192}, {
                4., 0}}, {{5., 0.65536}, {5., 0}}},
              VertexColors->None]}},
           Annotation[#, "Charting`Private`Tag$16192#1"]& ]}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
           AbsoluteThickness[1.6], {}, 
           PointBox[{{-5., 0.}, {-4., 0.}, {-3., 0.}, {-2., 0.}, {-1., 0.}, {
            0., 2.}, {1., 1.6}, {2., 1.28}, {3., 1.024}, {4., 0.8192}, {5., 
            0.65536}}], {}},
          Annotation[#, "Charting`Private`Tag$16192#1"]& ]}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{
         FormBox[
          TagBox["n", HoldForm], TraditionalForm], None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImageSize->80,
       Method->{
        "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
         "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.922526, 0.385626, 0.209179], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.528488, 0.470624, 0.701351], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.772079, 0.431554, 0.102387], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.363898, 0.618501, 0.782349], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[1, 0.75, 0], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.647624, 0.37816, 0.614037], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.571589, 0.586483, 0.], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.915, 0.3325, 0.2125], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[
            0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
            AbsoluteThickness[1.6]], 
           Directive[
            RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
            AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
         "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
         Scaled[0.05]},
       PlotRange->{{-5., 5.}, {-5., 5.}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 0}},
       Ticks->{None, None}]}
    }], TraditionalForm]],ExpressionUUID->
  "dfccb9db-c573-45cc-974b-fb0d0d1ad624"]
}], "SummaryNote",
 CellChangeTimes->{{3.8467039987871113`*^9, 3.846704054681207*^9}, {
  3.846704089964732*^9, 3.846704141731901*^9}, {3.846704183581121*^9, 
  3.846704242203904*^9}, {3.8472333659068274`*^9, 3.8472333961556115`*^9}, {
  3.847233558572616*^9, 3.847233591090792*^9}, {3.8472336404738445`*^9, 
  3.847233719366298*^9}},
 CellID->647294952,ExpressionUUID->"f361a62d-1489-433b-9010-3a214081d62e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSection",
 CellID->2081586209,ExpressionUUID->"741ef626-fe2b-45f6-9614-aea7be183716"],

Cell[TextData[{
 "Determine the inverse z-transform of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], "z"}], "+", "1", "+", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "-", 
     SuperscriptBox["z", 
      RowBox[{"-", "3"}]]}]}], TraditionalForm]],ExpressionUUID->
  "3bb89366-c4c5-4dd4-ad1f-713ce99a9f10"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.9169135013384304`*^9, 3.916913501476965*^9}, {
  3.919430665393629*^9, 3.9194306655793133`*^9}},
 CellID->563321386,ExpressionUUID->"f4f0e299-401b-457d-9f04-39e48eea14d3"],

Cell[CellGroupData[{

Cell[TextData[{
 "Given ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "7303f381-767f-4b83-8085-790c6a74bbc3"],
 " and the ROC, determine the inverse z-transform."
}], "Exercise",
 CellChangeTimes->{{3.898784237604451*^9, 3.898784237904112*^9}, {
   3.916913505269159*^9, 3.916913505376243*^9}, 3.916918190424822*^9, {
   3.919430676346379*^9, 3.9194306764622536`*^9}, 3.9303325232528667`*^9},
 CellID->1634618526,ExpressionUUID->"3b4412e5-c263-48d5-a2db-829234d28d6b"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox[
     RowBox[{"1", "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "4"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]]}], TraditionalForm]],ExpressionUUID->
  "638aa177-a604-480e-9ecd-55479341371d"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", " ", "z", " ", "\[RightBracketingBar]"}], 
    ">", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "7e820354-804d-4c35-a416-a7c9d258d0be"]
}], "ExerciseNote",
 CellChangeTimes->{{3.6665648897927413`*^9, 3.666564921602773*^9}, {
  3.666631792691969*^9, 3.666631802569243*^9}, {3.6667392453963194`*^9, 
  3.666739286860585*^9}, {3.666740222286992*^9, 3.666740257714138*^9}, {
  3.840885296717358*^9, 3.84088529874156*^9}, {3.864219564097123*^9, 
  3.864219564099557*^9}, {3.9201089387384663`*^9, 3.9201089395698586`*^9}},
 CellID->542761515,ExpressionUUID->"ecd19052-46da-4269-a546-d7abaf19997b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Given ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "134a6778-6447-40d6-b218-284700d17d5c"],
 " and the ROC, determine the inverse z-transform."
}], "Exercise",
 CellChangeTimes->{{3.9169135097968388`*^9, 3.916913509929041*^9}, {
   3.916918192820265*^9, 3.916918201708544*^9}, {3.9194316435516434`*^9, 
   3.9194316440003037`*^9}, 3.930332526256077*^9},
 CellID->275270411,ExpressionUUID->"629a460f-94a9-4ae9-aa8c-9390953f54ad"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"X", "(", "z", ")"}], "=", 
    FractionBox[
     RowBox[{"1", "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       FractionBox["1", "4"], 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}]]}], TraditionalForm]],ExpressionUUID->
  "9e02c7cc-fc5c-4e85-89f9-32f34c1988d4"],
 ",\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", " ", "z", " ", "\[RightBracketingBar]"}], 
    "<", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "9c01e2a3-44af-460c-b861-39ce4ea72922"]
}], "ExerciseNote",
 CellChangeTimes->{{3.6665648897927413`*^9, 3.666564921602773*^9}, {
  3.666631792691969*^9, 3.666631802569243*^9}, {3.6667392453963194`*^9, 
  3.666739286860585*^9}, {3.666740222286992*^9, 3.666740257714138*^9}, {
  3.840885296717358*^9, 3.84088529874156*^9}, {3.850487130486029*^9, 
  3.8504871309593735`*^9}, {3.864219564125876*^9, 3.8642195641294317`*^9}, {
  3.920108951971117*^9, 3.9201089527849064`*^9}},
 CellID->255181964,ExpressionUUID->"987432da-e693-48e0-895d-1262dbdd15b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Given ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "25d8ca08-97cc-454e-8983-182519a6034b"],
 ", determine the causal inverse z-transform."
}], "Exercise",
 CellChangeTimes->{{3.9169135147970047`*^9, 3.916913514950676*^9}, 
   3.916918205033764*^9, {3.9194316525166454`*^9, 3.919431652710602*^9}, 
   3.9303325303244343`*^9, {3.9332385107433453`*^9, 3.933238525596199*^9}},
 CellID->790022039,ExpressionUUID->"88cce10b-6fc5-426f-ae73-1d1948fa08f8"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"X", "(", "z", ")"}], "=", 
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"2", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}], 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["3", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]]}], 
  TraditionalForm]],ExpressionUUID->"934d6953-2d23-4198-a236-fc74b0ecfb60"]], \
"ExerciseNote",
 CellChangeTimes->{{3.6984995461965446`*^9, 3.6984995920762243`*^9}, {
  3.7311908308044615`*^9, 3.731190831476404*^9}, {3.8642195641509337`*^9, 
  3.864219564152171*^9}},
 CellID->201272230,ExpressionUUID->"540523fc-b3c4-4633-a2aa-21ed7febe783"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Consider a z-transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "(", "z", ")"}], TraditionalForm]],ExpressionUUID->
  "f718da22-2d08-476a-9206-6891ed6e89bf"],
 " whose pole-zero plot and ROC are as shown. "
}], "Exercise",
 CellChangeTimes->{{3.9169135184522953`*^9, 3.9169135186692524`*^9}, 
   3.916918211747108*^9, {3.9194316602616444`*^9, 3.9194316605080147`*^9}, {
   3.9339565794130898`*^9, 3.9339565976607685`*^9}},
 CellID->9020072,ExpressionUUID->"1dbfb4a3-3d99-478a-aa48-fbd2816ec83f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}}, {}, {{}, 
       InterpretationBox[{
         TagBox[{
           TagBox[{
             RGBColor[0.368417, 0.506779, 0.709798], 
             PointSize[Large], 
             AbsoluteThickness[2], 
             PointBox[{{-1., 0.}, {-1., 0.}}]}, 
            Annotation[#, "Charting`Private`Tag#1"]& ], 
           TagBox[{
             RGBColor[0.880722, 0.611041, 0.142051], 
             PointSize[Large], 
             AbsoluteThickness[2], 
             PointBox[{{0.5, 0.}, {2., 0.}}]}, 
            Annotation[#, "Charting`Private`Tag#2"]& ]}, {
          "WolframDynamicHighlight", <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>}], 
         DynamicBox[
          (Charting`HighlightActionBox["DynamicHighlight", {}, 
           Slot["HighlightElements"], 
           Slot["LayoutOptions"], 
           Slot["Meta"], 
           Charting`HighlightActionFunction["DynamicHighlight", {{
              Annotation[{
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                Point[{{-1., 0.}, {-1., 0.}}]}, "Charting`Private`Tag#1"], 
              Annotation[{
                Directive[
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                Point[{{0.5, 0.}, {2., 0.}}]}, "Charting`Private`Tag#2"]}}, <|
            "HighlightElements" -> <|
              "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
             "LayoutOptions" -> <|
              "PlotRange" -> {{-3., 3.}, {-1.5, 1.5}}, 
               "Frame" -> {{False, False}, {False, False}}, 
               "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 216}, 
               "Axes" -> {True, True}, "AspectRatio" -> Automatic, 
               "DefaultStyle" -> {
                 Directive[
                  RGBColor[0.368417, 0.506779, 0.709798], 
                  AbsoluteThickness[2], 
                  PointSize[Large]], 
                 Directive[
                  RGBColor[0.880722, 0.611041, 0.142051], 
                  AbsoluteThickness[2], 
                  PointSize[Large]]}, 
               "HighlightLabelingFunctions" -> <|
                "CoordinatesToolOptions" -> (Identity[
                    Part[#, 1]] + I Identity[
                    Part[#, 2]]& ), 
                 "ScalingFunctions" -> {{Identity, Identity}, {
                   Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
               False|>, 
             "Meta" -> <|
              "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
               "Function" -> ComplexListPlot, "GroupHighlight" -> 
               False|>|>]]& )[<|
           "HighlightElements" -> <|
             "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
            "LayoutOptions" -> <|
             "PlotRange" -> {{-3., 3.}, {-1.5, 1.5}}, 
              "Frame" -> {{False, False}, {False, False}}, 
              "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 216}, 
              "Axes" -> {True, True}, "AspectRatio" -> Automatic, 
              "DefaultStyle" -> {
                Directive[
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2], 
                 PointSize[Large]], 
                Directive[
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[2], 
                 PointSize[Large]]}, 
              "HighlightLabelingFunctions" -> <|
               "CoordinatesToolOptions" -> (Identity[
                   Part[#, 1]] + I Identity[
                    Part[#, 2]]& ), 
                "ScalingFunctions" -> {{Identity, Identity}, {
                  Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
              False|>, 
            "Meta" -> <|
             "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
              "Function" -> ComplexListPlot, "GroupHighlight" -> False|>|>], 
          ImageSizeCache -> {{
           4.503599627370496*^15, -4.503599627370496*^15}, {
           4.503599627370496*^15, -4.503599627370496*^15}}]}, 
        Annotation[{{
           Annotation[{
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2], 
              PointSize[Large]], 
             Point[{{-1., 0.}, {-1., 0.}}]}, "Charting`Private`Tag#1"], 
           Annotation[{
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[2], 
              PointSize[Large]], 
             Point[{{0.5, 0.}, {2., 0.}}]}, "Charting`Private`Tag#2"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"IndicatedBall"}|>, 
          "LayoutOptions" -> <|
           "PlotRange" -> {{-3., 3.}, {-1.5, 1.5}}, 
            "Frame" -> {{False, False}, {False, False}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {180, 216}, 
            "Axes" -> {True, True}, "AspectRatio" -> Automatic, 
            "DefaultStyle" -> {
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2], 
               PointSize[Large]], 
              Directive[
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2], 
               PointSize[Large]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> (Identity[
                 Part[#, 1]] + I Identity[
                  Part[#, 2]]& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ComplexListPlot, "GroupHighlight" -> False|>|>, 
         "DynamicHighlight"]], {{}, {}}}, {}, {{}, {{{}, {}, {}, {}}, {}}}}, {
     
      GraphicsComplexBox[CompressedData["
1:eJyFmHts1tUZxwvoEo0VhuKlMsRhtAIWZa0Whhxi5yXESMVrgLyRi9cuQXHB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       "], {{{
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2], 
          Opacity[0.3], 
          EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[CompressedData["
1:eJxNmXe4VdURxfccRERpCkpVmiC9POQh76Egiig2BAtSpCpKEbuJFWNiTey9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             "]], 
            PolygonBox[CompressedData["
1:eJw1lnf0l2MYxp/7UakoGkZEcjIicuwV7aWMTrKpjEIJhxONk9BCIjMafilN
kihOh1K0o0XRUKmUUVEpTZ/L9fXH5zzX/b7fd933c1/3t2rbTi0eyimlIVAM
yhBcCkdESnuJe7N+DHPQW6EZuiLnD6AnQ0l0ceiO3gNFnG9PXJ21GvGZ6NNh
IPowjtVD14EvicsRz4W3YRzxGuiMLsH5Ccn3XEA8v3CvD2AOugGMR6+GG9Fn
ZN97JvE81ibh366FWei6MAb9I9Tgt02gIseKw5NwMXFp1p85v5d1DzyM3gUn
c+5qOIpjAW3QA1iLOHcq63HEV0FZ9EGO1WL9J3ztCOiF7guD0L9DP/TzMBi9
DWaj34DR6JXQBt0cPkP/Ca3DOVeul8G36OthGnojXMGzL4Mp6CPDtTs8uxaq
YWv0raztiKuwfgOXZ/92A8fuZG0KE9FL4W70dfA5ege0RV8LU9F/wQPoHfAu
umNybc+CYuEaH617w9PofamQu2ytHD4B5Yn3E69L/m3Z7L2mayqgy8Gzyb85
CV0lO/f9iI9FH5+d6z6wXnUL56onbEL/En73vsm5qQVlwjmqja4Eh/Su2iew
HH4l/lo15dxm4hfQmXVR+Br9dlNybU5UwxRqVDn7mXqWjk2HR6Az4RLYonvD
jOR7rkWvU0+hu8EG9MZwbnvBDPRTMAD9HUxDd4LH0IuVI/SE8Lv+BjvRu2En
uhOckJ0j5Ubf+BrnOhLXZH2U+DR0T/TLye+0C/1g+FrV9Jjsd9K7qMc/Rf8A
29Hzk3tjP/yd3COT0Cvgj2SPyFzfsfCs92AYupVyztqV+MNwT6gXZsEn4Z5Q
L8xVj6JXhp+lPTsl7EHynnna09yrS7jWyuElxBfBpOQePgQHVAPi3dAh9FJ+
Fx2rH+459ZpqVC/sKfKSsTBIvQ+rkj1jGXqpPAX9FQzRt8FPyR7UKOxh8q4u
0DDsQfKe96El+naeX/n/e6h2MApdAuqgZyrHyTUehe6hPZzc4yMKPaNeUY/W
DnuavEz3KMW9z1fPy3eIb2BdDJvR02EkeiGsT85RK/QS2IJ+Jbm35SnyEvW4
3nUMcf/kd9beeTX8rtpDa6B09rN6wLnoa7Tn9Bsohn68UGt5uJ5VN9vr9cym
6G3oYdpr4Wvbh7XuIW9ux1oh7NH6Fnm8vF3fpNyMDn+bcqRZ0gDKh2eK9lpj
dKXkPXc/8VjWlsQ1WE8h7lbwki+Sa/1WuPaq+bjCNTUKPaJZNjzcq9ULtR8a
rq32QIuCR8gb1LNXZs8UzRJ5jmaDPFdeqxlxW3iGaHZ04NhLek7YS7VVPwr3
uHp7tjwA/T28nvwNyt052bNLOVRtLyQuVajxdtaa2bV4h7g/69nEC9FD9c3a
j+FnDYfGnNsaPqecNyJumP1/QNdMDc8QzQ4d014dGL5We7Y555plP2sR7NM3
w8hkj5A+GO7F/46FZ6RmozzrRfR52dcWwZthz5PXaSYODnuqvFT/Ebqjq2XX
TntU3jQ57A3yqPvQt8AC9Aq4F31z2FuWQ5/wMWnN5OfC1+i3msnPoO9RzpNz
rtzeRVwynGOduynsXfqNvG9iuFbywDu0D8NeoD1YP9vT5eXao13DM12zXDNO
vasZrNmrHl4Nqwp7Q99QPbtn1auasZpV48NepJl1QXZPqhf1jprdVbNnl2b4
v5ViUl8=
             "]]}]}, {}, {}, {}, {}}, {
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[2], 
         StyleBox[{
           LineBox[CompressedData["
1:eJwl00VsFVEUgOF5RRN0jxZZ4TsWuLWlaNFCsUJpkbY4CQES3N3dEhLc3YPL
DrdgCS7FXb4bFl/+e07zMvPeTOPTc1NyYlEU5ZERF0ULDMdJYy7z6McH+vOR
OnxmAJ/4yhfq8p0ffOMXP6nHH/7ym4Hhgq5VX+M0W2MabmQR2c4L9QxnWUwr
uwZ6jka0MS/TQSynrbmxXqAp7cyrdAiraW9uppdIopN5rV7hMuvIsluvI3jA
Qx6RTBF/G6WPeUIvWlLKvjRPnZ/Rm9bE21XgufMLXoZ7orLdOH3Fa7aE39du
s17nBhNJt5ugfcK90s28UycxNVzHPEUz6Ex38z6dxozwOfN07UsqPcyH9T73
6Bq+g90craXvdTY1nY+F76YtyHOuodVJJsvcXN9pNa1KEpnmRH2rs6jifFQT
wu/OG+eZHKGnuYve4S6Hwjthd1Bvsz88V/MBncze8K6Z9+gtdpFr3q3j2RHe
TfN2vclWcszb9BpXw/MnzW6TjqWi8xitpBu1vI7WMlqOsuH9pAQlKUpxilGb
QhSmACN9rqBu0Pw6XPPpMF1DR+fE8Aw5xVA62CXoRVaQaV6pJxlMirmJnmdJ
eI7mpXoifPfwjpkb6mnmx/7/7/4DAy99AQ==
            "]], 
           
           LineBox[{478, 522, 521, 562, 350, 330, 600, 420, 376, 530, 531, 
            529, 379, 352, 332, 532, 533, 484, 485, 354, 334, 463, 336, 601, 
            423, 383, 424, 602, 337, 465, 341, 551, 552, 550, 554, 553, 342, 
            466, 578, 579, 577, 581, 580, 450, 384, 603, 338, 464, 576, 537, 
            538, 534, 536, 535, 574, 462, 570, 571, 569, 573, 572, 377, 566, 
            567, 565, 421, 461, 564, 351, 563, 478}]}, 2 -> 
          RGBColor[0.880722, 0.611041, 0.142051]]}}], {}}}, AspectRatio -> 
    Automatic, Axes -> True, AxesOrigin -> {0, 0}, DisplayFunction -> 
    Identity, Epilog -> {
      RGBColor[1, 0, 0], 
      CircleBox[{0, 0}]}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], ImagePadding -> All, ImageSize -> Small, 
    Method -> {
     "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.528488, 0.470624, 0.701351], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.772079, 0.431554, 0.102387], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.363898, 0.618501, 0.782349], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[1, 0.75, 0], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.647624, 0.37816, 0.614037], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.571589, 0.586483, 0.], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.915, 0.3325, 0.2125], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
         AbsoluteThickness[2]], 
        Directive[
         RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
         AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
      "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05],
       "MessagesHead" -> ComplexListPlot, 
      "CoordinatesToolOptions" -> {"DisplayFunction" -> (Identity[
           Part[#, 1]] + I Identity[
            Part[#, 2]]& ), "CopiedValueFunction" -> (Identity[
           Part[#, 1]] + I Identity[
            Part[#, 2]]& )}}, PlotRange -> {{-3., 3.}, {-1.5, 1.5}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
    Ticks -> {{{-1, 
        FormBox[
         RowBox[{"-", "1"}], TraditionalForm]}, {
        NCache[
         Rational[1, 2], 0.5], 
        FormBox[
         FractionBox["1", "2"], TraditionalForm]}, {2, 
        FormBox["2", TraditionalForm]}}, {}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"zeros\"", "\"poles\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2], 
                    PointSize[Large]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   RowBox[{"PointSize", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "ExerciseNote",
 CellChangeTimes->{{3.893369556098564*^9, 3.893369576106341*^9}, 
   3.898784267491905*^9},
 CellID->116395045,ExpressionUUID->"e5dad805-cfed-4989-a22e-4e0587188336"],

Cell["Obtain the inverse z-transform.", "ExerciseNote",
 CellChangeTimes->{{3.850500834793929*^9, 3.850500844679705*^9}, 
   3.864219564203311*^9, {3.916913523560573*^9, 3.916913523714281*^9}, {
   3.9194316688365993`*^9, 3.919431669122265*^9}},
 CellID->265318150,ExpressionUUID->"4ab38514-f2e6-4092-ad21-b76fedcd4669"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["\[Copyright] 2024 Wolfram Media, Inc.", "SmallText",
 CellMargins->{{66, 66}, {20, 100}},
 CellGroupingRules->"SectionGrouping",
 FontSize->12,
 FontColor->RGBColor[
  0.7098039215686275, 0.7098039215686275, 0.7098039215686275],
 CellID->940421076,ExpressionUUID->"8d9945a8-5296-4365-bbe6-73f169a9735e"]
},
Editable->True,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellInsertionPointCell->None,
WindowSize->Automatic,
WindowMargins->{Automatic, Automatic},
WindowFrame->"Normal",
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"27. Inverse z\[Hyphen]Transform | Signals, Systems, and Signal \
Processing",
DockedCells->{
  Cell[
   TagBox[
    GridBox[{{
       PaneBox[
        TagBox[
         GridBox[{{
            StyleBox["Wolfram eTextbook Series", 12, 
             RGBColor[
             0.8823529411764706, 0.40784313725490196`, 0.1450980392156863], 
             FontFamily -> "Source Sans Pro"]}, {
            TemplateBox[{
              StyleBox["\"Signals, Systems, and Signal Processing\"", 20, 
               GrayLevel[1], FontWeight -> "SemiBold", FontFamily -> 
               "Source Sans Pro"], 
              "https://www.wolfram.com/wolfram-u/courses/image-signal-\
processing/signals-systems-and-signal-processing/"}, "HyperlinkURL"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}], "Grid"], 
        ImageSize -> Full, FrameMargins -> {{20, 20}, {5, 12}}], 
       PaneBox[
        PaneBox[
         TemplateBox[{"\[ThinSpace]", "\" \"", 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""},
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
               ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""},
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                 Method -> "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], "\"26. z\[Hyphen]Transform\"", TooltipDelay -> 
             0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, "26. z\[Hyphen]Transform", "Tooltip"]& ], 
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[5], Selectable -> False], 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-28_Z-Transform-Theorems.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                 Automatic, Method -> "Preemptive"], True -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{
                   "SignalsSystemsAndSignalProcessing-28_Z-Transform-Theorems.\
nb", ""}, FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                 GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                 "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], "\"28. z\[Hyphen]Transform Theorems\"", 
             TooltipDelay -> 0.15, LabelStyle -> "TextStyling"], 
            Annotation[#, "28. z\[Hyphen]Transform Theorems", "Tooltip"]& ]}, 
          "RowWithSeparators"], Alignment -> Right], Alignment -> Right, 
        FrameMargins -> {{0, 6}, {0, 0}}, ImageSize -> {100, 30}], 
       TagBox[
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0., 0.1607843137254902, 0.4], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "Cover" :> NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00a_Cover.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Preface" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-00b_Preface.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Signals and Systems\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "1. Introduction to Signals and Systems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-01_Introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2. Signal Classification" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-02_Signal-Classification.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3. Elementary Signals and Sequences" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-03_Elementary-Signals.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4. Elementary Operations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-04_Elementary-Operations.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5. System Properties" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-05_System-Properties.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "6. Continuous\[Hyphen]Time Systems as Differential Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-06_CT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "7. Differential Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-07_CT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "8. Continuous\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-08_CT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "9. Continuous\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-09_CT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Time-Domain Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10. Discrete\[Hyphen]Time Systems as Difference Equations" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-10_DT_System-Modeling.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "11. Difference Equation Solution Methods" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-11_DT_Solution-Methods.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "12. Discrete\[Hyphen]Time System Response" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-12_DT_System-Response.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13. Discrete\[Hyphen]Time Convolution" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-13_DT_Convolution.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Continuous)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "14. Continuous\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-14_CT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "15. Continuous\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-15_CT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "16. Continuous\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-16_CT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "17. Continuous\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-17_CT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Fourier Analysis (Discrete)\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "18. Discrete\[Hyphen]Time Fourier Series" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-18_DT_Fourier-Series.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "19. Discrete\[Hyphen]Time Fourier Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-19_DT_Fourier-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "20. Discrete\[Hyphen]Time Fourier Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-20_DT_Fourier-Transform-\
Theorems.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "21. Discrete\[Hyphen]Time Filters" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-21_DT_Filters.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Laplace Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "22. Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-22_Laplace-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "23. Inverse Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-23_Inverse-Laplace-Transform.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "24. Laplace Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-24_Laplace-Transform-Theorems.\
nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "25. Unilateral Laplace Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-25_Unilateral-Laplace-\
Transform.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"z\[Hyphen]Transform\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "26. z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-26_Z-Transform.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "27. Inverse z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-27_Inverse-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "28. z\[Hyphen]Transform Theorems" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-28_Z-Transform-Theorems.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "29. Unilateral z\[Hyphen]Transform" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-29_Unilateral-Z-Transform.nb", 
             ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          StyleBox["\"Sampling and Filter Design\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "30. Sampling" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-30_Sampling.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "31. FIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-31_FIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "32. Butterworth Filter" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-32_Butterworth-Filter.nb", ""},
             FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "33. IIR Filter Design" :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-33_IIR-Filter-Design.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], StyleBox["\"Sample Exam\"", Bold] :> 
          NotebookLocate[{
            "SignalsSystemsAndSignalProcessing-34_Sample-Exam.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None], 
        MouseAppearanceTag["LinkHand"]]}}, AutoDelete -> False, 
     GridBoxItemSize -> {
      "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"], 
   Background -> RGBColor[0., 0.1607843137254902, 0.4], 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrameColor -> 
   RGBColor[0., 0.1607843137254902, 0.4], CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameMargins -> {{0, 20}, {5, 0}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, CellGroupingRules -> {"SectionGrouping", 0}, 
   CellContext -> CellGroup], 
  Cell[
   BoxData[
    GridBox[{{
       DynamicModuleBox[{$CellContext`open$$ = False}, 
        PaneSelectorBox[{True -> ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{93, 93, 93, 19}, {140, 140, 
                   140, 237}, {115, 115, 115, 181}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {115, 115, 115, 181}, {140,
                    140, 140, 237}, {93, 93, 93, 19}}, {{140, 140, 140, 
                   236}, {179, 179, 179, 255}, {179, 179, 179, 255}, {127, 
                   127, 127, 216}, {92, 92, 92, 11}, {92, 92, 92, 11}, {127, 
                   127, 127, 216}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {140, 140, 140, 236}}, {{102, 102, 102, 119}, {167, 
                   167, 167, 255}, {179, 179, 179, 255}, {179, 179, 179, 
                   255}, {142, 142, 142, 240}, {141, 141, 141, 239}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {167, 167, 167, 
                   255}, {102, 102, 102, 119}}, {{0, 0, 0, 0}, {98, 98, 98, 
                   75}, {158, 158, 158, 251}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {179, 179, 179, 255}, {179, 179, 179, 255}, {
                   158, 158, 158, 251}, {98, 98, 98, 75}, {0, 0, 0, 0}}, {{0, 
                   0, 0, 0}, {0, 0, 0, 0}, {93, 93, 93, 38}, {144, 144, 144, 
                   241}, {179, 179, 179, 255}, {179, 179, 179, 255}, {144, 
                   144, 144, 241}, {93, 93, 93, 38}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {92, 92, 
                   92, 11}, {129, 129, 129, 222}, {129, 129, 129, 222}, {92, 
                   92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                   0}}}], {{0, 6.}, {10., 0}}, {0, 255}, ColorFunction -> 
                  RGBColor, ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {10., 6.}, PlotRange -> {{0, 10.}, {0, 6.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"], False -> 
          ButtonBox[
            TemplateBox[{
              StyleBox[
              "\"Mariusz Jankowski  |  Cite this eTextbook  \"", 11, 
               FontWeight -> "Regular", FontFamily -> "Source Sans Pro", 
               FontColor -> 
               RGBColor[
                0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[
                 RawArray["UnsignedInteger8",{{{0, 0, 0, 0}, {98, 98, 98, 
                   78}, {132, 132, 132, 225}, {97, 97, 97, 21}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{93, 93, 93, 49}, {168, 
                   168, 168, 255}, {179, 179, 179, 255}, {141, 141, 141, 
                   238}, {92, 92, 92, 11}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{102,
                    102, 102, 15}, {149, 149, 149, 246}, {179, 179, 179, 
                   255}, {179, 179, 179, 255}, {133, 133, 133, 229}, {102, 
                   102, 102, 5}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {95, 95, 95, 
                   40}, {156, 156, 156, 250}, {179, 179, 179, 255}, {179, 179,
                    179, 255}, {129, 129, 129, 217}, {255, 255, 255, 1}}, {{0,
                    0, 0, 0}, {0, 0, 0, 0}, {95, 95, 95, 56}, {163, 163, 163, 
                   253}, {179, 179, 179, 255}, {179, 179, 179, 255}, {115, 
                   115, 115, 181}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {103, 103, 
                   103, 123}, {174, 174, 174, 255}, {179, 179, 179, 255}, {
                   176, 176, 176, 255}, {102, 102, 102, 119}}, {{0, 0, 0, 
                   0}, {100, 100, 100, 102}, {172, 172, 172, 255}, {179, 179, 
                   179, 255}, {179, 179, 179, 255}, {109, 109, 109, 154}, {0, 
                   0, 0, 0}}, {{91, 91, 91, 42}, {167, 167, 167, 255}, {179, 
                   179, 179, 255}, {179, 179, 179, 255}, {114, 114, 114, 
                   176}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{97, 97, 97, 21}, {147,
                    147, 147, 245}, {179, 179, 179, 255}, {119, 119, 119, 
                   194}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0,
                    0}, {93, 93, 93, 19}, {103, 103, 103, 128}, {0, 0, 0, 
                   0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}], {{
                   0, 10.}, {7., 0}}, {0, 255}, ColorFunction -> RGBColor, 
                  ImageResolution -> {72., 72.}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {7., 10.}, PlotRange -> {{0, 7.}, {0, 10.}}, 
                ImageSize -> Magnification[1]]]}, "RowDefault"], 
            ButtonFunction :> 
            If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
              False, $CellGroupContext`open$$ = True], Appearance -> None, 
            Evaluator -> Automatic, Method -> "Preemptive"]}, 
         Dynamic[$CellGroupContext`open$$]], 
        Initialization :> ($CellGroupContext`open$$ = False), 
        DynamicModuleValues :> {}]}}, 
     GridBoxItemSize -> {"Columns" -> {{50}}, "Rows" -> {{Automatic}}}, 
     GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
     GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{0}}}]], "Text", 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   CellFrameMargins -> {{28, 0}, {2, 2}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.], CellContext -> 
   CellGroup], 
  Cell[
   BoxData[
    TemplateBox[{
      TemplateBox[{
        StyleBox[
        "\"M. Jankowski (2024), \"", FontWeight -> "Bold", FontSize -> 11, 
         FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Signals, Systems, and Signal Processing: A Computational Approach, \
\"", Selectable -> True, Copyable -> True, FontSlant -> Italic, FontWeight -> 
         "Bold", FontSize -> 11, FontFamily -> "Source Sans Pro", FontColor -> 
         RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
        StyleBox[
        "\"Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing.\"", 
         FontWeight -> "Bold", FontSize -> 11, FontFamily -> 
         "Source Sans Pro", FontColor -> 
         RGBColor[
          0.2784313725490196, 0.403921568627451, 0.5137254901960784]]}, 
       "RowDefault"], 
      "M. Jankowski (2024), \!\(\*StyleBox[\"Signals\",FontSlant->\"Italic\"]\
\)\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Systems\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\",\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \",FontSlant->\
\"Italic\"]\)\!\(\*StyleBox[\"and\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Signal\",FontSlant->\"Italic\"]\)\
\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Processing\",FontSlant->\"Italic\"\
]\)\!\(\*StyleBox[\":\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"A\",FontSlant->\"Italic\"]\)\!\(\*\
StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Computational\",FontSlant->\"\
Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"Approach\",FontSlant->\"Italic\"]\
\), Wolfram Media. \
wolfram-media.com/products/signals-systems-and-signal-processing."}, 
     "ClickToCopy2", BaseStyle -> {LineBreakWithin -> Automatic}]], "Text", 
   Selectable -> True, CellFrame -> {{0, 1}, {0, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {0, -1}}, 
   CellElementSpacings -> {"CellMinHeight" -> 2, "ClosedCellHeight" -> 1}, 
   Copyable -> True, CellOpen -> Dynamic[$CellGroupContext`open$$], 
   CellContext -> CellGroup, CellFrameMargins -> {{28, 0}, {5, 0}}, 
   CellFrameColor -> RGBColor[0.8627450980392157, 0.9333333333333333, 1.], 
   LineSpacing -> {1, -3}, ShowStringCharacters -> False, Background -> 
   RGBColor[0.8627450980392157, 0.9333333333333333, 1.]]},
ShowCellBracket->Automatic,
ShowCellLabel->False,
CellLabelAutoDelete->True,
CellLabelTemplate-><|
 "In" -> "In[`1`]:=", "InExpired" -> "In[`1`]:=", "Out" -> "Out[`1`]=", 
  "OutExpired" -> "Out[`1`]="|>,
ShowAutoSpellCheck->False,
ShowPredictiveInterface->False,
AutoStyleOptions->{"HighlightComments"->True},
AutoMultiplicationSymbol->{},
Magnification->1,
FrontEndVersion->"14.0 for Mac OS X ARM (64-bit) (December 12, 2023)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["eBook Styles", "Section"], 
      Cell[
       StyleData["ContentsTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       MenuSortingValue -> 20000, FontFamily -> "Helvetica", FontSize -> 36, 
       FontWeight -> "Bold", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
      Cell[
       StyleData["Leader"], TabFilling -> ".", MenuSortingValue -> 10000, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       18, FontWeight -> "Plain"], 
      Cell[
       StyleData["LeaderNoDots"], TabFilling -> " ", MenuSortingValue -> 
       10000, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["PageLink"], MenuSortingValue -> 10000, StyleMenuListing -> 
       None, ButtonStyleMenuListing -> Automatic, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontColor -> 
       RGBColor[0.269993, 0.308507, 0.6], 
       ButtonBoxOptions -> {
        Active -> True, Appearance -> {Automatic, None}, 
         ButtonFunction :> (FrontEndExecute[{
            FrontEnd`NotebookLocate[#2]}]& )}], 
      Cell[
       StyleData["TOCPage"], CellSize -> {40, Inherited}, TextAlignment -> 
       Right, MenuSortingValue -> 20010, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain"], 
      Cell[
       StyleData["TOCTitle"], CellMargins -> {{66, 66}, {4, 14}}, 
       CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 36, 
       CounterIncrements -> "TOCTitle", MenuSortingValue -> 20020, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontWeight -> "Bold", FontColor -> 
       GrayLevel[0]], 
      Cell[
       StyleData["TOCSection"], CellMargins -> {{95, 95}, {1, 1}}, 
       CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 34, 
       CounterIncrements -> "TOCSection", MenuSortingValue -> 20030, 
       FontFamily -> "Source Sans Pro", FontSize -> 16], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 81}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"ItemGrouping", 70}, CellFrameLabelMargins -> 
          4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Baskerville", FontSize -> 
          18], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{81, 81}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["SectionSingleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
       CellDingbat -> Cell[
         TextData[
          CounterBox["Section"], 
          StyleBox[
          "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
           RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
           FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]], 
         "SectionNumber"], CellMargins -> {{100, 100}, {12, 64}}, Evaluatable -> 
       True, CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
       True, ShowCellLabel -> False, 
       CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
       CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", FontSize -> 
       26, FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       InterpretationBoxOptions -> {Editable -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsubsection"], 
          CellMargins -> {{66, 66}, {2, 10}}, 
          StyleKeyMapping -> {
           "Backspace" -> 
            "Subsubsubsection", $CellContext`KeyEvent[
             "Tab", $CellContext`Modifiers -> {"Shift"}] -> 
            "Subsubsubsection"}, CellGroupingRules -> {"SectionGrouping", 70},
           PageBreakBelow -> False, LanguageCategory -> "NaturalLanguage", 
          CounterIncrements -> "Subsubsubsubsection", 
          CounterAssignments -> {{"Item", 0}, {"Subitem", 0}, {
            "Subsubitem", 0}, {"ItemNumbered", 0}, {"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> None, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsubsubsection", "Printout"], 
          CellMargins -> {{66, 66}, {2, 10}}], 
         Cell[
          StyleData["Chapter", "Printout"], 
          CellMargins -> {{Inherited, Inherited}, {62, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
       CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
       Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
       PageBreakBelow -> False, ShowCellLabel -> False, 
       CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
       RGBColor[0.901961, 0.411765, 0.027451], 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Exercise", 0}}, MenuSortingValue -> 10015, FontFamily -> 
       "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
       RGBColor[
        0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
       GridBoxOptions -> {GridBoxAlignment -> {}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{108, 108}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10025, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{110, 110}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummarySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], MenuSortingValue -> 9000, 
          FontFamily -> "Source Sans Pro", FontSize -> 18, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["SummarySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 9010, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryNote", "Printout"], 
          CellMargins -> {{68, 68}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SummaryList"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 9020, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["SummaryList", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Open]], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[5]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Appearance -> "PopupMenu",
                Method -> "Queued", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {"PageSize" -> {504, 720}}, 
       AutoStyleOptions -> {"UndefinedSymbolStyle" -> None}, Magnification -> 
       0.6], 
      Cell[
       StyleData[All, "Invisibles"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Solved Example\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`\
WBTInsertSolvedExampleAndSolvedExampleNoteCells[]), 
                "\"Solved Example Input\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleInputCell[]), 
                "\"Solved Example Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertSolvedExampleNoteCell[]), 
                Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseNote[]), Delimiter, 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, Appearance -> 
               "PopupMenu", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Method -> "Queued", 
               FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> 
         None}, $CellContext`GhostCellInEmptyNotebook -> False]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], 
       PrintingOptions -> {"PageHeaderMargins" -> {28, 28}}, StyleMenuListing -> 
       None, FontFamily -> "Source Sans Pro", FontSize -> 8, FontWeight -> 
       "Regular", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> WindowWidth, 
       PrintingOptions -> {
        "FirstPageHeader" -> True, "InnerOuterMargins" -> {30, 30}, 
         "PaperOrientation" -> "Portrait", "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, 64}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, 64}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{64, 64}, {12, 64}}, 
          CellGroupingRules -> {"SectionGrouping", 30}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{62, 62}, {52, 182}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, 112}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, 112}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionBar"], FontFamily -> "Source Sans Pro", 
          FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionBar", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], CellMargins -> {{64, 64}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, 64}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumbered"], CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Subsection"]}], "SubsectionNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{98, 98}, {Inherited, 32}}, CounterIncrements -> 
          "Subsection", FontFamily -> "Source Sans Pro Semibold", FontSize -> 
          18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsectionNumbered", "Printout"], 
          CellMargins -> {{102, 102}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumber"], FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          GrayLevel[0.25]], 
         Cell[
          StyleData["SubsectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionFirst"], CellMargins -> {{64, 64}, {2, 72}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, 64}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsubsectionTopMargin"], 
          CellMargins -> {{64, 64}, {2, 14}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsubsectionTopMargin", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsection"], CellMargins -> {{64, 64}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.45]], 
         Cell[
          StyleData["Subsubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, 64}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, 64}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsection"], 
          CellMargins -> {{64, 64}, {2, 10}}, FontFamily -> "Source Sans Pro",
           FontSize -> 16, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsectionSM"], 
          CellFrame -> {{0, 0}, {0.75, 0}}, 
          CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Regular", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {6, 15}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakBelow -> False, ShowCellLabel -> False, 
          CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, 64}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsectionSM"], 
          CellMargins -> {{64, 64}, {4, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ExerciseSubsectionSM", "Printout"], 
          CellMargins -> {{64, 64}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> False, CellMargins -> {{106, 106}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 62}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{108, 108}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellGroupingRules -> {"SectionGrouping", 62.}, PageBreakBelow -> 
          False, LineSpacing -> {1., 1., 2.}, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}, LineSpacing -> {0.8, 1., 2.}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {2, 12}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, CounterIncrements -> "Question", 
          MenuSortingValue -> 10030, MenuCommandKey :> "3", FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, 65}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> WindowWidth, 
          CellMargins -> {{66, 66}, {4, 1}}, ReturnCreatesNewCell -> True, 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`DefaultReturnCreatedCellStyle -> 
          "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 66}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSubsection"], CellMargins -> {{64, 64}, {2, 10}},
           FontFamily -> "Source Sans Pro", FontSize -> 16, FontSlant -> 
          "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["TechNoteSubsubsection", "Printout"], 
          CellMargins -> {{64, 64}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> WindowWidth, CellDingbat -> 
          Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, 93}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, 93}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteNoDingbat"], PageWidth :> WindowWidth, 
          CellMargins -> {{82, 82}, {4, 8}}, ReturnCreatesNewCell -> True, 
          CellFrameLabelMargins -> 4, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, 82}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> WindowWidth, CellDingbat -> Cell[
            TextData[{"\[FilledSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, 78}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 4, 
          LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 1, FontSize -> 
          14], 
         Cell[
          StyleData["TechNoteInput", "Printout"], 
          CellMargins -> {{99, 99}, {3, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TechNoteOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 14], 
         Cell[
          StyleData["TechNoteOutput", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> WindowWidth, 
          CellMargins -> {{64, 64}, {4, 8}}, ReturnCreatesNewCell -> True, 
          PageBreakBelow -> False, MenuSortingValue -> 10050, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], CellMargins -> {{64, 64}, {4, 8}},
           PageBreakBelow -> False, FontFamily -> "Source Sans Pro Light", 
          FontSize -> 14, FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, 64}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{1, 1}, {1, 1}}, CellMargins -> {{52, 52}, {-1, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{16, 8}, {6, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "Bold", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[1], Background -> 
          RGBColor[0.901961, 0.411765, 0.027451]], 
         Cell[
          StyleData["TakeawaysSection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysHeader"], CellMargins -> {{64, 64}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "SemiBold", 
          FontSlant -> "Regular", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysHeader", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysTable"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 0}}, CellMargins -> {{52, 52}, {12, -1}}, 
          ReturnCreatesNewCell -> True, 
          CellFrameMargins -> {{18, 12}, {20, 12}}, CellFrameLabelMargins -> 
          6, LineSpacing -> {1.25, 1., 2.}, SpanMaxSize -> 1, FontFamily -> 
          "Source Sans Pro Light", FontColor -> GrayLevel[0.25], Background -> 
          RGBColor[1., 0.9490196078431372, 0.8509803921568627], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"TakeawaysDingbat", Inherited}, 
              "Rows" -> {{SpanFromLeft, Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.75}}}}], 
         Cell[
          StyleData["TakeawaysTable", "Printout"], 
          CellMargins -> {{51.5, 51.5}, {12, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysText", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TakeawaysDingbat", StyleDefinitions -> StyleData["Text"]], 
          FontFamily -> "Source Sans Pro", FontSize -> 10, FontWeight -> 
          "SemiBold", FontColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TakeawaysDingbat", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeText", StyleDefinitions -> StyleData["Text"]], 
          CellMargins -> {{66, 66}, {3, 15}}, LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 1540, 
          MenuCommandKey :> $CellContext`MenuKey[
           "7", $CellContext`Modifiers -> {"Shift"}], FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeText", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 66}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 66}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], CellMargins -> {{99, 99}, {2, 12}}, 
          StripStyleOnPaste -> True, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 99}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, 100}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.135 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, 18}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, 49}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontFamily -> Automatic, FontSize -> 
            18, FontWeight -> GrayLevel[0], 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{81, 81}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontSize -> 17, FontFamily -> 
            "Automatic", FontWeight -> "Black", 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{80, 80}, {Inherited, Inherited}}, 
          CellDingbatMargin -> 2, 
          CellGroupingRules -> {
           "GroupTogetherNestedGrouping", 1.073741821*^9}, 
          CellChangeTimes -> {{3.8855684925344043`*^9, 
           3.885568495926271*^9}, {3.885643888233819*^9, 
           3.885643900721007*^9}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 81}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, 80}, {Inherited, 0.5 Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 85}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, 90}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Note"], CellFrame -> {{0, 0}, {0, 1}}, 
          CellMargins -> {{66, 66}, {8, 6}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameMargins -> {{14, 14}, {12, 12}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          LineSpacing -> {1.2, 1., 2.}, MenuSortingValue -> 1600, FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontColor -> GrayLevel[0.2], 
          Background -> RGBColor[1., 0.9647058823529412, 0.9411764705882353]], 
         Cell[
          StyleData["Note", "Printout"], CellMargins -> {{66, 66}, {10, 8}}, 
          FontSize -> 14]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EchoTiming"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}], 
         Cell[
          StyleData["EchoTiming", "Printout"], 
          CellMargins -> {{99, 99}, {Inherited, Inherited}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 100}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 125}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> WindowWidth, 
          CellFrame -> {{0, 0}, {0, 3}}, CellMargins -> {{64, 64}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, 64}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 80}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110586`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 66}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TextFirst"], CellMargins -> {{66, 66}, {4, 72}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 66}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 66}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SmallText"], CellMargins -> {{66, 66}, {6, 6}}, 
          LineSpacing -> {1, 3}, TabSpacings -> {2.5}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "SmallText", 
          MenuSortingValue -> 1750, StyleMenuListing -> None, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["SmallText", "Printout"], 
          CellMargins -> {{66, 66}, {7, 7}}, Hyphenation -> True]}, Closed]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 66}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 66}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 99}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 99}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 99}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 99}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 99}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 99}, {15, 10}}]}, Closed]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       StyleData[
       "CellLabelExpired", StyleDefinitions -> StyleData["CellLabel"]], 
       CellLabelMargins -> 6, FontSlant -> Italic, FontTracking -> 0.4, 
       FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["SummaryPanel"], GeneratedCell -> True, CellAutoOverwrite -> 
       True, CellChangeTimes -> {3.84753348107472*^9}, FontFamily :> 
       CurrentValue["PanelFontFamily"], FontSize :> 0.8 Inherited, FontWeight -> 
       "Plain", FontSlant -> "Plain", FontColor :> 
       CurrentValue[{"SystemColors", "DialogText"}], 
       TemplateBoxOptions -> {
        DisplayFunction -> (
          ButtonBox[#, Active -> False, Alignment -> Left, 
           Appearance -> {"Default" -> Image[CompressedData["
1:eJzNlk0KgkAUgKVatGzRAWohXqFty7ZFB1AyaWOgQXQozyIPZmCgxYBLQUQ6
gL2R/ElcBKWvgU+cQd/3ZhxnZmmdt8eRpmn+FC9b87r2PPO2m2Fl7/onx7UP
G/diO7a3ssbYOEcWyATJvyw/CFGECcNQRwIkQ3J4Eb4BrXqjDT55togdYFxd
OUs5ABj4fipllMdxnCdJ0gsqdoQOzC3FPIyGP1DtfXnbSCkLZ/ntGEDWZ7+7
xgGAPSo/Y4O5SxiDau5yAj/nrPZzTuDnlV9wMbhfCFH4Fep+cP9d1P2n9hOO
/z/MP+r/j3r9oV5/qfcf6v2X4vyB+XQenMo1sS/a5QlC6exw
               "], "Byte", ColorSpace -> "RGB", Interleaving -> True]}, 
           FrameMargins -> 7, BaseStyle -> {Deployed -> False}, 
           DefaultBaseStyle -> {"Pane", Background -> None}, BaselinePosition -> 
           Baseline]& ), Tooltip -> None}, 
       GraphicsBoxOptions -> {
        Axes -> False, 
         DefaultBaseStyle -> {"GraphicsNoFontOrMenu", CacheGraphics -> False},
          ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}, 
       Graphics3DBoxOptions -> {
        Axes -> False, DefaultBaseStyle -> {"Graphics3DNoFontOrMenu"}, 
         ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}], 
      Cell[
       StyleData["IconizedDefaultName"], FontSize -> 12, 
       PrivateFontOptions -> {"OperatorSubstitution" -> False}, FontColor -> 
       GrayLevel[0.15]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, 66}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, 100}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{106, 106}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{106, 106}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{106, 106}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{106, 106}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 66}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 66}, {8, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Tentative"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[
          0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
         "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
       StyleMenuListing -> None, Background -> 
       RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["PrintOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.89, 0.867, 0.99], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.89, 0.867, 0.99]], 
         Cell[
          StyleData["PrintOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Closed]], 
      Cell[
       StyleData["SolvedExampleNote", StyleDefinitions -> StyleData["Text"]], 
       CellMargins -> {{66, 66}, {8, 0}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleInput", StyleDefinitions -> StyleData["Input"]], 
       CellMargins -> {{66, 66}, {0, -10}}, 
       GeneratedCellStyles -> {"Output" -> "SolvedExampleOutput"}, Background -> 
       RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData[
       "SolvedExampleOutput", StyleDefinitions -> StyleData["Output"]], 
       CellMargins -> {{66, 66}, {8, -9}}, Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]], 
      Cell[
       StyleData["SolvedExample"], CellMargins -> {{66, 66}, {0, 16}}, 
       CounterIncrements -> "SolvedExample", FontFamily -> "Source Sans Pro", 
       FontSize -> 16.5, FontWeight -> "SemiBold", FontColor -> 
       RGBColor[0., 0.0078, 0.13], Background -> RGBColor[
         Rational[254, 255], 
         Rational[241, 255], 
         Rational[73, 85]]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0, 2}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["StandardForm", "Printout"], LineSpacing -> {1.25, 0, 2}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["OutputForm"], LineSpacing -> {0.6, 1}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["OutputForm", "Printout"], LineSpacing -> {0.6, 1}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputForm"], FontFamily -> "Source Sans Code"], 
         Cell[
          StyleData["InputForm", "Printout"], FontFamily -> 
          "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FormattedFunction"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]]], 
         Cell[
          StyleData["FormattedFunction", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup["ref/" <> #]]& ), ButtonSource -> 
            ButtonContents, Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FunctionLink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["FunctionLink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "FunctionHyperlink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["FunctionHyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ResourceFunctionlink", StyleDefinitions -> StyleData["Hyperlink"]],
           MenuSortingValue -> None, FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourceFunctionlink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Closed]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineMath"], SpanMaxSize -> 0, FontColor -> GrayLevel[0], 
       CellID -> 644119144], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.94 Inherited], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["DialogElementName"], 
       CellChangeTimes -> {3.642251807158844*^9, 3.8358753610849867`*^9, 
        3.835875471581566*^9}, FontFamily -> "Source Sans Pro SemiBold", 
       FontSize -> 0.95 Inherited, FontWeight -> "Regular"], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          1.05 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          1.1 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontSize -> 0.85 Inherited, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    PaneBox[
                    StyleBox[#4, "EntityTypeLabel"], BaselinePosition -> 
                    Baseline, ContentPadding -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               Directive[
                 RGBColor[1., 0.504768, 0.], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
          AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
          ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Helvetica", FontSize -> 0.85 Inherited, FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> Directive[
                 RGBColor[0.94227, 0.703639, 0.033387], 
                 AbsoluteThickness[1]], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4, 
               BaseStyle -> {FontFamily -> "Courier"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
              TooltipDelay -> 0.4]& ), Editable -> False, 
            InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
     Closed]]}, Visible -> False, FrontEndVersion -> 
  "14.0 for Mac OS X ARM (64-bit) (December 12, 2023)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"ffd73792-1803-4b6a-ba20-69757a5b7892"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[666, 24, 439, 6, 111, "SectionDoubleDigit",ExpressionUUID->"c30f2170-4564-4536-b02a-06c3e87e0df9",
 CounterAssignments->{{"Section", 26}, {"Subsection", 0}, {"Subsubsection", 0}, {"Exercise", 0}},
 CellID->636714798],
Cell[1108, 32, 370, 7, 38, "Text",ExpressionUUID->"9db5dd6c-71da-4311-a427-32889a9c22b0",
 CellID->354596985],
Cell[1481, 41, 674, 18, 60, "Text",ExpressionUUID->"112a4cc4-023b-4151-8db1-0c70f10b41e0",
 CellID->444406470],
Cell[2158, 61, 944, 15, 113, "Text",ExpressionUUID->"051a8669-370c-442d-8c60-ea7b6251b78f",
 CellID->191417024],
Cell[3105, 78, 1606, 45, 65, "Text",ExpressionUUID->"33c2c4d2-40e5-4ce0-843f-8ecd099f266c",
 CellID->215419162],
Cell[4714, 125, 832, 13, 113, "Text",ExpressionUUID->"aaea5527-8f36-4a45-bb45-540c279662e2",
 CellID->2039910539],
Cell[5549, 140, 526, 9, 63, "Text",ExpressionUUID->"76b94b4c-6bab-4b30-8519-d18e00208de6",
 CellID->200004618]
}, Open  ]],
Cell[CellGroupData[{
Cell[6112, 154, 400, 5, 57, "Subsection",ExpressionUUID->"9d8a3ec6-5f26-44ba-a343-6dc439f36237",
 CellID->665707171],
Cell[6515, 161, 1217, 27, 65, "Text",ExpressionUUID->"2fe21045-852c-4402-9eec-72f8f12691d9",
 CellID->150622127],
Cell[7735, 190, 1047, 34, 49, "Text",ExpressionUUID->"9fe6ee81-3fb6-4d3b-bda0-fbdd192404b7",
 CellID->1770352323],
Cell[8785, 226, 456, 11, 39, "Text",ExpressionUUID->"4d2bf175-ded6-48c8-b71d-bd9607dd95af",
 CellID->925563476],
Cell[9244, 239, 786, 23, 46, "Text",ExpressionUUID->"bb27de69-d651-4814-8fb8-76003e05e9d3",
 CellID->1721285911],
Cell[10033, 264, 994, 19, 66, "Text",ExpressionUUID->"d72f747c-4bb5-4483-b796-0e41a959f033",
 CellID->900097440],
Cell[11030, 285, 748, 18, 41, "Text",ExpressionUUID->"f1b8a451-ca1a-4200-915f-530f44f58620",
 CellID->1062864612],
Cell[11781, 305, 675, 14, 70, "Text",ExpressionUUID->"dbf500fa-5828-47e7-acf8-8e42581ad2fd",
 CellID->796558138],
Cell[12459, 321, 1065, 32, 70, "Text",ExpressionUUID->"c1baafcd-0520-4b5b-90a3-7a12ef251e2b",
 CellID->339569968]
}, Open  ]],
Cell[CellGroupData[{
Cell[13561, 358, 743, 10, 70, "Subsection",ExpressionUUID->"d5a6b6c9-5245-4739-9187-26fbaa6c968c",
 CellID->1288402097],
Cell[14307, 370, 649, 10, 70, "Text",ExpressionUUID->"ff0b7dae-ce35-4546-88b8-cf46273c156a",
 CellID->1096431578],
Cell[14959, 382, 1133, 32, 70, "Text",ExpressionUUID->"91989cf1-7a92-4437-b8b2-156de64b8b10",
 CellID->168356539],
Cell[CellGroupData[{
Cell[16117, 418, 216, 3, 70, "Subsubsection",ExpressionUUID->"819c6144-7109-47ba-a137-485218759341",
 CellID->1332387874],
Cell[16336, 423, 462, 10, 70, "Text",ExpressionUUID->"371b2382-32ed-4486-84cb-d2373d506f4f",
 CellID->1631011049],
Cell[CellGroupData[{
Cell[16823, 437, 1067, 30, 70, "Input",ExpressionUUID->"88a83666-53a9-4379-953b-d362da10d262",
 CellID->1921430235],
Cell[17893, 469, 1906, 54, 70, "Output",ExpressionUUID->"3995ed7b-6e3d-4641-a059-8c538820eb4d",
 CellID->693098080]
}, Open  ]],
Cell[CellGroupData[{
Cell[19836, 528, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"c963c3a9-487e-43ea-86a6-94acb71dc8ff",
 CellID->1766359706],
Cell[20000, 532, 577, 11, 70, "Text",ExpressionUUID->"39ffef6d-975e-4327-8b34-9426d85a3e85",
 CellID->393642614],
Cell[20580, 545, 742, 20, 70, "Text",ExpressionUUID->"c2211b1d-d8e7-474f-a603-a0fb95e9a80f",
 CellID->1701780738],
Cell[21325, 567, 599, 11, 70, "Text",ExpressionUUID->"305c53c3-55d8-4748-bfcf-4de993ecf9c9",
 CellID->1641652820],
Cell[21927, 580, 987, 18, 70, "Text",ExpressionUUID->"5911d312-1657-4e63-af7d-df87a44aa245",
 CellID->389049084],
Cell[22917, 600, 1062, 29, 70, "Text",ExpressionUUID->"04c45060-6731-46e5-aa44-c1ff09b91d6d",
 CellID->1807733320],
Cell[23982, 631, 594, 8, 70, "Text",ExpressionUUID->"f5815ca9-af2e-4474-b2e4-a76f66838705",
 CellID->2122755131],
Cell[24579, 641, 1181, 28, 70, "Text",ExpressionUUID->"6b88a424-f12b-456a-861c-c22421d44f1a",
 CellID->999659106],
Cell[25763, 671, 567, 16, 70, "Text",ExpressionUUID->"5812422c-6aff-4ce8-a79d-6fc34aea11f5",
 CellID->1506024061],
Cell[CellGroupData[{
Cell[26355, 691, 618, 14, 70, "Input",ExpressionUUID->"06d12b41-286b-49ff-af8f-3ec5a4c8c4a2",
 CellID->1504129685],
Cell[26976, 707, 311, 6, 70, "Output",ExpressionUUID->"1d9ddd30-8cc1-4334-9098-dbc5ce82b8ef",
 CellID->762490]
}, Open  ]],
Cell[CellGroupData[{
Cell[27324, 718, 596, 15, 70, "Input",ExpressionUUID->"bf79587b-1b32-44b5-b8b1-5b65dcab1d2e",
 CellID->1877606958],
Cell[27923, 735, 268, 5, 70, "Output",ExpressionUUID->"4577a6d5-39cd-4767-8f6c-f2a24b4c9580",
 CellID->169268107]
}, Open  ]],
Cell[28206, 743, 218, 3, 70, "Text",ExpressionUUID->"3811ecfb-ab36-429d-947c-e8bfeeb312fb",
 CellID->1815434088],
Cell[28427, 748, 1797, 46, 70, "Text",ExpressionUUID->"9a524d1b-c1a8-43ea-a7e6-d6745ff7da9d",
 CellID->553060440],
Cell[30227, 796, 568, 12, 70, "Text",ExpressionUUID->"d75e1fdc-2194-4226-b08c-443ca869c274",
 CellID->977590864],
Cell[30798, 810, 789, 24, 70, "Text",ExpressionUUID->"0d60dbea-f913-4685-8c9f-58225eb14067",
 CellID->2119751698]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31648, 841, 423, 6, 70, "Subsection",ExpressionUUID->"1f211018-cdd3-4c47-badf-86a9f28d8f7d",
 CellID->2060568203],
Cell[32074, 849, 933, 22, 70, "Text",ExpressionUUID->"b74af5b6-03be-4c40-b0a1-073f3ff09e8d",
 CellID->1648496299],
Cell[33010, 873, 1894, 46, 70, "Text",ExpressionUUID->"1de2648e-852d-4736-adc3-89f0dc721a3d",
 CellID->1590767346],
Cell[34907, 921, 483, 11, 70, "Text",ExpressionUUID->"c741ca00-8824-4270-ab30-b7f50b23c55e",
 CellID->2002862719],
Cell[35393, 934, 1806, 53, 70, "Text",ExpressionUUID->"8e5eb310-d3d8-4c71-966b-426edd29a6dd",
 CellID->307551508],
Cell[37202, 989, 945, 18, 70, "Text",ExpressionUUID->"8a47d9a2-4206-4574-bdeb-a4f4656c470a",
 CellID->25056627],
Cell[38150, 1009, 788, 20, 70, "Text",ExpressionUUID->"5b0e61d8-e3f1-4705-8a09-0db505e3d342",
 CellID->219935177],
Cell[38941, 1031, 1013, 26, 70, "Text",ExpressionUUID->"ba2457ce-895c-4304-94dd-ab4a89027798",
 CellID->631163352],
Cell[39957, 1059, 1143, 29, 70, "Text",ExpressionUUID->"33a4a342-a553-40b3-89e9-bdbe5eda500e",
 CellID->1540724531],
Cell[41103, 1090, 215, 3, 70, "Text",ExpressionUUID->"5cb5986e-5fd7-4229-ab83-1c41a500f288",
 CellID->599376991],
Cell[41321, 1095, 1702, 42, 70, "Text",ExpressionUUID->"098bb777-2773-474d-92f4-b24bfc85f1b3",
 CellID->2030783307]
}, Open  ]],
Cell[CellGroupData[{
Cell[43060, 1142, 466, 6, 70, "Subsection",ExpressionUUID->"cf105f74-730f-4cbd-aa26-9898e9b7115c",
 CellID->1417438978],
Cell[43529, 1150, 675, 11, 70, "Text",ExpressionUUID->"58a23179-d1d6-4522-a470-36aeda9c5816",
 CellID->860807075],
Cell[44207, 1163, 1005, 29, 70, "Text",ExpressionUUID->"6ba124a7-d250-4af5-8402-9754bdfe0397",
 CellID->2134663333],
Cell[CellGroupData[{
Cell[45237, 1196, 219, 3, 70, "Subsubsection",ExpressionUUID->"11ec7a4c-bd5c-4e20-9cfd-9be2807cc7e8",
 CellID->1424830949],
Cell[45459, 1201, 505, 11, 70, "Text",ExpressionUUID->"e4354fea-9db0-4f4e-9ba1-7ee28d3b2f8d",
 CellID->543612146],
Cell[CellGroupData[{
Cell[45989, 1216, 991, 25, 70, "Input",ExpressionUUID->"c75fd8a1-0245-481d-b0bb-b615d5634fac",
 CellID->1093903484],
Cell[46983, 1243, 481, 13, 70, "Output",ExpressionUUID->"cfc661f9-0cd2-47ae-bf6d-5ff1ebb57378",
 CellID->49333281]
}, Open  ]],
Cell[47479, 1259, 210, 2, 70, "Text",ExpressionUUID->"96561a82-139c-4102-8ffc-c4ad494801fc",
 CellID->628353621],
Cell[CellGroupData[{
Cell[47714, 1265, 566, 16, 70, "Input",ExpressionUUID->"c0979578-2abd-4527-8bc8-62c74571a28e",
 CellID->1562215848],
Cell[48283, 1283, 346, 8, 70, "Output",ExpressionUUID->"c84e6f20-d301-410d-b7ae-493ff8164fb5",
 CellID->57978281]
}, Open  ]],
Cell[CellGroupData[{
Cell[48666, 1296, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"08221c8f-befa-471a-ad10-3cb43e730450",
 CellID->1026689114],
Cell[48830, 1300, 997, 20, 70, "Text",ExpressionUUID->"ae593c71-9b26-414a-9389-da44346432c8",
 CellID->532835353],
Cell[49830, 1322, 1796, 45, 70, "Text",ExpressionUUID->"7e79243b-0c1b-44a3-bfd1-161522632509",
 CellID->356969881],
Cell[51629, 1369, 1097, 23, 70, "Text",ExpressionUUID->"7dad32a3-b896-4883-81b6-0a52fcb4917a",
 CellID->1670963896],
Cell[52729, 1394, 1870, 52, 70, "Text",ExpressionUUID->"cb18ed1e-c634-407f-9249-fccc9d0139bb",
 CellID->1246548253],
Cell[54602, 1448, 608, 13, 70, "Text",ExpressionUUID->"42fa42f9-4cec-48c9-9af3-5c731fbad54a",
 CellID->2033511686],
Cell[CellGroupData[{
Cell[55235, 1465, 773, 18, 70, "Input",ExpressionUUID->"81fecd77-06a4-410f-8115-05cc38499936",
 CellID->28664597],
Cell[56011, 1485, 406, 7, 70, "Output",ExpressionUUID->"d2bf30f2-9eb3-4820-965e-8598bb64e3c1",
 CellID->752241404]
}, Open  ]],
Cell[56432, 1495, 671, 17, 70, "Text",ExpressionUUID->"3fe3585c-cd6a-46c6-98c8-3ae308690e91",
 CellID->729544851],
Cell[CellGroupData[{
Cell[57128, 1516, 891, 20, 70, "Input",ExpressionUUID->"8381db7f-9814-4653-b393-becd70d3ac68",
 CellID->1476170034],
Cell[58022, 1538, 260, 4, 70, "Output",ExpressionUUID->"d331a016-60ce-4430-9c96-4344c7327c08",
 CellID->609443523]
}, Open  ]],
Cell[CellGroupData[{
Cell[58319, 1547, 1069, 26, 70, "Input",ExpressionUUID->"f9d68682-a464-4498-807b-29c71c53d836",
 CellID->111187647],
Cell[59391, 1575, 309, 5, 70, "Output",ExpressionUUID->"f3cdff1f-afc1-4ee1-a868-cad361ef94e6",
 CellID->179365035]
}, Open  ]],
Cell[59715, 1583, 267, 4, 70, "Text",ExpressionUUID->"f98b4ff3-ffa0-4f66-8211-320dc6436915",
 CellID->420010239],
Cell[59985, 1589, 1098, 33, 70, "Text",ExpressionUUID->"37a099d2-6d0c-46a2-b9e9-043dffd6db27",
 CellID->333339184],
Cell[61086, 1624, 629, 10, 70, "Text",ExpressionUUID->"23444c38-cb1f-4a33-a6eb-9ceada16eae2",
 CellID->1794314112],
Cell[CellGroupData[{
Cell[61740, 1638, 325, 7, 70, "Input",ExpressionUUID->"e5ffa992-ad13-4e99-9fc3-5eb9e03eaa6c",
 CellID->2071909210],
Cell[62068, 1647, 339, 7, 70, "Output",ExpressionUUID->"c727b46b-1fe7-4079-b6e9-1dcb48d5f977",
 CellID->12047558]
}, Open  ]],
Cell[62422, 1657, 857, 23, 70, "Text",ExpressionUUID->"4d1beae1-819d-4b99-b18a-b0d688a0a45e",
 CellID->1130756365],
Cell[CellGroupData[{
Cell[63304, 1684, 506, 13, 70, "Input",ExpressionUUID->"a621ba43-f34d-4ea1-bef3-a2ed6137fa5e",
 CellID->1539434252],
Cell[63813, 1699, 427, 8, 70, "Output",ExpressionUUID->"76b5bf9a-3b61-4368-b91b-b9336892b0dd",
 CellID->310702850]
}, Open  ]],
Cell[64255, 1710, 1065, 29, 70, "Text",ExpressionUUID->"74fc9b1e-1f54-4828-b3bd-9118d05fd52c",
 CellID->388494308],
Cell[CellGroupData[{
Cell[65345, 1743, 1025, 20, 70, "Input",ExpressionUUID->"c3d37353-6519-482f-a063-cd43d55ba9e2",
 CellID->1073547676],
Cell[66373, 1765, 871, 18, 70, "Output",ExpressionUUID->"bed00ed1-5f3a-4eee-9130-3cf51f148cc8",
 CellID->88816281]
}, Open  ]],
Cell[67259, 1786, 223, 3, 70, "Text",ExpressionUUID->"5cbac0bd-9361-41fd-a945-7d66db415579",
 CellID->2105672085],
Cell[67485, 1791, 986, 25, 70, "Text",ExpressionUUID->"f543dce7-fd66-4d0a-acd5-2b5482b2f09a",
 CellID->1647713682],
Cell[68474, 1818, 207, 2, 70, "Text",ExpressionUUID->"9f848ec1-5559-4e17-a48e-38027d751bc0",
 CellID->1322225309],
Cell[CellGroupData[{
Cell[68706, 1824, 640, 18, 70, "Input",ExpressionUUID->"46db8739-402a-40ea-9eb2-5274d9a29f3c",
 CellID->479989207],
Cell[69349, 1844, 398, 9, 70, "Output",ExpressionUUID->"81e47b4e-3938-46ed-af13-ae66b8051bb1",
 CellID->23473236]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69820, 1861, 616, 8, 70, "Subsection",ExpressionUUID->"c2a0a24b-30e5-4990-99b2-565713c51f35",
 CellID->1230023917],
Cell[70439, 1871, 481, 6, 70, "Text",ExpressionUUID->"5e3f00f0-2543-4022-823d-c8be3ca3edd8",
 CellID->1334386997],
Cell[70923, 1879, 596, 17, 70, "Input",ExpressionUUID->"810a5412-75f6-4730-8a24-01544546869c",
 CellID->870532958],
Cell[71522, 1898, 299, 4, 70, "Text",ExpressionUUID->"39465e18-f79c-40ca-82ff-5243673858a7",
 CellID->241338095],
Cell[71824, 1904, 638, 13, 70, "Text",ExpressionUUID->"b4a9eeb3-4ad3-4ac9-96c1-da1ab6ed739f",
 CellID->1720237129],
Cell[72465, 1919, 808, 18, 70, "Text",ExpressionUUID->"c7060c02-561c-4efb-8e41-490f76ded275",
 CellID->453087542],
Cell[CellGroupData[{
Cell[73298, 1941, 215, 3, 70, "Subsubsection",ExpressionUUID->"1b5f2f64-3845-4e75-a2ba-0c29b189a3de",
 CellID->65306132],
Cell[73516, 1946, 338, 4, 70, "Text",ExpressionUUID->"0376b7bd-911d-4813-aefd-a5d27bb192a4",
 CellID->236016907],
Cell[CellGroupData[{
Cell[73879, 1954, 3152, 68, 70, "Input",ExpressionUUID->"df0bc4e8-d9ec-4056-acbe-d7d66edc20a7",
 CellID->333859940],
Cell[77034, 2024, 16140, 366, 70, "Output",ExpressionUUID->"81e5247c-6a86-44c7-8952-5a29e271c3f6",
 CellID->494451371]
}, Open  ]],
Cell[93189, 2393, 734, 12, 70, "Text",ExpressionUUID->"4526b4da-8db3-4110-958a-3d043f5f3fa6",
 CellID->1956725616],
Cell[CellGroupData[{
Cell[93948, 2409, 1936, 39, 70, "Input",ExpressionUUID->"10112f30-ea00-49f9-9756-14c478b47f49",
 CellID->122857954],
Cell[95887, 2450, 42766, 720, 70, "Output",ExpressionUUID->"fd214362-c5da-46a6-9f2a-ed9d9e308887",
 CellID->53632302]
}, Open  ]],
Cell[138668, 3173, 719, 13, 70, "Text",ExpressionUUID->"eaf32f88-81b3-4cf9-81ac-4ea83a740b36",
 CellID->1141848111],
Cell[CellGroupData[{
Cell[139412, 3190, 715, 13, 70, "Input",ExpressionUUID->"b78f795e-499e-47ed-b1e8-dfe215c1922d",
 CellID->1127331985],
Cell[140130, 3205, 2607, 70, 70, "Output",ExpressionUUID->"43d4d586-2a2a-4370-a92c-d47ab27a8dbc",
 CellID->542977811]
}, Open  ]],
Cell[142752, 3278, 316, 4, 70, "Text",ExpressionUUID->"7c04350f-9e3b-4aba-8dcb-d952b6d23222",
 CellID->1967938061],
Cell[CellGroupData[{
Cell[143093, 3286, 1978, 39, 70, "Input",ExpressionUUID->"7fd97636-bd67-41b8-9cad-110da5d49561",
 CellID->1739343780],
Cell[145074, 3327, 4480, 111, 70, "Output",ExpressionUUID->"a5242f64-3f13-4a86-9256-e84d218aa5eb",
 CellID->753861776]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[149615, 3445, 444, 6, 70, "Subsection",ExpressionUUID->"1be40f24-64da-4f13-a2e9-4b0498cb4d77",
 CellID->1603507496],
Cell[150062, 3453, 1381, 26, 70, "Text",ExpressionUUID->"fc2148e8-5a75-4396-9068-4e1d577a7ed3",
 CellID->1378199069],
Cell[151446, 3481, 407, 5, 70, "Text",ExpressionUUID->"0c8e062d-fbf2-4291-b9b0-37241bcb38c3",
 CellID->633136141],
Cell[151856, 3488, 793, 22, 70, "Input",ExpressionUUID->"eae5db34-f3b6-45e3-9d6c-4b2078ad6022",
 CellID->337650902],
Cell[152652, 3512, 867, 22, 70, "Text",ExpressionUUID->"0e5efc7f-8483-4fde-9d0a-9967cdba679e",
 CellID->1246914540],
Cell[153522, 3536, 33268, 621, 70, "Output",ExpressionUUID->"7c9cf3d2-aa7a-4856-b84e-11083c697c80",
 CellID->1747246354]
}, Open  ]],
Cell[CellGroupData[{
Cell[186827, 4162, 764, 10, 70, "Subsection",ExpressionUUID->"9707bf36-9f12-4c76-b1c4-c6385c70bdf4",
 CellID->1278082600],
Cell[187594, 4174, 799, 12, 70, "Text",ExpressionUUID->"a096f032-6ea6-40b1-bca1-8854d82b35ae",
 CellID->1602820906],
Cell[188396, 4188, 1431, 37, 70, "Text",ExpressionUUID->"45d3a362-fe3b-4fa6-b537-7492a99a0cc8",
 CellID->576099174],
Cell[CellGroupData[{
Cell[189852, 4229, 362, 5, 70, "Subsubsection",ExpressionUUID->"69a4fee3-f6d5-477b-b38f-f5b3acab130a",
 CellID->1642536742],
Cell[190217, 4236, 203, 2, 70, "Text",ExpressionUUID->"01baf677-b221-46f6-a33a-3020ab8ff538",
 CellID->212740609],
Cell[CellGroupData[{
Cell[190445, 4242, 944, 20, 70, "Input",ExpressionUUID->"f4630743-75fc-4782-a494-38e290d4a80b",
 CellID->2118626855],
Cell[191392, 4264, 2016, 55, 70, "Output",ExpressionUUID->"01e5092e-c842-4442-a11a-f6e476bd4192",
 CellID->344981843]
}, Open  ]],
Cell[193423, 4322, 244, 3, 70, "Text",ExpressionUUID->"8c670ee0-a54d-48f1-b32c-2fe1114760b3",
 CellID->335201078],
Cell[CellGroupData[{
Cell[193692, 4329, 1811, 37, 70, "Input",ExpressionUUID->"cf036e49-07ae-4a61-b706-5e603236fc0e",
 CellID->874911865],
Cell[195506, 4368, 5106, 116, 70, "Output",ExpressionUUID->"c596a80f-bc5e-437f-85ba-a3a447878549",
 CellID->131238335]
}, Open  ]],
Cell[200627, 4487, 471, 8, 70, "Text",ExpressionUUID->"4122ad64-40a0-4cc0-bcf4-2bd6655c34d9",
 CellID->823184046],
Cell[CellGroupData[{
Cell[201123, 4499, 161, 2, 70, "Subsubsubsubsection",ExpressionUUID->"eb382cd2-014b-4475-8e54-6e8b63cdfdec",
 CellID->1164607148],
Cell[201287, 4503, 665, 13, 70, "Text",ExpressionUUID->"d523a256-0598-4a44-8ef7-5ab412f4b5c1",
 CellID->1386377678],
Cell[201955, 4518, 1247, 33, 70, "Text",ExpressionUUID->"da20f5ca-b2fb-4d72-aec9-3433595b615b",
 CellID->652064196],
Cell[203205, 4553, 471, 12, 70, "Text",ExpressionUUID->"d7dbefd9-4306-4173-8ecd-5d6f3646ed67",
 CellID->633891531],
Cell[CellGroupData[{
Cell[203701, 4569, 525, 14, 70, "Input",ExpressionUUID->"b550414c-1809-4a0e-b575-01187e368cd3",
 CellID->148588750],
Cell[204229, 4585, 308, 6, 70, "Output",ExpressionUUID->"3a224037-c4e6-457b-b1c5-1dcab2f89286",
 CellID->247839065]
}, Open  ]],
Cell[CellGroupData[{
Cell[204574, 4596, 522, 14, 70, "Input",ExpressionUUID->"a79ba079-23b1-4bf6-8a4f-a2842c3b5bec",
 CellID->1955123436],
Cell[205099, 4612, 257, 4, 70, "Output",ExpressionUUID->"070be13c-4845-403d-a6c6-c868015a3a67",
 CellID->29780168]
}, Open  ]],
Cell[205371, 4619, 219, 3, 70, "Text",ExpressionUUID->"f3866127-cb6d-4236-8409-c066a77f192c",
 CellID->1112306105],
Cell[205593, 4624, 744, 23, 70, "Text",ExpressionUUID->"3325963e-8c28-4303-8434-777e70f50b3d",
 CellID->683559600],
Cell[206340, 4649, 606, 10, 70, "Text",ExpressionUUID->"47f7ea6c-ed60-4584-a46f-e18d16c0c258",
 CellID->1696169397],
Cell[CellGroupData[{
Cell[206971, 4663, 398, 10, 70, "Input",ExpressionUUID->"f2312893-4dd9-4d76-8d25-2f4a129dcb17",
 CellID->1821125101],
Cell[207372, 4675, 343, 9, 70, "Output",ExpressionUUID->"2e2eddf9-2a98-4c44-aad6-f178efe4686a",
 CellID->61088352]
}, Open  ]],
Cell[CellGroupData[{
Cell[207752, 4689, 426, 10, 70, "Input",ExpressionUUID->"9458d775-cbe7-44f2-a55f-029059cdefd5",
 CellID->1712635463],
Cell[208181, 4701, 406, 11, 70, "Output",ExpressionUUID->"7bc1e392-00b6-4b8b-949c-f5fc6db455af",
 CellID->133765948]
}, Open  ]],
Cell[208602, 4715, 596, 9, 70, "Text",ExpressionUUID->"f8c1824c-723c-4ebd-abef-ce6207a1ca46",
 CellID->1540905900],
Cell[209201, 4726, 852, 26, 70, "Text",ExpressionUUID->"5cf4c8dd-e28d-4249-b806-aa1047d08b7a",
 CellID->1500162127]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[210114, 4759, 712, 10, 70, "Subsection",ExpressionUUID->"08bb878c-8d2e-4722-b35c-e988c2e0cde8",
 CellID->1766852709],
Cell[210829, 4771, 805, 12, 70, "Text",ExpressionUUID->"ce429f73-0578-4109-943e-28e03288e2de",
 CellID->89609447],
Cell[211637, 4785, 1329, 36, 70, "Text",ExpressionUUID->"d10154a0-0da7-401c-8684-0f42c5cfa44e",
 CellID->679939182],
Cell[CellGroupData[{
Cell[212991, 4825, 361, 5, 70, "Subsubsection",ExpressionUUID->"90fed691-a2e0-49ce-bc6c-2c093efe5247",
 CellID->977346187],
Cell[213355, 4832, 683, 11, 70, "Text",ExpressionUUID->"4e3a5161-9f36-4abf-9f3e-628db0fd84d0",
 CellID->154949006],
Cell[CellGroupData[{
Cell[214063, 4847, 876, 18, 70, "Input",ExpressionUUID->"27bd9419-a17d-4275-9a13-a2c0499d0e0f",
 CellID->1477763678],
Cell[214942, 4867, 2039, 55, 70, "Output",ExpressionUUID->"a2aaff78-456e-46a9-8612-2c50d2c6b62c",
 CellID->302594512]
}, Open  ]],
Cell[216996, 4925, 245, 3, 70, "Text",ExpressionUUID->"4c51a92a-a3cd-4fe7-a808-83cf696fb68b",
 CellID->1125758591],
Cell[CellGroupData[{
Cell[217266, 4932, 1605, 34, 70, "Input",ExpressionUUID->"124984d0-1cae-43e6-bd6e-aae8503ee1b6",
 CellID->1293708867],
Cell[218874, 4968, 4453, 109, 70, "Output",ExpressionUUID->"185b7904-d5d4-48f2-acd2-ba3c2fa34048",
 CellID->165017189]
}, Open  ]],
Cell[223342, 5080, 517, 8, 70, "Text",ExpressionUUID->"bb2d9a82-8f14-496e-b112-5d65d1625a0e",
 CellID->93001794]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[223908, 5094, 762, 10, 70, "Subsection",ExpressionUUID->"0ef46fbf-10d0-40e6-a1a7-ba75f9494285",
 CellID->1860540389],
Cell[224673, 5106, 796, 12, 70, "Text",ExpressionUUID->"7bf98989-e588-4697-977f-dd6aa0cb098d",
 CellID->592933956],
Cell[225472, 5120, 1367, 37, 70, "Text",ExpressionUUID->"e3bb3a7d-3132-4486-a39d-5544fd84abd7",
 CellID->1116876412],
Cell[CellGroupData[{
Cell[226864, 5161, 361, 5, 70, "Subsubsection",ExpressionUUID->"623f2859-3d05-4d83-8fdf-d84cd1e1f69b",
 CellID->187298057],
Cell[227228, 5168, 204, 2, 70, "Text",ExpressionUUID->"078ef227-839b-4b75-b06e-2c12fd68c314",
 CellID->1854901144],
Cell[CellGroupData[{
Cell[227457, 5174, 923, 20, 70, "Input",ExpressionUUID->"dee11a45-0381-47da-8e90-211199698003",
 CellID->303423709],
Cell[228383, 5196, 1949, 56, 70, "Output",ExpressionUUID->"f81dc383-b148-4640-a998-fa5c883d1798",
 CellID->58453344]
}, Open  ]],
Cell[230347, 5255, 245, 3, 70, "Text",ExpressionUUID->"a0d2d068-012f-41a9-a567-afefa33c4032",
 CellID->1516099185],
Cell[CellGroupData[{
Cell[230617, 5262, 1708, 35, 70, "Input",ExpressionUUID->"a438d879-a7d2-4735-a09e-597efeee4c3a",
 CellID->1185530640],
Cell[232328, 5299, 4888, 117, 70, "Output",ExpressionUUID->"278ac8ed-0623-4038-a07b-e3f2a3f83028",
 CellID->279381984]
}, Open  ]],
Cell[237231, 5419, 355, 4, 70, "Text",ExpressionUUID->"69ee7358-8a2d-4db7-90aa-b1c0fadb50bf",
 CellID->860189614],
Cell[CellGroupData[{
Cell[237611, 5427, 108, 1, 70, "SummarySection",ExpressionUUID->"29503115-38d8-486d-9479-836531c6eb8f",
 CellID->346930894],
Cell[237722, 5430, 549, 9, 70, "SummaryNote",ExpressionUUID->"0afd0ee6-0d2c-42f3-a535-03c2e28558fa",
 CellID->449433853],
Cell[238274, 5441, 343, 6, 70, "SummaryNote",ExpressionUUID->"939ace3e-0ef5-4bc7-9bef-f795f15ac90f",
 CellID->934780872],
Cell[238620, 5449, 342, 4, 70, "SummaryNote",ExpressionUUID->"953980cf-4369-4d07-a399-3728f2b797e5",
 CellID->2019237899],
Cell[238965, 5455, 46234, 916, 70, "SummaryNote",ExpressionUUID->"f361a62d-1489-433b-9010-3a214081d62e",
 CellID->647294952]
}, Open  ]],
Cell[CellGroupData[{
Cell[285236, 6376, 112, 1, 70, "ExerciseSection",ExpressionUUID->"741ef626-fe2b-45f6-9614-aea7be183716",
 CellID->2081586209],
Cell[285351, 6379, 671, 20, 33, "Exercise",ExpressionUUID->"f4f0e299-401b-457d-9f04-39e48eea14d3",
 CellID->563321386],
Cell[CellGroupData[{
Cell[286047, 6403, 521, 11, 25, "Exercise",ExpressionUUID->"3b4412e5-c263-48d5-a2db-829234d28d6b",
 CellID->1634618526],
Cell[286571, 6416, 1111, 29, 42, "ExerciseNote",ExpressionUUID->"ecd19052-46da-4269-a546-d7abaf19997b",
 CellID->542761515]
}, Open  ]],
Cell[CellGroupData[{
Cell[287719, 6450, 500, 11, 29, "Exercise",ExpressionUUID->"629a460f-94a9-4ae9-aa8c-9390953f54ad",
 CellID->275270411],
Cell[288222, 6463, 1162, 30, 42, "ExerciseNote",ExpressionUUID->"987432da-e693-48e0-895d-1262dbdd15b1",
 CellID->255181964]
}, Open  ]],
Cell[CellGroupData[{
Cell[289421, 6498, 519, 11, 29, "Exercise",ExpressionUUID->"88cce10b-6fc5-426f-ae73-1d1948fa08f8",
 CellID->790022039],
Cell[289943, 6511, 844, 25, 43, "ExerciseNote",ExpressionUUID->"540523fc-b3c4-4633-a2aa-21ed7febe783",
 CellID->201272230]
}, Open  ]],
Cell[CellGroupData[{
Cell[290824, 6541, 517, 11, 29, "Exercise",ExpressionUUID->"1dbfb4a3-3d99-478a-aa48-fbd2816ec83f",
 CellID->9020072],
Cell[291344, 6554, 26563, 544, 103, "ExerciseNote",ExpressionUUID->"e5dad805-cfed-4989-a22e-4e0587188336",
 CellID->116395045],
Cell[317910, 7100, 320, 4, 29, "ExerciseNote",ExpressionUUID->"4ab38514-f2e6-4092-ad21-b76fedcd4669",
 CellID->265318150]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[318281, 7110, 309, 6, 135, "SmallText",ExpressionUUID->"8d9945a8-5296-4365-bbe6-73f169a9735e",
 CellGroupingRules->"SectionGrouping",
 CellID->940421076]
}
]
*)

(* NotebookSignature AQcM6tQEe4hRJjuRBe7Cteii *)
